Class: MicrosoftGraph::Admin::Edge::InternetExplorerMode::SiteLists::Item::Publish::PublishRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/admin/edge/internet_explorer_mode/site_lists/item/publish/publish_request_builder.rb

Overview

Provides operations to call the publish method.

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new PublishRequestBuilder and sets the default values.

Parameters:

  • path_parameters —

    Path parameters for the request

  • request_adapter —

    The request adapter to use to execute the requests.



29
30
31
# File 'lib/admin/edge/internet_explorer_mode/site_lists/item/publish/publish_request_builder.rb', line 29

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/admin/edge/internetExplorerMode/siteLists/{browserSiteList%2Did}/publish")
end

Instance Method Details

#post(body, request_configuration = nil) ⇒ Object

Publish the specified browserSiteList for devices to download.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of browser_site_list

Raises:

  • (StandardError)


38
39
40
41
42
43
44
45
46
47
# File 'lib/admin/edge/internet_explorer_mode/site_lists/item/publish/publish_request_builder.rb', line 38

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::BrowserSiteList.create_from_discriminator_value(pn) }, error_mapping)
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Publish the specified browserSiteList for devices to download.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/admin/edge/internet_explorer_mode/site_lists/item/publish/publish_request_builder.rb', line 54

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end