Class: MicrosoftGraph::Admin::ServiceAnnouncement::Messages::Item::ServiceUpdateMessageItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Admin::ServiceAnnouncement::Messages::Item::ServiceUpdateMessageItemRequestBuilder
- Defined in:
- lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb
Overview
Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity.
Defined Under Namespace
Classes: ServiceUpdateMessageItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#attachments ⇒ Object
Provides operations to manage the attachments property of the microsoft.graph.serviceUpdateMessage entity.
-
#attachments_archive ⇒ Object
Provides operations to manage the media for the admin entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property messages for admin.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a serviceUpdateMessage object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ServiceUpdateMessageItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property messages in admin.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property messages for admin.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a serviceUpdateMessage object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property messages in admin.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ServiceUpdateMessageItemRequestBuilder and sets the default values.
37 38 39 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 37 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/admin/serviceAnnouncement/messages/{serviceUpdateMessage%2Did}{?%24select,%24expand}") end |
Instance Method Details
#attachments ⇒ Object
Provides operations to manage the attachments property of the microsoft.graph.serviceUpdateMessage entity.
23 24 25 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 23 def () return MicrosoftGraph::Admin::ServiceAnnouncement::Messages::Item::Attachments::AttachmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#attachments_archive ⇒ Object
Provides operations to manage the media for the admin entity.
28 29 30 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 28 def () return MicrosoftGraph::Admin::ServiceAnnouncement::Messages::Item::AttachmentsArchive::AttachmentsArchiveRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property messages for admin
45 46 47 48 49 50 51 52 53 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 45 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a serviceUpdateMessage object. This operation retrieves a specified service update message for the tenant. The operation returns an error if the message does not exist for the tenant.
59 60 61 62 63 64 65 66 67 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 59 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ServiceUpdateMessage.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property messages in admin
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 74 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ServiceUpdateMessage.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property messages for admin
89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 89 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a serviceUpdateMessage object. This operation retrieves a specified service update message for the tenant. The operation returns an error if the message does not exist for the tenant.
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 105 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property messages in admin
124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/admin/service_announcement/messages/item/service_update_message_item_request_builder.rb', line 124 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |