Class: MicrosoftGraph::Agreements::Item::File::FileRequestBuilder::FileRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/agreements/item/file/file_request_builder.rb

Overview

Retrieve the details of an agreement file, including the language and version information. The default file can have multiple versions, each with its own language, that can be retrieved by specifying the Accept-Language header.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



137
138
139
# File 'lib/agreements/item/file/file_request_builder.rb', line 137

def expand
  @expand
end

#selectObject

Select properties to be returned



140
141
142
# File 'lib/agreements/item/file/file_request_builder.rb', line 140

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


146
147
148
149
150
151
152
153
154
155
156
# File 'lib/agreements/item/file/file_request_builder.rb', line 146

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end