Class: MicrosoftGraph::Applications::Item::Owners::Item::DirectoryObjectItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Applications::Item::Owners::Item::DirectoryObjectItemRequestBuilder
- Defined in:
- lib/applications/item/owners/item/directory_object_item_request_builder.rb
Overview
Builds and executes requests for operations under applicationsapplication-idownersdirectoryObject-id
Instance Method Summary collapse
-
#graph_app_role_assignment ⇒ Object
Casts the previous resource to appRoleAssignment.
-
#graph_endpoint ⇒ Object
Casts the previous resource to endpoint.
-
#graph_service_principal ⇒ Object
Casts the previous resource to servicePrincipal.
-
#graph_user ⇒ Object
Casts the previous resource to user.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DirectoryObjectItemRequestBuilder and sets the default values.
-
#ref ⇒ Object
Provides operations to manage the collection of application entities.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DirectoryObjectItemRequestBuilder and sets the default values.
53 54 55 |
# File 'lib/applications/item/owners/item/directory_object_item_request_builder.rb', line 53 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/applications/{application%2Did}/owners/{directoryObject%2Did}") end |
Instance Method Details
#graph_app_role_assignment ⇒ Object
Casts the previous resource to appRoleAssignment.
24 25 26 |
# File 'lib/applications/item/owners/item/directory_object_item_request_builder.rb', line 24 def graph_app_role_assignment() return MicrosoftGraph::Applications::Item::Owners::Item::GraphAppRoleAssignment::GraphAppRoleAssignmentRequestBuilder.new(@path_parameters, @request_adapter) end |
#graph_endpoint ⇒ Object
Casts the previous resource to endpoint.
29 30 31 |
# File 'lib/applications/item/owners/item/directory_object_item_request_builder.rb', line 29 def graph_endpoint() return MicrosoftGraph::Applications::Item::Owners::Item::GraphEndpoint::GraphEndpointRequestBuilder.new(@path_parameters, @request_adapter) end |
#graph_service_principal ⇒ Object
Casts the previous resource to servicePrincipal.
34 35 36 |
# File 'lib/applications/item/owners/item/directory_object_item_request_builder.rb', line 34 def graph_service_principal() return MicrosoftGraph::Applications::Item::Owners::Item::GraphServicePrincipal::GraphServicePrincipalRequestBuilder.new(@path_parameters, @request_adapter) end |
#graph_user ⇒ Object
Casts the previous resource to user.
39 40 41 |
# File 'lib/applications/item/owners/item/directory_object_item_request_builder.rb', line 39 def graph_user() return MicrosoftGraph::Applications::Item::Owners::Item::GraphUser::GraphUserRequestBuilder.new(@path_parameters, @request_adapter) end |
#ref ⇒ Object
Provides operations to manage the collection of application entities.
44 45 46 |
# File 'lib/applications/item/owners/item/directory_object_item_request_builder.rb', line 44 def ref() return MicrosoftGraph::Applications::Item::Owners::Item::Ref::RefRequestBuilder.new(@path_parameters, @request_adapter) end |