Class: MicrosoftGraph::Chats::ChatsRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/chats/chats_request_builder.rb

Overview

Provides operations to manage the collection of chat entities.

Defined Under Namespace

Classes: ChatsRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ChatsRequestBuilder and sets the default values.



44
45
46
# File 'lib/chats/chats_request_builder.rb', line 44

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/chats{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_chat_id(chat_id) ⇒ Object

Provides operations to manage the collection of chat entities.

Raises:

  • (StandardError)


32
33
34
35
36
37
# File 'lib/chats/chats_request_builder.rb', line 32

def by_chat_id(chat_id)
    raise StandardError, 'chat_id cannot be null' if chat_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["chat%2Did"] = chat_id
    return MicrosoftGraph::Chats::Item::ChatItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



19
20
21
# File 'lib/chats/chats_request_builder.rb', line 19

def count()
    return MicrosoftGraph::Chats::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.



52
53
54
55
56
57
58
59
60
# File 'lib/chats/chats_request_builder.rb', line 52

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ChatCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#get_all_messagesObject

Provides operations to call the getAllMessages method.



24
25
26
# File 'lib/chats/chats_request_builder.rb', line 24

def get_all_messages()
    return MicrosoftGraph::Chats::GetAllMessages::GetAllMessagesRequestBuilder.new(@path_parameters, @request_adapter)
end

#post(body, request_configuration = nil) ⇒ Object

Create a new chat object.

Raises:

  • (StandardError)


67
68
69
70
71
72
73
74
75
76
# File 'lib/chats/chats_request_builder.rb', line 67

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Chat.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.



82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/chats/chats_request_builder.rb', line 82

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create a new chat object.

Raises:

  • (StandardError)


101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/chats/chats_request_builder.rb', line 101

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end