Class: MicrosoftGraph::Communications::Calls::CallsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Communications::Calls::CallsRequestBuilder
- Defined in:
- lib/communications/calls/calls_request_builder.rb
Overview
Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.
Defined Under Namespace
Classes: CallsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_call_id(call_id) ⇒ Object
Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a call object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new CallsRequestBuilder and sets the default values.
-
#log_teleconference_device_quality ⇒ Object
Provides operations to call the logTeleconferenceDeviceQuality method.
-
#post(body, request_configuration = nil) ⇒ Object
Create call enables your bot to create a new outgoing peer-to-peer or group call, or join an existing meeting.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a call object.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create call enables your bot to create a new outgoing peer-to-peer or group call, or join an existing meeting.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new CallsRequestBuilder and sets the default values.
46 47 48 |
# File 'lib/communications/calls/calls_request_builder.rb', line 46 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/communications/calls{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_call_id(call_id) ⇒ Object
Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.
34 35 36 37 38 39 |
# File 'lib/communications/calls/calls_request_builder.rb', line 34 def by_call_id(call_id) raise StandardError, 'call_id cannot be null' if call_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["call%2Did"] = call_id return MicrosoftGraph::Communications::Calls::Item::CallItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
21 22 23 |
# File 'lib/communications/calls/calls_request_builder.rb', line 21 def count() return MicrosoftGraph::Communications::Calls::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a call object.
54 55 56 57 58 59 60 61 62 |
# File 'lib/communications/calls/calls_request_builder.rb', line 54 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::CallCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#log_teleconference_device_quality ⇒ Object
Provides operations to call the logTeleconferenceDeviceQuality method.
26 27 28 |
# File 'lib/communications/calls/calls_request_builder.rb', line 26 def log_teleconference_device_quality() return MicrosoftGraph::Communications::Calls::LogTeleconferenceDeviceQuality::LogTeleconferenceDeviceQualityRequestBuilder.new(@path_parameters, @request_adapter) end |
#post(body, request_configuration = nil) ⇒ Object
Create call enables your bot to create a new outgoing peer-to-peer or group call, or join an existing meeting. You will need to register the calling bot and go through the list of permissions needed as mentioned below.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/communications/calls/calls_request_builder.rb', line 69 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Call.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a call object.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/communications/calls/calls_request_builder.rb', line 84 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create call enables your bot to create a new outgoing peer-to-peer or group call, or join an existing meeting. You will need to register the calling bot and go through the list of permissions needed as mentioned below.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/communications/calls/calls_request_builder.rb', line 103 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |