Class: MicrosoftGraph::Communications::Calls::Item::Answer::AnswerPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Communications::Calls::Item::Answer::AnswerPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/communications/calls/item/answer/answer_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#accepted_modalities ⇒ Object
Gets the acceptedModalities property value.
-
#accepted_modalities=(value) ⇒ Object
Sets the acceptedModalities property value.
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#call_options ⇒ Object
Gets the callOptions property value.
-
#call_options=(value) ⇒ Object
Sets the callOptions property value.
-
#callback_uri ⇒ Object
Gets the callbackUri property value.
-
#callback_uri=(value) ⇒ Object
Sets the callbackUri property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new answerPostRequestBody and sets the default values.
-
#media_config ⇒ Object
Gets the mediaConfig property value.
-
#media_config=(value) ⇒ Object
Sets the mediaConfig property value.
-
#participant_capacity ⇒ Object
Gets the participantCapacity property value.
-
#participant_capacity=(value) ⇒ Object
Sets the participantCapacity property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new answerPostRequestBody and sets the default values.
100 101 102 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 100 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
108 109 110 111 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 108 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AnswerPostRequestBody.new end |
Instance Method Details
#accepted_modalities ⇒ Object
Gets the acceptedModalities property value. The acceptedModalities property
40 41 42 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 40 def accepted_modalities return @accepted_modalities end |
#accepted_modalities=(value) ⇒ Object
Sets the acceptedModalities property value. The acceptedModalities property
48 49 50 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 48 def accepted_modalities=(value) @accepted_modalities = value end |
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
55 56 57 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 55 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
63 64 65 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 63 def additional_data=(value) @additional_data = value end |
#call_options ⇒ Object
Gets the callOptions property value. The callOptions property
70 71 72 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 70 def return end |
#call_options=(value) ⇒ Object
Sets the callOptions property value. The callOptions property
78 79 80 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 78 def (value) = value end |
#callback_uri ⇒ Object
Gets the callbackUri property value. The callbackUri property
85 86 87 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 85 def callback_uri return @callback_uri end |
#callback_uri=(value) ⇒ Object
Sets the callbackUri property value. The callbackUri property
93 94 95 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 93 def callback_uri=(value) @callback_uri = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
116 117 118 119 120 121 122 123 124 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 116 def get_field_deserializers() return { "acceptedModalities" => lambda {|n| @accepted_modalities = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Modality.create_from_discriminator_value(pn) }) }, "callOptions" => lambda {|n| = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IncomingCallOptions.create_from_discriminator_value(pn) }) }, "callbackUri" => lambda {|n| @callback_uri = n.get_string_value() }, "mediaConfig" => lambda {|n| @media_config = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::MediaConfig.create_from_discriminator_value(pn) }) }, "participantCapacity" => lambda {|n| @participant_capacity = n.get_number_value() }, } end |
#media_config ⇒ Object
Gets the mediaConfig property value. The mediaConfig property
129 130 131 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 129 def media_config return @media_config end |
#media_config=(value) ⇒ Object
Sets the mediaConfig property value. The mediaConfig property
137 138 139 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 137 def media_config=(value) @media_config = value end |
#participant_capacity ⇒ Object
Gets the participantCapacity property value. The participantCapacity property
144 145 146 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 144 def participant_capacity return @participant_capacity end |
#participant_capacity=(value) ⇒ Object
Sets the participantCapacity property value. The participantCapacity property
152 153 154 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 152 def participant_capacity=(value) @participant_capacity = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
160 161 162 163 164 165 166 167 168 |
# File 'lib/communications/calls/item/answer/answer_post_request_body.rb', line 160 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("acceptedModalities", @accepted_modalities) writer.write_object_value("callOptions", ) writer.write_string_value("callbackUri", @callback_uri) writer.write_object_value("mediaConfig", @media_config) writer.write_number_value("participantCapacity", @participant_capacity) writer.write_additional_data(@additional_data) end |