Class: MicrosoftGraph::Communications::Calls::Item::Participants::Invite::InvitePostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Communications::Calls::Item::Participants::Invite::InvitePostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/communications/calls/item/participants/invite/invite_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#client_context ⇒ Object
Gets the clientContext property value.
-
#client_context=(value) ⇒ Object
Sets the clientContext property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new invitePostRequestBody and sets the default values.
-
#participants ⇒ Object
Gets the participants property value.
-
#participants=(value) ⇒ Object
Sets the participants property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new invitePostRequestBody and sets the default values.
61 62 63 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 61 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
69 70 71 72 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 69 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return InvitePostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 39 def additional_data=(value) @additional_data = value end |
#client_context ⇒ Object
Gets the clientContext property value. The clientContext property
46 47 48 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 46 def client_context return @client_context end |
#client_context=(value) ⇒ Object
Sets the clientContext property value. The clientContext property
54 55 56 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 54 def client_context=(value) @client_context = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
77 78 79 80 81 82 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 77 def get_field_deserializers() return { "clientContext" => lambda {|n| @client_context = n.get_string_value() }, "participants" => lambda {|n| @participants = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::InvitationParticipantInfo.create_from_discriminator_value(pn) }) }, } end |
#participants ⇒ Object
Gets the participants property value. The participants property
87 88 89 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 87 def participants return @participants end |
#participants=(value) ⇒ Object
Sets the participants property value. The participants property
95 96 97 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 95 def participants=(value) @participants = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
103 104 105 106 107 108 |
# File 'lib/communications/calls/item/participants/invite/invite_post_request_body.rb', line 103 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("clientContext", @client_context) writer.write_collection_of_object_values("participants", @participants) writer.write_additional_data(@additional_data) end |