Class: MicrosoftGraph::Communications::Calls::Item::RecordResponse::RecordResponsePostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/communications/calls/item/record_response/record_response_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new recordResponsePostRequestBody and sets the default values.



92
93
94
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 92

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a record_response_post_request_body

Raises:

  • (StandardError)


100
101
102
103
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 100

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return RecordResponsePostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



47
48
49
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 47

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



55
56
57
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 55

def additional_data=(value)
    @additional_data = value
end

#barge_in_allowedObject

Gets the bargeInAllowed property value. The bargeInAllowed property

Returns:

  • a boolean



62
63
64
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 62

def barge_in_allowed
    return @barge_in_allowed
end

#barge_in_allowed=(value) ⇒ Object

Sets the bargeInAllowed property value. The bargeInAllowed property

Parameters:

  • value

    Value to set for the bargeInAllowed property.

Returns:

  • a void



70
71
72
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 70

def barge_in_allowed=(value)
    @barge_in_allowed = value
end

#client_contextObject

Gets the clientContext property value. The clientContext property

Returns:

  • a string



77
78
79
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 77

def client_context
    return @client_context
end

#client_context=(value) ⇒ Object

Sets the clientContext property value. The clientContext property

Parameters:

  • value

    Value to set for the clientContext property.

Returns:

  • a void



85
86
87
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 85

def client_context=(value)
    @client_context = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 108

def get_field_deserializers()
    return {
        "bargeInAllowed" => lambda {|n| @barge_in_allowed = n.get_boolean_value() },
        "clientContext" => lambda {|n| @client_context = n.get_string_value() },
        "initialSilenceTimeoutInSeconds" => lambda {|n| @initial_silence_timeout_in_seconds = n.get_number_value() },
        "maxRecordDurationInSeconds" => lambda {|n| @max_record_duration_in_seconds = n.get_number_value() },
        "maxSilenceTimeoutInSeconds" => lambda {|n| @max_silence_timeout_in_seconds = n.get_number_value() },
        "playBeep" => lambda {|n| @play_beep = n.get_boolean_value() },
        "prompts" => lambda {|n| @prompts = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Prompt.create_from_discriminator_value(pn) }) },
        "stopTones" => lambda {|n| @stop_tones = n.get_collection_of_primitive_values(String) },
    }
end

#initial_silence_timeout_in_secondsObject

Gets the initialSilenceTimeoutInSeconds property value. The initialSilenceTimeoutInSeconds property

Returns:

  • a integer



124
125
126
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 124

def initial_silence_timeout_in_seconds
    return @initial_silence_timeout_in_seconds
end

#initial_silence_timeout_in_seconds=(value) ⇒ Object

Sets the initialSilenceTimeoutInSeconds property value. The initialSilenceTimeoutInSeconds property

Parameters:

  • value

    Value to set for the initialSilenceTimeoutInSeconds property.

Returns:

  • a void



132
133
134
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 132

def initial_silence_timeout_in_seconds=(value)
    @initial_silence_timeout_in_seconds = value
end

#max_record_duration_in_secondsObject

Gets the maxRecordDurationInSeconds property value. The maxRecordDurationInSeconds property

Returns:

  • a integer



139
140
141
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 139

def max_record_duration_in_seconds
    return @max_record_duration_in_seconds
end

#max_record_duration_in_seconds=(value) ⇒ Object

Sets the maxRecordDurationInSeconds property value. The maxRecordDurationInSeconds property

Parameters:

  • value

    Value to set for the maxRecordDurationInSeconds property.

Returns:

  • a void



147
148
149
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 147

def max_record_duration_in_seconds=(value)
    @max_record_duration_in_seconds = value
end

#max_silence_timeout_in_secondsObject

Gets the maxSilenceTimeoutInSeconds property value. The maxSilenceTimeoutInSeconds property

Returns:

  • a integer



154
155
156
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 154

def max_silence_timeout_in_seconds
    return @max_silence_timeout_in_seconds
end

#max_silence_timeout_in_seconds=(value) ⇒ Object

Sets the maxSilenceTimeoutInSeconds property value. The maxSilenceTimeoutInSeconds property

Parameters:

  • value

    Value to set for the maxSilenceTimeoutInSeconds property.

Returns:

  • a void



162
163
164
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 162

def max_silence_timeout_in_seconds=(value)
    @max_silence_timeout_in_seconds = value
end

#play_beepObject

Gets the playBeep property value. The playBeep property

Returns:

  • a boolean



169
170
171
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 169

def play_beep
    return @play_beep
end

#play_beep=(value) ⇒ Object

Sets the playBeep property value. The playBeep property

Parameters:

  • value

    Value to set for the playBeep property.

Returns:

  • a void



177
178
179
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 177

def play_beep=(value)
    @play_beep = value
end

#promptsObject

Gets the prompts property value. The prompts property

Returns:

  • a prompt



184
185
186
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 184

def prompts
    return @prompts
end

#prompts=(value) ⇒ Object

Sets the prompts property value. The prompts property

Parameters:

  • value

    Value to set for the prompts property.

Returns:

  • a void



192
193
194
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 192

def prompts=(value)
    @prompts = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 200

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_boolean_value("bargeInAllowed", @barge_in_allowed)
    writer.write_string_value("clientContext", @client_context)
    writer.write_number_value("initialSilenceTimeoutInSeconds", @initial_silence_timeout_in_seconds)
    writer.write_number_value("maxRecordDurationInSeconds", @max_record_duration_in_seconds)
    writer.write_number_value("maxSilenceTimeoutInSeconds", @max_silence_timeout_in_seconds)
    writer.write_boolean_value("playBeep", @play_beep)
    writer.write_collection_of_object_values("prompts", @prompts)
    writer.write_collection_of_primitive_values("stopTones", @stop_tones)
    writer.write_additional_data(@additional_data)
end

#stop_tonesObject

Gets the stopTones property value. The stopTones property

Returns:

  • a string



216
217
218
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 216

def stop_tones
    return @stop_tones
end

#stop_tones=(value) ⇒ Object

Sets the stopTones property value. The stopTones property

Parameters:

  • value

    Value to set for the stopTones property.

Returns:

  • a void



224
225
226
# File 'lib/communications/calls/item/record_response/record_response_post_request_body.rb', line 224

def stop_tones=(value)
    @stop_tones = value
end