Class: MicrosoftGraph::Communications::Calls::Item::Reject::RejectPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Communications::Calls::Item::Reject::RejectPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/communications/calls/item/reject/reject_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#callback_uri ⇒ Object
Gets the callbackUri property value.
-
#callback_uri=(value) ⇒ Object
Sets the callbackUri property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new rejectPostRequestBody and sets the default values.
-
#reason ⇒ Object
Gets the reason property value.
-
#reason=(value) ⇒ Object
Sets the reason property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new rejectPostRequestBody and sets the default values.
59 60 61 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 59 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
67 68 69 70 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 67 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return RejectPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
29 30 31 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 29 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
37 38 39 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 37 def additional_data=(value) @additional_data = value end |
#callback_uri ⇒ Object
Gets the callbackUri property value. The callbackUri property
44 45 46 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 44 def callback_uri return @callback_uri end |
#callback_uri=(value) ⇒ Object
Sets the callbackUri property value. The callbackUri property
52 53 54 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 52 def callback_uri=(value) @callback_uri = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
75 76 77 78 79 80 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 75 def get_field_deserializers() return { "callbackUri" => lambda {|n| @callback_uri = n.get_string_value() }, "reason" => lambda {|n| @reason = n.get_enum_value(MicrosoftGraph::Models::RejectReason) }, } end |
#reason ⇒ Object
Gets the reason property value. The reason property
85 86 87 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 85 def reason return @reason end |
#reason=(value) ⇒ Object
Sets the reason property value. The reason property
93 94 95 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 93 def reason=(value) @reason = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
101 102 103 104 105 106 |
# File 'lib/communications/calls/item/reject/reject_post_request_body.rb', line 101 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("callbackUri", @callback_uri) writer.write_enum_value("reason", @reason) writer.write_additional_data(@additional_data) end |