Class: MicrosoftGraph::DeviceAppManagement::MobileApps::MobileAppsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::DeviceAppManagement::MobileApps::MobileAppsRequestBuilder
- Defined in:
- lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb
Overview
Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity.
Defined Under Namespace
Classes: MobileAppsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_mobile_app_id(mobile_app_id) ⇒ Object
Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
List properties and relationships of the androidLobApp objects.
-
#graph_managed_mobile_lob_app ⇒ Object
Casts the previous resource to managedMobileLobApp.
-
#graph_mobile_lob_app ⇒ Object
Casts the previous resource to mobileLobApp.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MobileAppsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a new microsoftStoreForBusinessApp object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
List properties and relationships of the androidLobApp objects.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new microsoftStoreForBusinessApp object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MobileAppsRequestBuilder and sets the default values.
52 53 54 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 52 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/deviceAppManagement/mobileApps{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_mobile_app_id(mobile_app_id) ⇒ Object
Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity.
40 41 42 43 44 45 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 40 def by_mobile_app_id(mobile_app_id) raise StandardError, 'mobile_app_id cannot be null' if mobile_app_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["mobileApp%2Did"] = mobile_app_id return MicrosoftGraph::DeviceAppManagement::MobileApps::Item::MobileAppItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
22 23 24 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 22 def count() return MicrosoftGraph::DeviceAppManagement::MobileApps::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
List properties and relationships of the androidLobApp objects.
60 61 62 63 64 65 66 67 68 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 60 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::MobileAppCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#graph_managed_mobile_lob_app ⇒ Object
Casts the previous resource to managedMobileLobApp.
27 28 29 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 27 def graph_managed_mobile_lob_app() return MicrosoftGraph::DeviceAppManagement::MobileApps::GraphManagedMobileLobApp::GraphManagedMobileLobAppRequestBuilder.new(@path_parameters, @request_adapter) end |
#graph_mobile_lob_app ⇒ Object
Casts the previous resource to mobileLobApp.
32 33 34 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 32 def graph_mobile_lob_app() return MicrosoftGraph::DeviceAppManagement::MobileApps::GraphMobileLobApp::GraphMobileLobAppRequestBuilder.new(@path_parameters, @request_adapter) end |
#post(body, request_configuration = nil) ⇒ Object
Create a new microsoftStoreForBusinessApp object.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 75 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::MobileApp.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
List properties and relationships of the androidLobApp objects.
90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 90 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new microsoftStoreForBusinessApp object.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/device_app_management/mobile_apps/mobile_apps_request_builder.rb', line 109 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |