Class: MicrosoftGraph::DeviceAppManagement::SyncMicrosoftStoreForBusinessApps::SyncMicrosoftStoreForBusinessAppsRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/device_app_management/sync_microsoft_store_for_business_apps/sync_microsoft_store_for_business_apps_request_builder.rb

Overview

Provides operations to call the syncMicrosoftStoreForBusinessApps method.

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new SyncMicrosoftStoreForBusinessAppsRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



20
21
22
# File 'lib/device_app_management/sync_microsoft_store_for_business_apps/sync_microsoft_store_for_business_apps_request_builder.rb', line 20

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/deviceAppManagement/syncMicrosoftStoreForBusinessApps")
end

Instance Method Details

#post(request_configuration = nil) ⇒ Object

Syncs Intune account with Microsoft Store For Business

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



28
29
30
31
32
33
34
35
36
# File 'lib/device_app_management/sync_microsoft_store_for_business_apps/sync_microsoft_store_for_business_apps_request_builder.rb', line 28

def post(request_configuration=nil)
    request_info = self.to_post_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#to_post_request_information(request_configuration = nil) ⇒ Object

Syncs Intune account with Microsoft Store For Business

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



42
43
44
45
46
47
48
49
50
51
52
# File 'lib/device_app_management/sync_microsoft_store_for_business_apps/sync_microsoft_store_for_business_apps_request_builder.rb', line 42

def to_post_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end