Class: MicrosoftGraph::DeviceManagement::DeviceManagementRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/device_management/device_management_request_builder.rb

Overview

Provides operations to manage the deviceManagement singleton.

Defined Under Namespace

Classes: DeviceManagementRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new DeviceManagementRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



363
364
365
# File 'lib/device_management/device_management_request_builder.rb', line 363

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/deviceManagement{?%24select,%24expand}")
end

Instance Method Details

#apple_push_notification_certificateObject

Provides operations to manage the applePushNotificationCertificate property of the microsoft.graph.deviceManagement entity.



74
75
76
# File 'lib/device_management/device_management_request_builder.rb', line 74

def apple_push_notification_certificate()
    return MicrosoftGraph::DeviceManagement::ApplePushNotificationCertificate::ApplePushNotificationCertificateRequestBuilder.new(@path_parameters, @request_adapter)
end

#audit_eventsObject

Provides operations to manage the auditEvents property of the microsoft.graph.deviceManagement entity.



79
80
81
# File 'lib/device_management/device_management_request_builder.rb', line 79

def audit_events()
    return MicrosoftGraph::DeviceManagement::AuditEvents::AuditEventsRequestBuilder.new(@path_parameters, @request_adapter)
end

#compliance_management_partnersObject

Provides operations to manage the complianceManagementPartners property of the microsoft.graph.deviceManagement entity.



84
85
86
# File 'lib/device_management/device_management_request_builder.rb', line 84

def compliance_management_partners()
    return MicrosoftGraph::DeviceManagement::ComplianceManagementPartners::ComplianceManagementPartnersRequestBuilder.new(@path_parameters, @request_adapter)
end

#conditional_access_settingsObject

Provides operations to manage the conditionalAccessSettings property of the microsoft.graph.deviceManagement entity.



89
90
91
# File 'lib/device_management/device_management_request_builder.rb', line 89

def conditional_access_settings()
    return MicrosoftGraph::DeviceManagement::ConditionalAccessSettings::ConditionalAccessSettingsRequestBuilder.new(@path_parameters, @request_adapter)
end

#detected_appsObject

Provides operations to manage the detectedApps property of the microsoft.graph.deviceManagement entity.



94
95
96
# File 'lib/device_management/device_management_request_builder.rb', line 94

def detected_apps()
    return MicrosoftGraph::DeviceManagement::DetectedApps::DetectedAppsRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_categoriesObject

Provides operations to manage the deviceCategories property of the microsoft.graph.deviceManagement entity.



99
100
101
# File 'lib/device_management/device_management_request_builder.rb', line 99

def device_categories()
    return MicrosoftGraph::DeviceManagement::DeviceCategories::DeviceCategoriesRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_compliance_policiesObject

Provides operations to manage the deviceCompliancePolicies property of the microsoft.graph.deviceManagement entity.



104
105
106
# File 'lib/device_management/device_management_request_builder.rb', line 104

def device_compliance_policies()
    return MicrosoftGraph::DeviceManagement::DeviceCompliancePolicies::DeviceCompliancePoliciesRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_compliance_policy_device_state_summaryObject

Provides operations to manage the deviceCompliancePolicyDeviceStateSummary property of the microsoft.graph.deviceManagement entity.



109
110
111
# File 'lib/device_management/device_management_request_builder.rb', line 109

def device_compliance_policy_device_state_summary()
    return MicrosoftGraph::DeviceManagement::DeviceCompliancePolicyDeviceStateSummary::DeviceCompliancePolicyDeviceStateSummaryRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_compliance_policy_setting_state_summariesObject

Provides operations to manage the deviceCompliancePolicySettingStateSummaries property of the microsoft.graph.deviceManagement entity.



114
115
116
# File 'lib/device_management/device_management_request_builder.rb', line 114

def device_compliance_policy_setting_state_summaries()
    return MicrosoftGraph::DeviceManagement::DeviceCompliancePolicySettingStateSummaries::DeviceCompliancePolicySettingStateSummariesRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_configuration_device_state_summariesObject

Provides operations to manage the deviceConfigurationDeviceStateSummaries property of the microsoft.graph.deviceManagement entity.



119
120
121
# File 'lib/device_management/device_management_request_builder.rb', line 119

def device_configuration_device_state_summaries()
    return MicrosoftGraph::DeviceManagement::DeviceConfigurationDeviceStateSummaries::DeviceConfigurationDeviceStateSummariesRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_configurationsObject

Provides operations to manage the deviceConfigurations property of the microsoft.graph.deviceManagement entity.



124
125
126
# File 'lib/device_management/device_management_request_builder.rb', line 124

def device_configurations()
    return MicrosoftGraph::DeviceManagement::DeviceConfigurations::DeviceConfigurationsRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_enrollment_configurationsObject

Provides operations to manage the deviceEnrollmentConfigurations property of the microsoft.graph.deviceManagement entity.



129
130
131
# File 'lib/device_management/device_management_request_builder.rb', line 129

def device_enrollment_configurations()
    return MicrosoftGraph::DeviceManagement::DeviceEnrollmentConfigurations::DeviceEnrollmentConfigurationsRequestBuilder.new(@path_parameters, @request_adapter)
end

#device_management_partnersObject

Provides operations to manage the deviceManagementPartners property of the microsoft.graph.deviceManagement entity.



134
135
136
# File 'lib/device_management/device_management_request_builder.rb', line 134

def device_management_partners()
    return MicrosoftGraph::DeviceManagement::DeviceManagementPartners::DeviceManagementPartnersRequestBuilder.new(@path_parameters, @request_adapter)
end

#exchange_connectorsObject

Provides operations to manage the exchangeConnectors property of the microsoft.graph.deviceManagement entity.



139
140
141
# File 'lib/device_management/device_management_request_builder.rb', line 139

def exchange_connectors()
    return MicrosoftGraph::DeviceManagement::ExchangeConnectors::ExchangeConnectorsRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Read properties and relationships of the deviceManagement object.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of device_management



371
372
373
374
375
376
377
378
379
# File 'lib/device_management/device_management_request_builder.rb', line 371

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DeviceManagement.create_from_discriminator_value(pn) }, error_mapping)
end

#get_effective_permissions_with_scope(scope) ⇒ Object

Provides operations to call the getEffectivePermissions method.

Parameters:

  • scope

    Usage: scope=‘scope’

Returns:

  • a get_effective_permissions_with_scope_request_builder

Raises:

  • (StandardError)


385
386
387
388
# File 'lib/device_management/device_management_request_builder.rb', line 385

def get_effective_permissions_with_scope(scope)
    raise StandardError, 'scope cannot be null' if scope.nil?
    return GetEffectivePermissionsWithScopeRequestBuilder.new(@path_parameters, @request_adapter, scope)
end

#imported_windows_autopilot_device_identitiesObject

Provides operations to manage the importedWindowsAutopilotDeviceIdentities property of the microsoft.graph.deviceManagement entity.



144
145
146
# File 'lib/device_management/device_management_request_builder.rb', line 144

def imported_windows_autopilot_device_identities()
    return MicrosoftGraph::DeviceManagement::ImportedWindowsAutopilotDeviceIdentities::ImportedWindowsAutopilotDeviceIdentitiesRequestBuilder.new(@path_parameters, @request_adapter)
end

#ios_update_statusesObject

Provides operations to manage the iosUpdateStatuses property of the microsoft.graph.deviceManagement entity.



149
150
151
# File 'lib/device_management/device_management_request_builder.rb', line 149

def ios_update_statuses()
    return MicrosoftGraph::DeviceManagement::IosUpdateStatuses::IosUpdateStatusesRequestBuilder.new(@path_parameters, @request_adapter)
end

#managed_device_overviewObject

Provides operations to manage the managedDeviceOverview property of the microsoft.graph.deviceManagement entity.



154
155
156
# File 'lib/device_management/device_management_request_builder.rb', line 154

def managed_device_overview()
    return MicrosoftGraph::DeviceManagement::ManagedDeviceOverview::ManagedDeviceOverviewRequestBuilder.new(@path_parameters, @request_adapter)
end

#managed_devicesObject

Provides operations to manage the managedDevices property of the microsoft.graph.deviceManagement entity.



159
160
161
# File 'lib/device_management/device_management_request_builder.rb', line 159

def managed_devices()
    return MicrosoftGraph::DeviceManagement::ManagedDevices::ManagedDevicesRequestBuilder.new(@path_parameters, @request_adapter)
end

#mobile_app_troubleshooting_eventsObject

Provides operations to manage the mobileAppTroubleshootingEvents property of the microsoft.graph.deviceManagement entity.



164
165
166
# File 'lib/device_management/device_management_request_builder.rb', line 164

def mobile_app_troubleshooting_events()
    return MicrosoftGraph::DeviceManagement::MobileAppTroubleshootingEvents::MobileAppTroubleshootingEventsRequestBuilder.new(@path_parameters, @request_adapter)
end

#mobile_threat_defense_connectorsObject

Provides operations to manage the mobileThreatDefenseConnectors property of the microsoft.graph.deviceManagement entity.



169
170
171
# File 'lib/device_management/device_management_request_builder.rb', line 169

def mobile_threat_defense_connectors()
    return MicrosoftGraph::DeviceManagement::MobileThreatDefenseConnectors::MobileThreatDefenseConnectorsRequestBuilder.new(@path_parameters, @request_adapter)
end

#notification_message_templatesObject

Provides operations to manage the notificationMessageTemplates property of the microsoft.graph.deviceManagement entity.



174
175
176
# File 'lib/device_management/device_management_request_builder.rb', line 174

def notification_message_templates()
    return MicrosoftGraph::DeviceManagement::NotificationMessageTemplates::NotificationMessageTemplatesRequestBuilder.new(@path_parameters, @request_adapter)
end

#patch(body, request_configuration = nil) ⇒ Object

Update the properties of a deviceManagement object.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of device_management

Raises:

  • (StandardError)


395
396
397
398
399
400
401
402
403
404
# File 'lib/device_management/device_management_request_builder.rb', line 395

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DeviceManagement.create_from_discriminator_value(pn) }, error_mapping)
end

#remote_assistance_partnersObject

Provides operations to manage the remoteAssistancePartners property of the microsoft.graph.deviceManagement entity.



179
180
181
# File 'lib/device_management/device_management_request_builder.rb', line 179

def remote_assistance_partners()
    return MicrosoftGraph::DeviceManagement::RemoteAssistancePartners::RemoteAssistancePartnersRequestBuilder.new(@path_parameters, @request_adapter)
end

#reportsObject

Provides operations to manage the reports property of the microsoft.graph.deviceManagement entity.



184
185
186
# File 'lib/device_management/device_management_request_builder.rb', line 184

def reports()
    return MicrosoftGraph::DeviceManagement::Reports::ReportsRequestBuilder.new(@path_parameters, @request_adapter)
end

#resource_operationsObject

Provides operations to manage the resourceOperations property of the microsoft.graph.deviceManagement entity.



189
190
191
# File 'lib/device_management/device_management_request_builder.rb', line 189

def resource_operations()
    return MicrosoftGraph::DeviceManagement::ResourceOperations::ResourceOperationsRequestBuilder.new(@path_parameters, @request_adapter)
end

#role_assignmentsObject

Provides operations to manage the roleAssignments property of the microsoft.graph.deviceManagement entity.



194
195
196
# File 'lib/device_management/device_management_request_builder.rb', line 194

def role_assignments()
    return MicrosoftGraph::DeviceManagement::RoleAssignments::RoleAssignmentsRequestBuilder.new(@path_parameters, @request_adapter)
end

#role_definitionsObject

Provides operations to manage the roleDefinitions property of the microsoft.graph.deviceManagement entity.



199
200
201
# File 'lib/device_management/device_management_request_builder.rb', line 199

def role_definitions()
    return MicrosoftGraph::DeviceManagement::RoleDefinitions::RoleDefinitionsRequestBuilder.new(@path_parameters, @request_adapter)
end

#software_update_status_summaryObject

Provides operations to manage the softwareUpdateStatusSummary property of the microsoft.graph.deviceManagement entity.



204
205
206
# File 'lib/device_management/device_management_request_builder.rb', line 204

def software_update_status_summary()
    return MicrosoftGraph::DeviceManagement::SoftwareUpdateStatusSummary::SoftwareUpdateStatusSummaryRequestBuilder.new(@path_parameters, @request_adapter)
end

#telecom_expense_management_partnersObject

Provides operations to manage the telecomExpenseManagementPartners property of the microsoft.graph.deviceManagement entity.



209
210
211
# File 'lib/device_management/device_management_request_builder.rb', line 209

def telecom_expense_management_partners()
    return MicrosoftGraph::DeviceManagement::TelecomExpenseManagementPartners::TelecomExpenseManagementPartnersRequestBuilder.new(@path_parameters, @request_adapter)
end

#terms_and_conditionsObject

Provides operations to manage the termsAndConditions property of the microsoft.graph.deviceManagement entity.



214
215
216
# File 'lib/device_management/device_management_request_builder.rb', line 214

def terms_and_conditions()
    return MicrosoftGraph::DeviceManagement::TermsAndConditions::TermsAndConditionsRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Read properties and relationships of the deviceManagement object.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/device_management/device_management_request_builder.rb', line 410

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update the properties of a deviceManagement object.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/device_management/device_management_request_builder.rb', line 429

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end

#troubleshooting_eventsObject

Provides operations to manage the troubleshootingEvents property of the microsoft.graph.deviceManagement entity.



219
220
221
# File 'lib/device_management/device_management_request_builder.rb', line 219

def troubleshooting_events()
    return MicrosoftGraph::DeviceManagement::TroubleshootingEvents::TroubleshootingEventsRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_application_performanceObject

Provides operations to manage the userExperienceAnalyticsAppHealthApplicationPerformance property of the microsoft.graph.deviceManagement entity.



224
225
226
# File 'lib/device_management/device_management_request_builder.rb', line 224

def user_experience_analytics_app_health_application_performance()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthApplicationPerformance::UserExperienceAnalyticsAppHealthApplicationPerformanceRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_application_performance_by_app_version_detailsObject

Provides operations to manage the userExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDetails property of the microsoft.graph.deviceManagement entity.



229
230
231
# File 'lib/device_management/device_management_request_builder.rb', line 229

def user_experience_analytics_app_health_application_performance_by_app_version_details()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDetails::UserExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDetailsRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_application_performance_by_app_version_device_idObject

Provides operations to manage the userExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDeviceId property of the microsoft.graph.deviceManagement entity.



234
235
236
# File 'lib/device_management/device_management_request_builder.rb', line 234

def user_experience_analytics_app_health_application_performance_by_app_version_device_id()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDeviceId::UserExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDeviceIdRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_application_performance_by_o_s_versionObject

Provides operations to manage the userExperienceAnalyticsAppHealthApplicationPerformanceByOSVersion property of the microsoft.graph.deviceManagement entity.



239
240
241
# File 'lib/device_management/device_management_request_builder.rb', line 239

def user_experience_analytics_app_health_application_performance_by_o_s_version()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthApplicationPerformanceByOSVersion::UserExperienceAnalyticsAppHealthApplicationPerformanceByOSVersionRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_device_model_performanceObject

Provides operations to manage the userExperienceAnalyticsAppHealthDeviceModelPerformance property of the microsoft.graph.deviceManagement entity.



244
245
246
# File 'lib/device_management/device_management_request_builder.rb', line 244

def user_experience_analytics_app_health_device_model_performance()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthDeviceModelPerformance::UserExperienceAnalyticsAppHealthDeviceModelPerformanceRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_device_performanceObject

Provides operations to manage the userExperienceAnalyticsAppHealthDevicePerformance property of the microsoft.graph.deviceManagement entity.



249
250
251
# File 'lib/device_management/device_management_request_builder.rb', line 249

def user_experience_analytics_app_health_device_performance()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthDevicePerformance::UserExperienceAnalyticsAppHealthDevicePerformanceRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_device_performance_detailsObject

Provides operations to manage the userExperienceAnalyticsAppHealthDevicePerformanceDetails property of the microsoft.graph.deviceManagement entity.



254
255
256
# File 'lib/device_management/device_management_request_builder.rb', line 254

def user_experience_analytics_app_health_device_performance_details()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthDevicePerformanceDetails::UserExperienceAnalyticsAppHealthDevicePerformanceDetailsRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_o_s_version_performanceObject

Provides operations to manage the userExperienceAnalyticsAppHealthOSVersionPerformance property of the microsoft.graph.deviceManagement entity.



259
260
261
# File 'lib/device_management/device_management_request_builder.rb', line 259

def user_experience_analytics_app_health_o_s_version_performance()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthOSVersionPerformance::UserExperienceAnalyticsAppHealthOSVersionPerformanceRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_app_health_overviewObject

Provides operations to manage the userExperienceAnalyticsAppHealthOverview property of the microsoft.graph.deviceManagement entity.



264
265
266
# File 'lib/device_management/device_management_request_builder.rb', line 264

def user_experience_analytics_app_health_overview()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsAppHealthOverview::UserExperienceAnalyticsAppHealthOverviewRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_baselinesObject

Provides operations to manage the userExperienceAnalyticsBaselines property of the microsoft.graph.deviceManagement entity.



269
270
271
# File 'lib/device_management/device_management_request_builder.rb', line 269

def user_experience_analytics_baselines()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsBaselines::UserExperienceAnalyticsBaselinesRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_categoriesObject

Provides operations to manage the userExperienceAnalyticsCategories property of the microsoft.graph.deviceManagement entity.



274
275
276
# File 'lib/device_management/device_management_request_builder.rb', line 274

def user_experience_analytics_categories()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsCategories::UserExperienceAnalyticsCategoriesRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_device_performanceObject

Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.



279
280
281
# File 'lib/device_management/device_management_request_builder.rb', line 279

def user_experience_analytics_device_performance()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDevicePerformance::UserExperienceAnalyticsDevicePerformanceRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_device_scoresObject

Provides operations to manage the userExperienceAnalyticsDeviceScores property of the microsoft.graph.deviceManagement entity.



284
285
286
# File 'lib/device_management/device_management_request_builder.rb', line 284

def user_experience_analytics_device_scores()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDeviceScores::UserExperienceAnalyticsDeviceScoresRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_device_startup_historyObject

Provides operations to manage the userExperienceAnalyticsDeviceStartupHistory property of the microsoft.graph.deviceManagement entity.



289
290
291
# File 'lib/device_management/device_management_request_builder.rb', line 289

def user_experience_analytics_device_startup_history()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDeviceStartupHistory::UserExperienceAnalyticsDeviceStartupHistoryRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_device_startup_processesObject

Provides operations to manage the userExperienceAnalyticsDeviceStartupProcesses property of the microsoft.graph.deviceManagement entity.



294
295
296
# File 'lib/device_management/device_management_request_builder.rb', line 294

def user_experience_analytics_device_startup_processes()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDeviceStartupProcesses::UserExperienceAnalyticsDeviceStartupProcessesRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_metric_historyObject

Provides operations to manage the userExperienceAnalyticsMetricHistory property of the microsoft.graph.deviceManagement entity.



299
300
301
# File 'lib/device_management/device_management_request_builder.rb', line 299

def user_experience_analytics_metric_history()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsMetricHistory::UserExperienceAnalyticsMetricHistoryRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_model_scoresObject

Provides operations to manage the userExperienceAnalyticsModelScores property of the microsoft.graph.deviceManagement entity.



304
305
306
# File 'lib/device_management/device_management_request_builder.rb', line 304

def user_experience_analytics_model_scores()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsModelScores::UserExperienceAnalyticsModelScoresRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_overviewObject

Provides operations to manage the userExperienceAnalyticsOverview property of the microsoft.graph.deviceManagement entity.



309
310
311
# File 'lib/device_management/device_management_request_builder.rb', line 309

def user_experience_analytics_overview()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsOverview::UserExperienceAnalyticsOverviewRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_score_historyObject

Provides operations to manage the userExperienceAnalyticsScoreHistory property of the microsoft.graph.deviceManagement entity.



314
315
316
# File 'lib/device_management/device_management_request_builder.rb', line 314

def user_experience_analytics_score_history()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsScoreHistory::UserExperienceAnalyticsScoreHistoryRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_summarize_work_from_anywhere_devicesObject

Provides operations to call the userExperienceAnalyticsSummarizeWorkFromAnywhereDevices method.



319
320
321
# File 'lib/device_management/device_management_request_builder.rb', line 319

def user_experience_analytics_summarize_work_from_anywhere_devices()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsSummarizeWorkFromAnywhereDevices::UserExperienceAnalyticsSummarizeWorkFromAnywhereDevicesRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_work_from_anywhere_hardware_readiness_metricObject

Provides operations to manage the userExperienceAnalyticsWorkFromAnywhereHardwareReadinessMetric property of the microsoft.graph.deviceManagement entity.



324
325
326
# File 'lib/device_management/device_management_request_builder.rb', line 324

def user_experience_analytics_work_from_anywhere_hardware_readiness_metric()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsWorkFromAnywhereHardwareReadinessMetric::UserExperienceAnalyticsWorkFromAnywhereHardwareReadinessMetricRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_work_from_anywhere_metricsObject

Provides operations to manage the userExperienceAnalyticsWorkFromAnywhereMetrics property of the microsoft.graph.deviceManagement entity.



329
330
331
# File 'lib/device_management/device_management_request_builder.rb', line 329

def user_experience_analytics_work_from_anywhere_metrics()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsWorkFromAnywhereMetrics::UserExperienceAnalyticsWorkFromAnywhereMetricsRequestBuilder.new(@path_parameters, @request_adapter)
end

#user_experience_analytics_work_from_anywhere_model_performanceObject

Provides operations to manage the userExperienceAnalyticsWorkFromAnywhereModelPerformance property of the microsoft.graph.deviceManagement entity.



334
335
336
# File 'lib/device_management/device_management_request_builder.rb', line 334

def user_experience_analytics_work_from_anywhere_model_performance()
    return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsWorkFromAnywhereModelPerformance::UserExperienceAnalyticsWorkFromAnywhereModelPerformanceRequestBuilder.new(@path_parameters, @request_adapter)
end

#verify_windows_enrollment_auto_discovery_with_domain_name(domain_name) ⇒ Object

Provides operations to call the verifyWindowsEnrollmentAutoDiscovery method.

Parameters:

  • domain_name

    Usage: domainName=‘domainName’

Returns:

  • a verify_windows_enrollment_auto_discovery_with_domain_name_request_builder

Raises:

  • (StandardError)


448
449
450
451
# File 'lib/device_management/device_management_request_builder.rb', line 448

def verify_windows_enrollment_auto_discovery_with_domain_name(domain_name)
    raise StandardError, 'domain_name cannot be null' if domain_name.nil?
    return VerifyWindowsEnrollmentAutoDiscoveryWithDomainNameRequestBuilder.new(@path_parameters, @request_adapter, domainName)
end

#windows_autopilot_device_identitiesObject

Provides operations to manage the windowsAutopilotDeviceIdentities property of the microsoft.graph.deviceManagement entity.



339
340
341
# File 'lib/device_management/device_management_request_builder.rb', line 339

def windows_autopilot_device_identities()
    return MicrosoftGraph::DeviceManagement::WindowsAutopilotDeviceIdentities::WindowsAutopilotDeviceIdentitiesRequestBuilder.new(@path_parameters, @request_adapter)
end

#windows_information_protection_app_learning_summariesObject

Provides operations to manage the windowsInformationProtectionAppLearningSummaries property of the microsoft.graph.deviceManagement entity.



344
345
346
# File 'lib/device_management/device_management_request_builder.rb', line 344

def windows_information_protection_app_learning_summaries()
    return MicrosoftGraph::DeviceManagement::WindowsInformationProtectionAppLearningSummaries::WindowsInformationProtectionAppLearningSummariesRequestBuilder.new(@path_parameters, @request_adapter)
end

#windows_information_protection_network_learning_summariesObject

Provides operations to manage the windowsInformationProtectionNetworkLearningSummaries property of the microsoft.graph.deviceManagement entity.



349
350
351
# File 'lib/device_management/device_management_request_builder.rb', line 349

def windows_information_protection_network_learning_summaries()
    return MicrosoftGraph::DeviceManagement::WindowsInformationProtectionNetworkLearningSummaries::WindowsInformationProtectionNetworkLearningSummariesRequestBuilder.new(@path_parameters, @request_adapter)
end

#windows_malware_informationObject

Provides operations to manage the windowsMalwareInformation property of the microsoft.graph.deviceManagement entity.



354
355
356
# File 'lib/device_management/device_management_request_builder.rb', line 354

def windows_malware_information()
    return MicrosoftGraph::DeviceManagement::WindowsMalwareInformation::WindowsMalwareInformationRequestBuilder.new(@path_parameters, @request_adapter)
end