Class: MicrosoftGraph::DeviceManagement::ExchangeConnectors::Item::Sync::SyncPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new syncPostRequestBody and sets the default values.



41
42
43
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 41

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a sync_post_request_body

Raises:

  • (StandardError)


49
50
51
52
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 49

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return SyncPostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



26
27
28
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 26

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



34
35
36
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 34

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



57
58
59
60
61
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 57

def get_field_deserializers()
    return {
        "syncType" => lambda {|n| @sync_type = n.get_enum_value(MicrosoftGraph::Models::DeviceManagementExchangeConnectorSyncType) },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


67
68
69
70
71
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 67

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_enum_value("syncType", @sync_type)
    writer.write_additional_data(@additional_data)
end

#sync_typeObject

Gets the syncType property value. The type of Exchange Connector sync requested.

Returns:

  • a device_management_exchange_connector_sync_type



76
77
78
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 76

def sync_type
    return @sync_type
end

#sync_type=(value) ⇒ Object

Sets the syncType property value. The type of Exchange Connector sync requested.

Parameters:

  • value

    Value to set for the syncType property.

Returns:

  • a void



84
85
86
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 84

def sync_type=(value)
    @sync_type = value
end