Class: MicrosoftGraph::DeviceManagement::ManagedDevices::Item::ManagedDeviceItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::DeviceManagement::ManagedDevices::Item::ManagedDeviceItemRequestBuilder
- Defined in:
- lib/device_management/managed_devices/item/managed_device_item_request_builder.rb
Overview
Provides operations to manage the managedDevices property of the microsoft.graph.deviceManagement entity.
Defined Under Namespace
Classes: ManagedDeviceItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#bypass_activation_lock ⇒ Object
Provides operations to call the bypassActivationLock method.
-
#clean_windows_device ⇒ Object
Provides operations to call the cleanWindowsDevice method.
-
#delete(request_configuration = nil) ⇒ Object
Deletes a managedDevice.
-
#delete_user_from_shared_apple_device ⇒ Object
Provides operations to call the deleteUserFromSharedAppleDevice method.
-
#device_category ⇒ Object
Provides operations to manage the deviceCategory property of the microsoft.graph.managedDevice entity.
-
#device_compliance_policy_states ⇒ Object
Provides operations to manage the deviceCompliancePolicyStates property of the microsoft.graph.managedDevice entity.
-
#device_configuration_states ⇒ Object
Provides operations to manage the deviceConfigurationStates property of the microsoft.graph.managedDevice entity.
-
#disable_lost_mode ⇒ Object
Provides operations to call the disableLostMode method.
-
#get(request_configuration = nil) ⇒ Object
Read properties and relationships of the managedDevice object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ManagedDeviceItemRequestBuilder and sets the default values.
-
#locate_device ⇒ Object
Provides operations to call the locateDevice method.
-
#log_collection_requests ⇒ Object
Provides operations to manage the logCollectionRequests property of the microsoft.graph.managedDevice entity.
-
#logout_shared_apple_device_active_user ⇒ Object
Provides operations to call the logoutSharedAppleDeviceActiveUser method.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of a managedDevice object.
-
#reboot_now ⇒ Object
Provides operations to call the rebootNow method.
-
#recover_passcode ⇒ Object
Provides operations to call the recoverPasscode method.
-
#remote_lock ⇒ Object
Provides operations to call the remoteLock method.
-
#request_remote_assistance ⇒ Object
Provides operations to call the requestRemoteAssistance method.
-
#reset_passcode ⇒ Object
Provides operations to call the resetPasscode method.
-
#retire ⇒ Object
Provides operations to call the retire method.
-
#shut_down ⇒ Object
Provides operations to call the shutDown method.
-
#sync_device ⇒ Object
Provides operations to call the syncDevice method.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Deletes a managedDevice.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Read properties and relationships of the managedDevice object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of a managedDevice object.
-
#update_windows_device_account ⇒ Object
Provides operations to call the updateWindowsDeviceAccount method.
-
#users ⇒ Object
Provides operations to manage the users property of the microsoft.graph.managedDevice entity.
-
#windows_defender_scan ⇒ Object
Provides operations to call the windowsDefenderScan method.
-
#windows_defender_update_signatures ⇒ Object
Provides operations to call the windowsDefenderUpdateSignatures method.
-
#windows_protection_state ⇒ Object
Provides operations to manage the windowsProtectionState property of the microsoft.graph.managedDevice entity.
-
#wipe ⇒ Object
Provides operations to call the wipe method.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ManagedDeviceItemRequestBuilder and sets the default values.
167 168 169 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 167 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/deviceManagement/managedDevices/{managedDevice%2Did}{?%24select,%24expand}") end |
Instance Method Details
#bypass_activation_lock ⇒ Object
Provides operations to call the bypassActivationLock method.
43 44 45 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 43 def bypass_activation_lock() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::BypassActivationLock::BypassActivationLockRequestBuilder.new(@path_parameters, @request_adapter) end |
#clean_windows_device ⇒ Object
Provides operations to call the cleanWindowsDevice method.
48 49 50 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 48 def clean_windows_device() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::CleanWindowsDevice::CleanWindowsDeviceRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Deletes a managedDevice.
175 176 177 178 179 180 181 182 183 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 175 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#delete_user_from_shared_apple_device ⇒ Object
Provides operations to call the deleteUserFromSharedAppleDevice method.
53 54 55 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 53 def delete_user_from_shared_apple_device() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::DeleteUserFromSharedAppleDevice::DeleteUserFromSharedAppleDeviceRequestBuilder.new(@path_parameters, @request_adapter) end |
#device_category ⇒ Object
Provides operations to manage the deviceCategory property of the microsoft.graph.managedDevice entity.
58 59 60 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 58 def device_category() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::DeviceCategory::DeviceCategoryRequestBuilder.new(@path_parameters, @request_adapter) end |
#device_compliance_policy_states ⇒ Object
Provides operations to manage the deviceCompliancePolicyStates property of the microsoft.graph.managedDevice entity.
63 64 65 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 63 def device_compliance_policy_states() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::DeviceCompliancePolicyStates::DeviceCompliancePolicyStatesRequestBuilder.new(@path_parameters, @request_adapter) end |
#device_configuration_states ⇒ Object
Provides operations to manage the deviceConfigurationStates property of the microsoft.graph.managedDevice entity.
68 69 70 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 68 def device_configuration_states() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::DeviceConfigurationStates::DeviceConfigurationStatesRequestBuilder.new(@path_parameters, @request_adapter) end |
#disable_lost_mode ⇒ Object
Provides operations to call the disableLostMode method.
73 74 75 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 73 def disable_lost_mode() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::DisableLostMode::DisableLostModeRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Read properties and relationships of the managedDevice object.
189 190 191 192 193 194 195 196 197 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 189 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ManagedDevice.create_from_discriminator_value(pn) }, error_mapping) end |
#locate_device ⇒ Object
Provides operations to call the locateDevice method.
78 79 80 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 78 def locate_device() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::LocateDevice::LocateDeviceRequestBuilder.new(@path_parameters, @request_adapter) end |
#log_collection_requests ⇒ Object
Provides operations to manage the logCollectionRequests property of the microsoft.graph.managedDevice entity.
83 84 85 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 83 def log_collection_requests() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::LogCollectionRequests::LogCollectionRequestsRequestBuilder.new(@path_parameters, @request_adapter) end |
#logout_shared_apple_device_active_user ⇒ Object
Provides operations to call the logoutSharedAppleDeviceActiveUser method.
88 89 90 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 88 def logout_shared_apple_device_active_user() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::LogoutSharedAppleDeviceActiveUser::LogoutSharedAppleDeviceActiveUserRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of a managedDevice object.
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 204 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ManagedDevice.create_from_discriminator_value(pn) }, error_mapping) end |
#reboot_now ⇒ Object
Provides operations to call the rebootNow method.
93 94 95 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 93 def reboot_now() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::RebootNow::RebootNowRequestBuilder.new(@path_parameters, @request_adapter) end |
#recover_passcode ⇒ Object
Provides operations to call the recoverPasscode method.
98 99 100 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 98 def recover_passcode() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::RecoverPasscode::RecoverPasscodeRequestBuilder.new(@path_parameters, @request_adapter) end |
#remote_lock ⇒ Object
Provides operations to call the remoteLock method.
103 104 105 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 103 def remote_lock() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::RemoteLock::RemoteLockRequestBuilder.new(@path_parameters, @request_adapter) end |
#request_remote_assistance ⇒ Object
Provides operations to call the requestRemoteAssistance method.
108 109 110 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 108 def request_remote_assistance() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::RequestRemoteAssistance::RequestRemoteAssistanceRequestBuilder.new(@path_parameters, @request_adapter) end |
#reset_passcode ⇒ Object
Provides operations to call the resetPasscode method.
113 114 115 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 113 def reset_passcode() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::ResetPasscode::ResetPasscodeRequestBuilder.new(@path_parameters, @request_adapter) end |
#retire ⇒ Object
Provides operations to call the retire method.
118 119 120 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 118 def retire() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::Retire::RetireRequestBuilder.new(@path_parameters, @request_adapter) end |
#shut_down ⇒ Object
Provides operations to call the shutDown method.
123 124 125 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 123 def shut_down() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::ShutDown::ShutDownRequestBuilder.new(@path_parameters, @request_adapter) end |
#sync_device ⇒ Object
Provides operations to call the syncDevice method.
128 129 130 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 128 def sync_device() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::SyncDevice::SyncDeviceRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Deletes a managedDevice.
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 219 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Read properties and relationships of the managedDevice object.
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 235 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of a managedDevice object.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 254 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |
#update_windows_device_account ⇒ Object
Provides operations to call the updateWindowsDeviceAccount method.
133 134 135 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 133 def update_windows_device_account() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::UpdateWindowsDeviceAccount::UpdateWindowsDeviceAccountRequestBuilder.new(@path_parameters, @request_adapter) end |
#users ⇒ Object
Provides operations to manage the users property of the microsoft.graph.managedDevice entity.
138 139 140 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 138 def users() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::Users::UsersRequestBuilder.new(@path_parameters, @request_adapter) end |
#windows_defender_scan ⇒ Object
Provides operations to call the windowsDefenderScan method.
143 144 145 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 143 def windows_defender_scan() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::WindowsDefenderScan::WindowsDefenderScanRequestBuilder.new(@path_parameters, @request_adapter) end |
#windows_defender_update_signatures ⇒ Object
Provides operations to call the windowsDefenderUpdateSignatures method.
148 149 150 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 148 def windows_defender_update_signatures() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::WindowsDefenderUpdateSignatures::WindowsDefenderUpdateSignaturesRequestBuilder.new(@path_parameters, @request_adapter) end |
#windows_protection_state ⇒ Object
Provides operations to manage the windowsProtectionState property of the microsoft.graph.managedDevice entity.
153 154 155 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 153 def windows_protection_state() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::WindowsProtectionState::WindowsProtectionStateRequestBuilder.new(@path_parameters, @request_adapter) end |
#wipe ⇒ Object
Provides operations to call the wipe method.
158 159 160 |
# File 'lib/device_management/managed_devices/item/managed_device_item_request_builder.rb', line 158 def wipe() return MicrosoftGraph::DeviceManagement::ManagedDevices::Item::Wipe::WipeRequestBuilder.new(@path_parameters, @request_adapter) end |