Class: MicrosoftGraph::DeviceManagement::ManagedDevices::Item::Wipe::WipePostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::DeviceManagement::ManagedDevices::Item::Wipe::WipePostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new wipePostRequestBody and sets the default values.
-
#keep_enrollment_data ⇒ Object
Gets the keepEnrollmentData property value.
-
#keep_enrollment_data=(value) ⇒ Object
Sets the keepEnrollmentData property value.
-
#keep_user_data ⇒ Object
Gets the keepUserData property value.
-
#keep_user_data=(value) ⇒ Object
Sets the keepUserData property value.
-
#mac_os_unlock_code ⇒ Object
Gets the macOsUnlockCode property value.
-
#mac_os_unlock_code=(value) ⇒ Object
Sets the macOsUnlockCode property value.
-
#persist_esim_data_plan ⇒ Object
Gets the persistEsimDataPlan property value.
-
#persist_esim_data_plan=(value) ⇒ Object
Sets the persistEsimDataPlan property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new wipePostRequestBody and sets the default values.
49 50 51 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 49 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
57 58 59 60 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 57 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WipePostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
34 35 36 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 34 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
42 43 44 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 42 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
65 66 67 68 69 70 71 72 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 65 def get_field_deserializers() return { "keepEnrollmentData" => lambda {|n| @keep_enrollment_data = n.get_boolean_value() }, "keepUserData" => lambda {|n| @keep_user_data = n.get_boolean_value() }, "macOsUnlockCode" => lambda {|n| @mac_os_unlock_code = n.get_string_value() }, "persistEsimDataPlan" => lambda {|n| @persist_esim_data_plan = n.get_boolean_value() }, } end |
#keep_enrollment_data ⇒ Object
Gets the keepEnrollmentData property value. The keepEnrollmentData property
77 78 79 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 77 def keep_enrollment_data return @keep_enrollment_data end |
#keep_enrollment_data=(value) ⇒ Object
Sets the keepEnrollmentData property value. The keepEnrollmentData property
85 86 87 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 85 def keep_enrollment_data=(value) @keep_enrollment_data = value end |
#keep_user_data ⇒ Object
Gets the keepUserData property value. The keepUserData property
92 93 94 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 92 def keep_user_data return @keep_user_data end |
#keep_user_data=(value) ⇒ Object
Sets the keepUserData property value. The keepUserData property
100 101 102 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 100 def keep_user_data=(value) @keep_user_data = value end |
#mac_os_unlock_code ⇒ Object
Gets the macOsUnlockCode property value. The macOsUnlockCode property
107 108 109 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 107 def mac_os_unlock_code return @mac_os_unlock_code end |
#mac_os_unlock_code=(value) ⇒ Object
Sets the macOsUnlockCode property value. The macOsUnlockCode property
115 116 117 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 115 def mac_os_unlock_code=(value) @mac_os_unlock_code = value end |
#persist_esim_data_plan ⇒ Object
Gets the persistEsimDataPlan property value. The persistEsimDataPlan property
122 123 124 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 122 def persist_esim_data_plan return @persist_esim_data_plan end |
#persist_esim_data_plan=(value) ⇒ Object
Sets the persistEsimDataPlan property value. The persistEsimDataPlan property
130 131 132 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 130 def persist_esim_data_plan=(value) @persist_esim_data_plan = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
138 139 140 141 142 143 144 145 |
# File 'lib/device_management/managed_devices/item/wipe/wipe_post_request_body.rb', line 138 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("keepEnrollmentData", @keep_enrollment_data) writer.write_boolean_value("keepUserData", @keep_user_data) writer.write_string_value("macOsUnlockCode", @mac_os_unlock_code) writer.write_boolean_value("persistEsimDataPlan", @persist_esim_data_plan) writer.write_additional_data(@additional_data) end |