Class: MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDevicePerformance::UserExperienceAnalyticsDevicePerformanceRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDevicePerformance::UserExperienceAnalyticsDevicePerformanceRequestBuilder
- Defined in:
- lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb
Overview
Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.
Defined Under Namespace
Classes: UserExperienceAnalyticsDevicePerformanceRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_user_experience_analytics_device_performance_id(user_experience_analytics_device_performance_id) ⇒ Object
Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
User experience analytics device performance.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new UserExperienceAnalyticsDevicePerformanceRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement.
-
#summarize_device_performance_devices_with_summarize_by(summarize_by) ⇒ Object
Provides operations to call the summarizeDevicePerformanceDevices method.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
User experience analytics device performance.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new UserExperienceAnalyticsDevicePerformanceRequestBuilder and sets the default values.
41 42 43 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 41 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/deviceManagement/userExperienceAnalyticsDevicePerformance{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_user_experience_analytics_device_performance_id(user_experience_analytics_device_performance_id) ⇒ Object
Provides operations to manage the userExperienceAnalyticsDevicePerformance property of the microsoft.graph.deviceManagement entity.
29 30 31 32 33 34 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 29 def by_user_experience_analytics_device_performance_id(user_experience_analytics_device_performance_id) raise StandardError, 'user_experience_analytics_device_performance_id cannot be null' if user_experience_analytics_device_performance_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["userExperienceAnalyticsDevicePerformance%2Did"] = user_experience_analytics_device_performance_id return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDevicePerformance::Item::UserExperienceAnalyticsDevicePerformanceItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
21 22 23 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 21 def count() return MicrosoftGraph::DeviceManagement::UserExperienceAnalyticsDevicePerformance::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
User experience analytics device performance
49 50 51 52 53 54 55 56 57 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 49 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::UserExperienceAnalyticsDevicePerformanceCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement
64 65 66 67 68 69 70 71 72 73 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 64 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::UserExperienceAnalyticsDevicePerformance.create_from_discriminator_value(pn) }, error_mapping) end |
#summarize_device_performance_devices_with_summarize_by(summarize_by) ⇒ Object
Provides operations to call the summarizeDevicePerformanceDevices method.
79 80 81 82 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 79 def summarize_device_performance_devices_with_summarize_by(summarize_by) raise StandardError, 'summarize_by cannot be null' if summarize_by.nil? return SummarizeDevicePerformanceDevicesWithSummarizeByRequestBuilder.new(@path_parameters, @request_adapter, summarizeBy) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
User experience analytics device performance
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 88 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to userExperienceAnalyticsDevicePerformance for deviceManagement
107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/device_management/user_experience_analytics_device_performance/user_experience_analytics_device_performance_request_builder.rb', line 107 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |