Class: MicrosoftGraph::DirectoryRoles::DirectoryRolesRequestBuilder::DirectoryRolesRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/directory_roles/directory_roles_request_builder.rb

Overview

List the directory roles that are activated in the tenant. This operation only returns roles that have been activated. A role becomes activated when an admin activates the role using the Activate directoryRole API. Not all built-in roles are initially activated. When assigning a role using the Azure portal, the role activation step is implicitly done on the admin’s behalf. To get the full list of roles that are available in Azure AD, use List directoryRoleTemplates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



140
141
142
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 140

def count
  @count
end

#expandObject

Expand related entities



143
144
145
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 143

def expand
  @expand
end

#filterObject

Filter items by property values



146
147
148
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 146

def filter
  @filter
end

#orderbyObject

Order items by property values



149
150
151
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 149

def orderby
  @orderby
end

#searchObject

Search items by search phrases



152
153
154
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 152

def search
  @search
end

#selectObject

Select properties to be returned



155
156
157
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 155

def select
  @select
end

#skipObject

Skip the first n items



158
159
160
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 158

def skip
  @skip
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/directory_roles/directory_roles_request_builder.rb', line 164

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "expand"
            return "%24expand"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "search"
            return "%24search"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        else
            return original_name
    end
end