Class: MicrosoftGraph::DirectoryRoles::Item::DirectoryRoleItemRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/directory_roles/item/directory_role_item_request_builder.rb

Overview

Provides operations to manage the collection of directoryRole entities.

Defined Under Namespace

Classes: DirectoryRoleItemRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new DirectoryRoleItemRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



63
64
65
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 63

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/directoryRoles/{directoryRole%2Did}{?%24select,%24expand}")
end

Instance Method Details

#check_member_groupsObject

Provides operations to call the checkMemberGroups method.



24
25
26
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 24

def check_member_groups()
    return MicrosoftGraph::DirectoryRoles::Item::CheckMemberGroups::CheckMemberGroupsRequestBuilder.new(@path_parameters, @request_adapter)
end

#check_member_objectsObject

Provides operations to call the checkMemberObjects method.



29
30
31
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 29

def check_member_objects()
    return MicrosoftGraph::DirectoryRoles::Item::CheckMemberObjects::CheckMemberObjectsRequestBuilder.new(@path_parameters, @request_adapter)
end

#delete(request_configuration = nil) ⇒ Object

Delete entity from directoryRoles

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



71
72
73
74
75
76
77
78
79
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 71

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Retrieve the properties of a directoryRole object. The role must be activated in tenant for a successful response. You can use both the object ID and template ID of the directoryRole with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see Role template IDs.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of directory_role



85
86
87
88
89
90
91
92
93
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 85

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DirectoryRole.create_from_discriminator_value(pn) }, error_mapping)
end

#get_member_groupsObject

Provides operations to call the getMemberGroups method.



34
35
36
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 34

def get_member_groups()
    return MicrosoftGraph::DirectoryRoles::Item::GetMemberGroups::GetMemberGroupsRequestBuilder.new(@path_parameters, @request_adapter)
end

#get_member_objectsObject

Provides operations to call the getMemberObjects method.



39
40
41
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 39

def get_member_objects()
    return MicrosoftGraph::DirectoryRoles::Item::GetMemberObjects::GetMemberObjectsRequestBuilder.new(@path_parameters, @request_adapter)
end

#membersObject

Provides operations to manage the members property of the microsoft.graph.directoryRole entity.



44
45
46
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 44

def members()
    return MicrosoftGraph::DirectoryRoles::Item::Members::MembersRequestBuilder.new(@path_parameters, @request_adapter)
end

#patch(body, request_configuration = nil) ⇒ Object

Update entity in directoryRoles

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of directory_role

Raises:

  • (StandardError)


100
101
102
103
104
105
106
107
108
109
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 100

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DirectoryRole.create_from_discriminator_value(pn) }, error_mapping)
end

#restoreObject

Provides operations to call the restore method.



49
50
51
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 49

def restore()
    return MicrosoftGraph::DirectoryRoles::Item::Restore::RestoreRequestBuilder.new(@path_parameters, @request_adapter)
end

#scoped_membersObject

Provides operations to manage the scopedMembers property of the microsoft.graph.directoryRole entity.



54
55
56
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 54

def scoped_members()
    return MicrosoftGraph::DirectoryRoles::Item::ScopedMembers::ScopedMembersRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Delete entity from directoryRoles

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



115
116
117
118
119
120
121
122
123
124
125
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 115

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve the properties of a directoryRole object. The role must be activated in tenant for a successful response. You can use both the object ID and template ID of the directoryRole with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see Role template IDs.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 131

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update entity in directoryRoles

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 150

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end