Class: MicrosoftGraph::DirectoryRoles::Item::Members::Item::Ref::RefRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/directory_roles/item/members/item/ref/ref_request_builder.rb

Overview

Provides operations to manage the collection of directoryRole entities.

Defined Under Namespace

Classes: RefRequestBuilderDeleteQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new RefRequestBuilder and sets the default values.



26
27
28
# File 'lib/directory_roles/item/members/item/ref/ref_request_builder.rb', line 26

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/directoryRoles/{directoryRole%2Did}/members/{directoryObject%2Did}/$ref{?%40id*}")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

Remove a member from a directoryRole. You can use both the object ID and template ID of the directoryRole with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see Role template IDs.



34
35
36
37
38
39
40
41
42
# File 'lib/directory_roles/item/members/item/ref/ref_request_builder.rb', line 34

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Remove a member from a directoryRole. You can use both the object ID and template ID of the directoryRole with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see Role template IDs.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/directory_roles/item/members/item/ref/ref_request_builder.rb', line 48

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end