Class: MicrosoftGraph::DirectoryRoles::Item::Members::Item::Ref::RefRequestBuilder::RefRequestBuilderDeleteQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/directory_roles/item/members/item/ref/ref_request_builder.rb

Overview

Remove a member from a directoryRole. You can use both the object ID and template ID of the directoryRole with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see Role template IDs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#idObject

Delete Uri



67
68
69
# File 'lib/directory_roles/item/members/item/ref/ref_request_builder.rb', line 67

def id
  @id
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


73
74
75
76
77
78
79
80
81
# File 'lib/directory_roles/item/members/item/ref/ref_request_builder.rb', line 73

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "id"
            return "%40id"
        else
            return original_name
    end
end