Class: MicrosoftGraph::Domains::DomainsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Domains::DomainsRequestBuilder
- Defined in:
- lib/domains/domains_request_builder.rb
Overview
Provides operations to manage the collection of domain entities.
Defined Under Namespace
Classes: DomainsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_domain_id(domain_id) ⇒ Object
Provides operations to manage the collection of domain entities.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a list of domain objects.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DomainsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Adds a domain to the tenant.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of domain objects.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Adds a domain to the tenant.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DomainsRequestBuilder and sets the default values.
38 39 40 |
# File 'lib/domains/domains_request_builder.rb', line 38 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/domains{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_domain_id(domain_id) ⇒ Object
Provides operations to manage the collection of domain entities.
26 27 28 29 30 31 |
# File 'lib/domains/domains_request_builder.rb', line 26 def by_domain_id(domain_id) raise StandardError, 'domain_id cannot be null' if domain_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["domain%2Did"] = domain_id return MicrosoftGraph::Domains::Item::DomainItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
18 19 20 |
# File 'lib/domains/domains_request_builder.rb', line 18 def count() return MicrosoftGraph::Domains::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a list of domain objects.
46 47 48 49 50 51 52 53 54 |
# File 'lib/domains/domains_request_builder.rb', line 46 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DomainCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Adds a domain to the tenant. Important: You cannot use an associated domain with your Azure AD tenant until ownership is verified. See List verificationDnsRecords for details. Root domains require verification. For example, contoso.com requires verification. If a root domain is verified, subdomains of the root domain are automatically verified. For example, subdomain.contoso.com is automatically be verified if contoso.com has been verified.
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/domains/domains_request_builder.rb', line 61 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Domain.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of domain objects.
76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/domains/domains_request_builder.rb', line 76 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Adds a domain to the tenant. Important: You cannot use an associated domain with your Azure AD tenant until ownership is verified. See List verificationDnsRecords for details. Root domains require verification. For example, contoso.com requires verification. If a root domain is verified, subdomains of the root domain are automatically verified. For example, subdomain.contoso.com is automatically be verified if contoso.com has been verified.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/domains/domains_request_builder.rb', line 95 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |