Class: MicrosoftGraph::Drives::Item::Items::Item::Checkin::CheckinPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::Checkin::CheckinPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/drives/item/items/item/checkin/checkin_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#check_in_as ⇒ Object
Gets the checkInAs property value.
-
#check_in_as=(value) ⇒ Object
Sets the checkInAs property value.
-
#comment ⇒ Object
Gets the comment property value.
-
#comment=(value) ⇒ Object
Sets the comment property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new checkinPostRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new checkinPostRequestBody and sets the default values.
75 76 77 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 75 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
83 84 85 86 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 83 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CheckinPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 30 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 38 def additional_data=(value) @additional_data = value end |
#check_in_as ⇒ Object
Gets the checkInAs property value. The checkInAs property
45 46 47 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 45 def check_in_as return @check_in_as end |
#check_in_as=(value) ⇒ Object
Sets the checkInAs property value. The checkInAs property
53 54 55 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 53 def check_in_as=(value) @check_in_as = value end |
#comment ⇒ Object
Gets the comment property value. The comment property
60 61 62 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 60 def comment return @comment end |
#comment=(value) ⇒ Object
Sets the comment property value. The comment property
68 69 70 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 68 def comment=(value) @comment = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
91 92 93 94 95 96 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 91 def get_field_deserializers() return { "checkInAs" => lambda {|n| @check_in_as = n.get_string_value() }, "comment" => lambda {|n| @comment = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
102 103 104 105 106 107 |
# File 'lib/drives/item/items/item/checkin/checkin_post_request_body.rb', line 102 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("checkInAs", @check_in_as) writer.write_string_value("comment", @comment) writer.write_additional_data(@additional_data) end |