Class: MicrosoftGraph::Drives::Item::Items::Item::LastModifiedByUser::LastModifiedByUserRequestBuilder::LastModifiedByUserRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::LastModifiedByUser::LastModifiedByUserRequestBuilder::LastModifiedByUserRequestBuilderGetQueryParameters
- Defined in:
- lib/drives/item/items/item/last_modified_by_user/last_modified_by_user_request_builder.rb
Overview
Identity of the user who last modified the item. Read-only.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
75 76 77 |
# File 'lib/drives/item/items/item/last_modified_by_user/last_modified_by_user_request_builder.rb', line 75 def @expand end |
#select ⇒ Object
Select properties to be returned
78 79 80 |
# File 'lib/drives/item/items/item/last_modified_by_user/last_modified_by_user_request_builder.rb', line 78 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/drives/item/items/item/last_modified_by_user/last_modified_by_user_request_builder.rb', line 84 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |