Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Hyperlink::HyperlinkPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Hyperlink::HyperlinkPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#friendly_name ⇒ Object
Gets the friendlyName property value.
-
#friendly_name=(value) ⇒ Object
Sets the friendlyName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new hyperlinkPostRequestBody and sets the default values.
-
#link_location ⇒ Object
Gets the linkLocation property value.
-
#link_location=(value) ⇒ Object
Sets the linkLocation property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new hyperlinkPostRequestBody and sets the default values.
50 51 52 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 50 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
58 59 60 61 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 58 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return HyperlinkPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
35 36 37 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 35 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
43 44 45 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 43 def additional_data=(value) @additional_data = value end |
#friendly_name ⇒ Object
Gets the friendlyName property value. The friendlyName property
66 67 68 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 66 def friendly_name return @friendly_name end |
#friendly_name=(value) ⇒ Object
Sets the friendlyName property value. The friendlyName property
74 75 76 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 74 def friendly_name=(value) @friendly_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
81 82 83 84 85 86 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 81 def get_field_deserializers() return { "friendlyName" => lambda {|n| @friendly_name = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "linkLocation" => lambda {|n| @link_location = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, } end |
#link_location ⇒ Object
Gets the linkLocation property value. The linkLocation property
91 92 93 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 91 def link_location return @link_location end |
#link_location=(value) ⇒ Object
Sets the linkLocation property value. The linkLocation property
99 100 101 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 99 def link_location=(value) @link_location = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
107 108 109 110 111 112 |
# File 'lib/drives/item/items/item/workbook/functions/hyperlink/hyperlink_post_request_body.rb', line 107 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("friendlyName", @friendly_name) writer.write_object_value("linkLocation", @link_location) writer.write_additional_data(@additional_data) end |