Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Midb::MidbPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Midb::MidbPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new midbPostRequestBody and sets the default values.
-
#num_bytes ⇒ Object
Gets the numBytes property value.
-
#num_bytes=(value) ⇒ Object
Sets the numBytes property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#start_num ⇒ Object
Gets the startNum property value.
-
#start_num=(value) ⇒ Object
Sets the startNum property value.
-
#text ⇒ Object
Gets the text property value.
-
#text=(value) ⇒ Object
Sets the text property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new midbPostRequestBody and sets the default values.
53 54 55 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 53 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
61 62 63 64 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 61 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MidbPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 38 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
46 47 48 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 46 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
69 70 71 72 73 74 75 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 69 def get_field_deserializers() return { "numBytes" => lambda {|n| @num_bytes = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "startNum" => lambda {|n| @start_num = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "text" => lambda {|n| @text = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, } end |
#num_bytes ⇒ Object
Gets the numBytes property value. The numBytes property
80 81 82 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 80 def num_bytes return @num_bytes end |
#num_bytes=(value) ⇒ Object
Sets the numBytes property value. The numBytes property
88 89 90 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 88 def num_bytes=(value) @num_bytes = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
96 97 98 99 100 101 102 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 96 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("numBytes", @num_bytes) writer.write_object_value("startNum", @start_num) writer.write_object_value("text", @text) writer.write_additional_data(@additional_data) end |
#start_num ⇒ Object
Gets the startNum property value. The startNum property
107 108 109 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 107 def start_num return @start_num end |
#start_num=(value) ⇒ Object
Sets the startNum property value. The startNum property
115 116 117 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 115 def start_num=(value) @start_num = value end |
#text ⇒ Object
Gets the text property value. The text property
122 123 124 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 122 def text return @text end |
#text=(value) ⇒ Object
Sets the text property value. The text property
130 131 132 |
# File 'lib/drives/item/items/item/workbook/functions/midb/midb_post_request_body.rb', line 130 def text=(value) @text = value end |