Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Not_escaped::NotPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Not_escaped::NotPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new notPostRequestBody and sets the default values.
-
#logical ⇒ Object
Gets the logical property value.
-
#logical=(value) ⇒ Object
Sets the logical property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new notPostRequestBody and sets the default values.
47 48 49 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 47 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
55 56 57 58 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 55 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return NotPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
32 33 34 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 32 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
40 41 42 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 40 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
63 64 65 66 67 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 63 def get_field_deserializers() return { "logical" => lambda {|n| @logical = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, } end |
#logical ⇒ Object
Gets the logical property value. The logical property
72 73 74 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 72 def logical return @logical end |
#logical=(value) ⇒ Object
Sets the logical property value. The logical property
80 81 82 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 80 def logical=(value) @logical = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
88 89 90 91 92 |
# File 'lib/drives/item/items/item/workbook/functions/not_escaped/not_post_request_body.rb', line 88 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("logical", @logical) writer.write_additional_data(@additional_data) end |