Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Rank_Avg::RankAvgPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Rank_Avg::RankAvgPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new RankAvgPostRequestBody and sets the default values.
-
#number ⇒ Object
Gets the number property value.
-
#number=(value) ⇒ Object
Sets the number property value.
-
#order ⇒ Object
Gets the order property value.
-
#order=(value) ⇒ Object
Sets the order property value.
-
#ref ⇒ Object
Gets the ref property value.
-
#ref=(value) ⇒ Object
Sets the ref property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new RankAvgPostRequestBody and sets the default values.
53 54 55 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 53 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
61 62 63 64 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 61 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return RankAvgPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 38 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
46 47 48 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 46 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
69 70 71 72 73 74 75 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 69 def get_field_deserializers() return { "number" => lambda {|n| @number = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "order" => lambda {|n| @order = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "ref" => lambda {|n| @ref = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, } end |
#number ⇒ Object
Gets the number property value. The number property
80 81 82 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 80 def number return @number end |
#number=(value) ⇒ Object
Sets the number property value. The number property
88 89 90 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 88 def number=(value) @number = value end |
#order ⇒ Object
Gets the order property value. The order property
95 96 97 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 95 def order return @order end |
#order=(value) ⇒ Object
Sets the order property value. The order property
103 104 105 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 103 def order=(value) @order = value end |
#ref ⇒ Object
Gets the ref property value. The ref property
110 111 112 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 110 def ref return @ref end |
#ref=(value) ⇒ Object
Sets the ref property value. The ref property
118 119 120 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 118 def ref=(value) @ref = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
126 127 128 129 130 131 132 |
# File 'lib/drives/item/items/item/workbook/functions/rank_avg/rank_avg_post_request_body.rb', line 126 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("number", @number) writer.write_object_value("order", @order) writer.write_object_value("ref", @ref) writer.write_additional_data(@additional_data) end |