Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::SeriesSum::SeriesSumPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize ⇒ Object

Instantiates a new seriesSumPostRequestBody and sets the default values.



71
72
73
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 71

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node —

    The parse node to use to read the discriminator value and create the object

Returns:

  • a series_sum_post_request_body

Raises:

  • (StandardError)


79
80
81
82
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 79

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return SeriesSumPostRequestBody.new
end

Instance Method Details

#additional_data ⇒ Object

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



41
42
43
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 41

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value —

    Value to set for the additionalData property.

Returns:

  • a void



49
50
51
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 49

def additional_data=(value)
    @additional_data = value
end

#coefficients ⇒ Object

Gets the coefficients property value. The coefficients property

Returns:

  • a json



56
57
58
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 56

def coefficients
    return @coefficients
end

#coefficients=(value) ⇒ Object

Sets the coefficients property value. The coefficients property

Parameters:

  • value —

    Value to set for the coefficients property.

Returns:

  • a void



64
65
66
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 64

def coefficients=(value)
    @coefficients = value
end

#get_field_deserializers ⇒ Object

The deserialization information for the current model

Returns:

  • a i_dictionary



87
88
89
90
91
92
93
94
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 87

def get_field_deserializers()
    return {
        "coefficients" => lambda {|n| @coefficients = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) },
        "m" => lambda {|n| @m = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) },
        "n" => lambda {|n| @n = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) },
        "x" => lambda {|n| @x = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) },
    }
end

#m ⇒ Object

Gets the m property value. The m property

Returns:

  • a json



99
100
101
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 99

def m
    return @m
end

#m=(value) ⇒ Object

Sets the m property value. The m property

Parameters:

  • value —

    Value to set for the m property.

Returns:

  • a void



107
108
109
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 107

def m=(value)
    @m = value
end

#n ⇒ Object

Gets the n property value. The n property

Returns:

  • a json



114
115
116
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 114

def n
    return @n
end

#n=(value) ⇒ Object

Sets the n property value. The n property

Parameters:

  • value —

    Value to set for the n property.

Returns:

  • a void



122
123
124
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 122

def n=(value)
    @n = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer —

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


130
131
132
133
134
135
136
137
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 130

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_object_value("coefficients", @coefficients)
    writer.write_object_value("m", @m)
    writer.write_object_value("n", @n)
    writer.write_object_value("x", @x)
    writer.write_additional_data(@additional_data)
end

#x ⇒ Object

Gets the x property value. The x property

Returns:

  • a json



142
143
144
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 142

def x
    return @x
end

#x=(value) ⇒ Object

Sets the x property value. The x property

Parameters:

  • value —

    Value to set for the x property.

Returns:

  • a void



150
151
152
# File 'lib/drives/item/items/item/workbook/functions/series_sum/series_sum_post_request_body.rb', line 150

def x=(value)
    @x = value
end