Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Syd::SydPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Syd::SydPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#cost ⇒ Object
Gets the cost property value.
-
#cost=(value) ⇒ Object
Sets the cost property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new sydPostRequestBody and sets the default values.
-
#life ⇒ Object
Gets the life property value.
-
#life=(value) ⇒ Object
Sets the life property value.
-
#per ⇒ Object
Gets the per property value.
-
#per=(value) ⇒ Object
Sets the per property value.
-
#salvage ⇒ Object
Gets the salvage property value.
-
#salvage=(value) ⇒ Object
Sets the salvage property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new sydPostRequestBody and sets the default values.
56 57 58 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 56 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
79 80 81 82 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 79 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SydPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
41 42 43 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 41 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
49 50 51 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 49 def additional_data=(value) @additional_data = value end |
#cost ⇒ Object
Gets the cost property value. The cost property
63 64 65 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 63 def cost return @cost end |
#cost=(value) ⇒ Object
Sets the cost property value. The cost property
71 72 73 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 71 def cost=(value) @cost = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
87 88 89 90 91 92 93 94 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 87 def get_field_deserializers() return { "cost" => lambda {|n| @cost = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "life" => lambda {|n| @life = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "per" => lambda {|n| @per = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "salvage" => lambda {|n| @salvage = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, } end |
#life ⇒ Object
Gets the life property value. The life property
99 100 101 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 99 def life return @life end |
#life=(value) ⇒ Object
Sets the life property value. The life property
107 108 109 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 107 def life=(value) @life = value end |
#per ⇒ Object
Gets the per property value. The per property
114 115 116 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 114 def per return @per end |
#per=(value) ⇒ Object
Sets the per property value. The per property
122 123 124 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 122 def per=(value) @per = value end |
#salvage ⇒ Object
Gets the salvage property value. The salvage property
129 130 131 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 129 def salvage return @salvage end |
#salvage=(value) ⇒ Object
Sets the salvage property value. The salvage property
137 138 139 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 137 def salvage=(value) @salvage = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
145 146 147 148 149 150 151 152 |
# File 'lib/drives/item/items/item/workbook/functions/syd/syd_post_request_body.rb', line 145 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("cost", @cost) writer.write_object_value("life", @life) writer.write_object_value("per", @per) writer.write_object_value("salvage", @salvage) writer.write_additional_data(@additional_data) end |