Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Worksheets::Add::AddRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Drives::Item::Items::Item::Workbook::Worksheets::Add::AddRequestBuilder
- Defined in:
- lib/drives/item/items/item/workbook/worksheets/add/add_request_builder.rb
Overview
Provides operations to call the add method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new AddRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Adds a new worksheet to the workbook.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Adds a new worksheet to the workbook.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new AddRequestBuilder and sets the default values.
31 32 33 |
# File 'lib/drives/item/items/item/workbook/worksheets/add/add_request_builder.rb', line 31 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook/worksheets/add") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Adds a new worksheet to the workbook. The worksheet will be added at the end of existing worksheets. If you wish to activate the newly added worksheet, call .activate() on it.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/drives/item/items/item/workbook/worksheets/add/add_request_builder.rb', line 40 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::WorkbookWorksheet.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Adds a new worksheet to the workbook. The worksheet will be added at the end of existing worksheets. If you wish to activate the newly added worksheet, call .activate() on it.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/drives/item/items/item/workbook/worksheets/add/add_request_builder.rb', line 56 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |