Class: MicrosoftGraph::Drives::Item::List::ListRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Drives::Item::List::ListRequestBuilder
- Defined in:
- lib/drives/item/list/list_request_builder.rb
Overview
Provides operations to manage the list property of the microsoft.graph.drive entity.
Defined Under Namespace
Classes: ListRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#columns ⇒ Object
Provides operations to manage the columns property of the microsoft.graph.list entity.
-
#content_types ⇒ Object
Provides operations to manage the contentTypes property of the microsoft.graph.list entity.
-
#created_by_user ⇒ Object
Provides operations to manage the createdByUser property of the microsoft.graph.baseItem entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property list for drives.
-
#drive ⇒ Object
Provides operations to manage the drive property of the microsoft.graph.list entity.
-
#get(request_configuration = nil) ⇒ Object
For drives in SharePoint, the underlying document library list.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ListRequestBuilder and sets the default values.
-
#items ⇒ Object
Provides operations to manage the items property of the microsoft.graph.list entity.
-
#last_modified_by_user ⇒ Object
Provides operations to manage the lastModifiedByUser property of the microsoft.graph.baseItem entity.
-
#operations ⇒ Object
Provides operations to manage the operations property of the microsoft.graph.list entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property list in drives.
-
#subscriptions ⇒ Object
Provides operations to manage the subscriptions property of the microsoft.graph.list entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property list for drives.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
For drives in SharePoint, the underlying document library list.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property list in drives.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ListRequestBuilder and sets the default values.
71 72 73 |
# File 'lib/drives/item/list/list_request_builder.rb', line 71 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/drives/{drive%2Did}/list{?%24select,%24expand}") end |
Instance Method Details
#columns ⇒ Object
Provides operations to manage the columns property of the microsoft.graph.list entity.
27 28 29 |
# File 'lib/drives/item/list/list_request_builder.rb', line 27 def columns() return MicrosoftGraph::Drives::Item::List::Columns::ColumnsRequestBuilder.new(@path_parameters, @request_adapter) end |
#content_types ⇒ Object
Provides operations to manage the contentTypes property of the microsoft.graph.list entity.
32 33 34 |
# File 'lib/drives/item/list/list_request_builder.rb', line 32 def content_types() return MicrosoftGraph::Drives::Item::List::ContentTypes::ContentTypesRequestBuilder.new(@path_parameters, @request_adapter) end |
#created_by_user ⇒ Object
Provides operations to manage the createdByUser property of the microsoft.graph.baseItem entity.
37 38 39 |
# File 'lib/drives/item/list/list_request_builder.rb', line 37 def created_by_user() return MicrosoftGraph::Drives::Item::List::CreatedByUser::CreatedByUserRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property list for drives
79 80 81 82 83 84 85 86 87 |
# File 'lib/drives/item/list/list_request_builder.rb', line 79 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#drive ⇒ Object
Provides operations to manage the drive property of the microsoft.graph.list entity.
42 43 44 |
# File 'lib/drives/item/list/list_request_builder.rb', line 42 def drive() return MicrosoftGraph::Drives::Item::List::Drive::DriveRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
For drives in SharePoint, the underlying document library list. Read-only. Nullable.
93 94 95 96 97 98 99 100 101 |
# File 'lib/drives/item/list/list_request_builder.rb', line 93 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::List.create_from_discriminator_value(pn) }, error_mapping) end |
#items ⇒ Object
Provides operations to manage the items property of the microsoft.graph.list entity.
47 48 49 |
# File 'lib/drives/item/list/list_request_builder.rb', line 47 def items() return MicrosoftGraph::Drives::Item::List::Items::ItemsRequestBuilder.new(@path_parameters, @request_adapter) end |
#last_modified_by_user ⇒ Object
Provides operations to manage the lastModifiedByUser property of the microsoft.graph.baseItem entity.
52 53 54 |
# File 'lib/drives/item/list/list_request_builder.rb', line 52 def last_modified_by_user() return MicrosoftGraph::Drives::Item::List::LastModifiedByUser::LastModifiedByUserRequestBuilder.new(@path_parameters, @request_adapter) end |
#operations ⇒ Object
Provides operations to manage the operations property of the microsoft.graph.list entity.
57 58 59 |
# File 'lib/drives/item/list/list_request_builder.rb', line 57 def operations() return MicrosoftGraph::Drives::Item::List::Operations::OperationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property list in drives
108 109 110 111 112 113 114 115 116 117 |
# File 'lib/drives/item/list/list_request_builder.rb', line 108 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::List.create_from_discriminator_value(pn) }, error_mapping) end |
#subscriptions ⇒ Object
Provides operations to manage the subscriptions property of the microsoft.graph.list entity.
62 63 64 |
# File 'lib/drives/item/list/list_request_builder.rb', line 62 def subscriptions() return MicrosoftGraph::Drives::Item::List::Subscriptions::SubscriptionsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property list for drives
123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/drives/item/list/list_request_builder.rb', line 123 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
For drives in SharePoint, the underlying document library list. Read-only. Nullable.
139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/drives/item/list/list_request_builder.rb', line 139 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property list in drives
158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/drives/item/list/list_request_builder.rb', line 158 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |