Class: MicrosoftGraph::Drives::Item::Root::RootRequestBuilder::RootRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/drives/item/root/root_request_builder.rb

Overview

Retrieve the metadata for a driveItem in a drive by file system path or ID.item-id is the ID of a driveItem. It may also be the unique ID of a SharePoint list item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



71
72
73
# File 'lib/drives/item/root/root_request_builder.rb', line 71

def expand
  @expand
end

#selectObject

Select properties to be returned



74
75
76
# File 'lib/drives/item/root/root_request_builder.rb', line 74

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • The original query parameter name in the class.

Returns:

  • a string

Raises:



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/drives/item/root/root_request_builder.rb', line 80

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end