Class: MicrosoftGraph::Education::Classes::Item::EducationClassItemRequestBuilder::EducationClassItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/education/classes/item/education_class_item_request_builder.rb

Overview

Retrieve a class from the system. A class is a universal group with a special property that indicates to the system that the group is a class. Group members represent the students; group admins represent the teachers in the class. If you're using the delegated token, the user will only see classes in which they are members.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



179
180
181
# File 'lib/education/classes/item/education_class_item_request_builder.rb', line 179

def expand
  @expand
end

#selectObject

Select properties to be returned



182
183
184
# File 'lib/education/classes/item/education_class_item_request_builder.rb', line 182

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


188
189
190
191
192
193
194
195
196
197
198
# File 'lib/education/classes/item/education_class_item_request_builder.rb', line 188

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end