Class: MicrosoftGraph::Education::Me::Assignments::Item::Rubric::RubricRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/education/me/assignments/item/rubric/rubric_request_builder.rb

Overview

Provides operations to manage the rubric property of the microsoft.graph.educationAssignment entity.

Defined Under Namespace

Classes: RubricRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new RubricRequestBuilder and sets the default values.

Parameters:

  • path_parameters —

    Path parameters for the request

  • request_adapter —

    The request adapter to use to execute the requests.



33
34
35
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 33

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/education/me/assignments/{educationAssignment%2Did}/rubric{?%24select,%24expand}")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

Remove an educationRubric from an educationAssignment. This method does not delete the rubric itself and can only be performed by teachers.

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



41
42
43
44
45
46
47
48
49
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 41

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Get the educationRubric object attached to an educationAssignment, if one exists. Only teachers, students, and applications with application permissions can perform this operation.

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of education_rubric



55
56
57
58
59
60
61
62
63
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 55

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EducationRubric.create_from_discriminator_value(pn) }, error_mapping)
end

#patch(body, request_configuration = nil) ⇒ Object

Attach an existing educationRubric object to an educationAssignment. Only teachers can perform this operation.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of education_rubric

Raises:

  • (StandardError)


70
71
72
73
74
75
76
77
78
79
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 70

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EducationRubric.create_from_discriminator_value(pn) }, error_mapping)
end

#ref ⇒ Object

Provides operations to manage the collection of educationRoot entities.



24
25
26
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 24

def ref()
    return MicrosoftGraph::Education::Me::Assignments::Item::Rubric::Ref::RefRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Remove an educationRubric from an educationAssignment. This method does not delete the rubric itself and can only be performed by teachers.

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 85

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get the educationRubric object attached to an educationAssignment, if one exists. Only teachers, students, and applications with application permissions can perform this operation.

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 101

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Attach an existing educationRubric object to an educationAssignment. Only teachers can perform this operation.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/education/me/assignments/item/rubric/rubric_request_builder.rb', line 120

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end