Class: MicrosoftGraph::Education::Me::MeRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Education::Me::MeRequestBuilder
- Defined in:
- lib/education/me/me_request_builder.rb
Overview
Provides operations to manage the me property of the microsoft.graph.educationRoot entity.
Defined Under Namespace
Classes: MeRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#assignments ⇒ Object
Provides operations to manage the assignments property of the microsoft.graph.educationUser entity.
-
#classes ⇒ Object
Provides operations to manage the classes property of the microsoft.graph.educationUser entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property me for education.
-
#get(request_configuration = nil) ⇒ Object
Get me from education.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MeRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property me in education.
-
#rubrics ⇒ Object
Provides operations to manage the rubrics property of the microsoft.graph.educationUser entity.
-
#schools ⇒ Object
Provides operations to manage the schools property of the microsoft.graph.educationUser entity.
-
#taught_classes ⇒ Object
Provides operations to manage the taughtClasses property of the microsoft.graph.educationUser entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property me for education.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get me from education.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property me in education.
-
#user ⇒ Object
Provides operations to manage the user property of the microsoft.graph.educationUser entity.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MeRequestBuilder and sets the default values.
57 58 59 |
# File 'lib/education/me/me_request_builder.rb', line 57 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/education/me{?%24select,%24expand}") end |
Instance Method Details
#assignments ⇒ Object
Provides operations to manage the assignments property of the microsoft.graph.educationUser entity.
23 24 25 |
# File 'lib/education/me/me_request_builder.rb', line 23 def assignments() return MicrosoftGraph::Education::Me::Assignments::AssignmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#classes ⇒ Object
Provides operations to manage the classes property of the microsoft.graph.educationUser entity.
28 29 30 |
# File 'lib/education/me/me_request_builder.rb', line 28 def classes() return MicrosoftGraph::Education::Me::Classes::ClassesRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property me for education
65 66 67 68 69 70 71 72 73 |
# File 'lib/education/me/me_request_builder.rb', line 65 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Get me from education
79 80 81 82 83 84 85 86 87 |
# File 'lib/education/me/me_request_builder.rb', line 79 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EducationUser.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property me in education
94 95 96 97 98 99 100 101 102 103 |
# File 'lib/education/me/me_request_builder.rb', line 94 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EducationUser.create_from_discriminator_value(pn) }, error_mapping) end |
#rubrics ⇒ Object
Provides operations to manage the rubrics property of the microsoft.graph.educationUser entity.
33 34 35 |
# File 'lib/education/me/me_request_builder.rb', line 33 def rubrics() return MicrosoftGraph::Education::Me::Rubrics::RubricsRequestBuilder.new(@path_parameters, @request_adapter) end |
#schools ⇒ Object
Provides operations to manage the schools property of the microsoft.graph.educationUser entity.
38 39 40 |
# File 'lib/education/me/me_request_builder.rb', line 38 def schools() return MicrosoftGraph::Education::Me::Schools::SchoolsRequestBuilder.new(@path_parameters, @request_adapter) end |
#taught_classes ⇒ Object
Provides operations to manage the taughtClasses property of the microsoft.graph.educationUser entity.
43 44 45 |
# File 'lib/education/me/me_request_builder.rb', line 43 def taught_classes() return MicrosoftGraph::Education::Me::TaughtClasses::TaughtClassesRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property me for education
109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/education/me/me_request_builder.rb', line 109 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get me from education
125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/education/me/me_request_builder.rb', line 125 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property me in education
144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/education/me/me_request_builder.rb', line 144 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |
#user ⇒ Object
Provides operations to manage the user property of the microsoft.graph.educationUser entity.
48 49 50 |
# File 'lib/education/me/me_request_builder.rb', line 48 def user() return MicrosoftGraph::Education::Me::User::UserRequestBuilder.new(@path_parameters, @request_adapter) end |