Class: MicrosoftGraph::Education::Users::Item::Assignments::Item::Rubric::Ref::RefRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb

Overview

Provides operations to manage the collection of educationRoot entities.

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new RefRequestBuilder and sets the default values.



31
32
33
# File 'lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb', line 31

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/education/users/{educationUser%2Did}/assignments/{educationAssignment%2Did}/rubric/$ref")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

Remove an educationRubric from an educationAssignment. This method does not delete the rubric itself and can only be performed by teachers.



39
40
41
42
43
44
45
46
47
# File 'lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb', line 39

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Get the educationRubric object attached to an educationAssignment, if one exists. Only teachers, students, and applications with application permissions can perform this operation.



53
54
55
56
57
58
59
60
61
# File 'lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb', line 53

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, string, error_mapping)
end

#put(body, request_configuration = nil) ⇒ Object

Attach an existing educationRubric object to an educationAssignment. Only teachers can perform this operation.

Raises:

  • (StandardError)


68
69
70
71
72
73
74
75
76
77
# File 'lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb', line 68

def put(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_put_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Remove an educationRubric from an educationAssignment. This method does not delete the rubric itself and can only be performed by teachers.



83
84
85
86
87
88
89
90
91
92
93
# File 'lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb', line 83

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get the educationRubric object attached to an educationAssignment, if one exists. Only teachers, students, and applications with application permissions can perform this operation.



99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb', line 99

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_put_request_information(body, request_configuration = nil) ⇒ Object

Attach an existing educationRubric object to an educationAssignment. Only teachers can perform this operation.

Raises:

  • (StandardError)


117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/education/users/item/assignments/item/rubric/ref/ref_request_builder.rb', line 117

def to_put_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PUT
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end