Class: MicrosoftGraph::Groups::Item::Calendar::CalendarRequestBuilder::CalendarRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Groups::Item::Calendar::CalendarRequestBuilder::CalendarRequestBuilderGetQueryParameters
- Defined in:
- lib/groups/item/calendar/calendar_request_builder.rb
Overview
The group’s calendar. Read-only.
Instance Attribute Summary collapse
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#select ⇒ Object
Select properties to be returned
99 100 101 |
# File 'lib/groups/item/calendar/calendar_request_builder.rb', line 99 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
105 106 107 108 109 110 111 112 113 |
# File 'lib/groups/item/calendar/calendar_request_builder.rb', line 105 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "select" return "%24select" else return original_name end end |