Class: MicrosoftGraph::Groups::Item::CalendarView::Item::Attachments::Item::AttachmentItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::CalendarView::Item::Attachments::Item::AttachmentItemRequestBuilder
- Defined in:
- lib/groups/item/calendar_view/item/attachments/item/attachment_item_request_builder.rb
Overview
Provides operations to manage the attachments property of the microsoft.graph.event entity.
Defined Under Namespace
Classes: AttachmentItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete an attachment from a user calendar event, mail message, or group post.
-
#get(request_configuration = nil) ⇒ Object
The collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new AttachmentItemRequestBuilder and sets the default values.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete an attachment from a user calendar event, mail message, or group post.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
The collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new AttachmentItemRequestBuilder and sets the default values.
29 30 31 |
# File 'lib/groups/item/calendar_view/item/attachments/item/attachment_item_request_builder.rb', line 29 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/calendarView/{event%2Did}/attachments/{attachment%2Did}{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete an attachment from a user calendar event, mail message, or group post.
37 38 39 40 41 42 43 44 45 |
# File 'lib/groups/item/calendar_view/item/attachments/item/attachment_item_request_builder.rb', line 37 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
The collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
51 52 53 54 55 56 57 58 59 |
# File 'lib/groups/item/calendar_view/item/attachments/item/attachment_item_request_builder.rb', line 51 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Attachment.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete an attachment from a user calendar event, mail message, or group post.
65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/groups/item/calendar_view/item/attachments/item/attachment_item_request_builder.rb', line 65 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
The collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/groups/item/calendar_view/item/attachments/item/attachment_item_request_builder.rb', line 81 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |