Class: MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::EventItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::EventItemRequestBuilder
- Defined in:
- lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb
Overview
Provides operations to manage the instances property of the microsoft.graph.event entity.
Defined Under Namespace
Classes: EventItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#accept ⇒ Object
Provides operations to call the accept method.
-
#attachments ⇒ Object
Provides operations to manage the attachments property of the microsoft.graph.event entity.
-
#calendar ⇒ Object
Provides operations to manage the calendar property of the microsoft.graph.event entity.
-
#cancel ⇒ Object
Provides operations to call the cancel method.
-
#decline ⇒ Object
Provides operations to call the decline method.
-
#dismiss_reminder ⇒ Object
Provides operations to call the dismissReminder method.
-
#extensions ⇒ Object
Provides operations to manage the extensions property of the microsoft.graph.event entity.
-
#forward ⇒ Object
Provides operations to call the forward method.
-
#get(request_configuration = nil) ⇒ Object
The occurrences of a recurring series, if the event is a series master.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new EventItemRequestBuilder and sets the default values.
-
#snooze_reminder ⇒ Object
Provides operations to call the snoozeReminder method.
-
#tentatively_accept ⇒ Object
Provides operations to call the tentativelyAccept method.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
The occurrences of a recurring series, if the event is a series master.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new EventItemRequestBuilder and sets the default values.
89 90 91 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 89 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/calendarView/{event%2Did}/instances/{event%2Did1}{?startDateTime*,endDateTime*,%24select}") end |
Instance Method Details
#accept ⇒ Object
Provides operations to call the accept method.
35 36 37 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 35 def accept() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::Accept::AcceptRequestBuilder.new(@path_parameters, @request_adapter) end |
#attachments ⇒ Object
Provides operations to manage the attachments property of the microsoft.graph.event entity.
40 41 42 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 40 def () return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::Attachments::AttachmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#calendar ⇒ Object
Provides operations to manage the calendar property of the microsoft.graph.event entity.
45 46 47 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 45 def calendar() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::Calendar::CalendarRequestBuilder.new(@path_parameters, @request_adapter) end |
#cancel ⇒ Object
Provides operations to call the cancel method.
50 51 52 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 50 def cancel() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::Cancel::CancelRequestBuilder.new(@path_parameters, @request_adapter) end |
#decline ⇒ Object
Provides operations to call the decline method.
55 56 57 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 55 def decline() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::Decline::DeclineRequestBuilder.new(@path_parameters, @request_adapter) end |
#dismiss_reminder ⇒ Object
Provides operations to call the dismissReminder method.
60 61 62 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 60 def dismiss_reminder() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::DismissReminder::DismissReminderRequestBuilder.new(@path_parameters, @request_adapter) end |
#extensions ⇒ Object
Provides operations to manage the extensions property of the microsoft.graph.event entity.
65 66 67 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 65 def extensions() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::Extensions::ExtensionsRequestBuilder.new(@path_parameters, @request_adapter) end |
#forward ⇒ Object
Provides operations to call the forward method.
70 71 72 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 70 def forward() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::Forward::ForwardRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.
97 98 99 100 101 102 103 104 105 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 97 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Event.create_from_discriminator_value(pn) }, error_mapping) end |
#snooze_reminder ⇒ Object
Provides operations to call the snoozeReminder method.
75 76 77 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 75 def snooze_reminder() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::SnoozeReminder::SnoozeReminderRequestBuilder.new(@path_parameters, @request_adapter) end |
#tentatively_accept ⇒ Object
Provides operations to call the tentativelyAccept method.
80 81 82 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 80 def tentatively_accept() return MicrosoftGraph::Groups::Item::CalendarView::Item::Instances::Item::TentativelyAccept::TentativelyAcceptRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.
111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/groups/item/calendar_view/item/instances/item/event_item_request_builder.rb', line 111 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |