Class: MicrosoftGraph::Groups::Item::Onenote::Notebooks::GetRecentNotebooksWithIncludePersonalNotebooks::GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilder::GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Groups::Item::Onenote::Notebooks::GetRecentNotebooksWithIncludePersonalNotebooks::GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilder::GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilderGetQueryParameters
- Defined in:
- lib/groups/item/onenote/notebooks/get_recent_notebooks_with_include_personal_notebooks/get_recent_notebooks_with_include_personal_notebooks_request_builder.rb
Overview
Invoke function getRecentNotebooks
Instance Attribute Summary collapse
-
#count ⇒ Object
Include count of items.
-
#filter ⇒ Object
Filter items by property values.
-
#search ⇒ Object
Search items by search phrases.
-
#skip ⇒ Object
Skip the first n items.
-
#top ⇒ Object
Show only the first n items.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#count ⇒ Object
Include count of items
69 70 71 |
# File 'lib/groups/item/onenote/notebooks/get_recent_notebooks_with_include_personal_notebooks/get_recent_notebooks_with_include_personal_notebooks_request_builder.rb', line 69 def count @count end |
#filter ⇒ Object
Filter items by property values
72 73 74 |
# File 'lib/groups/item/onenote/notebooks/get_recent_notebooks_with_include_personal_notebooks/get_recent_notebooks_with_include_personal_notebooks_request_builder.rb', line 72 def filter @filter end |
#search ⇒ Object
Search items by search phrases
75 76 77 |
# File 'lib/groups/item/onenote/notebooks/get_recent_notebooks_with_include_personal_notebooks/get_recent_notebooks_with_include_personal_notebooks_request_builder.rb', line 75 def search @search end |
#skip ⇒ Object
Skip the first n items
78 79 80 |
# File 'lib/groups/item/onenote/notebooks/get_recent_notebooks_with_include_personal_notebooks/get_recent_notebooks_with_include_personal_notebooks_request_builder.rb', line 78 def skip @skip end |
#top ⇒ Object
Show only the first n items
81 82 83 |
# File 'lib/groups/item/onenote/notebooks/get_recent_notebooks_with_include_personal_notebooks/get_recent_notebooks_with_include_personal_notebooks_request_builder.rb', line 81 def top @top end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/groups/item/onenote/notebooks/get_recent_notebooks_with_include_personal_notebooks/get_recent_notebooks_with_include_personal_notebooks_request_builder.rb', line 87 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "count" return "%24count" when "filter" return "%24filter" when "search" return "%24search" when "skip" return "%24skip" when "top" return "%24top" else return original_name end end |