Class: MicrosoftGraph::Groups::Item::Owners::OwnersRequestBuilder::OwnersRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/groups/item/owners/owners_request_builder.rb

Overview

The owners of the group. Limited to 100 owners. Nullable. If this property is not specified when creating a Microsoft 365 group, the calling user is automatically assigned as the group owner. Supports $filter (/$count eq 0, /$count ne 0, /$count eq 1, /$count ne 1). Supports $expand including nested $select. For example, /groups?$filter=startsWith(displayName,‘Role’)&$select=id,displayName&$expand=owners($select=id,userPrincipalName,displayName).

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



125
126
127
# File 'lib/groups/item/owners/owners_request_builder.rb', line 125

def count
  @count
end

#expandObject

Expand related entities



128
129
130
# File 'lib/groups/item/owners/owners_request_builder.rb', line 128

def expand
  @expand
end

#filterObject

Filter items by property values



131
132
133
# File 'lib/groups/item/owners/owners_request_builder.rb', line 131

def filter
  @filter
end

#orderbyObject

Order items by property values



134
135
136
# File 'lib/groups/item/owners/owners_request_builder.rb', line 134

def orderby
  @orderby
end

#searchObject

Search items by search phrases



137
138
139
# File 'lib/groups/item/owners/owners_request_builder.rb', line 137

def search
  @search
end

#selectObject

Select properties to be returned



140
141
142
# File 'lib/groups/item/owners/owners_request_builder.rb', line 140

def select
  @select
end

#skipObject

Skip the first n items



143
144
145
# File 'lib/groups/item/owners/owners_request_builder.rb', line 143

def skip
  @skip
end

#topObject

Show only the first n items



146
147
148
# File 'lib/groups/item/owners/owners_request_builder.rb', line 146

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/groups/item/owners/owners_request_builder.rb', line 152

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "expand"
            return "%24expand"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "search"
            return "%24search"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "top"
            return "%24top"
        else
            return original_name
    end
end