Class: MicrosoftGraph::Groups::Item::Owners::Ref::RefRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::Owners::Ref::RefRequestBuilder
- Defined in:
- lib/groups/item/owners/ref/ref_request_builder.rb
Overview
Provides operations to manage the collection of group entities.
Defined Under Namespace
Classes: RefRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
The owners of the group.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RefRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Add a user or service principal to a Microsoft 365 or security group’s owners.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
The owners of the group.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Add a user or service principal to a Microsoft 365 or security group’s owners.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RefRequestBuilder and sets the default values.
26 27 28 |
# File 'lib/groups/item/owners/ref/ref_request_builder.rb', line 26 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/owners/$ref{?%24top,%24skip,%24search,%24filter,%24count,%24orderby}") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
The owners of the group. Limited to 100 owners. Nullable. If this property is not specified when creating a Microsoft 365 group, the calling user is automatically assigned as the group owner. Supports $filter (/$count eq 0, /$count ne 0, /$count eq 1, /$count ne 1). Supports $expand including nested $select. For example, /groups?$filter=startsWith(displayName,‘Role’)&$select=id,displayName&$expand=owners($select=id,userPrincipalName,displayName).
34 35 36 37 38 39 40 41 42 |
# File 'lib/groups/item/owners/ref/ref_request_builder.rb', line 34 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::StringCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Add a user or service principal to a Microsoft 365 or security group’s owners. The owners are a set of users or service principals who are allowed to modify the group object.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/groups/item/owners/ref/ref_request_builder.rb', line 49 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
The owners of the group. Limited to 100 owners. Nullable. If this property is not specified when creating a Microsoft 365 group, the calling user is automatically assigned as the group owner. Supports $filter (/$count eq 0, /$count ne 0, /$count eq 1, /$count ne 1). Supports $expand including nested $select. For example, /groups?$filter=startsWith(displayName,‘Role’)&$select=id,displayName&$expand=owners($select=id,userPrincipalName,displayName).
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/groups/item/owners/ref/ref_request_builder.rb', line 64 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Add a user or service principal to a Microsoft 365 or security group’s owners. The owners are a set of users or service principals who are allowed to modify the group object.
83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/groups/item/owners/ref/ref_request_builder.rb', line 83 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |