Class: MicrosoftGraph::Groups::Item::RejectedSenders::Ref::RefRequestBuilder::RefRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/groups/item/rejected_senders/ref/ref_request_builder.rb

Overview

Users in the rejected senders list cannot post to conversations of the group (identified in the GET request URL). Make sure you do not specify the same user or group in the rejected senders and accepted senders lists, otherwise you will get an error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



103
104
105
# File 'lib/groups/item/rejected_senders/ref/ref_request_builder.rb', line 103

def count
  @count
end

#filterObject

Filter items by property values



106
107
108
# File 'lib/groups/item/rejected_senders/ref/ref_request_builder.rb', line 106

def filter
  @filter
end

#orderbyObject

Order items by property values



109
110
111
# File 'lib/groups/item/rejected_senders/ref/ref_request_builder.rb', line 109

def orderby
  @orderby
end

#skipObject

Skip the first n items



112
113
114
# File 'lib/groups/item/rejected_senders/ref/ref_request_builder.rb', line 112

def skip
  @skip
end

#topObject

Show only the first n items



115
116
117
# File 'lib/groups/item/rejected_senders/ref/ref_request_builder.rb', line 115

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Raises:

  • (StandardError)


121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/groups/item/rejected_senders/ref/ref_request_builder.rb', line 121

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "skip"
            return "%24skip"
        when "top"
            return "%24top"
        else
            return original_name
    end
end