Class: MicrosoftGraph::Groups::Item::Sites::SitesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::Sites::SitesRequestBuilder
- Defined in:
- lib/groups/item/sites/sites_request_builder.rb
Overview
Provides operations to manage the sites property of the microsoft.graph.group entity.
Defined Under Namespace
Classes: SitesRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#add ⇒ Object
Provides operations to call the add method.
-
#by_site_id(site_id) ⇒ Object
Provides operations to manage the sites property of the microsoft.graph.group entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
The list of SharePoint sites in this group.
-
#get_all_sites ⇒ Object
Provides operations to call the getAllSites method.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new SitesRequestBuilder and sets the default values.
-
#remove ⇒ Object
Provides operations to call the remove method.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
The list of SharePoint sites in this group.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new SitesRequestBuilder and sets the default values.
59 60 61 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 59 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/sites{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#add ⇒ Object
Provides operations to call the add method.
24 25 26 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 24 def add() return MicrosoftGraph::Groups::Item::Sites::Add::AddRequestBuilder.new(@path_parameters, @request_adapter) end |
#by_site_id(site_id) ⇒ Object
Provides operations to manage the sites property of the microsoft.graph.group entity.
47 48 49 50 51 52 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 47 def by_site_id(site_id) raise StandardError, 'site_id cannot be null' if site_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["site%2Did"] = site_id return MicrosoftGraph::Groups::Item::Sites::Item::SiteItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
29 30 31 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 29 def count() return MicrosoftGraph::Groups::Item::Sites::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
The list of SharePoint sites in this group. Access the default site with /sites/root.
67 68 69 70 71 72 73 74 75 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 67 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SiteCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#get_all_sites ⇒ Object
Provides operations to call the getAllSites method.
34 35 36 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 34 def get_all_sites() return MicrosoftGraph::Groups::Item::Sites::GetAllSites::GetAllSitesRequestBuilder.new(@path_parameters, @request_adapter) end |
#remove ⇒ Object
Provides operations to call the remove method.
39 40 41 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 39 def remove() return MicrosoftGraph::Groups::Item::Sites::Remove::RemoveRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
The list of SharePoint sites in this group. Access the default site with /sites/root.
81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/groups/item/sites/sites_request_builder.rb', line 81 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |