Class: MicrosoftGraph::Groups::Item::SubscribeByMail::SubscribeByMailRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::SubscribeByMail::SubscribeByMailRequestBuilder
- Defined in:
- lib/groups/item/subscribe_by_mail/subscribe_by_mail_request_builder.rb
Overview
Provides operations to call the subscribeByMail method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new SubscribeByMailRequestBuilder and sets the default values.
-
#post(request_configuration = nil) ⇒ Object
Calling this method will enable the current user to receive email notifications for this group, about new posts, events, and files in that group.
-
#to_post_request_information(request_configuration = nil) ⇒ Object
Calling this method will enable the current user to receive email notifications for this group, about new posts, events, and files in that group.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new SubscribeByMailRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/groups/item/subscribe_by_mail/subscribe_by_mail_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/subscribeByMail") end |
Instance Method Details
#post(request_configuration = nil) ⇒ Object
Calling this method will enable the current user to receive email notifications for this group, about new posts, events, and files in that group. Supported for Microsoft 365 groups only.
30 31 32 33 34 35 36 37 38 |
# File 'lib/groups/item/subscribe_by_mail/subscribe_by_mail_request_builder.rb', line 30 def post(request_configuration=nil) request_info = self.to_post_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(request_configuration = nil) ⇒ Object
Calling this method will enable the current user to receive email notifications for this group, about new posts, events, and files in that group. Supported for Microsoft 365 groups only.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/groups/item/subscribe_by_mail/subscribe_by_mail_request_builder.rb', line 44 def to_post_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |