Class: MicrosoftGraph::Groups::Item::Team::Members::MembersRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::Team::Members::MembersRequestBuilder
- Defined in:
- lib/groups/item/team/members/members_request_builder.rb
Overview
Provides operations to manage the members property of the microsoft.graph.team entity.
Defined Under Namespace
Classes: MembersRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#add ⇒ Object
Provides operations to call the add method.
-
#by_conversation_member_id(conversation_member_id) ⇒ Object
Provides operations to manage the members property of the microsoft.graph.team entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get the conversationMember collection of a team.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MembersRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Add a new conversationMember to a team.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the conversationMember collection of a team.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Add a new conversationMember to a team.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MembersRequestBuilder and sets the default values.
50 51 52 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 50 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/team/members{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#add ⇒ Object
Provides operations to call the add method.
25 26 27 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 25 def add() return MicrosoftGraph::Groups::Item::Team::Members::Add::AddRequestBuilder.new(@path_parameters, @request_adapter) end |
#by_conversation_member_id(conversation_member_id) ⇒ Object
Provides operations to manage the members property of the microsoft.graph.team entity.
38 39 40 41 42 43 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 38 def by_conversation_member_id(conversation_member_id) raise StandardError, 'conversation_member_id cannot be null' if conversation_member_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["conversationMember%2Did"] = conversation_member_id return MicrosoftGraph::Groups::Item::Team::Members::Item::ConversationMemberItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
30 31 32 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 30 def count() return MicrosoftGraph::Groups::Item::Team::Members::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get the conversationMember collection of a team.
58 59 60 61 62 63 64 65 66 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 58 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConversationMemberCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Add a new conversationMember to a team.
73 74 75 76 77 78 79 80 81 82 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 73 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConversationMember.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the conversationMember collection of a team.
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 88 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Add a new conversationMember to a team.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/groups/item/team/members/members_request_builder.rb', line 107 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |