Class: MicrosoftGraph::Groups::Item::Team::PrimaryChannel::Members::MembersRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/groups/item/team/primary_channel/members/members_request_builder.rb

Overview

Provides operations to manage the members property of the microsoft.graph.channel entity.

Defined Under Namespace

Classes: MembersRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new MembersRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



52
53
54
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 52

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/team/primaryChannel/members{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#addObject

Provides operations to call the add method.



27
28
29
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 27

def add()
    return MicrosoftGraph::Groups::Item::Team::PrimaryChannel::Members::Add::AddRequestBuilder.new(@path_parameters, @request_adapter)
end

#by_conversation_member_id(conversation_member_id) ⇒ Object

Provides operations to manage the members property of the microsoft.graph.channel entity.

Parameters:

  • The unique identifier of conversationMember

Returns:

  • a conversation_member_item_request_builder

Raises:



40
41
42
43
44
45
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 40

def by_conversation_member_id(conversation_member_id)
    raise StandardError, 'conversation_member_id cannot be null' if conversation_member_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["conversationMember%2Did"] = conversation_member_id
    return MicrosoftGraph::Groups::Item::Team::PrimaryChannel::Members::Item::ConversationMemberItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



32
33
34
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 32

def count()
    return MicrosoftGraph::Groups::Item::Team::PrimaryChannel::Members::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve a list of conversationMembers from a channel. This method supports federation. Only a user who is a member of the shared channel can retrieve the channel member list.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of conversation_member_collection_response



60
61
62
63
64
65
66
67
68
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 60

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConversationMemberCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Add a conversationMember to a channel. This operation is allowed only for channels with a membershipType value of private or shared.

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of conversation_member

Raises:



75
76
77
78
79
80
81
82
83
84
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 75

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConversationMember.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve a list of conversationMembers from a channel. This method supports federation. Only a user who is a member of the shared channel can retrieve the channel member list.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 90

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Add a conversationMember to a channel. This operation is allowed only for channels with a membershipType value of private or shared.

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:



109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/groups/item/team/primary_channel/members/members_request_builder.rb', line 109

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end