Class: MicrosoftGraph::Groups::Item::Team::Schedule::OfferShiftRequests::OfferShiftRequestsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::Team::Schedule::OfferShiftRequests::OfferShiftRequestsRequestBuilder
- Defined in:
- lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb
Overview
Provides operations to manage the offerShiftRequests property of the microsoft.graph.schedule entity.
Defined Under Namespace
Classes: OfferShiftRequestsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_offer_shift_request_id(offer_shift_request_id) ⇒ Object
Provides operations to manage the offerShiftRequests property of the microsoft.graph.schedule entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of all offerShiftRequest objects in a team.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new OfferShiftRequestsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create an instance of an offerShiftRequest.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of all offerShiftRequest objects in a team.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create an instance of an offerShiftRequest.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new OfferShiftRequestsRequestBuilder and sets the default values.
46 47 48 |
# File 'lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb', line 46 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/team/schedule/offerShiftRequests{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_offer_shift_request_id(offer_shift_request_id) ⇒ Object
Provides operations to manage the offerShiftRequests property of the microsoft.graph.schedule entity.
34 35 36 37 38 39 |
# File 'lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb', line 34 def by_offer_shift_request_id(offer_shift_request_id) raise StandardError, 'offer_shift_request_id cannot be null' if offer_shift_request_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["offerShiftRequest%2Did"] = offer_shift_request_id return MicrosoftGraph::Groups::Item::Team::Schedule::OfferShiftRequests::Item::OfferShiftRequestItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
26 27 28 |
# File 'lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb', line 26 def count() return MicrosoftGraph::Groups::Item::Team::Schedule::OfferShiftRequests::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of all offerShiftRequest objects in a team.
54 55 56 57 58 59 60 61 62 |
# File 'lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb', line 54 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OfferShiftRequestCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create an instance of an offerShiftRequest.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb', line 69 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OfferShiftRequest.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of all offerShiftRequest objects in a team.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb', line 84 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create an instance of an offerShiftRequest.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/groups/item/team/schedule/offer_shift_requests/offer_shift_requests_request_builder.rb', line 103 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |