Class: MicrosoftGraph::Groups::Item::Threads::Item::Posts::PostsRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/groups/item/threads/item/posts/posts_request_builder.rb

Overview

Provides operations to manage the posts property of the microsoft.graph.conversationThread entity.

Defined Under Namespace

Classes: PostsRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new PostsRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



45
46
47
# File 'lib/groups/item/threads/item/posts/posts_request_builder.rb', line 45

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/threads/{conversationThread%2Did}/posts{?%24top,%24skip,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_post_id(post_id) ⇒ Object

Provides operations to manage the posts property of the microsoft.graph.conversationThread entity.

Parameters:

  • The unique identifier of post

Returns:

  • a post_item_request_builder

Raises:



33
34
35
36
37
38
# File 'lib/groups/item/threads/item/posts/posts_request_builder.rb', line 33

def by_post_id(post_id)
    raise StandardError, 'post_id cannot be null' if post_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["post%2Did"] = post_id
    return MicrosoftGraph::Groups::Item::Threads::Item::Posts::Item::PostItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



25
26
27
# File 'lib/groups/item/threads/item/posts/posts_request_builder.rb', line 25

def count()
    return MicrosoftGraph::Groups::Item::Threads::Item::Posts::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Get the posts of the specified thread. You can specify both the parent conversation and the thread, or, you can specify the thread without referencing the parent conversation.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of post_collection_response



53
54
55
56
57
58
59
60
61
# File 'lib/groups/item/threads/item/posts/posts_request_builder.rb', line 53

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PostCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get the posts of the specified thread. You can specify both the parent conversation and the thread, or, you can specify the thread without referencing the parent conversation.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/groups/item/threads/item/posts/posts_request_builder.rb', line 67

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end