Class: MicrosoftGraph::Groups::Item::ValidateProperties::ValidatePropertiesPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Groups::Item::ValidateProperties::ValidatePropertiesPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/groups/item/validate_properties/validate_properties_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new validatePropertiesPostRequestBody and sets the default values.
-
#mail_nickname ⇒ Object
Gets the mailNickname property value.
-
#mail_nickname=(value) ⇒ Object
Sets the mailNickname property value.
-
#on_behalf_of_user_id ⇒ Object
Gets the onBehalfOfUserId property value.
-
#on_behalf_of_user_id=(value) ⇒ Object
Sets the onBehalfOfUserId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new validatePropertiesPostRequestBody and sets the default values.
44 45 46 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 44 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
52 53 54 55 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 52 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ValidatePropertiesPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
29 30 31 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 29 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
37 38 39 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 37 def additional_data=(value) @additional_data = value end |
#display_name ⇒ Object
Gets the displayName property value. The displayName property
60 61 62 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 60 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. The displayName property
68 69 70 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 68 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
75 76 77 78 79 80 81 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 75 def get_field_deserializers() return { "displayName" => lambda {|n| @display_name = n.get_string_value() }, "mailNickname" => lambda {|n| @mail_nickname = n.get_string_value() }, "onBehalfOfUserId" => lambda {|n| @on_behalf_of_user_id = n.get_guid_value() }, } end |
#mail_nickname ⇒ Object
Gets the mailNickname property value. The mailNickname property
86 87 88 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 86 def mail_nickname return @mail_nickname end |
#mail_nickname=(value) ⇒ Object
Sets the mailNickname property value. The mailNickname property
94 95 96 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 94 def mail_nickname=(value) @mail_nickname = value end |
#on_behalf_of_user_id ⇒ Object
Gets the onBehalfOfUserId property value. The onBehalfOfUserId property
101 102 103 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 101 def on_behalf_of_user_id return @on_behalf_of_user_id end |
#on_behalf_of_user_id=(value) ⇒ Object
Sets the onBehalfOfUserId property value. The onBehalfOfUserId property
109 110 111 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 109 def on_behalf_of_user_id=(value) @on_behalf_of_user_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
117 118 119 120 121 122 123 |
# File 'lib/groups/item/validate_properties/validate_properties_post_request_body.rb', line 117 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("displayName", @display_name) writer.write_string_value("mailNickname", @mail_nickname) writer.write_guid_value("onBehalfOfUserId", @on_behalf_of_user_id) writer.write_additional_data(@additional_data) end |