Class: MicrosoftGraph::Identity::B2xUserFlows::Item::ApiConnectorConfiguration::ApiConnectorConfigurationRequestBuilder::ApiConnectorConfigurationRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Identity::B2xUserFlows::Item::ApiConnectorConfiguration::ApiConnectorConfigurationRequestBuilder::ApiConnectorConfigurationRequestBuilderGetQueryParameters
- Defined in:
- lib/identity/b2x_user_flows/item/api_connector_configuration/api_connector_configuration_request_builder.rb
Overview
Configuration for enabling an API connector for use as part of the self-service sign-up user flow. You can only obtain the value of this object using Get userFlowApiConnectorConfiguration.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
79 80 81 |
# File 'lib/identity/b2x_user_flows/item/api_connector_configuration/api_connector_configuration_request_builder.rb', line 79 def end |
#select ⇒ Object
Select properties to be returned
82 83 84 |
# File 'lib/identity/b2x_user_flows/item/api_connector_configuration/api_connector_configuration_request_builder.rb', line 82 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/identity/b2x_user_flows/item/api_connector_configuration/api_connector_configuration_request_builder.rb', line 88 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |