Class: MicrosoftGraph::Identity::ConditionalAccess::AuthenticationStrength::Policies::Item::AuthenticationStrengthPolicyItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Identity::ConditionalAccess::AuthenticationStrength::Policies::Item::AuthenticationStrengthPolicyItemRequestBuilder
- Defined in:
- lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb
Overview
Provides operations to manage the policies property of the microsoft.graph.authenticationStrengthRoot entity.
Defined Under Namespace
Classes: AuthenticationStrengthPolicyItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#combination_configurations ⇒ Object
Provides operations to manage the combinationConfigurations property of the microsoft.graph.authenticationStrengthPolicy entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property policies for identity.
-
#get(request_configuration = nil) ⇒ Object
A collection of authentication strength policies that exist for this tenant, including both built-in and custom policies.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new AuthenticationStrengthPolicyItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property policies in identity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property policies for identity.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
A collection of authentication strength policies that exist for this tenant, including both built-in and custom policies.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property policies in identity.
-
#update_allowed_combinations ⇒ Object
Provides operations to call the updateAllowedCombinations method.
-
#usage ⇒ Object
Provides operations to call the usage method.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new AuthenticationStrengthPolicyItemRequestBuilder and sets the default values.
45 46 47 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 45 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identity/conditionalAccess/authenticationStrength/policies/{authenticationStrengthPolicy%2Did}{?%24select,%24expand}") end |
Instance Method Details
#combination_configurations ⇒ Object
Provides operations to manage the combinationConfigurations property of the microsoft.graph.authenticationStrengthPolicy entity.
26 27 28 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 26 def combination_configurations() return MicrosoftGraph::Identity::ConditionalAccess::AuthenticationStrength::Policies::Item::CombinationConfigurations::CombinationConfigurationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property policies for identity
53 54 55 56 57 58 59 60 61 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 53 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
A collection of authentication strength policies that exist for this tenant, including both built-in and custom policies.
67 68 69 70 71 72 73 74 75 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 67 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AuthenticationStrengthPolicy.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property policies in identity
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 82 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AuthenticationStrengthPolicy.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property policies for identity
97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 97 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
A collection of authentication strength policies that exist for this tenant, including both built-in and custom policies.
113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 113 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property policies in identity
132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 132 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |
#update_allowed_combinations ⇒ Object
Provides operations to call the updateAllowedCombinations method.
31 32 33 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 31 def update_allowed_combinations() return MicrosoftGraph::Identity::ConditionalAccess::AuthenticationStrength::Policies::Item::UpdateAllowedCombinations::UpdateAllowedCombinationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#usage ⇒ Object
Provides operations to call the usage method.
36 37 38 |
# File 'lib/identity/conditional_access/authentication_strength/policies/item/authentication_strength_policy_item_request_builder.rb', line 36 def usage() return MicrosoftGraph::Identity::ConditionalAccess::AuthenticationStrength::Policies::Item::Usage::UsageRequestBuilder.new(@path_parameters, @request_adapter) end |