Class: MicrosoftGraph::Identity::ConditionalAccess::ConditionalAccessRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Identity::ConditionalAccess::ConditionalAccessRequestBuilder
- Defined in:
- lib/identity/conditional_access/conditional_access_request_builder.rb
Overview
Provides operations to manage the conditionalAccess property of the microsoft.graph.identityContainer entity.
Defined Under Namespace
Classes: ConditionalAccessRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#authentication_context_class_references ⇒ Object
Provides operations to manage the authenticationContextClassReferences property of the microsoft.graph.conditionalAccessRoot entity.
-
#authentication_strength ⇒ Object
Provides operations to manage the authenticationStrength property of the microsoft.graph.conditionalAccessRoot entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property conditionalAccess for identity.
-
#get(request_configuration = nil) ⇒ Object
the entry point for the Conditional Access (CA) object model.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ConditionalAccessRequestBuilder and sets the default values.
-
#named_locations ⇒ Object
Provides operations to manage the namedLocations property of the microsoft.graph.conditionalAccessRoot entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property conditionalAccess in identity.
-
#policies ⇒ Object
Provides operations to manage the policies property of the microsoft.graph.conditionalAccessRoot entity.
-
#templates ⇒ Object
Provides operations to manage the templates property of the microsoft.graph.conditionalAccessRoot entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property conditionalAccess for identity.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
the entry point for the Conditional Access (CA) object model.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property conditionalAccess in identity.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ConditionalAccessRequestBuilder and sets the default values.
51 52 53 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 51 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identity/conditionalAccess{?%24select,%24expand}") end |
Instance Method Details
#authentication_context_class_references ⇒ Object
Provides operations to manage the authenticationContextClassReferences property of the microsoft.graph.conditionalAccessRoot entity.
22 23 24 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 22 def authentication_context_class_references() return MicrosoftGraph::Identity::ConditionalAccess::AuthenticationContextClassReferences::AuthenticationContextClassReferencesRequestBuilder.new(@path_parameters, @request_adapter) end |
#authentication_strength ⇒ Object
Provides operations to manage the authenticationStrength property of the microsoft.graph.conditionalAccessRoot entity.
27 28 29 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 27 def authentication_strength() return MicrosoftGraph::Identity::ConditionalAccess::AuthenticationStrength::AuthenticationStrengthRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property conditionalAccess for identity
59 60 61 62 63 64 65 66 67 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 59 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
the entry point for the Conditional Access (CA) object model.
73 74 75 76 77 78 79 80 81 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 73 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConditionalAccessRoot.create_from_discriminator_value(pn) }, error_mapping) end |
#named_locations ⇒ Object
Provides operations to manage the namedLocations property of the microsoft.graph.conditionalAccessRoot entity.
32 33 34 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 32 def named_locations() return MicrosoftGraph::Identity::ConditionalAccess::NamedLocations::NamedLocationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property conditionalAccess in identity
88 89 90 91 92 93 94 95 96 97 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 88 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConditionalAccessRoot.create_from_discriminator_value(pn) }, error_mapping) end |
#policies ⇒ Object
Provides operations to manage the policies property of the microsoft.graph.conditionalAccessRoot entity.
37 38 39 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 37 def policies() return MicrosoftGraph::Identity::ConditionalAccess::Policies::PoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#templates ⇒ Object
Provides operations to manage the templates property of the microsoft.graph.conditionalAccessRoot entity.
42 43 44 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 42 def templates() return MicrosoftGraph::Identity::ConditionalAccess::Templates::TemplatesRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property conditionalAccess for identity
103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 103 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
the entry point for the Conditional Access (CA) object model.
119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 119 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property conditionalAccess in identity
138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/identity/conditional_access/conditional_access_request_builder.rb', line 138 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |