Class: MicrosoftGraph::IdentityGovernance::AppConsent::AppConsentRequests::Item::UserConsentRequests::UserConsentRequestsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::AppConsent::AppConsentRequests::Item::UserConsentRequests::UserConsentRequestsRequestBuilder
- Defined in:
- lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb
Overview
Provides operations to manage the userConsentRequests property of the microsoft.graph.appConsentRequest entity.
Defined Under Namespace
Classes: UserConsentRequestsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_user_consent_request_id(user_consent_request_id) ⇒ Object
Provides operations to manage the userConsentRequests property of the microsoft.graph.appConsentRequest entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#filter_by_current_user_with_on(on) ⇒ Object
Provides operations to call the filterByCurrentUser method.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a collection of userConsentRequest objects and their properties.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new UserConsentRequestsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to userConsentRequests for identityGovernance.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a collection of userConsentRequest objects and their properties.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to userConsentRequests for identityGovernance.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new UserConsentRequestsRequestBuilder and sets the default values.
47 48 49 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 47 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/appConsent/appConsentRequests/{appConsentRequest%2Did}/userConsentRequests{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_user_consent_request_id(user_consent_request_id) ⇒ Object
Provides operations to manage the userConsentRequests property of the microsoft.graph.appConsentRequest entity.
35 36 37 38 39 40 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 35 def () raise StandardError, 'user_consent_request_id cannot be null' if .nil? url_tpl_params = @path_parameters.clone url_tpl_params["userConsentRequest%2Did"] = return MicrosoftGraph::IdentityGovernance::AppConsent::AppConsentRequests::Item::UserConsentRequests::Item::UserConsentRequestItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
27 28 29 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 27 def count() return MicrosoftGraph::IdentityGovernance::AppConsent::AppConsentRequests::Item::UserConsentRequests::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#filter_by_current_user_with_on(on) ⇒ Object
Provides operations to call the filterByCurrentUser method.
55 56 57 58 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 55 def filter_by_current_user_with_on(on) raise StandardError, 'on cannot be null' if on.nil? return FilterByCurrentUserWithOnRequestBuilder.new(@path_parameters, @request_adapter, on) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a collection of userConsentRequest objects and their properties.
64 65 66 67 68 69 70 71 72 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 64 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::UserConsentRequestCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to userConsentRequests for identityGovernance
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 79 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::UserConsentRequest.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a collection of userConsentRequest objects and their properties.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 94 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to userConsentRequests for identityGovernance
113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/identity_governance/app_consent/app_consent_requests/item/user_consent_requests/user_consent_requests_request_builder.rb', line 113 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |