Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::AccessPackagesRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb

Overview

Provides operations to manage the accessPackages property of the microsoft.graph.entitlementManagement entity.

Defined Under Namespace

Classes: AccessPackagesRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new AccessPackagesRequestBuilder and sets the default values.



43
44
45
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 43

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/entitlementManagement/accessPackages{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_access_package_id(access_package_id) ⇒ Object

Provides operations to manage the accessPackages property of the microsoft.graph.entitlementManagement entity.

Raises:

  • (StandardError)


31
32
33
34
35
36
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 31

def by_access_package_id(access_package_id)
    raise StandardError, 'access_package_id cannot be null' if access_package_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["accessPackage%2Did"] = access_package_id
    return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::AccessPackageItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



23
24
25
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 23

def count()
    return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#filter_by_current_user_with_on(on) ⇒ Object

Provides operations to call the filterByCurrentUser method.

Raises:

  • (StandardError)


51
52
53
54
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 51

def filter_by_current_user_with_on(on)
    raise StandardError, 'on cannot be null' if on.nil?
    return FilterByCurrentUserWithOnRequestBuilder.new(@path_parameters, @request_adapter, on)
end

#get(request_configuration = nil) ⇒ Object

Retrieve a list of accessPackage objects. The resulting list includes all the access packages that the caller has access to read, across all catalogs.



60
61
62
63
64
65
66
67
68
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 60

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackageCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Create a new accessPackage object. The access package will be added to an existing accessPackageCatalog.

Raises:

  • (StandardError)


75
76
77
78
79
80
81
82
83
84
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 75

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackage.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve a list of accessPackage objects. The resulting list includes all the access packages that the caller has access to read, across all catalogs.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 90

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create a new accessPackage object. The access package will be added to an existing accessPackageCatalog.

Raises:

  • (StandardError)


109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/identity_governance/entitlement_management/access_packages/access_packages_request_builder.rb', line 109

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end