Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::AccessPackageItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::AccessPackageItemRequestBuilder
- Defined in:
- lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb
Overview
Provides operations to manage the accessPackages property of the microsoft.graph.entitlementManagement entity.
Defined Under Namespace
Classes: AccessPackageItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#access_packages_incompatible_with ⇒ Object
Provides operations to manage the accessPackagesIncompatibleWith property of the microsoft.graph.accessPackage entity.
-
#assignment_policies ⇒ Object
Provides operations to manage the assignmentPolicies property of the microsoft.graph.accessPackage entity.
-
#catalog ⇒ Object
Provides operations to manage the catalog property of the microsoft.graph.accessPackage entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete an accessPackage object.
-
#get(request_configuration = nil) ⇒ Object
Retrieve an access package with a list of accessPackageResourceRoleScope objects.
-
#get_applicable_policy_requirements ⇒ Object
Provides operations to call the getApplicablePolicyRequirements method.
-
#incompatible_access_packages ⇒ Object
Provides operations to manage the incompatibleAccessPackages property of the microsoft.graph.accessPackage entity.
-
#incompatible_groups ⇒ Object
Provides operations to manage the incompatibleGroups property of the microsoft.graph.accessPackage entity.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new AccessPackageItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update an existing accessPackage object to change one or more of its properties, such as the display name or description.
-
#resource_role_scopes ⇒ Object
Provides operations to manage the resourceRoleScopes property of the microsoft.graph.accessPackage entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete an accessPackage object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve an access package with a list of accessPackageResourceRoleScope objects.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update an existing accessPackage object to change one or more of its properties, such as the display name or description.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new AccessPackageItemRequestBuilder and sets the default values.
67 68 69 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 67 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/entitlementManagement/accessPackages/{accessPackage%2Did}{?%24select,%24expand}") end |
Instance Method Details
#access_packages_incompatible_with ⇒ Object
Provides operations to manage the accessPackagesIncompatibleWith property of the microsoft.graph.accessPackage entity.
28 29 30 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 28 def access_packages_incompatible_with() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::AccessPackagesIncompatibleWith::AccessPackagesIncompatibleWithRequestBuilder.new(@path_parameters, @request_adapter) end |
#assignment_policies ⇒ Object
Provides operations to manage the assignmentPolicies property of the microsoft.graph.accessPackage entity.
33 34 35 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 33 def assignment_policies() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::AssignmentPolicies::AssignmentPoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#catalog ⇒ Object
Provides operations to manage the catalog property of the microsoft.graph.accessPackage entity.
38 39 40 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 38 def catalog() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::Catalog::CatalogRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete an accessPackage object. You cannot delete an access package if it has any accessPackageAssignment.
75 76 77 78 79 80 81 82 83 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 75 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Retrieve an access package with a list of accessPackageResourceRoleScope objects. These objects represent the resource roles that an access package assigns to each subject. Each object links to an accessPackageResourceRole and an accessPackageResourceScope.
89 90 91 92 93 94 95 96 97 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 89 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackage.create_from_discriminator_value(pn) }, error_mapping) end |
#get_applicable_policy_requirements ⇒ Object
Provides operations to call the getApplicablePolicyRequirements method.
43 44 45 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 43 def get_applicable_policy_requirements() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::GetApplicablePolicyRequirements::GetApplicablePolicyRequirementsRequestBuilder.new(@path_parameters, @request_adapter) end |
#incompatible_access_packages ⇒ Object
Provides operations to manage the incompatibleAccessPackages property of the microsoft.graph.accessPackage entity.
48 49 50 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 48 def incompatible_access_packages() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleAccessPackages::IncompatibleAccessPackagesRequestBuilder.new(@path_parameters, @request_adapter) end |
#incompatible_groups ⇒ Object
Provides operations to manage the incompatibleGroups property of the microsoft.graph.accessPackage entity.
53 54 55 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 53 def incompatible_groups() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::IncompatibleGroupsRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update an existing accessPackage object to change one or more of its properties, such as the display name or description.
104 105 106 107 108 109 110 111 112 113 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 104 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackage.create_from_discriminator_value(pn) }, error_mapping) end |
#resource_role_scopes ⇒ Object
Provides operations to manage the resourceRoleScopes property of the microsoft.graph.accessPackage entity.
58 59 60 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 58 def resource_role_scopes() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::ResourceRoleScopes::ResourceRoleScopesRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete an accessPackage object. You cannot delete an access package if it has any accessPackageAssignment.
119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 119 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve an access package with a list of accessPackageResourceRoleScope objects. These objects represent the resource roles that an access package assigns to each subject. Each object links to an accessPackageResourceRole and an accessPackageResourceScope.
135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 135 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update an existing accessPackage object to change one or more of its properties, such as the display name or description.
154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 154 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |