Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::AccessPackageItemRequestBuilder::AccessPackageItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb

Overview

Retrieve an access package with a list of accessPackageResourceRoleScope objects. These objects represent the resource roles that an access package assigns to each subject. Each object links to an accessPackageResourceRole and an accessPackageResourceScope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



175
176
177
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 175

def expand
  @expand
end

#selectObject

Select properties to be returned



178
179
180
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 178

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


184
185
186
187
188
189
190
191
192
193
194
# File 'lib/identity_governance/entitlement_management/access_packages/item/access_package_item_request_builder.rb', line 184

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end