Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::ConnectedOrganizationItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::ConnectedOrganizationItemRequestBuilder
- Defined in:
- lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb
Overview
Provides operations to manage the connectedOrganizations property of the microsoft.graph.entitlementManagement entity.
Defined Under Namespace
Classes: ConnectedOrganizationItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete a connectedOrganization object.
-
#external_sponsors ⇒ Object
Provides operations to manage the externalSponsors property of the microsoft.graph.connectedOrganization entity.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a connectedOrganization object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ConnectedOrganizationItemRequestBuilder and sets the default values.
-
#internal_sponsors ⇒ Object
Provides operations to manage the internalSponsors property of the microsoft.graph.connectedOrganization entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update a connectedOrganization object to change one or more of its properties.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a connectedOrganization object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a connectedOrganization object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update a connectedOrganization object to change one or more of its properties.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ConnectedOrganizationItemRequestBuilder and sets the default values.
37 38 39 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 37 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/entitlementManagement/connectedOrganizations/{connectedOrganization%2Did}{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete a connectedOrganization object.
45 46 47 48 49 50 51 52 53 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 45 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#external_sponsors ⇒ Object
Provides operations to manage the externalSponsors property of the microsoft.graph.connectedOrganization entity.
23 24 25 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 23 def external_sponsors() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::ExternalSponsors::ExternalSponsorsRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a connectedOrganization object.
59 60 61 62 63 64 65 66 67 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 59 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConnectedOrganization.create_from_discriminator_value(pn) }, error_mapping) end |
#internal_sponsors ⇒ Object
Provides operations to manage the internalSponsors property of the microsoft.graph.connectedOrganization entity.
28 29 30 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 28 def internal_sponsors() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::InternalSponsors::InternalSponsorsRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update a connectedOrganization object to change one or more of its properties.
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 74 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ConnectedOrganization.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a connectedOrganization object.
89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 89 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a connectedOrganization object.
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 105 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update a connectedOrganization object to change one or more of its properties.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/connected_organization_item_request_builder.rb', line 124 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |