Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::ExternalSponsors::GetByIds::GetByIdsPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::ExternalSponsors::GetByIds::GetByIdsPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#ids ⇒ Object
Gets the ids property value.
-
#ids=(value) ⇒ Object
Sets the ids property value.
-
#initialize ⇒ Object
constructor
Instantiates a new getByIdsPostRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#types ⇒ Object
Gets the types property value.
-
#types=(value) ⇒ Object
Sets the types property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new getByIdsPostRequestBody and sets the default values.
47 48 49 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 47 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
55 56 57 58 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 55 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GetByIdsPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
32 33 34 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 32 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
40 41 42 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 40 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
63 64 65 66 67 68 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 63 def get_field_deserializers() return { "ids" => lambda {|n| @ids = n.get_collection_of_primitive_values(String) }, "types" => lambda {|n| @types = n.get_collection_of_primitive_values(String) }, } end |
#ids ⇒ Object
Gets the ids property value. The ids property
73 74 75 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 73 def ids return @ids end |
#ids=(value) ⇒ Object
Sets the ids property value. The ids property
81 82 83 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 81 def ids=(value) @ids = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
89 90 91 92 93 94 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 89 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_primitive_values("ids", @ids) writer.write_collection_of_primitive_values("types", @types) writer.write_additional_data(@additional_data) end |
#types ⇒ Object
Gets the types property value. The types property
99 100 101 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 99 def types return @types end |
#types=(value) ⇒ Object
Sets the types property value. The types property
107 108 109 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/external_sponsors/get_by_ids/get_by_ids_post_request_body.rb', line 107 def types=(value) @types = value end |