Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::InternalSponsors::ValidateProperties::ValidatePropertiesPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::Item::InternalSponsors::ValidateProperties::ValidatePropertiesPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#entity_type ⇒ Object
Gets the entityType property value.
-
#entity_type=(value) ⇒ Object
Sets the entityType property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new validatePropertiesPostRequestBody and sets the default values.
-
#mail_nickname ⇒ Object
Gets the mailNickname property value.
-
#mail_nickname=(value) ⇒ Object
Sets the mailNickname property value.
-
#on_behalf_of_user_id ⇒ Object
Gets the onBehalfOfUserId property value.
-
#on_behalf_of_user_id=(value) ⇒ Object
Sets the onBehalfOfUserId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new validatePropertiesPostRequestBody and sets the default values.
53 54 55 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 53 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
61 62 63 64 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 61 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ValidatePropertiesPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 38 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
46 47 48 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 46 def additional_data=(value) @additional_data = value end |
#display_name ⇒ Object
Gets the displayName property value. The displayName property
69 70 71 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 69 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. The displayName property
77 78 79 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 77 def display_name=(value) @display_name = value end |
#entity_type ⇒ Object
Gets the entityType property value. The entityType property
84 85 86 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 84 def entity_type return @entity_type end |
#entity_type=(value) ⇒ Object
Sets the entityType property value. The entityType property
92 93 94 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 92 def entity_type=(value) @entity_type = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
99 100 101 102 103 104 105 106 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 99 def get_field_deserializers() return { "displayName" => lambda {|n| @display_name = n.get_string_value() }, "entityType" => lambda {|n| @entity_type = n.get_string_value() }, "mailNickname" => lambda {|n| @mail_nickname = n.get_string_value() }, "onBehalfOfUserId" => lambda {|n| @on_behalf_of_user_id = n.get_guid_value() }, } end |
#mail_nickname ⇒ Object
Gets the mailNickname property value. The mailNickname property
111 112 113 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 111 def mail_nickname return @mail_nickname end |
#mail_nickname=(value) ⇒ Object
Sets the mailNickname property value. The mailNickname property
119 120 121 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 119 def mail_nickname=(value) @mail_nickname = value end |
#on_behalf_of_user_id ⇒ Object
Gets the onBehalfOfUserId property value. The onBehalfOfUserId property
126 127 128 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 126 def on_behalf_of_user_id return @on_behalf_of_user_id end |
#on_behalf_of_user_id=(value) ⇒ Object
Sets the onBehalfOfUserId property value. The onBehalfOfUserId property
134 135 136 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 134 def on_behalf_of_user_id=(value) @on_behalf_of_user_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
142 143 144 145 146 147 148 149 |
# File 'lib/identity_governance/entitlement_management/connected_organizations/item/internal_sponsors/validate_properties/validate_properties_post_request_body.rb', line 142 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("displayName", @display_name) writer.write_string_value("entityType", @entity_type) writer.write_string_value("mailNickname", @mail_nickname) writer.write_guid_value("onBehalfOfUserId", @on_behalf_of_user_id) writer.write_additional_data(@additional_data) end |