Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::CatalogRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::CatalogRequestBuilder
- Defined in:
- lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb
Overview
Provides operations to manage the catalog property of the microsoft.graph.accessPackageResourceRequest entity.
Defined Under Namespace
Classes: CatalogRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#access_packages ⇒ Object
Provides operations to manage the accessPackages property of the microsoft.graph.accessPackageCatalog entity.
-
#custom_workflow_extensions ⇒ Object
Provides operations to manage the customWorkflowExtensions property of the microsoft.graph.accessPackageCatalog entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property catalog for identityGovernance.
-
#get(request_configuration = nil) ⇒ Object
Get catalog from identityGovernance.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new CatalogRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property catalog in identityGovernance.
-
#resource_roles ⇒ Object
Provides operations to manage the resourceRoles property of the microsoft.graph.accessPackageCatalog entity.
-
#resource_scopes ⇒ Object
Provides operations to manage the resourceScopes property of the microsoft.graph.accessPackageCatalog entity.
-
#resources ⇒ Object
Provides operations to manage the resources property of the microsoft.graph.accessPackageCatalog entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property catalog for identityGovernance.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get catalog from identityGovernance.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property catalog in identityGovernance.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new CatalogRequestBuilder and sets the default values.
57 58 59 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 57 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/entitlementManagement/resourceRequests/{accessPackageResourceRequest%2Did}/catalog{?%24select,%24expand}") end |
Instance Method Details
#access_packages ⇒ Object
Provides operations to manage the accessPackages property of the microsoft.graph.accessPackageCatalog entity.
28 29 30 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 28 def access_packages() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::AccessPackages::AccessPackagesRequestBuilder.new(@path_parameters, @request_adapter) end |
#custom_workflow_extensions ⇒ Object
Provides operations to manage the customWorkflowExtensions property of the microsoft.graph.accessPackageCatalog entity.
33 34 35 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 33 def custom_workflow_extensions() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::CustomWorkflowExtensions::CustomWorkflowExtensionsRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property catalog for identityGovernance
65 66 67 68 69 70 71 72 73 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 65 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Get catalog from identityGovernance
79 80 81 82 83 84 85 86 87 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 79 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackageCatalog.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property catalog in identityGovernance
94 95 96 97 98 99 100 101 102 103 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 94 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackageCatalog.create_from_discriminator_value(pn) }, error_mapping) end |
#resource_roles ⇒ Object
Provides operations to manage the resourceRoles property of the microsoft.graph.accessPackageCatalog entity.
38 39 40 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 38 def resource_roles() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::ResourceRoles::ResourceRolesRequestBuilder.new(@path_parameters, @request_adapter) end |
#resource_scopes ⇒ Object
Provides operations to manage the resourceScopes property of the microsoft.graph.accessPackageCatalog entity.
48 49 50 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 48 def resource_scopes() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::ResourceScopes::ResourceScopesRequestBuilder.new(@path_parameters, @request_adapter) end |
#resources ⇒ Object
Provides operations to manage the resources property of the microsoft.graph.accessPackageCatalog entity.
43 44 45 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 43 def resources() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::Resources::ResourcesRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property catalog for identityGovernance
109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 109 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get catalog from identityGovernance
125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 125 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property catalog in identityGovernance
144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/catalog_request_builder.rb', line 144 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |