Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::ResourceRoles::ResourceRolesRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb

Overview

Provides operations to manage the resourceRoles property of the microsoft.graph.accessPackageCatalog entity.

Defined Under Namespace

Classes: ResourceRolesRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ResourceRolesRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



48
49
50
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb', line 48

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/entitlementManagement/resourceRequests/{accessPackageResourceRequest%2Did}/catalog/resourceRoles{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_access_package_resource_role_id(access_package_resource_role_id) ⇒ Object

Provides operations to manage the resourceRoles property of the microsoft.graph.accessPackageCatalog entity.

Parameters:

  • access_package_resource_role_id

    The unique identifier of accessPackageResourceRole

Returns:

  • a access_package_resource_role_item_request_builder

Raises:

  • (StandardError)


36
37
38
39
40
41
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb', line 36

def by_access_package_resource_role_id(access_package_resource_role_id)
    raise StandardError, 'access_package_resource_role_id cannot be null' if access_package_resource_role_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["accessPackageResourceRole%2Did"] = access_package_resource_role_id
    return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::ResourceRoles::Item::AccessPackageResourceRoleItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



28
29
30
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb', line 28

def count()
    return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::Item::Catalog::ResourceRoles::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve a list of accessPackageResourceRole objects of an accessPackageResource in an accessPackageCatalog. The resource should have been added to the catalog by creating an accessPackageResourceRequest. This list of roles can then be used by the caller to select a role, which is needed when subsequently creating an accessPackageResourceRoleScope.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of access_package_resource_role_collection_response



56
57
58
59
60
61
62
63
64
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb', line 56

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackageResourceRoleCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Create new navigation property to resourceRoles for identityGovernance

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of access_package_resource_role

Raises:

  • (StandardError)


71
72
73
74
75
76
77
78
79
80
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb', line 71

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AccessPackageResourceRole.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve a list of accessPackageResourceRole objects of an accessPackageResource in an accessPackageCatalog. The resource should have been added to the catalog by creating an accessPackageResourceRequest. This list of roles can then be used by the caller to select a role, which is needed when subsequently creating an accessPackageResourceRoleScope.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb', line 86

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create new navigation property to resourceRoles for identityGovernance

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/identity_governance/entitlement_management/resource_requests/item/catalog/resource_roles/resource_roles_request_builder.rb', line 105

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end