Class: MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::DeletedItems::DeletedItemsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::DeletedItems::DeletedItemsRequestBuilder
- Defined in:
- lib/identity_governance/lifecycle_workflows/deleted_items/deleted_items_request_builder.rb
Overview
Provides operations to manage the deletedItems property of the microsoft.graph.identityGovernance.lifecycleWorkflowsContainer entity.
Defined Under Namespace
Classes: DeletedItemsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property deletedItems for identityGovernance.
-
#get(request_configuration = nil) ⇒ Object
Deleted workflows in your lifecycle workflows instance.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DeletedItemsRequestBuilder and sets the default values.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property deletedItems for identityGovernance.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Deleted workflows in your lifecycle workflows instance.
-
#workflows ⇒ Object
Provides operations to manage the workflows property of the microsoft.graph.deletedItemContainer entity.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DeletedItemsRequestBuilder and sets the default values.
29 30 31 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/deleted_items_request_builder.rb', line 29 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/lifecycleWorkflows/deletedItems{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete navigation property deletedItems for identityGovernance
37 38 39 40 41 42 43 44 45 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/deleted_items_request_builder.rb', line 37 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Deleted workflows in your lifecycle workflows instance.
51 52 53 54 55 56 57 58 59 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/deleted_items_request_builder.rb', line 51 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DeletedItemContainer.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property deletedItems for identityGovernance
65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/deleted_items_request_builder.rb', line 65 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Deleted workflows in your lifecycle workflows instance.
81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/deleted_items_request_builder.rb', line 81 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#workflows ⇒ Object
Provides operations to manage the workflows property of the microsoft.graph.deletedItemContainer entity.
20 21 22 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/deleted_items_request_builder.rb', line 20 def workflows() return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::DeletedItems::Workflows::WorkflowsRequestBuilder.new(@path_parameters, @request_adapter) end |