Class: MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::DeletedItems::Workflows::Item::ExecutionScope::ExecutionScopeRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::DeletedItems::Workflows::Item::ExecutionScope::ExecutionScopeRequestBuilder
- Defined in:
- lib/identity_governance/lifecycle_workflows/deleted_items/workflows/item/execution_scope/execution_scope_request_builder.rb
Overview
Provides operations to manage the executionScope property of the microsoft.graph.identityGovernance.workflow entity.
Defined Under Namespace
Classes: ExecutionScopeRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_user_processing_result_id(user_processing_result_id) ⇒ Object
Provides operations to manage the executionScope property of the microsoft.graph.identityGovernance.workflow entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
The unique identifier of the Azure AD identity that last modified the workflow object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ExecutionScopeRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
The unique identifier of the Azure AD identity that last modified the workflow object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ExecutionScopeRequestBuilder and sets the default values.
47 48 49 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/workflows/item/execution_scope/execution_scope_request_builder.rb', line 47 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/lifecycleWorkflows/deletedItems/workflows/{workflow%2Did}/executionScope{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_user_processing_result_id(user_processing_result_id) ⇒ Object
Provides operations to manage the executionScope property of the microsoft.graph.identityGovernance.workflow entity.
35 36 37 38 39 40 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/workflows/item/execution_scope/execution_scope_request_builder.rb', line 35 def by_user_processing_result_id(user_processing_result_id) raise StandardError, 'user_processing_result_id cannot be null' if user_processing_result_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["userProcessingResult%2Did"] = user_processing_result_id return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::DeletedItems::Workflows::Item::ExecutionScope::Item::UserProcessingResultItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
27 28 29 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/workflows/item/execution_scope/execution_scope_request_builder.rb', line 27 def count() return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::DeletedItems::Workflows::Item::ExecutionScope::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
The unique identifier of the Azure AD identity that last modified the workflow object.
55 56 57 58 59 60 61 62 63 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/workflows/item/execution_scope/execution_scope_request_builder.rb', line 55 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityGovernanceUserProcessingResultCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
The unique identifier of the Azure AD identity that last modified the workflow object.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/identity_governance/lifecycle_workflows/deleted_items/workflows/item/execution_scope/execution_scope_request_builder.rb', line 69 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |