Class: MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::TaskDefinitions::TaskDefinitionsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::TaskDefinitions::TaskDefinitionsRequestBuilder
- Defined in:
- lib/identity_governance/lifecycle_workflows/task_definitions/task_definitions_request_builder.rb
Overview
Provides operations to manage the taskDefinitions property of the microsoft.graph.identityGovernance.lifecycleWorkflowsContainer entity.
Defined Under Namespace
Classes: TaskDefinitionsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_task_definition_id(task_definition_id) ⇒ Object
Provides operations to manage the taskDefinitions property of the microsoft.graph.identityGovernance.lifecycleWorkflowsContainer entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get a list of the taskDefinition objects and their properties.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new TaskDefinitionsRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of the taskDefinition objects and their properties.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new TaskDefinitionsRequestBuilder and sets the default values.
41 42 43 |
# File 'lib/identity_governance/lifecycle_workflows/task_definitions/task_definitions_request_builder.rb', line 41 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/lifecycleWorkflows/taskDefinitions{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_task_definition_id(task_definition_id) ⇒ Object
Provides operations to manage the taskDefinitions property of the microsoft.graph.identityGovernance.lifecycleWorkflowsContainer entity.
29 30 31 32 33 34 |
# File 'lib/identity_governance/lifecycle_workflows/task_definitions/task_definitions_request_builder.rb', line 29 def by_task_definition_id(task_definition_id) raise StandardError, 'task_definition_id cannot be null' if task_definition_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["taskDefinition%2Did"] = task_definition_id return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::TaskDefinitions::Item::TaskDefinitionItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
21 22 23 |
# File 'lib/identity_governance/lifecycle_workflows/task_definitions/task_definitions_request_builder.rb', line 21 def count() return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::TaskDefinitions::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get a list of the taskDefinition objects and their properties.
49 50 51 52 53 54 55 56 57 |
# File 'lib/identity_governance/lifecycle_workflows/task_definitions/task_definitions_request_builder.rb', line 49 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityGovernanceTaskDefinitionCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of the taskDefinition objects and their properties.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/identity_governance/lifecycle_workflows/task_definitions/task_definitions_request_builder.rb', line 63 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |