Class: MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::Workflows::Item::Versions::Item::WorkflowVersionVersionNumberItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::Workflows::Item::Versions::Item::WorkflowVersionVersionNumberItemRequestBuilder
- Defined in:
- lib/identity_governance/lifecycle_workflows/workflows/item/versions/item/workflow_version_version_number_item_request_builder.rb
Overview
Provides operations to manage the versions property of the microsoft.graph.identityGovernance.workflow entity.
Defined Under Namespace
Classes: WorkflowVersionVersionNumberItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#created_by ⇒ Object
Provides operations to manage the createdBy property of the microsoft.graph.identityGovernance.workflowBase entity.
-
#get(request_configuration = nil) ⇒ Object
Read the properties and relationships of a workflowVersion object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new WorkflowVersionVersionNumberItemRequestBuilder and sets the default values.
-
#last_modified_by ⇒ Object
Provides operations to manage the lastModifiedBy property of the microsoft.graph.identityGovernance.workflowBase entity.
-
#tasks ⇒ Object
Provides operations to manage the tasks property of the microsoft.graph.identityGovernance.workflowBase entity.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Read the properties and relationships of a workflowVersion object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new WorkflowVersionVersionNumberItemRequestBuilder and sets the default values.
47 48 49 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/versions/item/workflow_version_version_number_item_request_builder.rb', line 47 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/lifecycleWorkflows/workflows/{workflow%2Did}/versions/{workflowVersion%2DversionNumber}{?%24select,%24expand}") end |
Instance Method Details
#created_by ⇒ Object
Provides operations to manage the createdBy property of the microsoft.graph.identityGovernance.workflowBase entity.
28 29 30 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/versions/item/workflow_version_version_number_item_request_builder.rb', line 28 def created_by() return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::Workflows::Item::Versions::Item::CreatedBy::CreatedByRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Read the properties and relationships of a workflowVersion object.
55 56 57 58 59 60 61 62 63 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/versions/item/workflow_version_version_number_item_request_builder.rb', line 55 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityGovernanceWorkflowVersion.create_from_discriminator_value(pn) }, error_mapping) end |
#last_modified_by ⇒ Object
Provides operations to manage the lastModifiedBy property of the microsoft.graph.identityGovernance.workflowBase entity.
33 34 35 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/versions/item/workflow_version_version_number_item_request_builder.rb', line 33 def last_modified_by() return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::Workflows::Item::Versions::Item::LastModifiedBy::LastModifiedByRequestBuilder.new(@path_parameters, @request_adapter) end |
#tasks ⇒ Object
Provides operations to manage the tasks property of the microsoft.graph.identityGovernance.workflowBase entity.
38 39 40 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/versions/item/workflow_version_version_number_item_request_builder.rb', line 38 def tasks() return MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::Workflows::Item::Versions::Item::Tasks::TasksRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Read the properties and relationships of a workflowVersion object.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/versions/item/workflow_version_version_number_item_request_builder.rb', line 69 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |