Class: MicrosoftGraph::IdentityGovernance::TermsOfUse::Agreements::Item::File::FileRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::TermsOfUse::Agreements::Item::File::FileRequestBuilder
- Defined in:
- lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb
Overview
Provides operations to manage the file property of the microsoft.graph.agreement entity.
Defined Under Namespace
Classes: FileRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property file for identityGovernance.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the details of an agreement file, including the language and version information.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new FileRequestBuilder and sets the default values.
-
#localizations ⇒ Object
Provides operations to manage the localizations property of the microsoft.graph.agreementFile entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property file in identityGovernance.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property file for identityGovernance.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the details of an agreement file, including the language and version information.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property file in identityGovernance.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new FileRequestBuilder and sets the default values.
33 34 35 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 33 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/termsOfUse/agreements/{agreement%2Did}/file{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete navigation property file for identityGovernance
41 42 43 44 45 46 47 48 49 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 41 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the details of an agreement file, including the language and version information. The default file can have multiple versions, each with its own language, that can be retrieved by specifying the Accept-Language header.
55 56 57 58 59 60 61 62 63 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 55 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AgreementFile.create_from_discriminator_value(pn) }, error_mapping) end |
#localizations ⇒ Object
Provides operations to manage the localizations property of the microsoft.graph.agreementFile entity.
24 25 26 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 24 def localizations() return MicrosoftGraph::IdentityGovernance::TermsOfUse::Agreements::Item::File::Localizations::LocalizationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property file in identityGovernance
70 71 72 73 74 75 76 77 78 79 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 70 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AgreementFile.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property file for identityGovernance
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 85 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the details of an agreement file, including the language and version information. The default file can have multiple versions, each with its own language, that can be retrieved by specifying the Accept-Language header.
101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 101 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property file in identityGovernance
120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/identity_governance/terms_of_use/agreements/item/file/file_request_builder.rb', line 120 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |