Class: MicrosoftGraph::IdentityProtection::IdentityProtectionRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/identity_protection/identity_protection_request_builder.rb

Overview

Provides operations to manage the identityProtectionRoot singleton.

Defined Under Namespace

Classes: IdentityProtectionRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new IdentityProtectionRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



43
44
45
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 43

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/identityProtection{?%24select,%24expand}")
end

Instance Method Details

#get(request_configuration = nil) ⇒ Object

Get identityProtection

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of identity_protection_root



51
52
53
54
55
56
57
58
59
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 51

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityProtectionRoot.create_from_discriminator_value(pn) }, error_mapping)
end

#patch(body, request_configuration = nil) ⇒ Object

Update identityProtection

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of identity_protection_root

Raises:

  • (StandardError)


66
67
68
69
70
71
72
73
74
75
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 66

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityProtectionRoot.create_from_discriminator_value(pn) }, error_mapping)
end

#risk_detectionsObject

Provides operations to manage the riskDetections property of the microsoft.graph.identityProtectionRoot entity.



19
20
21
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 19

def risk_detections()
    return MicrosoftGraph::IdentityProtection::RiskDetections::RiskDetectionsRequestBuilder.new(@path_parameters, @request_adapter)
end

#risky_service_principalsObject

Provides operations to manage the riskyServicePrincipals property of the microsoft.graph.identityProtectionRoot entity.



24
25
26
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 24

def risky_service_principals()
    return MicrosoftGraph::IdentityProtection::RiskyServicePrincipals::RiskyServicePrincipalsRequestBuilder.new(@path_parameters, @request_adapter)
end

#risky_usersObject

Provides operations to manage the riskyUsers property of the microsoft.graph.identityProtectionRoot entity.



29
30
31
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 29

def risky_users()
    return MicrosoftGraph::IdentityProtection::RiskyUsers::RiskyUsersRequestBuilder.new(@path_parameters, @request_adapter)
end

#service_principal_risk_detectionsObject

Provides operations to manage the servicePrincipalRiskDetections property of the microsoft.graph.identityProtectionRoot entity.



34
35
36
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 34

def service_principal_risk_detections()
    return MicrosoftGraph::IdentityProtection::ServicePrincipalRiskDetections::ServicePrincipalRiskDetectionsRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get identityProtection

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 81

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update identityProtection

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/identity_protection/identity_protection_request_builder.rb', line 100

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end