Class: MicrosoftGraph::InformationProtection::Bitlocker::RecoveryKeys::Item::BitlockerRecoveryKeyItemRequestBuilder::BitlockerRecoveryKeyItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/information_protection/bitlocker/recovery_keys/item/bitlocker_recovery_key_item_request_builder.rb

Overview

Retrieve the properties and relationships of a bitlockerRecoveryKey object. By default, this operation does not return the key property that represents the actual recovery key. To include the key property in the response, use the $select OData query parameter. Including the $select query parameter triggers an Azure AD audit of the operation and generates an audit log. For more information on audit logs for bitlocker recovery keys, see the KeyManagement category filter of Azure AD audit logs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



67
68
69
# File 'lib/information_protection/bitlocker/recovery_keys/item/bitlocker_recovery_key_item_request_builder.rb', line 67

def expand
  @expand
end

#selectObject

Select properties to be returned



70
71
72
# File 'lib/information_protection/bitlocker/recovery_keys/item/bitlocker_recovery_key_item_request_builder.rb', line 70

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • The original query parameter name in the class.

Returns:

  • a string

Raises:



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/information_protection/bitlocker/recovery_keys/item/bitlocker_recovery_key_item_request_builder.rb', line 76

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end