Class: MicrosoftGraph::Me::Authentication::PasswordMethods::Item::PasswordAuthenticationMethodItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Authentication::PasswordMethods::Item::PasswordAuthenticationMethodItemRequestBuilder
- Defined in:
- lib/me/authentication/password_methods/item/password_authentication_method_item_request_builder.rb
Overview
Provides operations to manage the passwordMethods property of the microsoft.graph.authentication entity.
Defined Under Namespace
Classes: PasswordAuthenticationMethodItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Retrieve a password that’s registered to a user, represented by a passwordAuthenticationMethod object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new PasswordAuthenticationMethodItemRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a password that’s registered to a user, represented by a passwordAuthenticationMethod object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new PasswordAuthenticationMethodItemRequestBuilder and sets the default values.
25 26 27 |
# File 'lib/me/authentication/password_methods/item/password_authentication_method_item_request_builder.rb', line 25 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/authentication/passwordMethods/{passwordAuthenticationMethod%2Did}{?%24select,%24expand}") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Retrieve a password that’s registered to a user, represented by a passwordAuthenticationMethod object. For security, the password itself will never be returned in the object and the password property is always null.
33 34 35 36 37 38 39 40 41 |
# File 'lib/me/authentication/password_methods/item/password_authentication_method_item_request_builder.rb', line 33 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PasswordAuthenticationMethod.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a password that’s registered to a user, represented by a passwordAuthenticationMethod object. For security, the password itself will never be returned in the object and the password property is always null.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/me/authentication/password_methods/item/password_authentication_method_item_request_builder.rb', line 47 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |