Class: MicrosoftGraph::Me::Authentication::PhoneMethods::Item::PhoneAuthenticationMethodItemRequestBuilder::PhoneAuthenticationMethodItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/authentication/phone_methods/item/phone_authentication_method_item_request_builder.rb

Overview

Retrieve a single phoneAuthenticationMethod object for a user. This method is available only for standard Azure AD and B2B users, but not B2C users.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



145
146
147
# File 'lib/me/authentication/phone_methods/item/phone_authentication_method_item_request_builder.rb', line 145

def expand
  @expand
end

#selectObject

Select properties to be returned



148
149
150
# File 'lib/me/authentication/phone_methods/item/phone_authentication_method_item_request_builder.rb', line 148

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Raises:

Parameters:

  • The original query parameter name in the class.

Returns:

  • a string



154
155
156
157
158
159
160
161
162
163
164
# File 'lib/me/authentication/phone_methods/item/phone_authentication_method_item_request_builder.rb', line 154

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end