Class: MicrosoftGraph::Me::Calendar::CalendarRequestBuilder::CalendarRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Calendar::CalendarRequestBuilder::CalendarRequestBuilderGetQueryParameters
- Defined in:
- lib/me/calendar/calendar_request_builder.rb
Overview
Get the properties and relationships of a calendar object. The calendar can be one for a user, or the default calendar of a Microsoft 365 group. There are two scenarios where an app can get another user's calendar:
Instance Attribute Summary collapse
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#select ⇒ Object
Select properties to be returned
133 134 135 |
# File 'lib/me/calendar/calendar_request_builder.rb', line 133 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
139 140 141 142 143 144 145 146 147 |
# File 'lib/me/calendar/calendar_request_builder.rb', line 139 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "select" return "%24select" else return original_name end end |