Class: MicrosoftGraph::Me::Calendar::CalendarView::Item::Accept::AcceptPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new acceptPostRequestBody and sets the default values.



60
61
62
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 60

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a accept_post_request_body

Raises:

  • (StandardError)


68
69
70
71
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 68

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AcceptPostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



30
31
32
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 30

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



38
39
40
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 38

def additional_data=(value)
    @additional_data = value
end

#commentObject

Gets the Comment property value. The Comment property

Returns:

  • a string



45
46
47
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 45

def comment
    return @comment
end

#comment=(value) ⇒ Object

Sets the Comment property value. The Comment property

Parameters:

  • value

    Value to set for the Comment property.

Returns:

  • a void



53
54
55
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 53

def comment=(value)
    @comment = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



76
77
78
79
80
81
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 76

def get_field_deserializers()
    return {
        "Comment" => lambda {|n| @comment = n.get_string_value() },
        "SendResponse" => lambda {|n| @send_response = n.get_boolean_value() },
    }
end

#send_responseObject

Gets the SendResponse property value. The SendResponse property

Returns:

  • a boolean



86
87
88
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 86

def send_response
    return @send_response
end

#send_response=(value) ⇒ Object

Sets the SendResponse property value. The SendResponse property

Parameters:

  • value

    Value to set for the SendResponse property.

Returns:

  • a void



94
95
96
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 94

def send_response=(value)
    @send_response = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


102
103
104
105
106
107
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 102

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("Comment", @comment)
    writer.write_boolean_value("SendResponse", @send_response)
    writer.write_additional_data(@additional_data)
end