Class: MicrosoftGraph::Me::Calendar::CalendarView::Item::Cancel::CancelRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/me/calendar/calendar_view/item/cancel/cancel_request_builder.rb

Overview

Provides operations to call the cancel method.

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new CancelRequestBuilder and sets the default values.

Parameters:

  • path_parameters —

    Path parameters for the request

  • request_adapter —

    The request adapter to use to execute the requests.



26
27
28
# File 'lib/me/calendar/calendar_view/item/cancel/cancel_request_builder.rb', line 26

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/me/calendar/calendarView/{event%2Did}/cancel")
end

Instance Method Details

#post(body, request_configuration = nil) ⇒ Object

This action allows the organizer of a meeting to send a cancellation message and cancel the event. The action moves the event to the Deleted Items folder. The organizer can also cancel an occurrence of a recurring meeting by providing the occurrence event ID. An attendee calling this action gets an error (HTTP 400 Bad Request), with the followingerror message: 'Your request can't be completed. You need to be an organizer to cancel a meeting.' This action differs from Delete in that Cancel is available to only the organizer, and letsthe organizer send a custom message to the attendees about the cancellation.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void

Raises:

  • (StandardError)


35
36
37
38
39
40
41
42
43
44
# File 'lib/me/calendar/calendar_view/item/cancel/cancel_request_builder.rb', line 35

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

This action allows the organizer of a meeting to send a cancellation message and cancel the event. The action moves the event to the Deleted Items folder. The organizer can also cancel an occurrence of a recurring meeting by providing the occurrence event ID. An attendee calling this action gets an error (HTTP 400 Bad Request), with the followingerror message: 'Your request can't be completed. You need to be an organizer to cancel a meeting.' This action differs from Delete in that Cancel is available to only the organizer, and letsthe organizer send a custom message to the attendees about the cancellation.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/me/calendar/calendar_view/item/cancel/cancel_request_builder.rb', line 51

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end