Class: MicrosoftGraph::Me::Calendar::CalendarView::Item::Decline::DeclinePostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Calendar::CalendarView::Item::Decline::DeclinePostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#comment ⇒ Object
Gets the Comment property value.
-
#comment=(value) ⇒ Object
Sets the Comment property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new declinePostRequestBody and sets the default values.
-
#proposed_new_time ⇒ Object
Gets the ProposedNewTime property value.
-
#proposed_new_time=(value) ⇒ Object
Sets the ProposedNewTime property value.
-
#send_response ⇒ Object
Gets the SendResponse property value.
-
#send_response=(value) ⇒ Object
Sets the SendResponse property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new declinePostRequestBody and sets the default values.
64 65 66 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 64 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
72 73 74 75 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 72 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return DeclinePostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
34 35 36 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 34 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
42 43 44 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 42 def additional_data=(value) @additional_data = value end |
#comment ⇒ Object
Gets the Comment property value. The Comment property
49 50 51 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 49 def comment return @comment end |
#comment=(value) ⇒ Object
Sets the Comment property value. The Comment property
57 58 59 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 57 def comment=(value) @comment = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
80 81 82 83 84 85 86 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 80 def get_field_deserializers() return { "Comment" => lambda {|n| @comment = n.get_string_value() }, "ProposedNewTime" => lambda {|n| @proposed_new_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TimeSlot.create_from_discriminator_value(pn) }) }, "SendResponse" => lambda {|n| @send_response = n.get_boolean_value() }, } end |
#proposed_new_time ⇒ Object
Gets the ProposedNewTime property value. The ProposedNewTime property
91 92 93 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 91 def proposed_new_time return @proposed_new_time end |
#proposed_new_time=(value) ⇒ Object
Sets the ProposedNewTime property value. The ProposedNewTime property
99 100 101 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 99 def proposed_new_time=(value) @proposed_new_time = value end |
#send_response ⇒ Object
Gets the SendResponse property value. The SendResponse property
106 107 108 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 106 def send_response return @send_response end |
#send_response=(value) ⇒ Object
Sets the SendResponse property value. The SendResponse property
114 115 116 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 114 def send_response=(value) @send_response = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
122 123 124 125 126 127 128 |
# File 'lib/me/calendar/calendar_view/item/decline/decline_post_request_body.rb', line 122 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("Comment", @comment) writer.write_object_value("ProposedNewTime", @proposed_new_time) writer.write_boolean_value("SendResponse", @send_response) writer.write_additional_data(@additional_data) end |