Class: MicrosoftGraph::Me::Calendar::CalendarView::Item::EventItemRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/me/calendar/calendar_view/item/event_item_request_builder.rb

Overview

Provides operations to manage the calendarView property of the microsoft.graph.calendar entity.

Defined Under Namespace

Classes: EventItemRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new EventItemRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



91
92
93
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 91

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/me/calendar/calendarView/{event%2Did}{?startDateTime*,endDateTime*,%24select}")
end

Instance Method Details

#acceptObject

Provides operations to call the accept method.



32
33
34
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 32

def accept()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Accept::AcceptRequestBuilder.new(@path_parameters, @request_adapter)
end

#attachmentsObject

Provides operations to manage the attachments property of the microsoft.graph.event entity.



37
38
39
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 37

def attachments()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Attachments::AttachmentsRequestBuilder.new(@path_parameters, @request_adapter)
end

#calendarObject

Provides operations to manage the calendar property of the microsoft.graph.event entity.



42
43
44
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 42

def calendar()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Calendar::CalendarRequestBuilder.new(@path_parameters, @request_adapter)
end

#cancelObject

Provides operations to call the cancel method.



47
48
49
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 47

def cancel()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Cancel::CancelRequestBuilder.new(@path_parameters, @request_adapter)
end

#declineObject

Provides operations to call the decline method.



52
53
54
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 52

def decline()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Decline::DeclineRequestBuilder.new(@path_parameters, @request_adapter)
end

#dismiss_reminderObject

Provides operations to call the dismissReminder method.



57
58
59
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 57

def dismiss_reminder()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::DismissReminder::DismissReminderRequestBuilder.new(@path_parameters, @request_adapter)
end

#extensionsObject

Provides operations to manage the extensions property of the microsoft.graph.event entity.



62
63
64
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 62

def extensions()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Extensions::ExtensionsRequestBuilder.new(@path_parameters, @request_adapter)
end

#forwardObject

Provides operations to call the forward method.



67
68
69
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 67

def forward()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Forward::ForwardRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

The calendar view for the calendar. Navigation property. Read-only.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of event



99
100
101
102
103
104
105
106
107
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 99

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Event.create_from_discriminator_value(pn) }, error_mapping)
end

#instancesObject

Provides operations to manage the instances property of the microsoft.graph.event entity.



72
73
74
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 72

def instances()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::Instances::InstancesRequestBuilder.new(@path_parameters, @request_adapter)
end

#snooze_reminderObject

Provides operations to call the snoozeReminder method.



77
78
79
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 77

def snooze_reminder()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::SnoozeReminder::SnoozeReminderRequestBuilder.new(@path_parameters, @request_adapter)
end

#tentatively_acceptObject

Provides operations to call the tentativelyAccept method.



82
83
84
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 82

def tentatively_accept()
    return MicrosoftGraph::Me::Calendar::CalendarView::Item::TentativelyAccept::TentativelyAcceptRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

The calendar view for the calendar. Navigation property. Read-only.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/me/calendar/calendar_view/item/event_item_request_builder.rb', line 113

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end