Class: MicrosoftGraph::Me::Calendar::CalendarView::Item::Forward::ForwardPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new forwardPostRequestBody and sets the default values.



61
62
63
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 61

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a forward_post_request_body

Raises:

  • (StandardError)


69
70
71
72
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 69

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ForwardPostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



31
32
33
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 31

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



39
40
41
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 39

def additional_data=(value)
    @additional_data = value
end

#commentObject

Gets the Comment property value. The Comment property

Returns:

  • a string



46
47
48
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 46

def comment
    return @comment
end

#comment=(value) ⇒ Object

Sets the Comment property value. The Comment property

Parameters:

  • value

    Value to set for the Comment property.

Returns:

  • a void



54
55
56
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 54

def comment=(value)
    @comment = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



77
78
79
80
81
82
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 77

def get_field_deserializers()
    return {
        "Comment" => lambda {|n| @comment = n.get_string_value() },
        "ToRecipients" => lambda {|n| @to_recipients = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Recipient.create_from_discriminator_value(pn) }) },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


88
89
90
91
92
93
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 88

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("Comment", @comment)
    writer.write_collection_of_object_values("ToRecipients", @to_recipients)
    writer.write_additional_data(@additional_data)
end

#to_recipientsObject

Gets the ToRecipients property value. The ToRecipients property

Returns:

  • a recipient



98
99
100
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 98

def to_recipients
    return @to_recipients
end

#to_recipients=(value) ⇒ Object

Sets the ToRecipients property value. The ToRecipients property

Parameters:

  • value

    Value to set for the ToRecipients property.

Returns:

  • a void



106
107
108
# File 'lib/me/calendar/calendar_view/item/forward/forward_post_request_body.rb', line 106

def to_recipients=(value)
    @to_recipients = value
end