Class: MicrosoftGraph::Me::Calendar::Events::Item::Extensions::ExtensionsRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/me/calendar/events/item/extensions/extensions_request_builder.rb

Overview

Provides operations to manage the extensions property of the microsoft.graph.event entity.

Defined Under Namespace

Classes: ExtensionsRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ExtensionsRequestBuilder and sets the default values.



46
47
48
# File 'lib/me/calendar/events/item/extensions/extensions_request_builder.rb', line 46

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/me/calendar/events/{event%2Did}/extensions{?%24top,%24skip,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_extension_id(extension_id) ⇒ Object

Provides operations to manage the extensions property of the microsoft.graph.event entity.

Raises:

  • (StandardError)


34
35
36
37
38
39
# File 'lib/me/calendar/events/item/extensions/extensions_request_builder.rb', line 34

def by_extension_id(extension_id)
    raise StandardError, 'extension_id cannot be null' if extension_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["extension%2Did"] = extension_id
    return MicrosoftGraph::Me::Calendar::Events::Item::Extensions::Item::ExtensionItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



26
27
28
# File 'lib/me/calendar/events/item/extensions/extensions_request_builder.rb', line 26

def count()
    return MicrosoftGraph::Me::Calendar::Events::Item::Extensions::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Get an open extension (openTypeExtension object) identified by name or fully qualified name. The table in the Permissions section lists the resources that support open extensions. The following table lists the three scenarios where you can get an open extension from a supported resource instance.



54
55
56
57
58
59
60
61
62
# File 'lib/me/calendar/events/item/extensions/extensions_request_builder.rb', line 54

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ExtensionCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Create an open extension (openTypeExtension object) and add custom properties in a new or existing instance of a resource. You can create an open extension in a resource instance and store custom data to it all in the same operation, except for specific resources. The table in the Permissions section lists the resources that support open extensions.

Raises:

  • (StandardError)


69
70
71
72
73
74
75
76
77
78
# File 'lib/me/calendar/events/item/extensions/extensions_request_builder.rb', line 69

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Extension.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get an open extension (openTypeExtension object) identified by name or fully qualified name. The table in the Permissions section lists the resources that support open extensions. The following table lists the three scenarios where you can get an open extension from a supported resource instance.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/me/calendar/events/item/extensions/extensions_request_builder.rb', line 84

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create an open extension (openTypeExtension object) and add custom properties in a new or existing instance of a resource. You can create an open extension in a resource instance and store custom data to it all in the same operation, except for specific resources. The table in the Permissions section lists the resources that support open extensions.

Raises:

  • (StandardError)


103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/me/calendar/events/item/extensions/extensions_request_builder.rb', line 103

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end