Class: MicrosoftGraph::Me::Calendar::Events::Item::Extensions::Item::ExtensionItemRequestBuilder::ExtensionItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/calendar/events/item/extensions/item/extension_item_request_builder.rb

Overview

Get an open extension (openTypeExtension object) identified by name or fully qualified name. The table in the Permissions section lists the resources that support open extensions. The following table lists the three scenarios where you can get an open extension from a supported resource instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expand ⇒ Object

Expand related entities



137
138
139
# File 'lib/me/calendar/events/item/extensions/item/extension_item_request_builder.rb', line 137

def expand
  @expand
end

#select ⇒ Object

Select properties to be returned



140
141
142
# File 'lib/me/calendar/events/item/extensions/item/extension_item_request_builder.rb', line 140

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name —

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


146
147
148
149
150
151
152
153
154
155
156
# File 'lib/me/calendar/events/item/extensions/item/extension_item_request_builder.rb', line 146

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end