Class: MicrosoftGraph::Me::Calendar::GetSchedule::GetSchedulePostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Calendar::GetSchedule::GetSchedulePostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/me/calendar/get_schedule/get_schedule_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#availability_view_interval ⇒ Object
Gets the AvailabilityViewInterval property value.
-
#availability_view_interval=(value) ⇒ Object
Sets the AvailabilityViewInterval property value.
-
#end_time ⇒ Object
Gets the EndTime property value.
-
#end_time=(value) ⇒ Object
Sets the EndTime property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new getSchedulePostRequestBody and sets the default values.
-
#schedules ⇒ Object
Gets the Schedules property value.
-
#schedules=(value) ⇒ Object
Sets the Schedules property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#start_time ⇒ Object
Gets the StartTime property value.
-
#start_time=(value) ⇒ Object
Sets the StartTime property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new getSchedulePostRequestBody and sets the default values.
63 64 65 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 63 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
71 72 73 74 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 71 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GetSchedulePostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 33 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
41 42 43 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 41 def additional_data=(value) @additional_data = value end |
#availability_view_interval ⇒ Object
Gets the AvailabilityViewInterval property value. The AvailabilityViewInterval property
48 49 50 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 48 def availability_view_interval return @availability_view_interval end |
#availability_view_interval=(value) ⇒ Object
Sets the AvailabilityViewInterval property value. The AvailabilityViewInterval property
56 57 58 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 56 def availability_view_interval=(value) @availability_view_interval = value end |
#end_time ⇒ Object
Gets the EndTime property value. The EndTime property
79 80 81 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 79 def end_time return @end_time end |
#end_time=(value) ⇒ Object
Sets the EndTime property value. The EndTime property
87 88 89 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 87 def end_time=(value) @end_time = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
94 95 96 97 98 99 100 101 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 94 def get_field_deserializers() return { "AvailabilityViewInterval" => lambda {|n| @availability_view_interval = n.get_number_value() }, "EndTime" => lambda {|n| @end_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DateTimeTimeZone.create_from_discriminator_value(pn) }) }, "Schedules" => lambda {|n| @schedules = n.get_collection_of_primitive_values(String) }, "StartTime" => lambda {|n| @start_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DateTimeTimeZone.create_from_discriminator_value(pn) }) }, } end |
#schedules ⇒ Object
Gets the Schedules property value. The Schedules property
106 107 108 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 106 def schedules return @schedules end |
#schedules=(value) ⇒ Object
Sets the Schedules property value. The Schedules property
114 115 116 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 114 def schedules=(value) @schedules = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
122 123 124 125 126 127 128 129 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 122 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("AvailabilityViewInterval", @availability_view_interval) writer.write_object_value("EndTime", @end_time) writer.write_collection_of_primitive_values("Schedules", @schedules) writer.write_object_value("StartTime", @start_time) writer.write_additional_data(@additional_data) end |
#start_time ⇒ Object
Gets the StartTime property value. The StartTime property
134 135 136 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 134 def start_time return @start_time end |
#start_time=(value) ⇒ Object
Sets the StartTime property value. The StartTime property
142 143 144 |
# File 'lib/me/calendar/get_schedule/get_schedule_post_request_body.rb', line 142 def start_time=(value) @start_time = value end |