Class: MicrosoftGraph::Me::CalendarView::Item::Accept::AcceptPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/me/calendar_view/item/accept/accept_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new acceptPostRequestBody and sets the default values.



58
59
60
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 58

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a accept_post_request_body

Raises:

  • (StandardError)


66
67
68
69
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 66

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AcceptPostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



28
29
30
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 28

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



36
37
38
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 36

def additional_data=(value)
    @additional_data = value
end

#commentObject

Gets the Comment property value. The Comment property

Returns:

  • a string



43
44
45
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 43

def comment
    return @comment
end

#comment=(value) ⇒ Object

Sets the Comment property value. The Comment property

Parameters:

  • value

    Value to set for the Comment property.

Returns:

  • a void



51
52
53
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 51

def comment=(value)
    @comment = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



74
75
76
77
78
79
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 74

def get_field_deserializers()
    return {
        "Comment" => lambda {|n| @comment = n.get_string_value() },
        "SendResponse" => lambda {|n| @send_response = n.get_boolean_value() },
    }
end

#send_responseObject

Gets the SendResponse property value. The SendResponse property

Returns:

  • a boolean



84
85
86
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 84

def send_response
    return @send_response
end

#send_response=(value) ⇒ Object

Sets the SendResponse property value. The SendResponse property

Parameters:

  • value

    Value to set for the SendResponse property.

Returns:

  • a void



92
93
94
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 92

def send_response=(value)
    @send_response = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


100
101
102
103
104
105
# File 'lib/me/calendar_view/item/accept/accept_post_request_body.rb', line 100

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("Comment", @comment)
    writer.write_boolean_value("SendResponse", @send_response)
    writer.write_additional_data(@additional_data)
end