Class: MicrosoftGraph::Me::CalendarView::Item::Calendar::CalendarRequestBuilder::CalendarRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::CalendarView::Item::Calendar::CalendarRequestBuilder::CalendarRequestBuilderGetQueryParameters
- Defined in:
- lib/me/calendar_view/item/calendar/calendar_request_builder.rb
Overview
The calendar that contains the event. Navigation property. Read-only.
Instance Attribute Summary collapse
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#select ⇒ Object
Select properties to be returned
67 68 69 |
# File 'lib/me/calendar_view/item/calendar/calendar_request_builder.rb', line 67 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
73 74 75 76 77 78 79 80 81 |
# File 'lib/me/calendar_view/item/calendar/calendar_request_builder.rb', line 73 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "select" return "%24select" else return original_name end end |