Class: MicrosoftGraph::Me::CalendarView::Item::Instances::InstancesRequestBuilder::InstancesRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/calendar_view/item/instances/instances_request_builder.rb

Overview

The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



91
92
93
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 91

def count
  @count
end

#end_date_timeObject

The end date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T20:00:00-08:00



94
95
96
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 94

def end_date_time
  @end_date_time
end

#filterObject

Filter items by property values



97
98
99
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 97

def filter
  @filter
end

#orderbyObject

Order items by property values



100
101
102
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 100

def orderby
  @orderby
end

#selectObject

Select properties to be returned



103
104
105
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 103

def select
  @select
end

#skipObject

Skip the first n items



106
107
108
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 106

def skip
  @skip
end

#start_date_timeObject

The start date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T19:00:00-08:00



109
110
111
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 109

def start_date_time
  @start_date_time
end

#topObject

Show only the first n items



112
113
114
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 112

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • The original query parameter name in the class.

Returns:

  • a string

Raises:



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/me/calendar_view/item/instances/instances_request_builder.rb', line 118

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "end_date_time"
            return "endDateTime"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "start_date_time"
            return "startDateTime"
        when "top"
            return "%24top"
        else
            return original_name
    end
end