Class: MicrosoftGraph::Me::CalendarView::Item::Instances::Item::EventItemRequestBuilder::EventItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/calendar_view/item/instances/item/event_item_request_builder.rb

Overview

The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#end_date_timeObject

The end date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T20:00:00-08:00



129
130
131
# File 'lib/me/calendar_view/item/instances/item/event_item_request_builder.rb', line 129

def end_date_time
  @end_date_time
end

#selectObject

Select properties to be returned



132
133
134
# File 'lib/me/calendar_view/item/instances/item/event_item_request_builder.rb', line 132

def select
  @select
end

#start_date_timeObject

The start date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T19:00:00-08:00



135
136
137
# File 'lib/me/calendar_view/item/instances/item/event_item_request_builder.rb', line 135

def start_date_time
  @start_date_time
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/me/calendar_view/item/instances/item/event_item_request_builder.rb', line 141

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "end_date_time"
            return "endDateTime"
        when "select"
            return "%24select"
        when "start_date_time"
            return "startDateTime"
        else
            return original_name
    end
end