Class: MicrosoftGraph::Me::Calendars::Item::CalendarView::Item::Attachments::AttachmentsRequestBuilder::AttachmentsRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb

Overview

Retrieve a list of attachment objects attached to an event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



132
133
134
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 132

def count
  @count
end

#expandObject

Expand related entities



135
136
137
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 135

def expand
  @expand
end

#filterObject

Filter items by property values



138
139
140
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 138

def filter
  @filter
end

#orderbyObject

Order items by property values



141
142
143
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 141

def orderby
  @orderby
end

#selectObject

Select properties to be returned



144
145
146
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 144

def select
  @select
end

#skipObject

Skip the first n items



147
148
149
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 147

def skip
  @skip
end

#topObject

Show only the first n items



150
151
152
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 150

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/me/calendars/item/calendar_view/item/attachments/attachments_request_builder.rb', line 156

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "expand"
            return "%24expand"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "top"
            return "%24top"
        else
            return original_name
    end
end