Class: MicrosoftGraph::Me::Chats::ChatsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Chats::ChatsRequestBuilder
- Defined in:
- lib/me/chats/chats_request_builder.rb
Overview
Provides operations to manage the chats property of the microsoft.graph.user entity.
Defined Under Namespace
Classes: ChatsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_chat_id(chat_id) ⇒ Object
Provides operations to manage the chats property of the microsoft.graph.user entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the list of chats that the user is part of.
-
#get_all_messages ⇒ Object
Provides operations to call the getAllMessages method.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ChatsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to chats for me.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the list of chats that the user is part of.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to chats for me.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ChatsRequestBuilder and sets the default values.
46 47 48 |
# File 'lib/me/chats/chats_request_builder.rb', line 46 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/chats{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_chat_id(chat_id) ⇒ Object
Provides operations to manage the chats property of the microsoft.graph.user entity.
34 35 36 37 38 39 |
# File 'lib/me/chats/chats_request_builder.rb', line 34 def by_chat_id(chat_id) raise StandardError, 'chat_id cannot be null' if chat_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["chat%2Did"] = chat_id return MicrosoftGraph::Me::Chats::Item::ChatItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
21 22 23 |
# File 'lib/me/chats/chats_request_builder.rb', line 21 def count() return MicrosoftGraph::Me::Chats::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.
54 55 56 57 58 59 60 61 62 |
# File 'lib/me/chats/chats_request_builder.rb', line 54 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ChatCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#get_all_messages ⇒ Object
Provides operations to call the getAllMessages method.
26 27 28 |
# File 'lib/me/chats/chats_request_builder.rb', line 26 def () return MicrosoftGraph::Me::Chats::GetAllMessages::GetAllMessagesRequestBuilder.new(@path_parameters, @request_adapter) end |
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to chats for me
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/me/chats/chats_request_builder.rb', line 69 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Chat.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/me/chats/chats_request_builder.rb', line 84 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to chats for me
103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/me/chats/chats_request_builder.rb', line 103 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |