Class: MicrosoftGraph::Me::Chats::Item::Messages::MessagesRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/me/chats/item/messages/messages_request_builder.rb

Overview

Provides operations to manage the messages property of the microsoft.graph.chat entity.

Defined Under Namespace

Classes: MessagesRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new MessagesRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



50
51
52
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 50

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/me/chats/{chat%2Did}/messages{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_chat_message_id(chat_message_id) ⇒ Object

Provides operations to manage the messages property of the microsoft.graph.chat entity.

Parameters:

  • The unique identifier of chatMessage

Returns:

  • a chat_message_item_request_builder

Raises:



38
39
40
41
42
43
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 38

def by_chat_message_id(chat_message_id)
    raise StandardError, 'chat_message_id cannot be null' if chat_message_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["chatMessage%2Did"] = chat_message_id
    return MicrosoftGraph::Me::Chats::Item::Messages::Item::ChatMessageItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



25
26
27
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 25

def count()
    return MicrosoftGraph::Me::Chats::Item::Messages::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#deltaObject

Provides operations to call the delta method.



30
31
32
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 30

def delta()
    return MicrosoftGraph::Me::Chats::Item::Messages::Delta::DeltaRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve the list of messages in a chat. This method supports federation. To list chat messages in application context, the request must be made from the tenant that the channel owner belongs to (represented by the tenantId property on the channel).

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of chat_message_collection_response



58
59
60
61
62
63
64
65
66
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 58

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ChatMessageCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Send a new chatMessage in the specified channel or a chat.

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of chat_message

Raises:



73
74
75
76
77
78
79
80
81
82
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 73

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ChatMessage.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve the list of messages in a chat. This method supports federation. To list chat messages in application context, the request must be made from the tenant that the channel owner belongs to (represented by the tenantId property on the channel).

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 88

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Send a new chatMessage in the specified channel or a chat.

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:



107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 107

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end