Class: MicrosoftGraph::Me::ContactFolders::Delta::DeltaRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::ContactFolders::Delta::DeltaRequestBuilder
- Defined in:
- lib/me/contact_folders/delta/delta_request_builder.rb
Overview
Provides operations to call the delta method.
Defined Under Namespace
Classes: DeltaRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Get a set of contact folders that have been added, deleted, or removed from the user's mailbox.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DeltaRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a set of contact folders that have been added, deleted, or removed from the user's mailbox.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DeltaRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/me/contact_folders/delta/delta_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/contactFolders/delta(){?%24top,%24skip,%24search,%24filter,%24count,%24select,%24orderby}") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Get a set of contact folders that have been added, deleted, or removed from the user's mailbox. A delta function call for contact folders in a mailbox is similar to a GET request, except that by appropriately applying state tokens in one or more of these calls, you can query for incremental changes in the contact folders. This allows you to maintain and synchronize a local store of a user's contact folders without having to fetch all the contact folders of that mailbox from the server every time.
30 31 32 33 34 35 36 37 38 |
# File 'lib/me/contact_folders/delta/delta_request_builder.rb', line 30 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Me::ContactFolders::Delta::DeltaResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a set of contact folders that have been added, deleted, or removed from the user's mailbox. A delta function call for contact folders in a mailbox is similar to a GET request, except that by appropriately applying state tokens in one or more of these calls, you can query for incremental changes in the contact folders. This allows you to maintain and synchronize a local store of a user's contact folders without having to fetch all the contact folders of that mailbox from the server every time.
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/me/contact_folders/delta/delta_request_builder.rb', line 44 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |