Class: MicrosoftGraph::Me::ContactFolders::Item::ContactFolderItemRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/me/contact_folders/item/contact_folder_item_request_builder.rb

Overview

Provides operations to manage the contactFolders property of the microsoft.graph.user entity.

Defined Under Namespace

Classes: ContactFolderItemRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ContactFolderItemRequestBuilder and sets the default values.

Parameters:

  • path_parameters —

    Path parameters for the request

  • request_adapter —

    The request adapter to use to execute the requests.



35
36
37
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 35

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/me/contactFolders/{contactFolder%2Did}{?%24select,%24expand}")
end

Instance Method Details

#child_folders ⇒ Object

Provides operations to manage the childFolders property of the microsoft.graph.contactFolder entity.



21
22
23
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 21

def child_folders()
    return MicrosoftGraph::Me::ContactFolders::Item::ChildFolders::ChildFoldersRequestBuilder.new(@path_parameters, @request_adapter)
end

#contacts ⇒ Object

Provides operations to manage the contacts property of the microsoft.graph.contactFolder entity.



26
27
28
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 26

def contacts()
    return MicrosoftGraph::Me::ContactFolders::Item::Contacts::ContactsRequestBuilder.new(@path_parameters, @request_adapter)
end

#delete(request_configuration = nil) ⇒ Object

Delete contactFolder other than the default contactFolder.

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



43
44
45
46
47
48
49
50
51
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 43

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Get a contact folder by using the contact folder ID. There are two scenarios where an app can get another user's contact folder:

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of contact_folder



57
58
59
60
61
62
63
64
65
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 57

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ContactFolder.create_from_discriminator_value(pn) }, error_mapping)
end

#patch(body, request_configuration = nil) ⇒ Object

Update the properties of contactfolder object.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of contact_folder

Raises:

  • (StandardError)


72
73
74
75
76
77
78
79
80
81
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 72

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ContactFolder.create_from_discriminator_value(pn) }, error_mapping)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Delete contactFolder other than the default contactFolder.

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



87
88
89
90
91
92
93
94
95
96
97
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 87

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get a contact folder by using the contact folder ID. There are two scenarios where an app can get another user's contact folder:

Parameters:

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 103

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update the properties of contactfolder object.

Parameters:

  • body —

    The request body

  • request_configuration (defaults to: nil) —

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/me/contact_folders/item/contact_folder_item_request_builder.rb', line 122

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end