Class: MicrosoftGraph::Me::Events::EventsRequestBuilder::EventsRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/events/events_request_builder.rb

Overview

Get a list of event objects in the user’s mailbox. The list contains single instance meetings and series masters. To get expanded event instances, you can get the calendar view, or get the instances of an event. Currently, this operation returns event bodies in only HTML format. There are two scenarios where an app can get events in another user’s calendar:

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



124
125
126
# File 'lib/me/events/events_request_builder.rb', line 124

def count
  @count
end

#expandObject

Expand related entities



127
128
129
# File 'lib/me/events/events_request_builder.rb', line 127

def expand
  @expand
end

#filterObject

Filter items by property values



130
131
132
# File 'lib/me/events/events_request_builder.rb', line 130

def filter
  @filter
end

#orderbyObject

Order items by property values



133
134
135
# File 'lib/me/events/events_request_builder.rb', line 133

def orderby
  @orderby
end

#selectObject

Select properties to be returned



136
137
138
# File 'lib/me/events/events_request_builder.rb', line 136

def select
  @select
end

#skipObject

Skip the first n items



139
140
141
# File 'lib/me/events/events_request_builder.rb', line 139

def skip
  @skip
end

#topObject

Show only the first n items



142
143
144
# File 'lib/me/events/events_request_builder.rb', line 142

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/me/events/events_request_builder.rb', line 148

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "expand"
            return "%24expand"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "top"
            return "%24top"
        else
            return original_name
    end
end