Class: MicrosoftGraph::Me::FindMeetingTimes::FindMeetingTimesPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/me/find_meeting_times/find_meeting_times_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize ⇒ Object

Instantiates a new findMeetingTimesPostRequestBody and sets the default values.



75
76
77
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 75

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node —

    The parse node to use to read the discriminator value and create the object

Returns:

  • a find_meeting_times_post_request_body

Raises:

  • (StandardError)


83
84
85
86
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 83

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return FindMeetingTimesPostRequestBody.new
end

Instance Method Details

#additional_data ⇒ Object

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



45
46
47
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 45

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value —

    Value to set for the additionalData property.

Returns:

  • a void



53
54
55
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 53

def additional_data=(value)
    @additional_data = value
end

#attendees ⇒ Object

Gets the attendees property value. The attendees property

Returns:

  • a attendee_base



60
61
62
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 60

def attendees
    return @attendees
end

#attendees=(value) ⇒ Object

Sets the attendees property value. The attendees property

Parameters:

  • value —

    Value to set for the attendees property.

Returns:

  • a void



68
69
70
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 68

def attendees=(value)
    @attendees = value
end

#get_field_deserializers ⇒ Object

The deserialization information for the current model

Returns:

  • a i_dictionary



91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 91

def get_field_deserializers()
    return {
        "attendees" => lambda {|n| @attendees = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AttendeeBase.create_from_discriminator_value(pn) }) },
        "isOrganizerOptional" => lambda {|n| @is_organizer_optional = n.get_boolean_value() },
        "locationConstraint" => lambda {|n| @location_constraint = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::LocationConstraint.create_from_discriminator_value(pn) }) },
        "maxCandidates" => lambda {|n| @max_candidates = n.get_number_value() },
        "meetingDuration" => lambda {|n| @meeting_duration = n.get_duration_value() },
        "minimumAttendeePercentage" => lambda {|n| @minimum_attendee_percentage = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "returnSuggestionReasons" => lambda {|n| @return_suggestion_reasons = n.get_boolean_value() },
        "timeConstraint" => lambda {|n| @time_constraint = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TimeConstraint.create_from_discriminator_value(pn) }) },
    }
end

#is_organizer_optional ⇒ Object

Gets the isOrganizerOptional property value. The isOrganizerOptional property

Returns:

  • a boolean



107
108
109
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 107

def is_organizer_optional
    return @is_organizer_optional
end

#is_organizer_optional=(value) ⇒ Object

Sets the isOrganizerOptional property value. The isOrganizerOptional property

Parameters:

  • value —

    Value to set for the isOrganizerOptional property.

Returns:

  • a void



115
116
117
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 115

def is_organizer_optional=(value)
    @is_organizer_optional = value
end

#location_constraint ⇒ Object

Gets the locationConstraint property value. The locationConstraint property

Returns:

  • a location_constraint



122
123
124
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 122

def location_constraint
    return @location_constraint
end

#location_constraint=(value) ⇒ Object

Sets the locationConstraint property value. The locationConstraint property

Parameters:

  • value —

    Value to set for the locationConstraint property.

Returns:

  • a void



130
131
132
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 130

def location_constraint=(value)
    @location_constraint = value
end

#max_candidates ⇒ Object

Gets the maxCandidates property value. The maxCandidates property

Returns:

  • a integer



137
138
139
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 137

def max_candidates
    return @max_candidates
end

#max_candidates=(value) ⇒ Object

Sets the maxCandidates property value. The maxCandidates property

Parameters:

  • value —

    Value to set for the maxCandidates property.

Returns:

  • a void



145
146
147
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 145

def max_candidates=(value)
    @max_candidates = value
end

#meeting_duration ⇒ Object

Gets the meetingDuration property value. The meetingDuration property

Returns:

  • a microsoft_kiota_abstractions::_i_s_o_duration



152
153
154
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 152

def meeting_duration
    return @meeting_duration
end

#meeting_duration=(value) ⇒ Object

Sets the meetingDuration property value. The meetingDuration property

Parameters:

  • value —

    Value to set for the meetingDuration property.

Returns:

  • a void



160
161
162
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 160

def meeting_duration=(value)
    @meeting_duration = value
end

#minimum_attendee_percentage ⇒ Object

Gets the minimumAttendeePercentage property value. The minimumAttendeePercentage property

Returns:

  • a double



167
168
169
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 167

def minimum_attendee_percentage
    return @minimum_attendee_percentage
end

#minimum_attendee_percentage=(value) ⇒ Object

Sets the minimumAttendeePercentage property value. The minimumAttendeePercentage property

Parameters:

  • value —

    Value to set for the minimumAttendeePercentage property.

Returns:

  • a void



175
176
177
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 175

def minimum_attendee_percentage=(value)
    @minimum_attendee_percentage = value
end

#return_suggestion_reasons ⇒ Object

Gets the returnSuggestionReasons property value. The returnSuggestionReasons property

Returns:

  • a boolean



182
183
184
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 182

def return_suggestion_reasons
    return @return_suggestion_reasons
end

#return_suggestion_reasons=(value) ⇒ Object

Sets the returnSuggestionReasons property value. The returnSuggestionReasons property

Parameters:

  • value —

    Value to set for the returnSuggestionReasons property.

Returns:

  • a void



190
191
192
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 190

def return_suggestion_reasons=(value)
    @return_suggestion_reasons = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer —

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 198

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_object_values("attendees", @attendees)
    writer.write_boolean_value("isOrganizerOptional", @is_organizer_optional)
    writer.write_object_value("locationConstraint", @location_constraint)
    writer.write_number_value("maxCandidates", @max_candidates)
    writer.write_duration_value("meetingDuration", @meeting_duration)
    writer.write_object_value("minimumAttendeePercentage", @minimum_attendee_percentage)
    writer.write_boolean_value("returnSuggestionReasons", @return_suggestion_reasons)
    writer.write_object_value("timeConstraint", @time_constraint)
    writer.write_additional_data(@additional_data)
end

#time_constraint ⇒ Object

Gets the timeConstraint property value. The timeConstraint property

Returns:

  • a time_constraint



214
215
216
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 214

def time_constraint
    return @time_constraint
end

#time_constraint=(value) ⇒ Object

Sets the timeConstraint property value. The timeConstraint property

Parameters:

  • value —

    Value to set for the timeConstraint property.

Returns:

  • a void



222
223
224
# File 'lib/me/find_meeting_times/find_meeting_times_post_request_body.rb', line 222

def time_constraint=(value)
    @time_constraint = value
end