Class: MicrosoftGraph::Me::InferenceClassification::Overrides::Item::InferenceClassificationOverrideItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::InferenceClassification::Overrides::Item::InferenceClassificationOverrideItemRequestBuilder
- Defined in:
- lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb
Overview
Provides operations to manage the overrides property of the microsoft.graph.inferenceClassification entity.
Defined Under Namespace
Classes: InferenceClassificationOverrideItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete an override specified by its ID.
-
#get(request_configuration = nil) ⇒ Object
A set of overrides for a user to always classify messages from specific senders in certain ways: focused, or other.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new InferenceClassificationOverrideItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Change the classifyAs field of an override as specified.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete an override specified by its ID.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
A set of overrides for a user to always classify messages from specific senders in certain ways: focused, or other.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Change the classifyAs field of an override as specified.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new InferenceClassificationOverrideItemRequestBuilder and sets the default values.
25 26 27 |
# File 'lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb', line 25 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/inferenceClassification/overrides/{inferenceClassificationOverride%2Did}{?%24select}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete an override specified by its ID.
33 34 35 36 37 38 39 40 41 |
# File 'lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb', line 33 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
A set of overrides for a user to always classify messages from specific senders in certain ways: focused, or other. Read-only. Nullable.
47 48 49 50 51 52 53 54 55 |
# File 'lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb', line 47 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::InferenceClassificationOverride.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Change the classifyAs field of an override as specified. You cannot use PATCH to change any other fields in an inferenceClassificationOverride instance. If an override exists for a sender and the sender changes his/her display name, you can use POST to force an update to the name field in the existing override. If an override exists for a sender and the sender changes his/her SMTP address, deleting the existing override and creating a new one withthe new SMTP address is the only way to ‘update’ the override for this sender.
62 63 64 65 66 67 68 69 70 71 |
# File 'lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb', line 62 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::InferenceClassificationOverride.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete an override specified by its ID.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb', line 77 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
A set of overrides for a user to always classify messages from specific senders in certain ways: focused, or other. Read-only. Nullable.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb', line 93 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Change the classifyAs field of an override as specified. You cannot use PATCH to change any other fields in an inferenceClassificationOverride instance. If an override exists for a sender and the sender changes his/her display name, you can use POST to force an update to the name field in the existing override. If an override exists for a sender and the sender changes his/her SMTP address, deleting the existing override and creating a new one withthe new SMTP address is the only way to ‘update’ the override for this sender.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/me/inference_classification/overrides/item/inference_classification_override_item_request_builder.rb', line 112 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |