Class: MicrosoftGraph::Me::Insights::Shared::Item::Resource::ResourceRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Insights::Shared::Item::Resource::ResourceRequestBuilder
- Defined in:
- lib/me/insights/shared/item/resource/resource_request_builder.rb
Overview
Provides operations to manage the resource property of the microsoft.graph.sharedInsight entity.
Defined Under Namespace
Classes: ResourceRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Used for navigating to the item that was shared.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ResourceRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Used for navigating to the item that was shared.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ResourceRequestBuilder and sets the default values.
27 28 29 |
# File 'lib/me/insights/shared/item/resource/resource_request_builder.rb', line 27 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/insights/shared/{sharedInsight%2Did}/resource{?%24select,%24expand}") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Used for navigating to the item that was shared. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.
35 36 37 38 39 40 41 42 43 |
# File 'lib/me/insights/shared/item/resource/resource_request_builder.rb', line 35 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Entity.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Used for navigating to the item that was shared. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/me/insights/shared/item/resource/resource_request_builder.rb', line 49 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |