Class: MicrosoftGraph::Me::Insights::Shared::Item::SharedInsightItemRequestBuilder::SharedInsightItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/insights/shared/item/shared_insight_item_request_builder.rb

Overview

Calculated relationship identifying documents shared with or by the user. This includes URLs, file attachments, and reference attachments to OneDrive for Business and SharePoint files found in Outlook messages and meetings. This also includes URLs and reference attachments to Teams conversations. Ordered by recency of share.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expand ⇒ Object

Expand related entities



145
146
147
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 145

def expand
  @expand
end

#select ⇒ Object

Select properties to be returned



148
149
150
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 148

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name —

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


154
155
156
157
158
159
160
161
162
163
164
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 154

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end