Class: MicrosoftGraph::Me::Insights::Shared::SharedRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Insights::Shared::SharedRequestBuilder
- Defined in:
- lib/me/insights/shared/shared_request_builder.rb
Overview
Provides operations to manage the shared property of the microsoft.graph.officeGraphInsights entity.
Defined Under Namespace
Classes: SharedRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_shared_insight_id(shared_insight_id) ⇒ Object
Provides operations to manage the shared property of the microsoft.graph.officeGraphInsights entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Calculated insight that includes the list of documents shared with a user.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new SharedRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to shared for me.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Calculated insight that includes the list of documents shared with a user.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to shared for me.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new SharedRequestBuilder and sets the default values.
42 43 44 |
# File 'lib/me/insights/shared/shared_request_builder.rb', line 42 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/insights/shared{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_shared_insight_id(shared_insight_id) ⇒ Object
Provides operations to manage the shared property of the microsoft.graph.officeGraphInsights entity.
30 31 32 33 34 35 |
# File 'lib/me/insights/shared/shared_request_builder.rb', line 30 def by_shared_insight_id(shared_insight_id) raise StandardError, 'shared_insight_id cannot be null' if shared_insight_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["sharedInsight%2Did"] = shared_insight_id return MicrosoftGraph::Me::Insights::Shared::Item::SharedInsightItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
22 23 24 |
# File 'lib/me/insights/shared/shared_request_builder.rb', line 22 def count() return MicrosoftGraph::Me::Insights::Shared::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Calculated insight that includes the list of documents shared with a user. This insight includes documents hosted on OneDrive/SharePoint in the user’s Microsoft 365 tenant that are shared with the user, and documents that are attached as files and sent to the user.
50 51 52 53 54 55 56 57 58 |
# File 'lib/me/insights/shared/shared_request_builder.rb', line 50 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SharedInsightCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to shared for me
65 66 67 68 69 70 71 72 73 74 |
# File 'lib/me/insights/shared/shared_request_builder.rb', line 65 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SharedInsight.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Calculated insight that includes the list of documents shared with a user. This insight includes documents hosted on OneDrive/SharePoint in the user’s Microsoft 365 tenant that are shared with the user, and documents that are attached as files and sent to the user.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/me/insights/shared/shared_request_builder.rb', line 80 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to shared for me
99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/me/insights/shared/shared_request_builder.rb', line 99 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |