Class: MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::ChannelItemRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb

Overview

Provides operations to manage the channels property of the microsoft.graph.team entity.

Defined Under Namespace

Classes: ChannelItemRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ChannelItemRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



81
82
83
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 81

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/me/joinedTeams/{team%2Did}/channels/{channel%2Did}{?%24select,%24expand}")
end

Instance Method Details

#complete_migrationObject

Provides operations to call the completeMigration method.



32
33
34
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 32

def complete_migration()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::CompleteMigration::CompleteMigrationRequestBuilder.new(@path_parameters, @request_adapter)
end

#delete(request_configuration = nil) ⇒ Object

Delete the channel.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



89
90
91
92
93
94
95
96
97
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 89

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_nameObject

Provides operations to call the doesUserHaveAccess method.



37
38
39
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 37

def does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_name()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName::DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder.new(@path_parameters, @request_adapter)
end

#files_folderObject

Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.



42
43
44
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 42

def files_folder()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::FilesFolder::FilesFolderRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve the properties and relationships of a channel. This method supports federation. Only a user who is a member of the shared channel can retrieve channel information.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of channel



103
104
105
106
107
108
109
110
111
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 103

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Channel.create_from_discriminator_value(pn) }, error_mapping)
end

#membersObject

Provides operations to manage the members property of the microsoft.graph.channel entity.



47
48
49
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 47

def members()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::Members::MembersRequestBuilder.new(@path_parameters, @request_adapter)
end

#messagesObject

Provides operations to manage the messages property of the microsoft.graph.channel entity.



52
53
54
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 52

def messages()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::Messages::MessagesRequestBuilder.new(@path_parameters, @request_adapter)
end

#patch(body, request_configuration = nil) ⇒ Object

Update the properties of the specified channel.

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of channel

Raises:



118
119
120
121
122
123
124
125
126
127
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 118

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Channel.create_from_discriminator_value(pn) }, error_mapping)
end

#provision_emailObject

Provides operations to call the provisionEmail method.



57
58
59
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 57

def provision_email()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::ProvisionEmail::ProvisionEmailRequestBuilder.new(@path_parameters, @request_adapter)
end

#remove_emailObject

Provides operations to call the removeEmail method.



62
63
64
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 62

def remove_email()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::RemoveEmail::RemoveEmailRequestBuilder.new(@path_parameters, @request_adapter)
end

#shared_with_teamsObject

Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.



67
68
69
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 67

def shared_with_teams()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::SharedWithTeams::SharedWithTeamsRequestBuilder.new(@path_parameters, @request_adapter)
end

#tabsObject

Provides operations to manage the tabs property of the microsoft.graph.channel entity.



72
73
74
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 72

def tabs()
    return MicrosoftGraph::Me::JoinedTeams::Item::Channels::Item::Tabs::TabsRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Delete the channel.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



133
134
135
136
137
138
139
140
141
142
143
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 133

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve the properties and relationships of a channel. This method supports federation. Only a user who is a member of the shared channel can retrieve channel information.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 149

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update the properties of the specified channel.

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:



168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/me/joined_teams/item/channels/item/channel_item_request_builder.rb', line 168

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end