Class: MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::PrimaryChannelRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::PrimaryChannelRequestBuilder
- Defined in:
- lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb
Overview
Provides operations to manage the primaryChannel property of the microsoft.graph.team entity.
Defined Under Namespace
Classes: PrimaryChannelRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#complete_migration ⇒ Object
Provides operations to call the completeMigration method.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for me.
-
#does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_name ⇒ Object
Provides operations to call the doesUserHaveAccess method.
-
#files_folder ⇒ Object
Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
-
#get(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new PrimaryChannelRequestBuilder and sets the default values.
-
#members ⇒ Object
Provides operations to manage the members property of the microsoft.graph.channel entity.
-
#messages ⇒ Object
Provides operations to manage the messages property of the microsoft.graph.channel entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in me.
-
#provision_email ⇒ Object
Provides operations to call the provisionEmail method.
-
#remove_email ⇒ Object
Provides operations to call the removeEmail method.
-
#shared_with_teams ⇒ Object
Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
-
#tabs ⇒ Object
Provides operations to manage the tabs property of the microsoft.graph.channel entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for me.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in me.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new PrimaryChannelRequestBuilder and sets the default values.
79 80 81 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 79 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/joinedTeams/{team%2Did}/primaryChannel{?%24select,%24expand}") end |
Instance Method Details
#complete_migration ⇒ Object
Provides operations to call the completeMigration method.
30 31 32 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 30 def complete_migration() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::CompleteMigration::CompleteMigrationRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for me
87 88 89 90 91 92 93 94 95 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 87 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_name ⇒ Object
Provides operations to call the doesUserHaveAccess method.
35 36 37 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 35 def does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_name() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName::DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder.new(@path_parameters, @request_adapter) end |
#files_folder ⇒ Object
Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
40 41 42 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 40 def files_folder() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::FilesFolder::FilesFolderRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
101 102 103 104 105 106 107 108 109 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 101 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Channel.create_from_discriminator_value(pn) }, error_mapping) end |
#members ⇒ Object
Provides operations to manage the members property of the microsoft.graph.channel entity.
45 46 47 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 45 def members() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::Members::MembersRequestBuilder.new(@path_parameters, @request_adapter) end |
#messages ⇒ Object
Provides operations to manage the messages property of the microsoft.graph.channel entity.
50 51 52 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 50 def () return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::Messages::MessagesRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in me
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 116 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Channel.create_from_discriminator_value(pn) }, error_mapping) end |
#provision_email ⇒ Object
Provides operations to call the provisionEmail method.
55 56 57 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 55 def provision_email() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::ProvisionEmail::ProvisionEmailRequestBuilder.new(@path_parameters, @request_adapter) end |
#remove_email ⇒ Object
Provides operations to call the removeEmail method.
60 61 62 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 60 def remove_email() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::RemoveEmail::RemoveEmailRequestBuilder.new(@path_parameters, @request_adapter) end |
#shared_with_teams ⇒ Object
Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
65 66 67 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 65 def shared_with_teams() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::SharedWithTeams::SharedWithTeamsRequestBuilder.new(@path_parameters, @request_adapter) end |
#tabs ⇒ Object
Provides operations to manage the tabs property of the microsoft.graph.channel entity.
70 71 72 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 70 def tabs() return MicrosoftGraph::Me::JoinedTeams::Item::PrimaryChannel::Tabs::TabsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for me
131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 131 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 147 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in me
166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/me/joined_teams/item/primary_channel/primary_channel_request_builder.rb', line 166 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |