Class: MicrosoftGraph::Me::JoinedTeams::Item::Schedule::ScheduleRequestBuilder::ScheduleRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/joined_teams/item/schedule/schedule_request_builder.rb

Overview

Retrieve the properties and relationships of a schedule object. The schedule creation process conforms to the One API guideline for resource based long running operations (RELO).When clients use the PUT method, if the schedule is provisioned, the operation updates the schedule; otherwise, the operation starts the schedule provisioning process in the background. During schedule provisioning, clients can use the GET method to get the schedule and look at the provisionStatus property for the current state of the provisioning. If the provisioning failed, clients can get additional information from the provisionStatusCode property. Clients can also inspect the configuration of the schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



193
194
195
# File 'lib/me/joined_teams/item/schedule/schedule_request_builder.rb', line 193

def expand
  @expand
end

#selectObject

Select properties to be returned



196
197
198
# File 'lib/me/joined_teams/item/schedule/schedule_request_builder.rb', line 196

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


202
203
204
205
206
207
208
209
210
211
212
# File 'lib/me/joined_teams/item/schedule/schedule_request_builder.rb', line 202

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end