Class: MicrosoftGraph::Me::MailFolders::Item::MessageRules::MessageRulesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::MailFolders::Item::MessageRules::MessageRulesRequestBuilder
- Defined in:
- lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb
Overview
Provides operations to manage the messageRules property of the microsoft.graph.mailFolder entity.
Defined Under Namespace
Classes: MessageRulesRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_message_rule_id(message_rule_id) ⇒ Object
Provides operations to manage the messageRules property of the microsoft.graph.mailFolder entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get all the messageRule objects defined for the user’s inbox.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MessageRulesRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a messageRule object by specifying a set of conditions and actions.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get all the messageRule objects defined for the user’s inbox.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a messageRule object by specifying a set of conditions and actions.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MessageRulesRequestBuilder and sets the default values.
44 45 46 |
# File 'lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb', line 44 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/mailFolders/{mailFolder%2Did}/messageRules{?%24top,%24skip,%24filter,%24count,%24orderby,%24select}") end |
Instance Method Details
#by_message_rule_id(message_rule_id) ⇒ Object
Provides operations to manage the messageRules property of the microsoft.graph.mailFolder entity.
32 33 34 35 36 37 |
# File 'lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb', line 32 def () raise StandardError, 'message_rule_id cannot be null' if .nil? url_tpl_params = @path_parameters.clone url_tpl_params["messageRule%2Did"] = return MicrosoftGraph::Me::MailFolders::Item::MessageRules::Item::MessageRuleItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
24 25 26 |
# File 'lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb', line 24 def count() return MicrosoftGraph::Me::MailFolders::Item::MessageRules::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get all the messageRule objects defined for the user’s inbox.
52 53 54 55 56 57 58 59 60 |
# File 'lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb', line 52 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::MessageRuleCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create a messageRule object by specifying a set of conditions and actions. Outlook carries out those actions if an incoming message in the user’s Inbox meets the specified conditions.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb', line 67 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::MessageRule.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get all the messageRule objects defined for the user’s inbox.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb', line 82 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a messageRule object by specifying a set of conditions and actions. Outlook carries out those actions if an incoming message in the user’s Inbox meets the specified conditions.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/me/mail_folders/item/message_rules/message_rules_request_builder.rb', line 101 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |