Class: MicrosoftGraph::Me::MeRequestBuilder::MeRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/me_request_builder.rb

Overview

Returns the user or organizational contact assigned as the user’s manager. Optionally, you can expand the manager’s chain up to the root node.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



529
530
531
# File 'lib/me/me_request_builder.rb', line 529

def expand
  @expand
end

#selectObject

Select properties to be returned



532
533
534
# File 'lib/me/me_request_builder.rb', line 532

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


538
539
540
541
542
543
544
545
546
547
548
# File 'lib/me/me_request_builder.rb', line 538

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end