Class: MicrosoftGraph::Me::Messages::Delta::DeltaRequestBuilder::DeltaRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/messages/delta/delta_request_builder.rb

Overview

Get a set of messages that have been added, deleted, or updated in a specified folder. A delta function call for messages in a folder is similar to a GET request, except that by appropriately applying state tokens in one or more of these calls, you can query for incremental changes in the messages in that folder. This allows you to maintain and synchronize a local store of a user's messages without having to fetch the entire set of messages from the server every time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#count ⇒ Object

Include count of items



64
65
66
# File 'lib/me/messages/delta/delta_request_builder.rb', line 64

def count
  @count
end

#filter ⇒ Object

Filter items by property values



67
68
69
# File 'lib/me/messages/delta/delta_request_builder.rb', line 67

def filter
  @filter
end

#orderby ⇒ Object

Order items by property values



70
71
72
# File 'lib/me/messages/delta/delta_request_builder.rb', line 70

def orderby
  @orderby
end

#search ⇒ Object

Search items by search phrases



73
74
75
# File 'lib/me/messages/delta/delta_request_builder.rb', line 73

def search
  @search
end

#select ⇒ Object

Select properties to be returned



76
77
78
# File 'lib/me/messages/delta/delta_request_builder.rb', line 76

def select
  @select
end

#skip ⇒ Object

Skip the first n items



79
80
81
# File 'lib/me/messages/delta/delta_request_builder.rb', line 79

def skip
  @skip
end

#top ⇒ Object

Show only the first n items



82
83
84
# File 'lib/me/messages/delta/delta_request_builder.rb', line 82

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name —

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/me/messages/delta/delta_request_builder.rb', line 88

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "search"
            return "%24search"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "top"
            return "%24top"
        else
            return original_name
    end
end