Class: MicrosoftGraph::Me::Onenote::Notebooks::GetNotebookFromWebUrl::GetNotebookFromWebUrlPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Onenote::Notebooks::GetNotebookFromWebUrl::GetNotebookFromWebUrlPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new getNotebookFromWebUrlPostRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#web_url ⇒ Object
Gets the webUrl property value.
-
#web_url=(value) ⇒ Object
Sets the webUrl property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new getNotebookFromWebUrlPostRequestBody and sets the default values.
40 41 42 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 40 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GetNotebookFromWebUrlPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 33 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
56 57 58 59 60 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 56 def get_field_deserializers() return { "webUrl" => lambda {|n| @web_url = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
66 67 68 69 70 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 66 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("webUrl", @web_url) writer.write_additional_data(@additional_data) end |
#web_url ⇒ Object
Gets the webUrl property value. The webUrl property
75 76 77 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 75 def web_url return @web_url end |
#web_url=(value) ⇒ Object
Sets the webUrl property value. The webUrl property
83 84 85 |
# File 'lib/me/onenote/notebooks/get_notebook_from_web_url/get_notebook_from_web_url_post_request_body.rb', line 83 def web_url=(value) @web_url = value end |