Class: MicrosoftGraph::Me::Onenote::Notebooks::Item::NotebookItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Onenote::Notebooks::Item::NotebookItemRequestBuilder
- Defined in:
- lib/me/onenote/notebooks/item/notebook_item_request_builder.rb
Overview
Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.
Defined Under Namespace
Classes: NotebookItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#copy_notebook ⇒ Object
Provides operations to call the copyNotebook method.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property notebooks for me.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a notebook object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new NotebookItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property notebooks in me.
-
#section_groups ⇒ Object
Provides operations to manage the sectionGroups property of the microsoft.graph.notebook entity.
-
#sections ⇒ Object
Provides operations to manage the sections property of the microsoft.graph.notebook entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property notebooks for me.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a notebook object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property notebooks in me.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new NotebookItemRequestBuilder and sets the default values.
43 44 45 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 43 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/onenote/notebooks/{notebook%2Did}{?%24select,%24expand}") end |
Instance Method Details
#copy_notebook ⇒ Object
Provides operations to call the copyNotebook method.
24 25 26 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 24 def copy_notebook() return MicrosoftGraph::Me::Onenote::Notebooks::Item::CopyNotebook::CopyNotebookRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property notebooks for me
51 52 53 54 55 56 57 58 59 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 51 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a notebook object.
65 66 67 68 69 70 71 72 73 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 65 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Notebook.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property notebooks in me
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 80 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Notebook.create_from_discriminator_value(pn) }, error_mapping) end |
#section_groups ⇒ Object
Provides operations to manage the sectionGroups property of the microsoft.graph.notebook entity.
29 30 31 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 29 def section_groups() return MicrosoftGraph::Me::Onenote::Notebooks::Item::SectionGroups::SectionGroupsRequestBuilder.new(@path_parameters, @request_adapter) end |
#sections ⇒ Object
Provides operations to manage the sections property of the microsoft.graph.notebook entity.
34 35 36 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 34 def sections() return MicrosoftGraph::Me::Onenote::Notebooks::Item::Sections::SectionsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property notebooks for me
95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 95 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a notebook object.
111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 111 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property notebooks in me
130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/me/onenote/notebooks/item/notebook_item_request_builder.rb', line 130 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |