Class: MicrosoftGraph::Me::Onenote::Notebooks::Item::Sections::Item::CopyToSectionGroup::CopyToSectionGroupPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new copyToSectionGroupPostRequestBody and sets the default values.



58
59
60
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 58

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a copy_to_section_group_post_request_body

Raises:

  • (StandardError)


66
67
68
69
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 66

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return CopyToSectionGroupPostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



43
44
45
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 43

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



51
52
53
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 51

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



74
75
76
77
78
79
80
81
82
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 74

def get_field_deserializers()
    return {
        "groupId" => lambda {|n| @group_id = n.get_string_value() },
        "id" => lambda {|n| @id = n.get_string_value() },
        "renameAs" => lambda {|n| @rename_as = n.get_string_value() },
        "siteCollectionId" => lambda {|n| @site_collection_id = n.get_string_value() },
        "siteId" => lambda {|n| @site_id = n.get_string_value() },
    }
end

#group_idObject

Gets the groupId property value. The groupId property

Returns:

  • a string



87
88
89
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 87

def group_id
    return @group_id
end

#group_id=(value) ⇒ Object

Sets the groupId property value. The groupId property

Parameters:

  • value

    Value to set for the groupId property.

Returns:

  • a void



95
96
97
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 95

def group_id=(value)
    @group_id = value
end

#idObject

Gets the id property value. The id property

Returns:

  • a string



102
103
104
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 102

def id
    return @id
end

#id=(value) ⇒ Object

Sets the id property value. The id property

Parameters:

  • value

    Value to set for the id property.

Returns:

  • a void



110
111
112
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 110

def id=(value)
    @id = value
end

#rename_asObject

Gets the renameAs property value. The renameAs property

Returns:

  • a string



117
118
119
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 117

def rename_as
    return @rename_as
end

#rename_as=(value) ⇒ Object

Sets the renameAs property value. The renameAs property

Parameters:

  • value

    Value to set for the renameAs property.

Returns:

  • a void



125
126
127
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 125

def rename_as=(value)
    @rename_as = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


133
134
135
136
137
138
139
140
141
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 133

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("groupId", @group_id)
    writer.write_string_value("id", @id)
    writer.write_string_value("renameAs", @rename_as)
    writer.write_string_value("siteCollectionId", @site_collection_id)
    writer.write_string_value("siteId", @site_id)
    writer.write_additional_data(@additional_data)
end

#site_collection_idObject

Gets the siteCollectionId property value. The siteCollectionId property

Returns:

  • a string



146
147
148
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 146

def site_collection_id
    return @site_collection_id
end

#site_collection_id=(value) ⇒ Object

Sets the siteCollectionId property value. The siteCollectionId property

Parameters:

  • value

    Value to set for the siteCollectionId property.

Returns:

  • a void



154
155
156
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 154

def site_collection_id=(value)
    @site_collection_id = value
end

#site_idObject

Gets the siteId property value. The siteId property

Returns:

  • a string



161
162
163
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 161

def site_id
    return @site_id
end

#site_id=(value) ⇒ Object

Sets the siteId property value. The siteId property

Parameters:

  • value

    Value to set for the siteId property.

Returns:

  • a void



169
170
171
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 169

def site_id=(value)
    @site_id = value
end