Class: MicrosoftGraph::Me::Onenote::Notebooks::NotebooksRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/me/onenote/notebooks/notebooks_request_builder.rb

Overview

Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.

Defined Under Namespace

Classes: NotebooksRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new NotebooksRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



49
50
51
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 49

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/me/onenote/notebooks{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_notebook_id(notebook_id) ⇒ Object

Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.

Parameters:

  • notebook_id

    The unique identifier of notebook

Returns:

  • a notebook_item_request_builder

Raises:

  • (StandardError)


37
38
39
40
41
42
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 37

def by_notebook_id(notebook_id)
    raise StandardError, 'notebook_id cannot be null' if notebook_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["notebook%2Did"] = notebook_id
    return MicrosoftGraph::Me::Onenote::Notebooks::Item::NotebookItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



24
25
26
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 24

def count()
    return MicrosoftGraph::Me::Onenote::Notebooks::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve a list of notebook objects.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of notebook_collection_response



57
58
59
60
61
62
63
64
65
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 57

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::NotebookCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#get_notebook_from_web_urlObject

Provides operations to call the getNotebookFromWebUrl method.



29
30
31
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 29

def get_notebook_from_web_url()
    return MicrosoftGraph::Me::Onenote::Notebooks::GetNotebookFromWebUrl::GetNotebookFromWebUrlRequestBuilder.new(@path_parameters, @request_adapter)
end

#get_recent_notebooks_with_include_personal_notebooks(include_personal_notebooks) ⇒ Object

Provides operations to call the getRecentNotebooks method.

Parameters:

  • include_personal_notebooks

    Usage: includePersonalNotebooks=includePersonalNotebooks

Returns:

  • a get_recent_notebooks_with_include_personal_notebooks_request_builder

Raises:

  • (StandardError)


71
72
73
74
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 71

def get_recent_notebooks_with_include_personal_notebooks(include_personal_notebooks)
    raise StandardError, 'include_personal_notebooks cannot be null' if include_personal_notebooks.nil?
    return GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilder.new(@path_parameters, @request_adapter, includePersonalNotebooks)
end

#post(body, request_configuration = nil) ⇒ Object

Create a new OneNote notebook.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of notebook

Raises:

  • (StandardError)


81
82
83
84
85
86
87
88
89
90
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 81

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Notebook.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve a list of notebook objects.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 96

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create a new OneNote notebook.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/me/onenote/notebooks/notebooks_request_builder.rb', line 115

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end