Class: MicrosoftGraph::Me::Onenote::Operations::Item::OnenoteOperationItemRequestBuilder::OnenoteOperationItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/onenote/operations/item/onenote_operation_item_request_builder.rb

Overview

Get the status of a long-running OneNote operation. This applies to operations that return the Operation-Location header in the response, such as CopyNotebook, CopyToNotebook, CopyToSectionGroup, and CopyToSection. You can poll the Operation-Location endpoint until the status property returns completed or failed. If the status is completed, the resourceLocation property contains the resource endpoint URI. If the status is failed, the error and @api.diagnostics properties provide error information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



133
134
135
# File 'lib/me/onenote/operations/item/onenote_operation_item_request_builder.rb', line 133

def expand
  @expand
end

#selectObject

Select properties to be returned



136
137
138
# File 'lib/me/onenote/operations/item/onenote_operation_item_request_builder.rb', line 136

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Raises:

Parameters:

  • The original query parameter name in the class.

Returns:

  • a string



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/me/onenote/operations/item/onenote_operation_item_request_builder.rb', line 142

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end