Class: MicrosoftGraph::Me::Onenote::Pages::Item::OnenotePageItemRequestBuilder::OnenotePageItemRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Onenote::Pages::Item::OnenotePageItemRequestBuilder::OnenotePageItemRequestBuilderGetQueryParameters
- Defined in:
- lib/me/onenote/pages/item/onenote_page_item_request_builder.rb
Overview
Retrieve the properties and relationships of a page object. Getting page information Access a page's metadata by page identifier: Getting page content You can use the page's content endpoint to get the HTML content of a page: The includeIDs=true query option is used to update pages.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
169 170 171 |
# File 'lib/me/onenote/pages/item/onenote_page_item_request_builder.rb', line 169 def @expand end |
#select ⇒ Object
Select properties to be returned
172 173 174 |
# File 'lib/me/onenote/pages/item/onenote_page_item_request_builder.rb', line 172 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/me/onenote/pages/item/onenote_page_item_request_builder.rb', line 178 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |