Class: MicrosoftGraph::Me::People::PeopleRequestBuilder::PeopleRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/me/people/people_request_builder.rb

Overview

Retrieve a collection of person objects ordered by their relevance to the user, which is determined by the user’s communication and collaboration patterns, and business relationships. You can get this information via the People API. For examples, see the Examples section and the article Use the People API to get information about the people most relevant to you.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



81
82
83
# File 'lib/me/people/people_request_builder.rb', line 81

def count
  @count
end

#filterObject

Filter items by property values



84
85
86
# File 'lib/me/people/people_request_builder.rb', line 84

def filter
  @filter
end

#orderbyObject

Order items by property values



87
88
89
# File 'lib/me/people/people_request_builder.rb', line 87

def orderby
  @orderby
end

#searchObject

Search items by search phrases



90
91
92
# File 'lib/me/people/people_request_builder.rb', line 90

def search
  @search
end

#selectObject

Select properties to be returned



93
94
95
# File 'lib/me/people/people_request_builder.rb', line 93

def select
  @select
end

#skipObject

Skip the first n items



96
97
98
# File 'lib/me/people/people_request_builder.rb', line 96

def skip
  @skip
end

#topObject

Show only the first n items



99
100
101
# File 'lib/me/people/people_request_builder.rb', line 99

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • The original query parameter name in the class.

Returns:

  • a string

Raises:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/me/people/people_request_builder.rb', line 105

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "search"
            return "%24search"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "top"
            return "%24top"
        else
            return original_name
    end
end