Class: MicrosoftGraph::Me::Presence::SetUserPreferredPresence::SetUserPreferredPresencePostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Presence::SetUserPreferredPresence::SetUserPreferredPresencePostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#activity ⇒ Object
Gets the activity property value.
-
#activity=(value) ⇒ Object
Sets the activity property value.
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#availability ⇒ Object
Gets the availability property value.
-
#availability=(value) ⇒ Object
Sets the availability property value.
-
#expiration_duration ⇒ Object
Gets the expirationDuration property value.
-
#expiration_duration=(value) ⇒ Object
Sets the expirationDuration property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new setUserPreferredPresencePostRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new setUserPreferredPresencePostRequestBody and sets the default values.
74 75 76 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 74 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
82 83 84 85 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 82 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SetUserPreferredPresencePostRequestBody.new end |
Instance Method Details
#activity ⇒ Object
Gets the activity property value. The activity property
29 30 31 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 29 def activity return @activity end |
#activity=(value) ⇒ Object
Sets the activity property value. The activity property
37 38 39 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 37 def activity=(value) @activity = value end |
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
44 45 46 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 44 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
52 53 54 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 52 def additional_data=(value) @additional_data = value end |
#availability ⇒ Object
Gets the availability property value. The availability property
59 60 61 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 59 def availability return @availability end |
#availability=(value) ⇒ Object
Sets the availability property value. The availability property
67 68 69 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 67 def availability=(value) @availability = value end |
#expiration_duration ⇒ Object
Gets the expirationDuration property value. The expirationDuration property
90 91 92 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 90 def expiration_duration return @expiration_duration end |
#expiration_duration=(value) ⇒ Object
Sets the expirationDuration property value. The expirationDuration property
98 99 100 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 98 def expiration_duration=(value) @expiration_duration = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
105 106 107 108 109 110 111 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 105 def get_field_deserializers() return { "activity" => lambda {|n| @activity = n.get_string_value() }, "availability" => lambda {|n| @availability = n.get_string_value() }, "expirationDuration" => lambda {|n| @expiration_duration = n.get_duration_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
117 118 119 120 121 122 123 |
# File 'lib/me/presence/set_user_preferred_presence/set_user_preferred_presence_post_request_body.rb', line 117 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("activity", @activity) writer.write_string_value("availability", @availability) writer.write_duration_value("expirationDuration", @expiration_duration) writer.write_additional_data(@additional_data) end |