Class: MicrosoftGraph::Models::AccessPackageAssignmentApprovalSettings

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/access_package_assignment_approval_settings.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new accessPackageAssignmentApprovalSettings and sets the default values.



43
44
45
# File 'lib/models/access_package_assignment_approval_settings.rb', line 43

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a access_package_assignment_approval_settings

Raises:

  • (StandardError)


51
52
53
54
# File 'lib/models/access_package_assignment_approval_settings.rb', line 51

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AccessPackageAssignmentApprovalSettings.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



28
29
30
# File 'lib/models/access_package_assignment_approval_settings.rb', line 28

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



36
37
38
# File 'lib/models/access_package_assignment_approval_settings.rb', line 36

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



59
60
61
62
63
64
65
66
# File 'lib/models/access_package_assignment_approval_settings.rb', line 59

def get_field_deserializers()
    return {
        "isApprovalRequiredForAdd" => lambda {|n| @is_approval_required_for_add = n.get_boolean_value() },
        "isApprovalRequiredForUpdate" => lambda {|n| @is_approval_required_for_update = n.get_boolean_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "stages" => lambda {|n| @stages = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AccessPackageApprovalStage.create_from_discriminator_value(pn) }) },
    }
end

#is_approval_required_for_addObject

Gets the isApprovalRequiredForAdd property value. If false, then approval is not required for new requests in this policy.

Returns:

  • a boolean



71
72
73
# File 'lib/models/access_package_assignment_approval_settings.rb', line 71

def is_approval_required_for_add
    return @is_approval_required_for_add
end

#is_approval_required_for_add=(value) ⇒ Object

Sets the isApprovalRequiredForAdd property value. If false, then approval is not required for new requests in this policy.

Parameters:

  • value

    Value to set for the isApprovalRequiredForAdd property.

Returns:

  • a void



79
80
81
# File 'lib/models/access_package_assignment_approval_settings.rb', line 79

def is_approval_required_for_add=(value)
    @is_approval_required_for_add = value
end

#is_approval_required_for_updateObject

Gets the isApprovalRequiredForUpdate property value. If false, then approval is not required for updates to requests in this policy.

Returns:

  • a boolean



86
87
88
# File 'lib/models/access_package_assignment_approval_settings.rb', line 86

def is_approval_required_for_update
    return @is_approval_required_for_update
end

#is_approval_required_for_update=(value) ⇒ Object

Sets the isApprovalRequiredForUpdate property value. If false, then approval is not required for updates to requests in this policy.

Parameters:

  • value

    Value to set for the isApprovalRequiredForUpdate property.

Returns:

  • a void



94
95
96
# File 'lib/models/access_package_assignment_approval_settings.rb', line 94

def is_approval_required_for_update=(value)
    @is_approval_required_for_update = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



101
102
103
# File 'lib/models/access_package_assignment_approval_settings.rb', line 101

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



109
110
111
# File 'lib/models/access_package_assignment_approval_settings.rb', line 109

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


117
118
119
120
121
122
123
124
# File 'lib/models/access_package_assignment_approval_settings.rb', line 117

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_boolean_value("isApprovalRequiredForAdd", @is_approval_required_for_add)
    writer.write_boolean_value("isApprovalRequiredForUpdate", @is_approval_required_for_update)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_collection_of_object_values("stages", @stages)
    writer.write_additional_data(@additional_data)
end

#stagesObject

Gets the stages property value. If approval is required, the one, two or three elements of this collection define each of the stages of approval. An empty array is present if no approval is required.

Returns:

  • a access_package_approval_stage



129
130
131
# File 'lib/models/access_package_assignment_approval_settings.rb', line 129

def stages
    return @stages
end

#stages=(value) ⇒ Object

Sets the stages property value. If approval is required, the one, two or three elements of this collection define each of the stages of approval. An empty array is present if no approval is required.

Parameters:

  • value

    Value to set for the stages property.

Returns:

  • a void



137
138
139
# File 'lib/models/access_package_assignment_approval_settings.rb', line 137

def stages=(value)
    @stages = value
end