Class: MicrosoftGraph::Models::AccessPackageAssignmentPolicy

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/access_package_assignment_policy.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new accessPackageAssignmentPolicy and sets the default values.



119
120
121
# File 'lib/models/access_package_assignment_policy.rb', line 119

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a access_package_assignment_policy

Raises:

  • (StandardError)


142
143
144
145
# File 'lib/models/access_package_assignment_policy.rb', line 142

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AccessPackageAssignmentPolicy.new
end

Instance Method Details

#access_packageObject

Gets the accessPackage property value. Access package containing this policy. Read-only. Supports $expand.

Returns:

  • a access_package



59
60
61
# File 'lib/models/access_package_assignment_policy.rb', line 59

def access_package
    return @access_package
end

#access_package=(value) ⇒ Object

Sets the accessPackage property value. Access package containing this policy. Read-only. Supports $expand.

Parameters:

  • value

    Value to set for the accessPackage property.

Returns:

  • a void



67
68
69
# File 'lib/models/access_package_assignment_policy.rb', line 67

def access_package=(value)
    @access_package = value
end

#allowed_target_scopeObject

Gets the allowedTargetScope property value. Principals that can be assigned the access package through this policy. The possible values are: notSpecified, specificDirectoryUsers, specificConnectedOrganizationUsers, specificDirectoryServicePrincipals, allMemberUsers, allDirectoryUsers, allDirectoryServicePrincipals, allConfiguredConnectedOrganizationUsers, allExternalUsers, unknownFutureValue.

Returns:

  • a allowed_target_scope



74
75
76
# File 'lib/models/access_package_assignment_policy.rb', line 74

def allowed_target_scope
    return @allowed_target_scope
end

#allowed_target_scope=(value) ⇒ Object

Sets the allowedTargetScope property value. Principals that can be assigned the access package through this policy. The possible values are: notSpecified, specificDirectoryUsers, specificConnectedOrganizationUsers, specificDirectoryServicePrincipals, allMemberUsers, allDirectoryUsers, allDirectoryServicePrincipals, allConfiguredConnectedOrganizationUsers, allExternalUsers, unknownFutureValue.

Parameters:

  • value

    Value to set for the allowedTargetScope property.

Returns:

  • a void



82
83
84
# File 'lib/models/access_package_assignment_policy.rb', line 82

def allowed_target_scope=(value)
    @allowed_target_scope = value
end

#automatic_request_settingsObject

Gets the automaticRequestSettings property value. This property is only present for an auto assignment policy; if absent, this is a request-based policy.

Returns:

  • a access_package_automatic_request_settings



89
90
91
# File 'lib/models/access_package_assignment_policy.rb', line 89

def automatic_request_settings
    return @automatic_request_settings
end

#automatic_request_settings=(value) ⇒ Object

Sets the automaticRequestSettings property value. This property is only present for an auto assignment policy; if absent, this is a request-based policy.

Parameters:

  • value

    Value to set for the automaticRequestSettings property.

Returns:

  • a void



97
98
99
# File 'lib/models/access_package_assignment_policy.rb', line 97

def automatic_request_settings=(value)
    @automatic_request_settings = value
end

#catalogObject

Gets the catalog property value. Catalog of the access package containing this policy. Read-only.

Returns:

  • a access_package_catalog



104
105
106
# File 'lib/models/access_package_assignment_policy.rb', line 104

def catalog
    return @catalog
end

#catalog=(value) ⇒ Object

Sets the catalog property value. Catalog of the access package containing this policy. Read-only.

Parameters:

  • value

    Value to set for the catalog property.

Returns:

  • a void



112
113
114
# File 'lib/models/access_package_assignment_policy.rb', line 112

def catalog=(value)
    @catalog = value
end

#created_date_timeObject

Gets the createdDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.

Returns:

  • a date_time



126
127
128
# File 'lib/models/access_package_assignment_policy.rb', line 126

def created_date_time
    return @created_date_time
end

#created_date_time=(value) ⇒ Object

Sets the createdDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.

Parameters:

  • value

    Value to set for the createdDateTime property.

Returns:

  • a void



134
135
136
# File 'lib/models/access_package_assignment_policy.rb', line 134

def created_date_time=(value)
    @created_date_time = value
end

#custom_extension_stage_settingsObject

Gets the customExtensionStageSettings property value. The collection of stages when to execute one or more custom access package workflow extensions. Supports $expand.

Returns:

  • a custom_extension_stage_setting



150
151
152
# File 'lib/models/access_package_assignment_policy.rb', line 150

def custom_extension_stage_settings
    return @custom_extension_stage_settings
end

#custom_extension_stage_settings=(value) ⇒ Object

Sets the customExtensionStageSettings property value. The collection of stages when to execute one or more custom access package workflow extensions. Supports $expand.

Parameters:

  • value

    Value to set for the customExtensionStageSettings property.

Returns:

  • a void



158
159
160
# File 'lib/models/access_package_assignment_policy.rb', line 158

def custom_extension_stage_settings=(value)
    @custom_extension_stage_settings = value
end

#descriptionObject

Gets the description property value. The description of the policy.

Returns:

  • a string



165
166
167
# File 'lib/models/access_package_assignment_policy.rb', line 165

def description
    return @description
end

#description=(value) ⇒ Object

Sets the description property value. The description of the policy.

Parameters:

  • value

    Value to set for the description property.

Returns:

  • a void



173
174
175
# File 'lib/models/access_package_assignment_policy.rb', line 173

def description=(value)
    @description = value
end

#display_nameObject

Gets the displayName property value. The display name of the policy.

Returns:

  • a string



180
181
182
# File 'lib/models/access_package_assignment_policy.rb', line 180

def display_name
    return @display_name
end

#display_name=(value) ⇒ Object

Sets the displayName property value. The display name of the policy.

Parameters:

  • value

    Value to set for the displayName property.

Returns:

  • a void



188
189
190
# File 'lib/models/access_package_assignment_policy.rb', line 188

def display_name=(value)
    @display_name = value
end

#expirationObject

Gets the expiration property value. The expiration date for assignments created in this policy.

Returns:

  • a expiration_pattern



195
196
197
# File 'lib/models/access_package_assignment_policy.rb', line 195

def expiration
    return @expiration
end

#expiration=(value) ⇒ Object

Sets the expiration property value. The expiration date for assignments created in this policy.

Parameters:

  • value

    Value to set for the expiration property.

Returns:

  • a void



203
204
205
# File 'lib/models/access_package_assignment_policy.rb', line 203

def expiration=(value)
    @expiration = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/models/access_package_assignment_policy.rb', line 210

def get_field_deserializers()
    return super.merge({
        "accessPackage" => lambda {|n| @access_package = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessPackage.create_from_discriminator_value(pn) }) },
        "allowedTargetScope" => lambda {|n| @allowed_target_scope = n.get_enum_value(MicrosoftGraph::Models::AllowedTargetScope) },
        "automaticRequestSettings" => lambda {|n| @automatic_request_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessPackageAutomaticRequestSettings.create_from_discriminator_value(pn) }) },
        "catalog" => lambda {|n| @catalog = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessPackageCatalog.create_from_discriminator_value(pn) }) },
        "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() },
        "customExtensionStageSettings" => lambda {|n| @custom_extension_stage_settings = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::CustomExtensionStageSetting.create_from_discriminator_value(pn) }) },
        "description" => lambda {|n| @description = n.get_string_value() },
        "displayName" => lambda {|n| @display_name = n.get_string_value() },
        "expiration" => lambda {|n| @expiration = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExpirationPattern.create_from_discriminator_value(pn) }) },
        "modifiedDateTime" => lambda {|n| @modified_date_time = n.get_date_time_value() },
        "questions" => lambda {|n| @questions = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AccessPackageQuestion.create_from_discriminator_value(pn) }) },
        "requestApprovalSettings" => lambda {|n| @request_approval_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessPackageAssignmentApprovalSettings.create_from_discriminator_value(pn) }) },
        "requestorSettings" => lambda {|n| @requestor_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessPackageAssignmentRequestorSettings.create_from_discriminator_value(pn) }) },
        "reviewSettings" => lambda {|n| @review_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessPackageAssignmentReviewSettings.create_from_discriminator_value(pn) }) },
        "specificAllowedTargets" => lambda {|n| @specific_allowed_targets = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::SubjectSet.create_from_discriminator_value(pn) }) },
    })
end

#modified_date_timeObject

Gets the modifiedDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.

Returns:

  • a date_time



233
234
235
# File 'lib/models/access_package_assignment_policy.rb', line 233

def modified_date_time
    return @modified_date_time
end

#modified_date_time=(value) ⇒ Object

Sets the modifiedDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.

Parameters:

  • value

    Value to set for the modifiedDateTime property.

Returns:

  • a void



241
242
243
# File 'lib/models/access_package_assignment_policy.rb', line 241

def modified_date_time=(value)
    @modified_date_time = value
end

#questionsObject

Gets the questions property value. Questions that are posed to the requestor.

Returns:

  • a access_package_question



248
249
250
# File 'lib/models/access_package_assignment_policy.rb', line 248

def questions
    return @questions
end

#questions=(value) ⇒ Object

Sets the questions property value. Questions that are posed to the requestor.

Parameters:

  • value

    Value to set for the questions property.

Returns:

  • a void



256
257
258
# File 'lib/models/access_package_assignment_policy.rb', line 256

def questions=(value)
    @questions = value
end

#request_approval_settingsObject

Gets the requestApprovalSettings property value. Specifies the settings for approval of requests for an access package assignment through this policy. For example, if approval is required for new requests.

Returns:

  • a access_package_assignment_approval_settings



263
264
265
# File 'lib/models/access_package_assignment_policy.rb', line 263

def request_approval_settings
    return @request_approval_settings
end

#request_approval_settings=(value) ⇒ Object

Sets the requestApprovalSettings property value. Specifies the settings for approval of requests for an access package assignment through this policy. For example, if approval is required for new requests.

Parameters:

  • value

    Value to set for the requestApprovalSettings property.

Returns:

  • a void



271
272
273
# File 'lib/models/access_package_assignment_policy.rb', line 271

def request_approval_settings=(value)
    @request_approval_settings = value
end

#requestor_settingsObject

Gets the requestorSettings property value. Provides additional settings to select who can create a request for an access package assignment through this policy, and what they can include in their request.

Returns:

  • a access_package_assignment_requestor_settings



278
279
280
# File 'lib/models/access_package_assignment_policy.rb', line 278

def requestor_settings
    return @requestor_settings
end

#requestor_settings=(value) ⇒ Object

Sets the requestorSettings property value. Provides additional settings to select who can create a request for an access package assignment through this policy, and what they can include in their request.

Parameters:

  • value

    Value to set for the requestorSettings property.

Returns:

  • a void



286
287
288
# File 'lib/models/access_package_assignment_policy.rb', line 286

def requestor_settings=(value)
    @requestor_settings = value
end

#review_settingsObject

Gets the reviewSettings property value. Settings for access reviews of assignments through this policy.

Returns:

  • a access_package_assignment_review_settings



293
294
295
# File 'lib/models/access_package_assignment_policy.rb', line 293

def review_settings
    return @review_settings
end

#review_settings=(value) ⇒ Object

Sets the reviewSettings property value. Settings for access reviews of assignments through this policy.

Parameters:

  • value

    Value to set for the reviewSettings property.

Returns:

  • a void



301
302
303
# File 'lib/models/access_package_assignment_policy.rb', line 301

def review_settings=(value)
    @review_settings = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/models/access_package_assignment_policy.rb', line 309

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("accessPackage", @access_package)
    writer.write_enum_value("allowedTargetScope", @allowed_target_scope)
    writer.write_object_value("automaticRequestSettings", @automatic_request_settings)
    writer.write_object_value("catalog", @catalog)
    writer.write_date_time_value("createdDateTime", @created_date_time)
    writer.write_collection_of_object_values("customExtensionStageSettings", @custom_extension_stage_settings)
    writer.write_string_value("description", @description)
    writer.write_string_value("displayName", @display_name)
    writer.write_object_value("expiration", @expiration)
    writer.write_date_time_value("modifiedDateTime", @modified_date_time)
    writer.write_collection_of_object_values("questions", @questions)
    writer.write_object_value("requestApprovalSettings", @request_approval_settings)
    writer.write_object_value("requestorSettings", @requestor_settings)
    writer.write_object_value("reviewSettings", @review_settings)
    writer.write_collection_of_object_values("specificAllowedTargets", @specific_allowed_targets)
end

#specific_allowed_targetsObject

Gets the specificAllowedTargets property value. The principals that can be assigned access from an access package through this policy.

Returns:

  • a subject_set



332
333
334
# File 'lib/models/access_package_assignment_policy.rb', line 332

def specific_allowed_targets
    return @specific_allowed_targets
end

#specific_allowed_targets=(value) ⇒ Object

Sets the specificAllowedTargets property value. The principals that can be assigned access from an access package through this policy.

Parameters:

  • value

    Value to set for the specificAllowedTargets property.

Returns:

  • a void



340
341
342
# File 'lib/models/access_package_assignment_policy.rb', line 340

def specific_allowed_targets=(value)
    @specific_allowed_targets = value
end