Class: MicrosoftGraph::Models::AccessReviewHistoryInstance

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/access_review_history_instance.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new accessReviewHistoryInstance and sets the default values.



35
36
37
# File 'lib/models/access_review_history_instance.rb', line 35

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Raises:

  • (StandardError)


43
44
45
46
# File 'lib/models/access_review_history_instance.rb', line 43

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AccessReviewHistoryInstance.new
end

Instance Method Details

#download_uriObject

Gets the downloadUri property value. Uri which can be used to retrieve review history data. This URI will be active for 24 hours after being generated. Required.



51
52
53
# File 'lib/models/access_review_history_instance.rb', line 51

def download_uri
    return @download_uri
end

#download_uri=(value) ⇒ Object

Sets the downloadUri property value. Uri which can be used to retrieve review history data. This URI will be active for 24 hours after being generated. Required.



59
60
61
# File 'lib/models/access_review_history_instance.rb', line 59

def download_uri=(value)
    @download_uri = value
end

#expiration_date_timeObject

Gets the expirationDateTime property value. Timestamp when this instance and associated data expires and the history is deleted. Required.



66
67
68
# File 'lib/models/access_review_history_instance.rb', line 66

def expiration_date_time
    return @expiration_date_time
end

#expiration_date_time=(value) ⇒ Object

Sets the expirationDateTime property value. Timestamp when this instance and associated data expires and the history is deleted. Required.



74
75
76
# File 'lib/models/access_review_history_instance.rb', line 74

def expiration_date_time=(value)
    @expiration_date_time = value
end

#fulfilled_date_timeObject

Gets the fulfilledDateTime property value. Timestamp when all of the available data for this instance was collected. This will be set after this instance’s status is set to done. Required.



81
82
83
# File 'lib/models/access_review_history_instance.rb', line 81

def fulfilled_date_time
    return @fulfilled_date_time
end

#fulfilled_date_time=(value) ⇒ Object

Sets the fulfilledDateTime property value. Timestamp when all of the available data for this instance was collected. This will be set after this instance’s status is set to done. Required.



89
90
91
# File 'lib/models/access_review_history_instance.rb', line 89

def fulfilled_date_time=(value)
    @fulfilled_date_time = value
end

#get_field_deserializersObject

The deserialization information for the current model



96
97
98
99
100
101
102
103
104
105
106
# File 'lib/models/access_review_history_instance.rb', line 96

def get_field_deserializers()
    return super.merge({
        "downloadUri" => lambda {|n| @download_uri = n.get_string_value() },
        "expirationDateTime" => lambda {|n| @expiration_date_time = n.get_date_time_value() },
        "fulfilledDateTime" => lambda {|n| @fulfilled_date_time = n.get_date_time_value() },
        "reviewHistoryPeriodEndDateTime" => lambda {|n| @review_history_period_end_date_time = n.get_date_time_value() },
        "reviewHistoryPeriodStartDateTime" => lambda {|n| @review_history_period_start_date_time = n.get_date_time_value() },
        "runDateTime" => lambda {|n| @run_date_time = n.get_date_time_value() },
        "status" => lambda {|n| @status = n.get_enum_value(MicrosoftGraph::Models::AccessReviewHistoryStatus) },
    })
end

#review_history_period_end_date_timeObject

Gets the reviewHistoryPeriodEndDateTime property value. Timestamp, reviews ending on or before this date will be included in the fetched history data.



111
112
113
# File 'lib/models/access_review_history_instance.rb', line 111

def review_history_period_end_date_time
    return @review_history_period_end_date_time
end

#review_history_period_end_date_time=(value) ⇒ Object

Sets the reviewHistoryPeriodEndDateTime property value. Timestamp, reviews ending on or before this date will be included in the fetched history data.



119
120
121
# File 'lib/models/access_review_history_instance.rb', line 119

def review_history_period_end_date_time=(value)
    @review_history_period_end_date_time = value
end

#review_history_period_start_date_timeObject

Gets the reviewHistoryPeriodStartDateTime property value. Timestamp, reviews starting on or after this date will be included in the fetched history data.



126
127
128
# File 'lib/models/access_review_history_instance.rb', line 126

def review_history_period_start_date_time
    return @review_history_period_start_date_time
end

#review_history_period_start_date_time=(value) ⇒ Object

Sets the reviewHistoryPeriodStartDateTime property value. Timestamp, reviews starting on or after this date will be included in the fetched history data.



134
135
136
# File 'lib/models/access_review_history_instance.rb', line 134

def review_history_period_start_date_time=(value)
    @review_history_period_start_date_time = value
end

#run_date_timeObject

Gets the runDateTime property value. Timestamp when the instance’s history data is scheduled to be generated.



141
142
143
# File 'lib/models/access_review_history_instance.rb', line 141

def run_date_time
    return @run_date_time
end

#run_date_time=(value) ⇒ Object

Sets the runDateTime property value. Timestamp when the instance’s history data is scheduled to be generated.



149
150
151
# File 'lib/models/access_review_history_instance.rb', line 149

def run_date_time=(value)
    @run_date_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Raises:

  • (StandardError)


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/models/access_review_history_instance.rb', line 157

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("downloadUri", @download_uri)
    writer.write_date_time_value("expirationDateTime", @expiration_date_time)
    writer.write_date_time_value("fulfilledDateTime", @fulfilled_date_time)
    writer.write_date_time_value("reviewHistoryPeriodEndDateTime", @review_history_period_end_date_time)
    writer.write_date_time_value("reviewHistoryPeriodStartDateTime", @review_history_period_start_date_time)
    writer.write_date_time_value("runDateTime", @run_date_time)
    writer.write_enum_value("status", @status)
end

#statusObject

Gets the status property value. Represents the status of the review history data collection. The possible values are: done, inProgress, error, requested, unknownFutureValue. Once the status has been marked as done, a link can be generated to retrieve the instance’s data by calling generateDownloadUri method.



172
173
174
# File 'lib/models/access_review_history_instance.rb', line 172

def status
    return @status
end

#status=(value) ⇒ Object

Sets the status property value. Represents the status of the review history data collection. The possible values are: done, inProgress, error, requested, unknownFutureValue. Once the status has been marked as done, a link can be generated to retrieve the instance’s data by calling generateDownloadUri method.



180
181
182
# File 'lib/models/access_review_history_instance.rb', line 180

def status=(value)
    @status = value
end