Class: MicrosoftGraph::Models::AccessReviewInstanceDecisionItem

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/access_review_instance_decision_item.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new accessReviewInstanceDecisionItem and sets the default values.



116
117
118
# File 'lib/models/access_review_instance_decision_item.rb', line 116

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a access_review_instance_decision_item

Raises:

  • (StandardError)


124
125
126
127
# File 'lib/models/access_review_instance_decision_item.rb', line 124

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AccessReviewInstanceDecisionItem.new
end

Instance Method Details

#access_review_idObject

Gets the accessReviewId property value. The identifier of the accessReviewInstance parent. Supports $select. Read-only.

Returns:

  • a string



56
57
58
# File 'lib/models/access_review_instance_decision_item.rb', line 56

def access_review_id
    return @access_review_id
end

#access_review_id=(value) ⇒ Object

Sets the accessReviewId property value. The identifier of the accessReviewInstance parent. Supports $select. Read-only.

Parameters:

  • value

    Value to set for the accessReviewId property.

Returns:

  • a void



64
65
66
# File 'lib/models/access_review_instance_decision_item.rb', line 64

def access_review_id=(value)
    @access_review_id = value
end

#applied_byObject

Gets the appliedBy property value. The identifier of the user who applied the decision. Read-only.

Returns:

  • a user_identity



71
72
73
# File 'lib/models/access_review_instance_decision_item.rb', line 71

def applied_by
    return @applied_by
end

#applied_by=(value) ⇒ Object

Sets the appliedBy property value. The identifier of the user who applied the decision. Read-only.

Parameters:

  • value

    Value to set for the appliedBy property.

Returns:

  • a void



79
80
81
# File 'lib/models/access_review_instance_decision_item.rb', line 79

def applied_by=(value)
    @applied_by = value
end

#applied_date_timeObject

Gets the appliedDateTime property value. The timestamp when the approval decision was applied.00000000-0000-0000-0000-000000000000 if the assigned reviewer hasn’t applied the decision or it was automatically applied. The DatetimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $select. Read-only.

Returns:

  • a date_time



86
87
88
# File 'lib/models/access_review_instance_decision_item.rb', line 86

def applied_date_time
    return @applied_date_time
end

#applied_date_time=(value) ⇒ Object

Sets the appliedDateTime property value. The timestamp when the approval decision was applied.00000000-0000-0000-0000-000000000000 if the assigned reviewer hasn’t applied the decision or it was automatically applied. The DatetimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $select. Read-only.

Parameters:

  • value

    Value to set for the appliedDateTime property.

Returns:

  • a void



94
95
96
# File 'lib/models/access_review_instance_decision_item.rb', line 94

def applied_date_time=(value)
    @applied_date_time = value
end

#apply_resultObject

Gets the applyResult property value. The result of applying the decision. Possible values: New, AppliedSuccessfully, AppliedWithUnknownFailure, AppliedSuccessfullyButObjectNotFound and ApplyNotSupported. Supports $select, $orderby, and $filter (eq only). Read-only.

Returns:

  • a string



101
102
103
# File 'lib/models/access_review_instance_decision_item.rb', line 101

def apply_result
    return @apply_result
end

#apply_result=(value) ⇒ Object

Sets the applyResult property value. The result of applying the decision. Possible values: New, AppliedSuccessfully, AppliedWithUnknownFailure, AppliedSuccessfullyButObjectNotFound and ApplyNotSupported. Supports $select, $orderby, and $filter (eq only). Read-only.

Parameters:

  • value

    Value to set for the applyResult property.

Returns:

  • a void



109
110
111
# File 'lib/models/access_review_instance_decision_item.rb', line 109

def apply_result=(value)
    @apply_result = value
end

#decisionObject

Gets the decision property value. Result of the review. Possible values: Approve, Deny, NotReviewed, or DontKnow. Supports $select, $orderby, and $filter (eq only).

Returns:

  • a string



132
133
134
# File 'lib/models/access_review_instance_decision_item.rb', line 132

def decision
    return @decision
end

#decision=(value) ⇒ Object

Sets the decision property value. Result of the review. Possible values: Approve, Deny, NotReviewed, or DontKnow. Supports $select, $orderby, and $filter (eq only).

Parameters:

  • value

    Value to set for the decision property.

Returns:

  • a void



140
141
142
# File 'lib/models/access_review_instance_decision_item.rb', line 140

def decision=(value)
    @decision = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/models/access_review_instance_decision_item.rb', line 147

def get_field_deserializers()
    return super.merge({
        "accessReviewId" => lambda {|n| @access_review_id = n.get_string_value() },
        "appliedBy" => lambda {|n| @applied_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::UserIdentity.create_from_discriminator_value(pn) }) },
        "appliedDateTime" => lambda {|n| @applied_date_time = n.get_date_time_value() },
        "applyResult" => lambda {|n| @apply_result = n.get_string_value() },
        "decision" => lambda {|n| @decision = n.get_string_value() },
        "insights" => lambda {|n| @insights = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::GovernanceInsight.create_from_discriminator_value(pn) }) },
        "justification" => lambda {|n| @justification = n.get_string_value() },
        "principal" => lambda {|n| @principal = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Identity.create_from_discriminator_value(pn) }) },
        "principalLink" => lambda {|n| @principal_link = n.get_string_value() },
        "recommendation" => lambda {|n| @recommendation = n.get_string_value() },
        "resource" => lambda {|n| @resource = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessReviewInstanceDecisionItemResource.create_from_discriminator_value(pn) }) },
        "resourceLink" => lambda {|n| @resource_link = n.get_string_value() },
        "reviewedBy" => lambda {|n| @reviewed_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::UserIdentity.create_from_discriminator_value(pn) }) },
        "reviewedDateTime" => lambda {|n| @reviewed_date_time = n.get_date_time_value() },
    })
end

#insightsObject

Gets the insights property value. Insights are recommendations to reviewers on whether to approve or deny a decision. There can be multiple insights associated with an accessReviewInstanceDecisionItem.

Returns:

  • a governance_insight



169
170
171
# File 'lib/models/access_review_instance_decision_item.rb', line 169

def insights
    return @insights
end

#insights=(value) ⇒ Object

Sets the insights property value. Insights are recommendations to reviewers on whether to approve or deny a decision. There can be multiple insights associated with an accessReviewInstanceDecisionItem.

Parameters:

  • value

    Value to set for the insights property.

Returns:

  • a void



177
178
179
# File 'lib/models/access_review_instance_decision_item.rb', line 177

def insights=(value)
    @insights = value
end

#justificationObject

Gets the justification property value. Justification left by the reviewer when they made the decision.

Returns:

  • a string



184
185
186
# File 'lib/models/access_review_instance_decision_item.rb', line 184

def justification
    return @justification
end

#justification=(value) ⇒ Object

Sets the justification property value. Justification left by the reviewer when they made the decision.

Parameters:

  • value

    Value to set for the justification property.

Returns:

  • a void



192
193
194
# File 'lib/models/access_review_instance_decision_item.rb', line 192

def justification=(value)
    @justification = value
end

#principalObject

Gets the principal property value. Every decision item in an access review represents a principal’s access to a resource. This property represents details of the principal. For example, if a decision item represents access of User ‘Bob’ to Group ‘Sales’ - The principal is ‘Bob’ and the resource is ‘Sales’. Principals can be of two types - userIdentity and servicePrincipalIdentity. Supports $select. Read-only.

Returns:

  • a identity



199
200
201
# File 'lib/models/access_review_instance_decision_item.rb', line 199

def principal
    return @principal
end

#principal=(value) ⇒ Object

Sets the principal property value. Every decision item in an access review represents a principal’s access to a resource. This property represents details of the principal. For example, if a decision item represents access of User ‘Bob’ to Group ‘Sales’ - The principal is ‘Bob’ and the resource is ‘Sales’. Principals can be of two types - userIdentity and servicePrincipalIdentity. Supports $select. Read-only.

Parameters:

  • value

    Value to set for the principal property.

Returns:

  • a void



207
208
209
# File 'lib/models/access_review_instance_decision_item.rb', line 207

def principal=(value)
    @principal = value
end

Gets the principalLink property value. A link to the principal object. For example, graph.microsoft.com/v1.0/users/a6c7aecb-cbfd-4763-87ef-e91b4bd509d9. Read-only.

Returns:

  • a string



214
215
216
# File 'lib/models/access_review_instance_decision_item.rb', line 214

def principal_link
    return @principal_link
end

#principal_link=(value) ⇒ Object

Sets the principalLink property value. A link to the principal object. For example, graph.microsoft.com/v1.0/users/a6c7aecb-cbfd-4763-87ef-e91b4bd509d9. Read-only.

Parameters:

  • value

    Value to set for the principalLink property.

Returns:

  • a void



222
223
224
# File 'lib/models/access_review_instance_decision_item.rb', line 222

def principal_link=(value)
    @principal_link = value
end

#recommendationObject

Gets the recommendation property value. A system-generated recommendation for the approval decision based off last interactive sign-in to tenant. Recommend approve if sign-in is within thirty days of start of review. Recommend deny if sign-in is greater than thirty days of start of review. Recommendation not available otherwise. Possible values: Approve, Deny, or NoInfoAvailable. Supports $select, $orderby, and $filter (eq only). Read-only.

Returns:

  • a string



229
230
231
# File 'lib/models/access_review_instance_decision_item.rb', line 229

def recommendation
    return @recommendation
end

#recommendation=(value) ⇒ Object

Sets the recommendation property value. A system-generated recommendation for the approval decision based off last interactive sign-in to tenant. Recommend approve if sign-in is within thirty days of start of review. Recommend deny if sign-in is greater than thirty days of start of review. Recommendation not available otherwise. Possible values: Approve, Deny, or NoInfoAvailable. Supports $select, $orderby, and $filter (eq only). Read-only.

Parameters:

  • value

    Value to set for the recommendation property.

Returns:

  • a void



237
238
239
# File 'lib/models/access_review_instance_decision_item.rb', line 237

def recommendation=(value)
    @recommendation = value
end

#resourceObject

Gets the resource property value. Every decision item in an access review represents a principal’s access to a resource. This property represents details of the resource. For example, if a decision item represents access of User ‘Bob’ to Group ‘Sales’ - The principal is Bob and the resource is ‘Sales’. Resources can be of multiple types. See accessReviewInstanceDecisionItemResource. Read-only.

Returns:

  • a access_review_instance_decision_item_resource



244
245
246
# File 'lib/models/access_review_instance_decision_item.rb', line 244

def resource
    return @resource
end

#resource=(value) ⇒ Object

Sets the resource property value. Every decision item in an access review represents a principal’s access to a resource. This property represents details of the resource. For example, if a decision item represents access of User ‘Bob’ to Group ‘Sales’ - The principal is Bob and the resource is ‘Sales’. Resources can be of multiple types. See accessReviewInstanceDecisionItemResource. Read-only.

Parameters:

  • value

    Value to set for the resource property.

Returns:

  • a void



252
253
254
# File 'lib/models/access_review_instance_decision_item.rb', line 252

def resource=(value)
    @resource = value
end

Gets the resourceLink property value. A link to the resource. For example, graph.microsoft.com/v1.0/servicePrincipals/c86300f3-8695-4320-9f6e-32a2555f5ff8. Supports $select. Read-only.

Returns:

  • a string



259
260
261
# File 'lib/models/access_review_instance_decision_item.rb', line 259

def resource_link
    return @resource_link
end

#resource_link=(value) ⇒ Object

Sets the resourceLink property value. A link to the resource. For example, graph.microsoft.com/v1.0/servicePrincipals/c86300f3-8695-4320-9f6e-32a2555f5ff8. Supports $select. Read-only.

Parameters:

  • value

    Value to set for the resourceLink property.

Returns:

  • a void



267
268
269
# File 'lib/models/access_review_instance_decision_item.rb', line 267

def resource_link=(value)
    @resource_link = value
end

#reviewed_byObject

Gets the reviewedBy property value. The identifier of the reviewer.00000000-0000-0000-0000-000000000000 if the assigned reviewer hasn’t reviewed. Supports $select. Read-only.

Returns:

  • a user_identity



274
275
276
# File 'lib/models/access_review_instance_decision_item.rb', line 274

def reviewed_by
    return @reviewed_by
end

#reviewed_by=(value) ⇒ Object

Sets the reviewedBy property value. The identifier of the reviewer.00000000-0000-0000-0000-000000000000 if the assigned reviewer hasn’t reviewed. Supports $select. Read-only.

Parameters:

  • value

    Value to set for the reviewedBy property.

Returns:

  • a void



282
283
284
# File 'lib/models/access_review_instance_decision_item.rb', line 282

def reviewed_by=(value)
    @reviewed_by = value
end

#reviewed_date_timeObject

Gets the reviewedDateTime property value. The timestamp when the review decision occurred. Supports $select. Read-only.

Returns:

  • a date_time



289
290
291
# File 'lib/models/access_review_instance_decision_item.rb', line 289

def reviewed_date_time
    return @reviewed_date_time
end

#reviewed_date_time=(value) ⇒ Object

Sets the reviewedDateTime property value. The timestamp when the review decision occurred. Supports $select. Read-only.

Parameters:

  • value

    Value to set for the reviewedDateTime property.

Returns:

  • a void



297
298
299
# File 'lib/models/access_review_instance_decision_item.rb', line 297

def reviewed_date_time=(value)
    @reviewed_date_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/models/access_review_instance_decision_item.rb', line 305

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("accessReviewId", @access_review_id)
    writer.write_object_value("appliedBy", @applied_by)
    writer.write_date_time_value("appliedDateTime", @applied_date_time)
    writer.write_string_value("applyResult", @apply_result)
    writer.write_string_value("decision", @decision)
    writer.write_collection_of_object_values("insights", @insights)
    writer.write_string_value("justification", @justification)
    writer.write_object_value("principal", @principal)
    writer.write_string_value("principalLink", @principal_link)
    writer.write_string_value("recommendation", @recommendation)
    writer.write_object_value("resource", @resource)
    writer.write_string_value("resourceLink", @resource_link)
    writer.write_object_value("reviewedBy", @reviewed_by)
    writer.write_date_time_value("reviewedDateTime", @reviewed_date_time)
end