Class: MicrosoftGraph::Models::AccessReviewNotificationRecipientItem
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::AccessReviewNotificationRecipientItem
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/access_review_notification_recipient_item.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new accessReviewNotificationRecipientItem and sets the default values.
-
#notification_recipient_scope ⇒ Object
Gets the notificationRecipientScope property value.
-
#notification_recipient_scope=(value) ⇒ Object
Sets the notificationRecipientScope property value.
-
#notification_template_type ⇒ Object
Gets the notificationTemplateType property value.
-
#notification_template_type=(value) ⇒ Object
Sets the notificationTemplateType property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new accessReviewNotificationRecipientItem and sets the default values.
40 41 42 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 40 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AccessReviewNotificationRecipientItem.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 33 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
56 57 58 59 60 61 62 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 56 def get_field_deserializers() return { "notificationRecipientScope" => lambda {|n| @notification_recipient_scope = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessReviewNotificationRecipientScope.create_from_discriminator_value(pn) }) }, "notificationTemplateType" => lambda {|n| @notification_template_type = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, } end |
#notification_recipient_scope ⇒ Object
Gets the notificationRecipientScope property value. Determines the recipient of the notification email.
67 68 69 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 67 def notification_recipient_scope return @notification_recipient_scope end |
#notification_recipient_scope=(value) ⇒ Object
Sets the notificationRecipientScope property value. Determines the recipient of the notification email.
75 76 77 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 75 def notification_recipient_scope=(value) @notification_recipient_scope = value end |
#notification_template_type ⇒ Object
Gets the notificationTemplateType property value. Indicates the type of access review email to be sent. Supported template type is CompletedAdditionalRecipients, which sends review completion notifications to the recipients.
82 83 84 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 82 def notification_template_type return @notification_template_type end |
#notification_template_type=(value) ⇒ Object
Sets the notificationTemplateType property value. Indicates the type of access review email to be sent. Supported template type is CompletedAdditionalRecipients, which sends review completion notifications to the recipients.
90 91 92 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 90 def notification_template_type=(value) @notification_template_type = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
97 98 99 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 97 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
105 106 107 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 105 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
113 114 115 116 117 118 119 |
# File 'lib/models/access_review_notification_recipient_item.rb', line 113 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("notificationRecipientScope", @notification_recipient_scope) writer.write_string_value("notificationTemplateType", @notification_template_type) writer.write_string_value("@odata.type", @odata_type) writer.write_additional_data(@additional_data) end |