Class: MicrosoftGraph::Models::AccessReviewStageSettings

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/access_review_stage_settings.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new accessReviewStageSettings and sets the default values.



58
59
60
# File 'lib/models/access_review_stage_settings.rb', line 58

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a access_review_stage_settings

Raises:

  • (StandardError)


66
67
68
69
# File 'lib/models/access_review_stage_settings.rb', line 66

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AccessReviewStageSettings.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



43
44
45
# File 'lib/models/access_review_stage_settings.rb', line 43

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



51
52
53
# File 'lib/models/access_review_stage_settings.rb', line 51

def additional_data=(value)
    @additional_data = value
end

#decisions_that_will_move_to_next_stageObject

Gets the decisionsThatWillMoveToNextStage property value. Indicate which decisions will go to the next stage. Can be a sub-set of Approve, Deny, Recommendation, or NotReviewed. If not provided, all decisions will go to the next stage. Optional.

Returns:

  • a string



74
75
76
# File 'lib/models/access_review_stage_settings.rb', line 74

def decisions_that_will_move_to_next_stage
    return @decisions_that_will_move_to_next_stage
end

#decisions_that_will_move_to_next_stage=(value) ⇒ Object

Sets the decisionsThatWillMoveToNextStage property value. Indicate which decisions will go to the next stage. Can be a sub-set of Approve, Deny, Recommendation, or NotReviewed. If not provided, all decisions will go to the next stage. Optional.

Parameters:

  • value

    Value to set for the decisionsThatWillMoveToNextStage property.

Returns:

  • a void



82
83
84
# File 'lib/models/access_review_stage_settings.rb', line 82

def decisions_that_will_move_to_next_stage=(value)
    @decisions_that_will_move_to_next_stage = value
end

#depends_onObject

Gets the dependsOn property value. Defines the sequential or parallel order of the stages and depends on the stageId. Only sequential stages are currently supported. For example, if stageId is 2, then dependsOn must be 1. If stageId is 1, do not specify dependsOn. Required if stageId is not 1.

Returns:

  • a string



89
90
91
# File 'lib/models/access_review_stage_settings.rb', line 89

def depends_on
    return @depends_on
end

#depends_on=(value) ⇒ Object

Sets the dependsOn property value. Defines the sequential or parallel order of the stages and depends on the stageId. Only sequential stages are currently supported. For example, if stageId is 2, then dependsOn must be 1. If stageId is 1, do not specify dependsOn. Required if stageId is not 1.

Parameters:

  • value

    Value to set for the dependsOn property.

Returns:

  • a void



97
98
99
# File 'lib/models/access_review_stage_settings.rb', line 97

def depends_on=(value)
    @depends_on = value
end

#duration_in_daysObject

Gets the durationInDays property value. The duration of the stage. Required. NOTE: The cumulative value of this property across all stages 1. Will override the instanceDurationInDays setting on the accessReviewScheduleDefinition object. 2. Cannot exceed the length of one recurrence. That is, if the review recurs weekly, the cumulative durationInDays cannot exceed 7.

Returns:

  • a integer



104
105
106
# File 'lib/models/access_review_stage_settings.rb', line 104

def duration_in_days
    return @duration_in_days
end

#duration_in_days=(value) ⇒ Object

Sets the durationInDays property value. The duration of the stage. Required. NOTE: The cumulative value of this property across all stages 1. Will override the instanceDurationInDays setting on the accessReviewScheduleDefinition object. 2. Cannot exceed the length of one recurrence. That is, if the review recurs weekly, the cumulative durationInDays cannot exceed 7.

Parameters:

  • value

    Value to set for the durationInDays property.

Returns:

  • a void



112
113
114
# File 'lib/models/access_review_stage_settings.rb', line 112

def duration_in_days=(value)
    @duration_in_days = value
end

#fallback_reviewersObject

Gets the fallbackReviewers property value. If provided, the fallback reviewers are asked to complete a review if the primary reviewers do not exist. For example, if managers are selected as reviewers and a principal under review does not have a manager in Azure AD, the fallback reviewers are asked to review that principal. NOTE: The value of this property will override the corresponding setting on the accessReviewScheduleDefinition object.

Returns:

  • a access_review_reviewer_scope



119
120
121
# File 'lib/models/access_review_stage_settings.rb', line 119

def fallback_reviewers
    return @fallback_reviewers
end

#fallback_reviewers=(value) ⇒ Object

Sets the fallbackReviewers property value. If provided, the fallback reviewers are asked to complete a review if the primary reviewers do not exist. For example, if managers are selected as reviewers and a principal under review does not have a manager in Azure AD, the fallback reviewers are asked to review that principal. NOTE: The value of this property will override the corresponding setting on the accessReviewScheduleDefinition object.

Parameters:

  • value

    Value to set for the fallbackReviewers property.

Returns:

  • a void



127
128
129
# File 'lib/models/access_review_stage_settings.rb', line 127

def fallback_reviewers=(value)
    @fallback_reviewers = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/models/access_review_stage_settings.rb', line 134

def get_field_deserializers()
    return {
        "decisionsThatWillMoveToNextStage" => lambda {|n| @decisions_that_will_move_to_next_stage = n.get_collection_of_primitive_values(String) },
        "dependsOn" => lambda {|n| @depends_on = n.get_collection_of_primitive_values(String) },
        "durationInDays" => lambda {|n| @duration_in_days = n.get_number_value() },
        "fallbackReviewers" => lambda {|n| @fallback_reviewers = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AccessReviewReviewerScope.create_from_discriminator_value(pn) }) },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "recommendationInsightSettings" => lambda {|n| @recommendation_insight_settings = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AccessReviewRecommendationInsightSetting.create_from_discriminator_value(pn) }) },
        "recommendationsEnabled" => lambda {|n| @recommendations_enabled = n.get_boolean_value() },
        "reviewers" => lambda {|n| @reviewers = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AccessReviewReviewerScope.create_from_discriminator_value(pn) }) },
        "stageId" => lambda {|n| @stage_id = n.get_string_value() },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



151
152
153
# File 'lib/models/access_review_stage_settings.rb', line 151

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



159
160
161
# File 'lib/models/access_review_stage_settings.rb', line 159

def odata_type=(value)
    @odata_type = value
end

#recommendation_insight_settingsObject

Gets the recommendationInsightSettings property value. The recommendationInsightSettings property

Returns:

  • a access_review_recommendation_insight_setting



166
167
168
# File 'lib/models/access_review_stage_settings.rb', line 166

def recommendation_insight_settings
    return @recommendation_insight_settings
end

#recommendation_insight_settings=(value) ⇒ Object

Sets the recommendationInsightSettings property value. The recommendationInsightSettings property

Parameters:

  • value

    Value to set for the recommendationInsightSettings property.

Returns:

  • a void



174
175
176
# File 'lib/models/access_review_stage_settings.rb', line 174

def recommendation_insight_settings=(value)
    @recommendation_insight_settings = value
end

#recommendations_enabledObject

Gets the recommendationsEnabled property value. Indicates whether showing recommendations to reviewers is enabled. Required. NOTE: The value of this property will override override the corresponding setting on the accessReviewScheduleDefinition object.

Returns:

  • a boolean



181
182
183
# File 'lib/models/access_review_stage_settings.rb', line 181

def recommendations_enabled
    return @recommendations_enabled
end

#recommendations_enabled=(value) ⇒ Object

Sets the recommendationsEnabled property value. Indicates whether showing recommendations to reviewers is enabled. Required. NOTE: The value of this property will override override the corresponding setting on the accessReviewScheduleDefinition object.

Parameters:

  • value

    Value to set for the recommendationsEnabled property.

Returns:

  • a void



189
190
191
# File 'lib/models/access_review_stage_settings.rb', line 189

def recommendations_enabled=(value)
    @recommendations_enabled = value
end

#reviewersObject

Gets the reviewers property value. Defines who the reviewers are. If none are specified, the review is a self-review (users review their own access). For examples of options for assigning reviewers, see Assign reviewers to your access review definition using the Microsoft Graph API. NOTE: The value of this property will override the corresponding setting on the accessReviewScheduleDefinition.

Returns:

  • a access_review_reviewer_scope



196
197
198
# File 'lib/models/access_review_stage_settings.rb', line 196

def reviewers
    return @reviewers
end

#reviewers=(value) ⇒ Object

Sets the reviewers property value. Defines who the reviewers are. If none are specified, the review is a self-review (users review their own access). For examples of options for assigning reviewers, see Assign reviewers to your access review definition using the Microsoft Graph API. NOTE: The value of this property will override the corresponding setting on the accessReviewScheduleDefinition.

Parameters:

  • value

    Value to set for the reviewers property.

Returns:

  • a void



204
205
206
# File 'lib/models/access_review_stage_settings.rb', line 204

def reviewers=(value)
    @reviewers = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/models/access_review_stage_settings.rb', line 212

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_primitive_values("decisionsThatWillMoveToNextStage", @decisions_that_will_move_to_next_stage)
    writer.write_collection_of_primitive_values("dependsOn", @depends_on)
    writer.write_number_value("durationInDays", @duration_in_days)
    writer.write_collection_of_object_values("fallbackReviewers", @fallback_reviewers)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_collection_of_object_values("recommendationInsightSettings", @recommendation_insight_settings)
    writer.write_boolean_value("recommendationsEnabled", @recommendations_enabled)
    writer.write_collection_of_object_values("reviewers", @reviewers)
    writer.write_string_value("stageId", @stage_id)
    writer.write_additional_data(@additional_data)
end

#stage_idObject

Gets the stageId property value. Unique identifier of the accessReviewStageSettings object. The stageId will be used by the dependsOn property to indicate the order of the stages. Required.

Returns:

  • a string



229
230
231
# File 'lib/models/access_review_stage_settings.rb', line 229

def stage_id
    return @stage_id
end

#stage_id=(value) ⇒ Object

Sets the stageId property value. Unique identifier of the accessReviewStageSettings object. The stageId will be used by the dependsOn property to indicate the order of the stages. Required.

Parameters:

  • value

    Value to set for the stageId property.

Returns:

  • a void



237
238
239
# File 'lib/models/access_review_stage_settings.rb', line 237

def stage_id=(value)
    @stage_id = value
end