Class: MicrosoftGraph::Models::AgreementAcceptance

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/agreement_acceptance.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new agreementAcceptance and sets the default values.



83
84
85
# File 'lib/models/agreement_acceptance.rb', line 83

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Raises:

  • (StandardError)


91
92
93
94
# File 'lib/models/agreement_acceptance.rb', line 91

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AgreementAcceptance.new
end

Instance Method Details

#agreement_file_idObject

Gets the agreementFileId property value. The identifier of the agreement file accepted by the user.



53
54
55
# File 'lib/models/agreement_acceptance.rb', line 53

def agreement_file_id
    return @agreement_file_id
end

#agreement_file_id=(value) ⇒ Object

Sets the agreementFileId property value. The identifier of the agreement file accepted by the user.



61
62
63
# File 'lib/models/agreement_acceptance.rb', line 61

def agreement_file_id=(value)
    @agreement_file_id = value
end

#agreement_idObject

Gets the agreementId property value. The identifier of the agreement.



68
69
70
# File 'lib/models/agreement_acceptance.rb', line 68

def agreement_id
    return @agreement_id
end

#agreement_id=(value) ⇒ Object

Sets the agreementId property value. The identifier of the agreement.



76
77
78
# File 'lib/models/agreement_acceptance.rb', line 76

def agreement_id=(value)
    @agreement_id = value
end

#device_display_nameObject

Gets the deviceDisplayName property value. The display name of the device used for accepting the agreement.



99
100
101
# File 'lib/models/agreement_acceptance.rb', line 99

def device_display_name
    return @device_display_name
end

#device_display_name=(value) ⇒ Object

Sets the deviceDisplayName property value. The display name of the device used for accepting the agreement.



107
108
109
# File 'lib/models/agreement_acceptance.rb', line 107

def device_display_name=(value)
    @device_display_name = value
end

#device_idObject

Gets the deviceId property value. The unique identifier of the device used for accepting the agreement. Supports $filter (eq) and eq for null values.



114
115
116
# File 'lib/models/agreement_acceptance.rb', line 114

def device_id
    return @device_id
end

#device_id=(value) ⇒ Object

Sets the deviceId property value. The unique identifier of the device used for accepting the agreement. Supports $filter (eq) and eq for null values.



122
123
124
# File 'lib/models/agreement_acceptance.rb', line 122

def device_id=(value)
    @device_id = value
end

#device_o_s_typeObject

Gets the deviceOSType property value. The operating system used to accept the agreement.



129
130
131
# File 'lib/models/agreement_acceptance.rb', line 129

def device_o_s_type
    return @device_o_s_type
end

#device_o_s_type=(value) ⇒ Object

Sets the deviceOSType property value. The operating system used to accept the agreement.



137
138
139
# File 'lib/models/agreement_acceptance.rb', line 137

def device_o_s_type=(value)
    @device_o_s_type = value
end

#device_o_s_versionObject

Gets the deviceOSVersion property value. The operating system version of the device used to accept the agreement.



144
145
146
# File 'lib/models/agreement_acceptance.rb', line 144

def device_o_s_version
    return @device_o_s_version
end

#device_o_s_version=(value) ⇒ Object

Sets the deviceOSVersion property value. The operating system version of the device used to accept the agreement.



152
153
154
# File 'lib/models/agreement_acceptance.rb', line 152

def device_o_s_version=(value)
    @device_o_s_version = value
end

#expiration_date_timeObject

Gets the expirationDateTime property value. The expiration date time of the acceptance. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ge, le) and eq for null values.



159
160
161
# File 'lib/models/agreement_acceptance.rb', line 159

def expiration_date_time
    return @expiration_date_time
end

#expiration_date_time=(value) ⇒ Object

Sets the expirationDateTime property value. The expiration date time of the acceptance. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ge, le) and eq for null values.



167
168
169
# File 'lib/models/agreement_acceptance.rb', line 167

def expiration_date_time=(value)
    @expiration_date_time = value
end

#get_field_deserializersObject

The deserialization information for the current model



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/models/agreement_acceptance.rb', line 174

def get_field_deserializers()
    return super.merge({
        "agreementFileId" => lambda {|n| @agreement_file_id = n.get_string_value() },
        "agreementId" => lambda {|n| @agreement_id = n.get_string_value() },
        "deviceDisplayName" => lambda {|n| @device_display_name = n.get_string_value() },
        "deviceId" => lambda {|n| @device_id = n.get_string_value() },
        "deviceOSType" => lambda {|n| @device_o_s_type = n.get_string_value() },
        "deviceOSVersion" => lambda {|n| @device_o_s_version = n.get_string_value() },
        "expirationDateTime" => lambda {|n| @expiration_date_time = n.get_date_time_value() },
        "recordedDateTime" => lambda {|n| @recorded_date_time = n.get_date_time_value() },
        "state" => lambda {|n| @state = n.get_enum_value(MicrosoftGraph::Models::AgreementAcceptanceState) },
        "userDisplayName" => lambda {|n| @user_display_name = n.get_string_value() },
        "userEmail" => lambda {|n| @user_email = n.get_string_value() },
        "userId" => lambda {|n| @user_id = n.get_string_value() },
        "userPrincipalName" => lambda {|n| @user_principal_name = n.get_string_value() },
    })
end

#recorded_date_timeObject

Gets the recordedDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.



195
196
197
# File 'lib/models/agreement_acceptance.rb', line 195

def recorded_date_time
    return @recorded_date_time
end

#recorded_date_time=(value) ⇒ Object

Sets the recordedDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.



203
204
205
# File 'lib/models/agreement_acceptance.rb', line 203

def recorded_date_time=(value)
    @recorded_date_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Raises:

  • (StandardError)


211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/models/agreement_acceptance.rb', line 211

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("agreementFileId", @agreement_file_id)
    writer.write_string_value("agreementId", @agreement_id)
    writer.write_string_value("deviceDisplayName", @device_display_name)
    writer.write_string_value("deviceId", @device_id)
    writer.write_string_value("deviceOSType", @device_o_s_type)
    writer.write_string_value("deviceOSVersion", @device_o_s_version)
    writer.write_date_time_value("expirationDateTime", @expiration_date_time)
    writer.write_date_time_value("recordedDateTime", @recorded_date_time)
    writer.write_enum_value("state", @state)
    writer.write_string_value("userDisplayName", @user_display_name)
    writer.write_string_value("userEmail", @user_email)
    writer.write_string_value("userId", @user_id)
    writer.write_string_value("userPrincipalName", @user_principal_name)
end

#stateObject

Gets the state property value. The state of the agreement acceptance. Possible values are: accepted, declined. Supports $filter (eq).



232
233
234
# File 'lib/models/agreement_acceptance.rb', line 232

def state
    return @state
end

#state=(value) ⇒ Object

Sets the state property value. The state of the agreement acceptance. Possible values are: accepted, declined. Supports $filter (eq).



240
241
242
# File 'lib/models/agreement_acceptance.rb', line 240

def state=(value)
    @state = value
end

#user_display_nameObject

Gets the userDisplayName property value. Display name of the user when the acceptance was recorded.



247
248
249
# File 'lib/models/agreement_acceptance.rb', line 247

def user_display_name
    return @user_display_name
end

#user_display_name=(value) ⇒ Object

Sets the userDisplayName property value. Display name of the user when the acceptance was recorded.



255
256
257
# File 'lib/models/agreement_acceptance.rb', line 255

def user_display_name=(value)
    @user_display_name = value
end

#user_emailObject

Gets the userEmail property value. Email of the user when the acceptance was recorded.



262
263
264
# File 'lib/models/agreement_acceptance.rb', line 262

def user_email
    return @user_email
end

#user_email=(value) ⇒ Object

Sets the userEmail property value. Email of the user when the acceptance was recorded.



270
271
272
# File 'lib/models/agreement_acceptance.rb', line 270

def user_email=(value)
    @user_email = value
end

#user_idObject

Gets the userId property value. The identifier of the user who accepted the agreement. Supports $filter (eq).



277
278
279
# File 'lib/models/agreement_acceptance.rb', line 277

def user_id
    return @user_id
end

#user_id=(value) ⇒ Object

Sets the userId property value. The identifier of the user who accepted the agreement. Supports $filter (eq).



285
286
287
# File 'lib/models/agreement_acceptance.rb', line 285

def user_id=(value)
    @user_id = value
end

#user_principal_nameObject

Gets the userPrincipalName property value. UPN of the user when the acceptance was recorded.



292
293
294
# File 'lib/models/agreement_acceptance.rb', line 292

def user_principal_name
    return @user_principal_name
end

#user_principal_name=(value) ⇒ Object

Sets the userPrincipalName property value. UPN of the user when the acceptance was recorded.



300
301
302
# File 'lib/models/agreement_acceptance.rb', line 300

def user_principal_name=(value)
    @user_principal_name = value
end