Class: MicrosoftGraph::Models::AndroidManagedAppProtection
- Inherits:
-
TargetedManagedAppProtection
- Object
- Entity
- ManagedAppPolicy
- ManagedAppProtection
- TargetedManagedAppProtection
- MicrosoftGraph::Models::AndroidManagedAppProtection
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/android_managed_app_protection.rb
Overview
Policy used to configure detailed management settings targeted to specific security groups and for a specified set of apps on an Android device
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#apps ⇒ Object
Gets the apps property value.
-
#apps=(value) ⇒ Object
Sets the apps property value.
-
#custom_browser_display_name ⇒ Object
Gets the customBrowserDisplayName property value.
-
#custom_browser_display_name=(value) ⇒ Object
Sets the customBrowserDisplayName property value.
-
#custom_browser_package_id ⇒ Object
Gets the customBrowserPackageId property value.
-
#custom_browser_package_id=(value) ⇒ Object
Sets the customBrowserPackageId property value.
-
#deployed_app_count ⇒ Object
Gets the deployedAppCount property value.
-
#deployed_app_count=(value) ⇒ Object
Sets the deployedAppCount property value.
-
#deployment_summary ⇒ Object
Gets the deploymentSummary property value.
-
#deployment_summary=(value) ⇒ Object
Sets the deploymentSummary property value.
-
#disable_app_encryption_if_device_encryption_is_enabled ⇒ Object
Gets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value.
-
#disable_app_encryption_if_device_encryption_is_enabled=(value) ⇒ Object
Sets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value.
-
#encrypt_app_data ⇒ Object
Gets the encryptAppData property value.
-
#encrypt_app_data=(value) ⇒ Object
Sets the encryptAppData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new androidManagedAppProtection and sets the default values.
-
#minimum_required_patch_version ⇒ Object
Gets the minimumRequiredPatchVersion property value.
-
#minimum_required_patch_version=(value) ⇒ Object
Sets the minimumRequiredPatchVersion property value.
-
#minimum_warning_patch_version ⇒ Object
Gets the minimumWarningPatchVersion property value.
-
#minimum_warning_patch_version=(value) ⇒ Object
Sets the minimumWarningPatchVersion property value.
-
#screen_capture_blocked ⇒ Object
Gets the screenCaptureBlocked property value.
-
#screen_capture_blocked=(value) ⇒ Object
Sets the screenCaptureBlocked property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from TargetedManagedAppProtection
#assignments, #assignments=, #is_assigned, #is_assigned=
Methods inherited from ManagedAppProtection
#allowed_data_storage_locations, #allowed_data_storage_locations=, #allowed_inbound_data_transfer_sources, #allowed_inbound_data_transfer_sources=, #allowed_outbound_clipboard_sharing_level, #allowed_outbound_clipboard_sharing_level=, #allowed_outbound_data_transfer_destinations, #allowed_outbound_data_transfer_destinations=, #contact_sync_blocked, #contact_sync_blocked=, #data_backup_blocked, #data_backup_blocked=, #device_compliance_required, #device_compliance_required=, #disable_app_pin_if_device_pin_is_set, #disable_app_pin_if_device_pin_is_set=, #fingerprint_blocked, #fingerprint_blocked=, #managed_browser, #managed_browser=, #managed_browser_to_open_links_required, #managed_browser_to_open_links_required=, #maximum_pin_retries, #maximum_pin_retries=, #minimum_pin_length, #minimum_pin_length=, #minimum_required_app_version, #minimum_required_app_version=, #minimum_required_os_version, #minimum_required_os_version=, #minimum_warning_app_version, #minimum_warning_app_version=, #minimum_warning_os_version, #minimum_warning_os_version=, #organizational_credentials_required, #organizational_credentials_required=, #period_before_pin_reset, #period_before_pin_reset=, #period_offline_before_access_check, #period_offline_before_access_check=, #period_offline_before_wipe_is_enforced, #period_offline_before_wipe_is_enforced=, #period_online_before_access_check, #period_online_before_access_check=, #pin_character_set, #pin_character_set=, #pin_required, #pin_required=, #print_blocked, #print_blocked=, #save_as_blocked, #save_as_blocked=, #simple_pin_blocked, #simple_pin_blocked=
Methods inherited from ManagedAppPolicy
#created_date_time, #created_date_time=, #description, #description=, #display_name, #display_name=, #last_modified_date_time, #last_modified_date_time=, #version, #version=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new androidManagedAppProtection and sets the default values.
60 61 62 63 |
# File 'lib/models/android_managed_app_protection.rb', line 60 def initialize() super @odata_type = "#microsoft.graph.androidManagedAppProtection" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
69 70 71 72 |
# File 'lib/models/android_managed_app_protection.rb', line 69 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AndroidManagedAppProtection.new end |
Instance Method Details
#apps ⇒ Object
Gets the apps property value. List of apps to which the policy is deployed.
45 46 47 |
# File 'lib/models/android_managed_app_protection.rb', line 45 def apps return @apps end |
#apps=(value) ⇒ Object
Sets the apps property value. List of apps to which the policy is deployed.
53 54 55 |
# File 'lib/models/android_managed_app_protection.rb', line 53 def apps=(value) @apps = value end |
#custom_browser_display_name ⇒ Object
Gets the customBrowserDisplayName property value. Friendly name of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
77 78 79 |
# File 'lib/models/android_managed_app_protection.rb', line 77 def custom_browser_display_name return @custom_browser_display_name end |
#custom_browser_display_name=(value) ⇒ Object
Sets the customBrowserDisplayName property value. Friendly name of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
85 86 87 |
# File 'lib/models/android_managed_app_protection.rb', line 85 def custom_browser_display_name=(value) @custom_browser_display_name = value end |
#custom_browser_package_id ⇒ Object
Gets the customBrowserPackageId property value. Unique identifier of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
92 93 94 |
# File 'lib/models/android_managed_app_protection.rb', line 92 def custom_browser_package_id return @custom_browser_package_id end |
#custom_browser_package_id=(value) ⇒ Object
Sets the customBrowserPackageId property value. Unique identifier of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
100 101 102 |
# File 'lib/models/android_managed_app_protection.rb', line 100 def custom_browser_package_id=(value) @custom_browser_package_id = value end |
#deployed_app_count ⇒ Object
Gets the deployedAppCount property value. Count of apps to which the current policy is deployed.
107 108 109 |
# File 'lib/models/android_managed_app_protection.rb', line 107 def deployed_app_count return @deployed_app_count end |
#deployed_app_count=(value) ⇒ Object
Sets the deployedAppCount property value. Count of apps to which the current policy is deployed.
115 116 117 |
# File 'lib/models/android_managed_app_protection.rb', line 115 def deployed_app_count=(value) @deployed_app_count = value end |
#deployment_summary ⇒ Object
Gets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
122 123 124 |
# File 'lib/models/android_managed_app_protection.rb', line 122 def deployment_summary return @deployment_summary end |
#deployment_summary=(value) ⇒ Object
Sets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
130 131 132 |
# File 'lib/models/android_managed_app_protection.rb', line 130 def deployment_summary=(value) @deployment_summary = value end |
#disable_app_encryption_if_device_encryption_is_enabled ⇒ Object
Gets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled
137 138 139 |
# File 'lib/models/android_managed_app_protection.rb', line 137 def disable_app_encryption_if_device_encryption_is_enabled return @disable_app_encryption_if_device_encryption_is_enabled end |
#disable_app_encryption_if_device_encryption_is_enabled=(value) ⇒ Object
Sets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled
145 146 147 |
# File 'lib/models/android_managed_app_protection.rb', line 145 def disable_app_encryption_if_device_encryption_is_enabled=(value) @disable_app_encryption_if_device_encryption_is_enabled = value end |
#encrypt_app_data ⇒ Object
Gets the encryptAppData property value. Indicates whether application data for managed apps should be encrypted
152 153 154 |
# File 'lib/models/android_managed_app_protection.rb', line 152 def encrypt_app_data return @encrypt_app_data end |
#encrypt_app_data=(value) ⇒ Object
Sets the encryptAppData property value. Indicates whether application data for managed apps should be encrypted
160 161 162 |
# File 'lib/models/android_managed_app_protection.rb', line 160 def encrypt_app_data=(value) @encrypt_app_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/models/android_managed_app_protection.rb', line 167 def get_field_deserializers() return super.merge({ "apps" => lambda {|n| @apps = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ManagedMobileApp.create_from_discriminator_value(pn) }) }, "customBrowserDisplayName" => lambda {|n| @custom_browser_display_name = n.get_string_value() }, "customBrowserPackageId" => lambda {|n| @custom_browser_package_id = n.get_string_value() }, "deployedAppCount" => lambda {|n| @deployed_app_count = n.get_number_value() }, "deploymentSummary" => lambda {|n| @deployment_summary = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ManagedAppPolicyDeploymentSummary.create_from_discriminator_value(pn) }) }, "disableAppEncryptionIfDeviceEncryptionIsEnabled" => lambda {|n| @disable_app_encryption_if_device_encryption_is_enabled = n.get_boolean_value() }, "encryptAppData" => lambda {|n| @encrypt_app_data = n.get_boolean_value() }, "minimumRequiredPatchVersion" => lambda {|n| @minimum_required_patch_version = n.get_string_value() }, "minimumWarningPatchVersion" => lambda {|n| @minimum_warning_patch_version = n.get_string_value() }, "screenCaptureBlocked" => lambda {|n| @screen_capture_blocked = n.get_boolean_value() }, }) end |
#minimum_required_patch_version ⇒ Object
Gets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app.
185 186 187 |
# File 'lib/models/android_managed_app_protection.rb', line 185 def minimum_required_patch_version return @minimum_required_patch_version end |
#minimum_required_patch_version=(value) ⇒ Object
Sets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app.
193 194 195 |
# File 'lib/models/android_managed_app_protection.rb', line 193 def minimum_required_patch_version=(value) @minimum_required_patch_version = value end |
#minimum_warning_patch_version ⇒ Object
Gets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app.
200 201 202 |
# File 'lib/models/android_managed_app_protection.rb', line 200 def minimum_warning_patch_version return @minimum_warning_patch_version end |
#minimum_warning_patch_version=(value) ⇒ Object
Sets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app.
208 209 210 |
# File 'lib/models/android_managed_app_protection.rb', line 208 def minimum_warning_patch_version=(value) @minimum_warning_patch_version = value end |
#screen_capture_blocked ⇒ Object
Gets the screenCaptureBlocked property value. Indicates whether a managed user can take screen captures of managed apps
215 216 217 |
# File 'lib/models/android_managed_app_protection.rb', line 215 def screen_capture_blocked return @screen_capture_blocked end |
#screen_capture_blocked=(value) ⇒ Object
Sets the screenCaptureBlocked property value. Indicates whether a managed user can take screen captures of managed apps
223 224 225 |
# File 'lib/models/android_managed_app_protection.rb', line 223 def screen_capture_blocked=(value) @screen_capture_blocked = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/models/android_managed_app_protection.rb', line 231 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_collection_of_object_values("apps", @apps) writer.write_string_value("customBrowserDisplayName", @custom_browser_display_name) writer.write_string_value("customBrowserPackageId", @custom_browser_package_id) writer.write_number_value("deployedAppCount", @deployed_app_count) writer.write_object_value("deploymentSummary", @deployment_summary) writer.write_boolean_value("disableAppEncryptionIfDeviceEncryptionIsEnabled", @disable_app_encryption_if_device_encryption_is_enabled) writer.write_boolean_value("encryptAppData", @encrypt_app_data) writer.write_string_value("minimumRequiredPatchVersion", @minimum_required_patch_version) writer.write_string_value("minimumWarningPatchVersion", @minimum_warning_patch_version) writer.write_boolean_value("screenCaptureBlocked", @screen_capture_blocked) end |