Class: MicrosoftGraph::Models::AutomaticRepliesMailTips

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/automatic_replies_mail_tips.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new automaticRepliesMailTips and sets the default values.



46
47
48
# File 'lib/models/automatic_replies_mail_tips.rb', line 46

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • The parse node to use to read the discriminator value and create the object

Returns:

  • a automatic_replies_mail_tips

Raises:



54
55
56
57
# File 'lib/models/automatic_replies_mail_tips.rb', line 54

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AutomaticRepliesMailTips.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



31
32
33
# File 'lib/models/automatic_replies_mail_tips.rb', line 31

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • Value to set for the additionalData property.

Returns:

  • a void



39
40
41
# File 'lib/models/automatic_replies_mail_tips.rb', line 39

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



62
63
64
65
66
67
68
69
70
# File 'lib/models/automatic_replies_mail_tips.rb', line 62

def get_field_deserializers()
    return {
        "message" => lambda {|n| @message = n.get_string_value() },
        "messageLanguage" => lambda {|n| @message_language = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::LocaleInfo.create_from_discriminator_value(pn) }) },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "scheduledEndTime" => lambda {|n| @scheduled_end_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DateTimeTimeZone.create_from_discriminator_value(pn) }) },
        "scheduledStartTime" => lambda {|n| @scheduled_start_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DateTimeTimeZone.create_from_discriminator_value(pn) }) },
    }
end

#messageObject

Gets the message property value. The automatic reply message.

Returns:

  • a string



75
76
77
# File 'lib/models/automatic_replies_mail_tips.rb', line 75

def message
    return @message
end

#message=(value) ⇒ Object

Sets the message property value. The automatic reply message.

Parameters:

  • Value to set for the message property.

Returns:

  • a void



83
84
85
# File 'lib/models/automatic_replies_mail_tips.rb', line 83

def message=(value)
    @message = value
end

#message_languageObject

Gets the messageLanguage property value. The language that the automatic reply message is in.

Returns:

  • a locale_info



90
91
92
# File 'lib/models/automatic_replies_mail_tips.rb', line 90

def message_language
    return @message_language
end

#message_language=(value) ⇒ Object

Sets the messageLanguage property value. The language that the automatic reply message is in.

Parameters:

  • Value to set for the messageLanguage property.

Returns:

  • a void



98
99
100
# File 'lib/models/automatic_replies_mail_tips.rb', line 98

def message_language=(value)
    @message_language = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



105
106
107
# File 'lib/models/automatic_replies_mail_tips.rb', line 105

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • Value to set for the @odata.type property.

Returns:

  • a void



113
114
115
# File 'lib/models/automatic_replies_mail_tips.rb', line 113

def odata_type=(value)
    @odata_type = value
end

#scheduled_end_timeObject

Gets the scheduledEndTime property value. The date and time that automatic replies are set to end.

Returns:

  • a date_time_time_zone



120
121
122
# File 'lib/models/automatic_replies_mail_tips.rb', line 120

def scheduled_end_time
    return @scheduled_end_time
end

#scheduled_end_time=(value) ⇒ Object

Sets the scheduledEndTime property value. The date and time that automatic replies are set to end.

Parameters:

  • Value to set for the scheduledEndTime property.

Returns:

  • a void



128
129
130
# File 'lib/models/automatic_replies_mail_tips.rb', line 128

def scheduled_end_time=(value)
    @scheduled_end_time = value
end

#scheduled_start_timeObject

Gets the scheduledStartTime property value. The date and time that automatic replies are set to begin.

Returns:

  • a date_time_time_zone



135
136
137
# File 'lib/models/automatic_replies_mail_tips.rb', line 135

def scheduled_start_time
    return @scheduled_start_time
end

#scheduled_start_time=(value) ⇒ Object

Sets the scheduledStartTime property value. The date and time that automatic replies are set to begin.

Parameters:

  • Value to set for the scheduledStartTime property.

Returns:

  • a void



143
144
145
# File 'lib/models/automatic_replies_mail_tips.rb', line 143

def scheduled_start_time=(value)
    @scheduled_start_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • Serialization writer to use to serialize this model

Returns:

  • a void

Raises:



151
152
153
154
155
156
157
158
159
# File 'lib/models/automatic_replies_mail_tips.rb', line 151

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("message", @message)
    writer.write_object_value("messageLanguage", @message_language)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_object_value("scheduledEndTime", @scheduled_end_time)
    writer.write_object_value("scheduledStartTime", @scheduled_start_time)
    writer.write_additional_data(@additional_data)
end