Class: MicrosoftGraph::Models::BroadcastMeetingCaptionSettings
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::BroadcastMeetingCaptionSettings
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/broadcast_meeting_caption_settings.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new broadcastMeetingCaptionSettings and sets the default values.
-
#is_caption_enabled ⇒ Object
Gets the isCaptionEnabled property value.
-
#is_caption_enabled=(value) ⇒ Object
Sets the isCaptionEnabled property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#spoken_language ⇒ Object
Gets the spokenLanguage property value.
-
#spoken_language=(value) ⇒ Object
Sets the spokenLanguage property value.
-
#translation_languages ⇒ Object
Gets the translationLanguages property value.
-
#translation_languages=(value) ⇒ Object
Sets the translationLanguages property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new broadcastMeetingCaptionSettings and sets the default values.
43 44 45 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 43 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
51 52 53 54 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 51 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return BroadcastMeetingCaptionSettings.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
28 29 30 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 28 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
36 37 38 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 36 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
59 60 61 62 63 64 65 66 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 59 def get_field_deserializers() return { "isCaptionEnabled" => lambda {|n| @is_caption_enabled = n.get_boolean_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "spokenLanguage" => lambda {|n| @spoken_language = n.get_string_value() }, "translationLanguages" => lambda {|n| @translation_languages = n.get_collection_of_primitive_values(String) }, } end |
#is_caption_enabled ⇒ Object
Gets the isCaptionEnabled property value. Indicates whether captions are enabled for this Teams live event.
71 72 73 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 71 def is_caption_enabled return @is_caption_enabled end |
#is_caption_enabled=(value) ⇒ Object
Sets the isCaptionEnabled property value. Indicates whether captions are enabled for this Teams live event.
79 80 81 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 79 def is_caption_enabled=(value) @is_caption_enabled = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
86 87 88 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 86 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
94 95 96 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 94 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
102 103 104 105 106 107 108 109 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 102 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("isCaptionEnabled", @is_caption_enabled) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("spokenLanguage", @spoken_language) writer.write_collection_of_primitive_values("translationLanguages", @translation_languages) writer.write_additional_data(@additional_data) end |
#spoken_language ⇒ Object
Gets the spokenLanguage property value. The spoken language.
114 115 116 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 114 def spoken_language return @spoken_language end |
#spoken_language=(value) ⇒ Object
Sets the spokenLanguage property value. The spoken language.
122 123 124 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 122 def spoken_language=(value) @spoken_language = value end |
#translation_languages ⇒ Object
Gets the translationLanguages property value. The translation languages (choose up to 6).
129 130 131 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 129 def translation_languages return @translation_languages end |
#translation_languages=(value) ⇒ Object
Sets the translationLanguages property value. The translation languages (choose up to 6).
137 138 139 |
# File 'lib/models/broadcast_meeting_caption_settings.rb', line 137 def translation_languages=(value) @translation_languages = value end |