Class: MicrosoftGraph::Models::BrowserSite
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/browser_site.rb
Overview
Singleton entity which is used to specify IE mode site metadata
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#allow_redirect ⇒ Object
Gets the allowRedirect property value.
-
#allow_redirect=(value) ⇒ Object
Sets the allowRedirect property value.
-
#comment ⇒ Object
Gets the comment property value.
-
#comment=(value) ⇒ Object
Sets the comment property value.
-
#compatibility_mode ⇒ Object
Gets the compatibilityMode property value.
-
#compatibility_mode=(value) ⇒ Object
Sets the compatibilityMode property value.
-
#created_date_time ⇒ Object
Gets the createdDateTime property value.
-
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value.
-
#deleted_date_time ⇒ Object
Gets the deletedDateTime property value.
-
#deleted_date_time=(value) ⇒ Object
Sets the deletedDateTime property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#history ⇒ Object
Gets the history property value.
-
#history=(value) ⇒ Object
Sets the history property value.
-
#initialize ⇒ Object
constructor
Instantiates a new browserSite and sets the default values.
-
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value.
-
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value.
-
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value.
-
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value.
-
#merge_type ⇒ Object
Gets the mergeType property value.
-
#merge_type=(value) ⇒ Object
Sets the mergeType property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#status ⇒ Object
Gets the status property value.
-
#status=(value) ⇒ Object
Sets the status property value.
-
#target_environment ⇒ Object
Gets the targetEnvironment property value.
-
#target_environment=(value) ⇒ Object
Sets the targetEnvironment property value.
-
#web_url ⇒ Object
Gets the webUrl property value.
-
#web_url=(value) ⇒ Object
Sets the webUrl property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new browserSite and sets the default values.
97 98 99 |
# File 'lib/models/browser_site.rb', line 97 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
120 121 122 123 |
# File 'lib/models/browser_site.rb', line 120 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return BrowserSite.new end |
Instance Method Details
#allow_redirect ⇒ Object
Gets the allowRedirect property value. Controls the behavior of redirected sites. If true, indicates that the site will open in Internet Explorer 11 or Microsoft Edge even if the site is navigated to as part of a HTTP or meta refresh redirection chain.
52 53 54 |
# File 'lib/models/browser_site.rb', line 52 def allow_redirect return @allow_redirect end |
#allow_redirect=(value) ⇒ Object
Sets the allowRedirect property value. Controls the behavior of redirected sites. If true, indicates that the site will open in Internet Explorer 11 or Microsoft Edge even if the site is navigated to as part of a HTTP or meta refresh redirection chain.
60 61 62 |
# File 'lib/models/browser_site.rb', line 60 def allow_redirect=(value) @allow_redirect = value end |
#comment ⇒ Object
Gets the comment property value. The comment for the site.
67 68 69 |
# File 'lib/models/browser_site.rb', line 67 def comment return @comment end |
#comment=(value) ⇒ Object
Sets the comment property value. The comment for the site.
75 76 77 |
# File 'lib/models/browser_site.rb', line 75 def comment=(value) @comment = value end |
#compatibility_mode ⇒ Object
Gets the compatibilityMode property value. The compatibilityMode property
82 83 84 |
# File 'lib/models/browser_site.rb', line 82 def compatibility_mode return @compatibility_mode end |
#compatibility_mode=(value) ⇒ Object
Sets the compatibilityMode property value. The compatibilityMode property
90 91 92 |
# File 'lib/models/browser_site.rb', line 90 def compatibility_mode=(value) @compatibility_mode = value end |
#created_date_time ⇒ Object
Gets the createdDateTime property value. The date and time when the site was created.
104 105 106 |
# File 'lib/models/browser_site.rb', line 104 def created_date_time return @created_date_time end |
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value. The date and time when the site was created.
112 113 114 |
# File 'lib/models/browser_site.rb', line 112 def created_date_time=(value) @created_date_time = value end |
#deleted_date_time ⇒ Object
Gets the deletedDateTime property value. The date and time when the site was deleted.
128 129 130 |
# File 'lib/models/browser_site.rb', line 128 def deleted_date_time return @deleted_date_time end |
#deleted_date_time=(value) ⇒ Object
Sets the deletedDateTime property value. The date and time when the site was deleted.
136 137 138 |
# File 'lib/models/browser_site.rb', line 136 def deleted_date_time=(value) @deleted_date_time = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/models/browser_site.rb', line 143 def get_field_deserializers() return super.merge({ "allowRedirect" => lambda {|n| @allow_redirect = n.get_boolean_value() }, "comment" => lambda {|n| @comment = n.get_string_value() }, "compatibilityMode" => lambda {|n| @compatibility_mode = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteCompatibilityMode) }, "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() }, "deletedDateTime" => lambda {|n| @deleted_date_time = n.get_date_time_value() }, "history" => lambda {|n| @history = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::BrowserSiteHistory.create_from_discriminator_value(pn) }) }, "lastModifiedBy" => lambda {|n| @last_modified_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) }, "lastModifiedDateTime" => lambda {|n| @last_modified_date_time = n.get_date_time_value() }, "mergeType" => lambda {|n| @merge_type = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteMergeType) }, "status" => lambda {|n| @status = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteStatus) }, "targetEnvironment" => lambda {|n| @target_environment = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteTargetEnvironment) }, "webUrl" => lambda {|n| @web_url = n.get_string_value() }, }) end |
#history ⇒ Object
Gets the history property value. The history of modifications applied to the site.
163 164 165 |
# File 'lib/models/browser_site.rb', line 163 def history return @history end |
#history=(value) ⇒ Object
Sets the history property value. The history of modifications applied to the site.
171 172 173 |
# File 'lib/models/browser_site.rb', line 171 def history=(value) @history = value end |
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value. The user who last modified the site.
178 179 180 |
# File 'lib/models/browser_site.rb', line 178 def last_modified_by return @last_modified_by end |
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value. The user who last modified the site.
186 187 188 |
# File 'lib/models/browser_site.rb', line 186 def last_modified_by=(value) @last_modified_by = value end |
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value. The date and time when the site was last modified.
193 194 195 |
# File 'lib/models/browser_site.rb', line 193 def last_modified_date_time return @last_modified_date_time end |
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value. The date and time when the site was last modified.
201 202 203 |
# File 'lib/models/browser_site.rb', line 201 def last_modified_date_time=(value) @last_modified_date_time = value end |
#merge_type ⇒ Object
Gets the mergeType property value. The mergeType property
208 209 210 |
# File 'lib/models/browser_site.rb', line 208 def merge_type return @merge_type end |
#merge_type=(value) ⇒ Object
Sets the mergeType property value. The mergeType property
216 217 218 |
# File 'lib/models/browser_site.rb', line 216 def merge_type=(value) @merge_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/models/browser_site.rb', line 224 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_boolean_value("allowRedirect", @allow_redirect) writer.write_string_value("comment", @comment) writer.write_enum_value("compatibilityMode", @compatibility_mode) writer.write_date_time_value("createdDateTime", @created_date_time) writer.write_date_time_value("deletedDateTime", @deleted_date_time) writer.write_collection_of_object_values("history", @history) writer.write_object_value("lastModifiedBy", @last_modified_by) writer.write_date_time_value("lastModifiedDateTime", @last_modified_date_time) writer.write_enum_value("mergeType", @merge_type) writer.write_enum_value("status", @status) writer.write_enum_value("targetEnvironment", @target_environment) writer.write_string_value("webUrl", @web_url) end |
#status ⇒ Object
Gets the status property value. The status property
244 245 246 |
# File 'lib/models/browser_site.rb', line 244 def status return @status end |
#status=(value) ⇒ Object
Sets the status property value. The status property
252 253 254 |
# File 'lib/models/browser_site.rb', line 252 def status=(value) @status = value end |
#target_environment ⇒ Object
Gets the targetEnvironment property value. The targetEnvironment property
259 260 261 |
# File 'lib/models/browser_site.rb', line 259 def target_environment return @target_environment end |
#target_environment=(value) ⇒ Object
Sets the targetEnvironment property value. The targetEnvironment property
267 268 269 |
# File 'lib/models/browser_site.rb', line 267 def target_environment=(value) @target_environment = value end |
#web_url ⇒ Object
Gets the webUrl property value. The URL of the site.
274 275 276 |
# File 'lib/models/browser_site.rb', line 274 def web_url return @web_url end |
#web_url=(value) ⇒ Object
Sets the webUrl property value. The URL of the site.
282 283 284 |
# File 'lib/models/browser_site.rb', line 282 def web_url=(value) @web_url = value end |