Class: MicrosoftGraph::Models::BrowserSiteHistory

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/browser_site_history.rb

Overview

The history for the site modifications

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new browserSiteHistory and sets the default values.



103
104
105
# File 'lib/models/browser_site_history.rb', line 103

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a browser_site_history

Raises:

  • (StandardError)


111
112
113
114
# File 'lib/models/browser_site_history.rb', line 111

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return BrowserSiteHistory.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



43
44
45
# File 'lib/models/browser_site_history.rb', line 43

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



51
52
53
# File 'lib/models/browser_site_history.rb', line 51

def additional_data=(value)
    @additional_data = value
end

#allow_redirectObject

Gets the allowRedirect property value. Controls the behavior of redirected sites. If true, indicates that the site will open in Internet Explorer 11 or Microsoft Edge even if the site is navigated to as part of a HTTP or meta refresh redirection chain.

Returns:

  • a boolean



58
59
60
# File 'lib/models/browser_site_history.rb', line 58

def allow_redirect
    return @allow_redirect
end

#allow_redirect=(value) ⇒ Object

Sets the allowRedirect property value. Controls the behavior of redirected sites. If true, indicates that the site will open in Internet Explorer 11 or Microsoft Edge even if the site is navigated to as part of a HTTP or meta refresh redirection chain.

Parameters:

  • value

    Value to set for the allowRedirect property.

Returns:

  • a void



66
67
68
# File 'lib/models/browser_site_history.rb', line 66

def allow_redirect=(value)
    @allow_redirect = value
end

#commentObject

Gets the comment property value. The comment for the site.

Returns:

  • a string



73
74
75
# File 'lib/models/browser_site_history.rb', line 73

def comment
    return @comment
end

#comment=(value) ⇒ Object

Sets the comment property value. The comment for the site.

Parameters:

  • value

    Value to set for the comment property.

Returns:

  • a void



81
82
83
# File 'lib/models/browser_site_history.rb', line 81

def comment=(value)
    @comment = value
end

#compatibility_modeObject

Gets the compatibilityMode property value. Controls what compatibility setting is used for specific sites or domains. The possible values are: default, internetExplorer8Enterprise, internetExplorer7Enterprise, internetExplorer11, internetExplorer10, internetExplorer9, internetExplorer8, internetExplorer7, internetExplorer5, unknownFutureValue.

Returns:

  • a browser_site_compatibility_mode



88
89
90
# File 'lib/models/browser_site_history.rb', line 88

def compatibility_mode
    return @compatibility_mode
end

#compatibility_mode=(value) ⇒ Object

Sets the compatibilityMode property value. Controls what compatibility setting is used for specific sites or domains. The possible values are: default, internetExplorer8Enterprise, internetExplorer7Enterprise, internetExplorer11, internetExplorer10, internetExplorer9, internetExplorer8, internetExplorer7, internetExplorer5, unknownFutureValue.

Parameters:

  • value

    Value to set for the compatibilityMode property.

Returns:

  • a void



96
97
98
# File 'lib/models/browser_site_history.rb', line 96

def compatibility_mode=(value)
    @compatibility_mode = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/models/browser_site_history.rb', line 119

def get_field_deserializers()
    return {
        "allowRedirect" => lambda {|n| @allow_redirect = n.get_boolean_value() },
        "comment" => lambda {|n| @comment = n.get_string_value() },
        "compatibilityMode" => lambda {|n| @compatibility_mode = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteCompatibilityMode) },
        "lastModifiedBy" => lambda {|n| @last_modified_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) },
        "mergeType" => lambda {|n| @merge_type = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteMergeType) },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "publishedDateTime" => lambda {|n| @published_date_time = n.get_date_time_value() },
        "targetEnvironment" => lambda {|n| @target_environment = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteTargetEnvironment) },
    }
end

#last_modified_byObject

Gets the lastModifiedBy property value. The user who last modified the site.

Returns:

  • a identity_set



135
136
137
# File 'lib/models/browser_site_history.rb', line 135

def last_modified_by
    return @last_modified_by
end

#last_modified_by=(value) ⇒ Object

Sets the lastModifiedBy property value. The user who last modified the site.

Parameters:

  • value

    Value to set for the lastModifiedBy property.

Returns:

  • a void



143
144
145
# File 'lib/models/browser_site_history.rb', line 143

def last_modified_by=(value)
    @last_modified_by = value
end

#merge_typeObject

Gets the mergeType property value. The merge type of the site. The possible values are: noMerge, default, unknownFutureValue.

Returns:

  • a browser_site_merge_type



150
151
152
# File 'lib/models/browser_site_history.rb', line 150

def merge_type
    return @merge_type
end

#merge_type=(value) ⇒ Object

Sets the mergeType property value. The merge type of the site. The possible values are: noMerge, default, unknownFutureValue.

Parameters:

  • value

    Value to set for the mergeType property.

Returns:

  • a void



158
159
160
# File 'lib/models/browser_site_history.rb', line 158

def merge_type=(value)
    @merge_type = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



165
166
167
# File 'lib/models/browser_site_history.rb', line 165

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



173
174
175
# File 'lib/models/browser_site_history.rb', line 173

def odata_type=(value)
    @odata_type = value
end

#published_date_timeObject

Gets the publishedDateTime property value. The date and time when the site was last published.

Returns:

  • a date_time



180
181
182
# File 'lib/models/browser_site_history.rb', line 180

def published_date_time
    return @published_date_time
end

#published_date_time=(value) ⇒ Object

Sets the publishedDateTime property value. The date and time when the site was last published.

Parameters:

  • value

    Value to set for the publishedDateTime property.

Returns:

  • a void



188
189
190
# File 'lib/models/browser_site_history.rb', line 188

def published_date_time=(value)
    @published_date_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/models/browser_site_history.rb', line 196

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_boolean_value("allowRedirect", @allow_redirect)
    writer.write_string_value("comment", @comment)
    writer.write_enum_value("compatibilityMode", @compatibility_mode)
    writer.write_object_value("lastModifiedBy", @last_modified_by)
    writer.write_enum_value("mergeType", @merge_type)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_date_time_value("publishedDateTime", @published_date_time)
    writer.write_enum_value("targetEnvironment", @target_environment)
    writer.write_additional_data(@additional_data)
end

#target_environmentObject

Gets the targetEnvironment property value. The target environment that the site should open in. The possible values are: internetExplorerMode, internetExplorer11, microsoftEdge, configurable, none, unknownFutureValue.Prior to June 15, 2022, the internetExplorer11 option would allow opening a site in the Internet Explorer 11 (IE11) desktop application. Following the retirement of IE11 on June 15, 2022, the internetExplorer11 option will no longer open an IE11 window and will instead behave the same as the internetExplorerMode option.

Returns:

  • a browser_site_target_environment



212
213
214
# File 'lib/models/browser_site_history.rb', line 212

def target_environment
    return @target_environment
end

#target_environment=(value) ⇒ Object

Sets the targetEnvironment property value. The target environment that the site should open in. The possible values are: internetExplorerMode, internetExplorer11, microsoftEdge, configurable, none, unknownFutureValue.Prior to June 15, 2022, the internetExplorer11 option would allow opening a site in the Internet Explorer 11 (IE11) desktop application. Following the retirement of IE11 on June 15, 2022, the internetExplorer11 option will no longer open an IE11 window and will instead behave the same as the internetExplorerMode option.

Parameters:

  • value

    Value to set for the targetEnvironment property.

Returns:

  • a void



220
221
222
# File 'lib/models/browser_site_history.rb', line 220

def target_environment=(value)
    @target_environment = value
end