Class: MicrosoftGraph::Models::CalendarGroup

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/calendar_group.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new calendarGroup and sets the default values.



70
71
72
# File 'lib/models/calendar_group.rb', line 70

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Raises:

  • (StandardError)


78
79
80
81
# File 'lib/models/calendar_group.rb', line 78

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return CalendarGroup.new
end

Instance Method Details

#calendarsObject

Gets the calendars property value. The calendars in the calendar group. Navigation property. Read-only. Nullable.



25
26
27
# File 'lib/models/calendar_group.rb', line 25

def calendars
    return @calendars
end

#calendars=(value) ⇒ Object

Sets the calendars property value. The calendars in the calendar group. Navigation property. Read-only. Nullable.



33
34
35
# File 'lib/models/calendar_group.rb', line 33

def calendars=(value)
    @calendars = value
end

#change_keyObject

Gets the changeKey property value. Identifies the version of the calendar group. Every time the calendar group is changed, ChangeKey changes as well. This allows Exchange to apply changes to the correct version of the object. Read-only.



40
41
42
# File 'lib/models/calendar_group.rb', line 40

def change_key
    return @change_key
end

#change_key=(value) ⇒ Object

Sets the changeKey property value. Identifies the version of the calendar group. Every time the calendar group is changed, ChangeKey changes as well. This allows Exchange to apply changes to the correct version of the object. Read-only.



48
49
50
# File 'lib/models/calendar_group.rb', line 48

def change_key=(value)
    @change_key = value
end

#class_idObject

Gets the classId property value. The class identifier. Read-only.



55
56
57
# File 'lib/models/calendar_group.rb', line 55

def class_id
    return @class_id
end

#class_id=(value) ⇒ Object

Sets the classId property value. The class identifier. Read-only.



63
64
65
# File 'lib/models/calendar_group.rb', line 63

def class_id=(value)
    @class_id = value
end

#get_field_deserializersObject

The deserialization information for the current model



86
87
88
89
90
91
92
93
# File 'lib/models/calendar_group.rb', line 86

def get_field_deserializers()
    return super.merge({
        "calendars" => lambda {|n| @calendars = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Calendar.create_from_discriminator_value(pn) }) },
        "changeKey" => lambda {|n| @change_key = n.get_string_value() },
        "classId" => lambda {|n| @class_id = n.get_guid_value() },
        "name" => lambda {|n| @name = n.get_string_value() },
    })
end

#nameObject

Gets the name property value. The group name.



98
99
100
# File 'lib/models/calendar_group.rb', line 98

def name
    return @name
end

#name=(value) ⇒ Object

Sets the name property value. The group name.



106
107
108
# File 'lib/models/calendar_group.rb', line 106

def name=(value)
    @name = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Raises:

  • (StandardError)


114
115
116
117
118
119
120
121
# File 'lib/models/calendar_group.rb', line 114

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("calendars", @calendars)
    writer.write_string_value("changeKey", @change_key)
    writer.write_guid_value("classId", @class_id)
    writer.write_string_value("name", @name)
end