Class: MicrosoftGraph::Models::CallEndedEventMessageDetail

Inherits:
EventMessageDetail show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/call_ended_event_message_detail.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from EventMessageDetail

#additional_data, #additional_data=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new callEndedEventMessageDetail and sets the default values.



88
89
90
91
# File 'lib/models/call_ended_event_message_detail.rb', line 88

def initialize()
    super
    @odata_type = "#microsoft.graph.callEndedEventMessageDetail"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a call_ended_event_message_detail

Raises:

  • (StandardError)


97
98
99
100
# File 'lib/models/call_ended_event_message_detail.rb', line 97

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return CallEndedEventMessageDetail.new
end

Instance Method Details

#call_durationObject

Gets the callDuration property value. Duration of the call.

Returns:

  • a microsoft_kiota_abstractions::_i_s_o_duration



28
29
30
# File 'lib/models/call_ended_event_message_detail.rb', line 28

def call_duration
    return @call_duration
end

#call_duration=(value) ⇒ Object

Sets the callDuration property value. Duration of the call.

Parameters:

  • value

    Value to set for the callDuration property.

Returns:

  • a void



36
37
38
# File 'lib/models/call_ended_event_message_detail.rb', line 36

def call_duration=(value)
    @call_duration = value
end

#call_event_typeObject

Gets the callEventType property value. Represents the call event type. Possible values are: call, meeting, screenShare, unknownFutureValue.

Returns:

  • a teamwork_call_event_type



43
44
45
# File 'lib/models/call_ended_event_message_detail.rb', line 43

def call_event_type
    return @call_event_type
end

#call_event_type=(value) ⇒ Object

Sets the callEventType property value. Represents the call event type. Possible values are: call, meeting, screenShare, unknownFutureValue.

Parameters:

  • value

    Value to set for the callEventType property.

Returns:

  • a void



51
52
53
# File 'lib/models/call_ended_event_message_detail.rb', line 51

def call_event_type=(value)
    @call_event_type = value
end

#call_idObject

Gets the callId property value. Unique identifier of the call.

Returns:

  • a string



58
59
60
# File 'lib/models/call_ended_event_message_detail.rb', line 58

def call_id
    return @call_id
end

#call_id=(value) ⇒ Object

Sets the callId property value. Unique identifier of the call.

Parameters:

  • value

    Value to set for the callId property.

Returns:

  • a void



66
67
68
# File 'lib/models/call_ended_event_message_detail.rb', line 66

def call_id=(value)
    @call_id = value
end

#call_participantsObject

Gets the callParticipants property value. List of call participants.

Returns:

  • a call_participant_info



73
74
75
# File 'lib/models/call_ended_event_message_detail.rb', line 73

def call_participants
    return @call_participants
end

#call_participants=(value) ⇒ Object

Sets the callParticipants property value. List of call participants.

Parameters:

  • value

    Value to set for the callParticipants property.

Returns:

  • a void



81
82
83
# File 'lib/models/call_ended_event_message_detail.rb', line 81

def call_participants=(value)
    @call_participants = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



105
106
107
108
109
110
111
112
113
# File 'lib/models/call_ended_event_message_detail.rb', line 105

def get_field_deserializers()
    return super.merge({
        "callDuration" => lambda {|n| @call_duration = n.get_duration_value() },
        "callEventType" => lambda {|n| @call_event_type = n.get_enum_value(MicrosoftGraph::Models::TeamworkCallEventType) },
        "callId" => lambda {|n| @call_id = n.get_string_value() },
        "callParticipants" => lambda {|n| @call_participants = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::CallParticipantInfo.create_from_discriminator_value(pn) }) },
        "initiator" => lambda {|n| @initiator = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) },
    })
end

#initiatorObject

Gets the initiator property value. Initiator of the event.

Returns:

  • a identity_set



118
119
120
# File 'lib/models/call_ended_event_message_detail.rb', line 118

def initiator
    return @initiator
end

#initiator=(value) ⇒ Object

Sets the initiator property value. Initiator of the event.

Parameters:

  • value

    Value to set for the initiator property.

Returns:

  • a void



126
127
128
# File 'lib/models/call_ended_event_message_detail.rb', line 126

def initiator=(value)
    @initiator = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


134
135
136
137
138
139
140
141
142
# File 'lib/models/call_ended_event_message_detail.rb', line 134

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_duration_value("callDuration", @call_duration)
    writer.write_enum_value("callEventType", @call_event_type)
    writer.write_string_value("callId", @call_id)
    writer.write_collection_of_object_values("callParticipants", @call_participants)
    writer.write_object_value("initiator", @initiator)
end