Class: MicrosoftGraph::Models::ChatMessageMention
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::ChatMessageMention
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/chat_message_mention.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new chatMessageMention and sets the default values.
-
#mention_text ⇒ Object
Gets the mentionText property value.
-
#mention_text=(value) ⇒ Object
Sets the mentionText property value.
-
#mentioned ⇒ Object
Gets the mentioned property value.
-
#mentioned=(value) ⇒ Object
Sets the mentioned property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new chatMessageMention and sets the default values.
43 44 45 |
# File 'lib/models/chat_message_mention.rb', line 43 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
51 52 53 54 |
# File 'lib/models/chat_message_mention.rb', line 51 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ChatMessageMention.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
28 29 30 |
# File 'lib/models/chat_message_mention.rb', line 28 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
36 37 38 |
# File 'lib/models/chat_message_mention.rb', line 36 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
59 60 61 62 63 64 65 66 |
# File 'lib/models/chat_message_mention.rb', line 59 def get_field_deserializers() return { "id" => lambda {|n| @id = n.get_number_value() }, "mentionText" => lambda {|n| @mention_text = n.get_string_value() }, "mentioned" => lambda {|n| @mentioned = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ChatMessageMentionedIdentitySet.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, } end |
#id ⇒ Object
Gets the id property value. Index of an entity being mentioned in the specified chatMessage. Matches the index value in the corresponding