Class: MicrosoftGraph::Models::ChoiceColumn

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/choice_column.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new choiceColumn and sets the default values.



73
74
75
# File 'lib/models/choice_column.rb', line 73

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a choice_column

Raises:

  • (StandardError)


81
82
83
84
# File 'lib/models/choice_column.rb', line 81

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ChoiceColumn.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



28
29
30
# File 'lib/models/choice_column.rb', line 28

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



36
37
38
# File 'lib/models/choice_column.rb', line 36

def additional_data=(value)
    @additional_data = value
end

#allow_text_entryObject

Gets the allowTextEntry property value. If true, allows custom values that aren’t in the configured choices.

Returns:

  • a boolean



43
44
45
# File 'lib/models/choice_column.rb', line 43

def allow_text_entry
    return @allow_text_entry
end

#allow_text_entry=(value) ⇒ Object

Sets the allowTextEntry property value. If true, allows custom values that aren’t in the configured choices.

Parameters:

  • value

    Value to set for the allowTextEntry property.

Returns:

  • a void



51
52
53
# File 'lib/models/choice_column.rb', line 51

def allow_text_entry=(value)
    @allow_text_entry = value
end

#choicesObject

Gets the choices property value. The list of values available for this column.

Returns:

  • a string



58
59
60
# File 'lib/models/choice_column.rb', line 58

def choices
    return @choices
end

#choices=(value) ⇒ Object

Sets the choices property value. The list of values available for this column.

Parameters:

  • value

    Value to set for the choices property.

Returns:

  • a void



66
67
68
# File 'lib/models/choice_column.rb', line 66

def choices=(value)
    @choices = value
end

#display_asObject

Gets the displayAs property value. How the choices are to be presented in the UX. Must be one of checkBoxes, dropDownMenu, or radioButtons

Returns:

  • a string



89
90
91
# File 'lib/models/choice_column.rb', line 89

def display_as
    return @display_as
end

#display_as=(value) ⇒ Object

Sets the displayAs property value. How the choices are to be presented in the UX. Must be one of checkBoxes, dropDownMenu, or radioButtons

Parameters:

  • value

    Value to set for the displayAs property.

Returns:

  • a void



97
98
99
# File 'lib/models/choice_column.rb', line 97

def display_as=(value)
    @display_as = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



104
105
106
107
108
109
110
111
# File 'lib/models/choice_column.rb', line 104

def get_field_deserializers()
    return {
        "allowTextEntry" => lambda {|n| @allow_text_entry = n.get_boolean_value() },
        "choices" => lambda {|n| @choices = n.get_collection_of_primitive_values(String) },
        "displayAs" => lambda {|n| @display_as = n.get_string_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



116
117
118
# File 'lib/models/choice_column.rb', line 116

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



124
125
126
# File 'lib/models/choice_column.rb', line 124

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


132
133
134
135
136
137
138
139
# File 'lib/models/choice_column.rb', line 132

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_boolean_value("allowTextEntry", @allow_text_entry)
    writer.write_collection_of_primitive_values("choices", @choices)
    writer.write_string_value("displayAs", @display_as)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_additional_data(@additional_data)
end