Class: MicrosoftGraph::Models::ColumnDefinition
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/column_definition.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#boolean ⇒ Object
Gets the boolean property value.
-
#boolean=(value) ⇒ Object
Sets the boolean property value.
-
#calculated ⇒ Object
Gets the calculated property value.
-
#calculated=(value) ⇒ Object
Sets the calculated property value.
-
#choice ⇒ Object
Gets the choice property value.
-
#choice=(value) ⇒ Object
Sets the choice property value.
-
#column_group ⇒ Object
Gets the columnGroup property value.
-
#column_group=(value) ⇒ Object
Sets the columnGroup property value.
-
#content_approval_status ⇒ Object
Gets the contentApprovalStatus property value.
-
#content_approval_status=(value) ⇒ Object
Sets the contentApprovalStatus property value.
-
#currency ⇒ Object
Gets the currency property value.
-
#currency=(value) ⇒ Object
Sets the currency property value.
-
#date_time ⇒ Object
Gets the dateTime property value.
-
#date_time=(value) ⇒ Object
Sets the dateTime property value.
-
#default_value ⇒ Object
Gets the defaultValue property value.
-
#default_value=(value) ⇒ Object
Sets the defaultValue property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#enforce_unique_values ⇒ Object
Gets the enforceUniqueValues property value.
-
#enforce_unique_values=(value) ⇒ Object
Sets the enforceUniqueValues property value.
-
#geolocation ⇒ Object
Gets the geolocation property value.
-
#geolocation=(value) ⇒ Object
Sets the geolocation property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#hidden ⇒ Object
Gets the hidden property value.
-
#hidden=(value) ⇒ Object
Sets the hidden property value.
-
#hyperlink_or_picture ⇒ Object
Gets the hyperlinkOrPicture property value.
-
#hyperlink_or_picture=(value) ⇒ Object
Sets the hyperlinkOrPicture property value.
-
#indexed ⇒ Object
Gets the indexed property value.
-
#indexed=(value) ⇒ Object
Sets the indexed property value.
-
#initialize ⇒ Object
constructor
Instantiates a new columnDefinition and sets the default values.
-
#is_deletable ⇒ Object
Gets the isDeletable property value.
-
#is_deletable=(value) ⇒ Object
Sets the isDeletable property value.
-
#is_reorderable ⇒ Object
Gets the isReorderable property value.
-
#is_reorderable=(value) ⇒ Object
Sets the isReorderable property value.
-
#is_sealed ⇒ Object
Gets the isSealed property value.
-
#is_sealed=(value) ⇒ Object
Sets the isSealed property value.
-
#lookup ⇒ Object
Gets the lookup property value.
-
#lookup=(value) ⇒ Object
Sets the lookup property value.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#number ⇒ Object
Gets the number property value.
-
#number=(value) ⇒ Object
Sets the number property value.
-
#person_or_group ⇒ Object
Gets the personOrGroup property value.
-
#person_or_group=(value) ⇒ Object
Sets the personOrGroup property value.
-
#propagate_changes ⇒ Object
Gets the propagateChanges property value.
-
#propagate_changes=(value) ⇒ Object
Sets the propagateChanges property value.
-
#read_only ⇒ Object
Gets the readOnly property value.
-
#read_only=(value) ⇒ Object
Sets the readOnly property value.
-
#required ⇒ Object
Gets the required property value.
-
#required=(value) ⇒ Object
Sets the required property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#source_column ⇒ Object
Gets the sourceColumn property value.
-
#source_column=(value) ⇒ Object
Sets the sourceColumn property value.
-
#source_content_type ⇒ Object
Gets the sourceContentType property value.
-
#source_content_type=(value) ⇒ Object
Sets the sourceContentType property value.
-
#term ⇒ Object
Gets the term property value.
-
#term=(value) ⇒ Object
Sets the term property value.
-
#text ⇒ Object
Gets the text property value.
-
#text=(value) ⇒ Object
Sets the text property value.
-
#thumbnail ⇒ Object
Gets the thumbnail property value.
-
#thumbnail=(value) ⇒ Object
Sets the thumbnail property value.
-
#type ⇒ Object
Gets the type property value.
-
#type=(value) ⇒ Object
Sets the type property value.
-
#validation ⇒ Object
Gets the validation property value.
-
#validation=(value) ⇒ Object
Sets the validation property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new columnDefinition and sets the default values.
169 170 171 |
# File 'lib/models/column_definition.rb', line 169 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
192 193 194 195 |
# File 'lib/models/column_definition.rb', line 192 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ColumnDefinition.new end |
Instance Method Details
#boolean ⇒ Object
Gets the boolean property value. This column stores boolean values.
109 110 111 |
# File 'lib/models/column_definition.rb', line 109 def boolean return @boolean end |
#boolean=(value) ⇒ Object
Sets the boolean property value. This column stores boolean values.
117 118 119 |
# File 'lib/models/column_definition.rb', line 117 def boolean=(value) @boolean = value end |
#calculated ⇒ Object
Gets the calculated property value. This column’s data is calculated based on other columns.
124 125 126 |
# File 'lib/models/column_definition.rb', line 124 def calculated return @calculated end |
#calculated=(value) ⇒ Object
Sets the calculated property value. This column’s data is calculated based on other columns.
132 133 134 |
# File 'lib/models/column_definition.rb', line 132 def calculated=(value) @calculated = value end |
#choice ⇒ Object
Gets the choice property value. This column stores data from a list of choices.
139 140 141 |
# File 'lib/models/column_definition.rb', line 139 def choice return @choice end |
#choice=(value) ⇒ Object
Sets the choice property value. This column stores data from a list of choices.
147 148 149 |
# File 'lib/models/column_definition.rb', line 147 def choice=(value) @choice = value end |
#column_group ⇒ Object
Gets the columnGroup property value. For site columns, the name of the group this column belongs to. Helps organize related columns.
154 155 156 |
# File 'lib/models/column_definition.rb', line 154 def column_group return @column_group end |
#column_group=(value) ⇒ Object
Sets the columnGroup property value. For site columns, the name of the group this column belongs to. Helps organize related columns.
162 163 164 |
# File 'lib/models/column_definition.rb', line 162 def column_group=(value) @column_group = value end |
#content_approval_status ⇒ Object
Gets the contentApprovalStatus property value. This column stores content approval status.
176 177 178 |
# File 'lib/models/column_definition.rb', line 176 def content_approval_status return @content_approval_status end |
#content_approval_status=(value) ⇒ Object
Sets the contentApprovalStatus property value. This column stores content approval status.
184 185 186 |
# File 'lib/models/column_definition.rb', line 184 def content_approval_status=(value) @content_approval_status = value end |
#currency ⇒ Object
Gets the currency property value. This column stores currency values.
200 201 202 |
# File 'lib/models/column_definition.rb', line 200 def currency return @currency end |
#currency=(value) ⇒ Object
Sets the currency property value. This column stores currency values.
208 209 210 |
# File 'lib/models/column_definition.rb', line 208 def currency=(value) @currency = value end |
#date_time ⇒ Object
Gets the dateTime property value. This column stores DateTime values.
215 216 217 |
# File 'lib/models/column_definition.rb', line 215 def date_time return @date_time end |
#date_time=(value) ⇒ Object
Sets the dateTime property value. This column stores DateTime values.
223 224 225 |
# File 'lib/models/column_definition.rb', line 223 def date_time=(value) @date_time = value end |
#default_value ⇒ Object
Gets the defaultValue property value. The default value for this column.
230 231 232 |
# File 'lib/models/column_definition.rb', line 230 def default_value return @default_value end |
#default_value=(value) ⇒ Object
Sets the defaultValue property value. The default value for this column.
238 239 240 |
# File 'lib/models/column_definition.rb', line 238 def default_value=(value) @default_value = value end |
#description ⇒ Object
Gets the description property value. The user-facing description of the column.
245 246 247 |
# File 'lib/models/column_definition.rb', line 245 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. The user-facing description of the column.
253 254 255 |
# File 'lib/models/column_definition.rb', line 253 def description=(value) @description = value end |
#display_name ⇒ Object
Gets the displayName property value. The user-facing name of the column.
260 261 262 |
# File 'lib/models/column_definition.rb', line 260 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. The user-facing name of the column.
268 269 270 |
# File 'lib/models/column_definition.rb', line 268 def display_name=(value) @display_name = value end |
#enforce_unique_values ⇒ Object
Gets the enforceUniqueValues property value. If true, no two list items may have the same value for this column.
275 276 277 |
# File 'lib/models/column_definition.rb', line 275 def enforce_unique_values return @enforce_unique_values end |
#enforce_unique_values=(value) ⇒ Object
Sets the enforceUniqueValues property value. If true, no two list items may have the same value for this column.
283 284 285 |
# File 'lib/models/column_definition.rb', line 283 def enforce_unique_values=(value) @enforce_unique_values = value end |
#geolocation ⇒ Object
Gets the geolocation property value. This column stores a geolocation.
290 291 292 |
# File 'lib/models/column_definition.rb', line 290 def geolocation return @geolocation end |
#geolocation=(value) ⇒ Object
Sets the geolocation property value. This column stores a geolocation.
298 299 300 |
# File 'lib/models/column_definition.rb', line 298 def geolocation=(value) @geolocation = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/models/column_definition.rb', line 305 def get_field_deserializers() return super.merge({ "boolean" => lambda {|n| @boolean = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::BooleanColumn.create_from_discriminator_value(pn) }) }, "calculated" => lambda {|n| @calculated = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::CalculatedColumn.create_from_discriminator_value(pn) }) }, "choice" => lambda {|n| @choice = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ChoiceColumn.create_from_discriminator_value(pn) }) }, "columnGroup" => lambda {|n| @column_group = n.get_string_value() }, "contentApprovalStatus" => lambda {|n| @content_approval_status = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ContentApprovalStatusColumn.create_from_discriminator_value(pn) }) }, "currency" => lambda {|n| @currency = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::CurrencyColumn.create_from_discriminator_value(pn) }) }, "dateTime" => lambda {|n| @date_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DateTimeColumn.create_from_discriminator_value(pn) }) }, "defaultValue" => lambda {|n| @default_value = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DefaultColumnValue.create_from_discriminator_value(pn) }) }, "description" => lambda {|n| @description = n.get_string_value() }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, "enforceUniqueValues" => lambda {|n| @enforce_unique_values = n.get_boolean_value() }, "geolocation" => lambda {|n| @geolocation = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::GeolocationColumn.create_from_discriminator_value(pn) }) }, "hidden" => lambda {|n| @hidden = n.get_boolean_value() }, "hyperlinkOrPicture" => lambda {|n| @hyperlink_or_picture = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::HyperlinkOrPictureColumn.create_from_discriminator_value(pn) }) }, "indexed" => lambda {|n| @indexed = n.get_boolean_value() }, "isDeletable" => lambda {|n| @is_deletable = n.get_boolean_value() }, "isReorderable" => lambda {|n| @is_reorderable = n.get_boolean_value() }, "isSealed" => lambda {|n| @is_sealed = n.get_boolean_value() }, "lookup" => lambda {|n| @lookup = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::LookupColumn.create_from_discriminator_value(pn) }) }, "name" => lambda {|n| @name = n.get_string_value() }, "number" => lambda {|n| @number = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::NumberColumn.create_from_discriminator_value(pn) }) }, "personOrGroup" => lambda {|n| @person_or_group = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::PersonOrGroupColumn.create_from_discriminator_value(pn) }) }, "propagateChanges" => lambda {|n| @propagate_changes = n.get_boolean_value() }, "readOnly" => lambda {|n| @read_only = n.get_boolean_value() }, "required" => lambda {|n| @required = n.get_boolean_value() }, "sourceColumn" => lambda {|n| @source_column = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ColumnDefinition.create_from_discriminator_value(pn) }) }, "sourceContentType" => lambda {|n| @source_content_type = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ContentTypeInfo.create_from_discriminator_value(pn) }) }, "term" => lambda {|n| @term = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TermColumn.create_from_discriminator_value(pn) }) }, "text" => lambda {|n| @text = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TextColumn.create_from_discriminator_value(pn) }) }, "thumbnail" => lambda {|n| @thumbnail = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ThumbnailColumn.create_from_discriminator_value(pn) }) }, "type" => lambda {|n| @type = n.get_enum_value(MicrosoftGraph::Models::ColumnTypes) }, "validation" => lambda {|n| @validation = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ColumnValidation.create_from_discriminator_value(pn) }) }, }) end |
#hidden ⇒ Object
Gets the hidden property value. Specifies whether the column is displayed in the user interface.
345 346 347 |
# File 'lib/models/column_definition.rb', line 345 def hidden return @hidden end |
#hidden=(value) ⇒ Object
Sets the hidden property value. Specifies whether the column is displayed in the user interface.
353 354 355 |
# File 'lib/models/column_definition.rb', line 353 def hidden=(value) @hidden = value end |
#hyperlink_or_picture ⇒ Object
Gets the hyperlinkOrPicture property value. This column stores hyperlink or picture values.
360 361 362 |
# File 'lib/models/column_definition.rb', line 360 def hyperlink_or_picture return @hyperlink_or_picture end |
#hyperlink_or_picture=(value) ⇒ Object
Sets the hyperlinkOrPicture property value. This column stores hyperlink or picture values.
368 369 370 |
# File 'lib/models/column_definition.rb', line 368 def hyperlink_or_picture=(value) @hyperlink_or_picture = value end |
#indexed ⇒ Object
Gets the indexed property value. Specifies whether the column values can be used for sorting and searching.
375 376 377 |
# File 'lib/models/column_definition.rb', line 375 def indexed return @indexed end |
#indexed=(value) ⇒ Object
Sets the indexed property value. Specifies whether the column values can be used for sorting and searching.
383 384 385 |
# File 'lib/models/column_definition.rb', line 383 def indexed=(value) @indexed = value end |
#is_deletable ⇒ Object
Gets the isDeletable property value. Indicates whether this column can be deleted.
390 391 392 |
# File 'lib/models/column_definition.rb', line 390 def is_deletable return @is_deletable end |
#is_deletable=(value) ⇒ Object
Sets the isDeletable property value. Indicates whether this column can be deleted.
398 399 400 |
# File 'lib/models/column_definition.rb', line 398 def is_deletable=(value) @is_deletable = value end |
#is_reorderable ⇒ Object
Gets the isReorderable property value. Indicates whether values in the column can be reordered. Read-only.
405 406 407 |
# File 'lib/models/column_definition.rb', line 405 def is_reorderable return @is_reorderable end |
#is_reorderable=(value) ⇒ Object
Sets the isReorderable property value. Indicates whether values in the column can be reordered. Read-only.
413 414 415 |
# File 'lib/models/column_definition.rb', line 413 def is_reorderable=(value) @is_reorderable = value end |
#is_sealed ⇒ Object
Gets the isSealed property value. Specifies whether the column can be changed.
420 421 422 |
# File 'lib/models/column_definition.rb', line 420 def is_sealed return @is_sealed end |
#is_sealed=(value) ⇒ Object
Sets the isSealed property value. Specifies whether the column can be changed.
428 429 430 |
# File 'lib/models/column_definition.rb', line 428 def is_sealed=(value) @is_sealed = value end |
#lookup ⇒ Object
Gets the lookup property value. This column’s data is looked up from another source in the site.
435 436 437 |
# File 'lib/models/column_definition.rb', line 435 def lookup return @lookup end |
#lookup=(value) ⇒ Object
Sets the lookup property value. This column’s data is looked up from another source in the site.
443 444 445 |
# File 'lib/models/column_definition.rb', line 443 def lookup=(value) @lookup = value end |
#name ⇒ Object
Gets the name property value. The API-facing name of the column as it appears in the [fields][] on a [listItem][]. For the user-facing name, see displayName.
450 451 452 |
# File 'lib/models/column_definition.rb', line 450 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. The API-facing name of the column as it appears in the [fields][] on a [listItem][]. For the user-facing name, see displayName.
458 459 460 |
# File 'lib/models/column_definition.rb', line 458 def name=(value) @name = value end |
#number ⇒ Object
Gets the number property value. This column stores number values.
465 466 467 |
# File 'lib/models/column_definition.rb', line 465 def number return @number end |
#number=(value) ⇒ Object
Sets the number property value. This column stores number values.
473 474 475 |
# File 'lib/models/column_definition.rb', line 473 def number=(value) @number = value end |
#person_or_group ⇒ Object
Gets the personOrGroup property value. This column stores Person or Group values.
480 481 482 |
# File 'lib/models/column_definition.rb', line 480 def person_or_group return @person_or_group end |
#person_or_group=(value) ⇒ Object
Sets the personOrGroup property value. This column stores Person or Group values.
488 489 490 |
# File 'lib/models/column_definition.rb', line 488 def person_or_group=(value) @person_or_group = value end |
#propagate_changes ⇒ Object
Gets the propagateChanges property value. If ‘true’, changes to this column will be propagated to lists that implement the column.
495 496 497 |
# File 'lib/models/column_definition.rb', line 495 def propagate_changes return @propagate_changes end |
#propagate_changes=(value) ⇒ Object
Sets the propagateChanges property value. If ‘true’, changes to this column will be propagated to lists that implement the column.
503 504 505 |
# File 'lib/models/column_definition.rb', line 503 def propagate_changes=(value) @propagate_changes = value end |
#read_only ⇒ Object
Gets the readOnly property value. Specifies whether the column values can be modified.
510 511 512 |
# File 'lib/models/column_definition.rb', line 510 def read_only return @read_only end |
#read_only=(value) ⇒ Object
Sets the readOnly property value. Specifies whether the column values can be modified.
518 519 520 |
# File 'lib/models/column_definition.rb', line 518 def read_only=(value) @read_only = value end |
#required ⇒ Object
Gets the required property value. Specifies whether the column value isn’t optional.
525 526 527 |
# File 'lib/models/column_definition.rb', line 525 def required return @required end |
#required=(value) ⇒ Object
Sets the required property value. Specifies whether the column value isn’t optional.
533 534 535 |
# File 'lib/models/column_definition.rb', line 533 def required=(value) @required = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/models/column_definition.rb', line 541 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("boolean", @boolean) writer.write_object_value("calculated", @calculated) writer.write_object_value("choice", @choice) writer.write_string_value("columnGroup", @column_group) writer.write_object_value("contentApprovalStatus", @content_approval_status) writer.write_object_value("currency", @currency) writer.write_object_value("dateTime", @date_time) writer.write_object_value("defaultValue", @default_value) writer.write_string_value("description", @description) writer.write_string_value("displayName", @display_name) writer.write_boolean_value("enforceUniqueValues", @enforce_unique_values) writer.write_object_value("geolocation", @geolocation) writer.write_boolean_value("hidden", @hidden) writer.write_object_value("hyperlinkOrPicture", @hyperlink_or_picture) writer.write_boolean_value("indexed", @indexed) writer.write_boolean_value("isDeletable", @is_deletable) writer.write_boolean_value("isReorderable", @is_reorderable) writer.write_boolean_value("isSealed", @is_sealed) writer.write_object_value("lookup", @lookup) writer.write_string_value("name", @name) writer.write_object_value("number", @number) writer.write_object_value("personOrGroup", @person_or_group) writer.write_boolean_value("propagateChanges", @propagate_changes) writer.write_boolean_value("readOnly", @read_only) writer.write_boolean_value("required", @required) writer.write_object_value("sourceColumn", @source_column) writer.write_object_value("sourceContentType", @source_content_type) writer.write_object_value("term", @term) writer.write_object_value("text", @text) writer.write_object_value("thumbnail", @thumbnail) writer.write_enum_value("type", @type) writer.write_object_value("validation", @validation) end |
#source_column ⇒ Object
Gets the sourceColumn property value. The source column for the content type column.
581 582 583 |
# File 'lib/models/column_definition.rb', line 581 def source_column return @source_column end |
#source_column=(value) ⇒ Object
Sets the sourceColumn property value. The source column for the content type column.
589 590 591 |
# File 'lib/models/column_definition.rb', line 589 def source_column=(value) @source_column = value end |
#source_content_type ⇒ Object
Gets the sourceContentType property value. ContentType from which this column is inherited from. Present only in contentTypes columns response. Read-only.
596 597 598 |
# File 'lib/models/column_definition.rb', line 596 def source_content_type return @source_content_type end |
#source_content_type=(value) ⇒ Object
Sets the sourceContentType property value. ContentType from which this column is inherited from. Present only in contentTypes columns response. Read-only.
604 605 606 |
# File 'lib/models/column_definition.rb', line 604 def source_content_type=(value) @source_content_type = value end |
#term ⇒ Object
Gets the term property value. This column stores taxonomy terms.
611 612 613 |
# File 'lib/models/column_definition.rb', line 611 def term return @term end |
#term=(value) ⇒ Object
Sets the term property value. This column stores taxonomy terms.
619 620 621 |
# File 'lib/models/column_definition.rb', line 619 def term=(value) @term = value end |
#text ⇒ Object
Gets the text property value. This column stores text values.
626 627 628 |
# File 'lib/models/column_definition.rb', line 626 def text return @text end |
#text=(value) ⇒ Object
Sets the text property value. This column stores text values.
634 635 636 |
# File 'lib/models/column_definition.rb', line 634 def text=(value) @text = value end |
#thumbnail ⇒ Object
Gets the thumbnail property value. This column stores thumbnail values.
641 642 643 |
# File 'lib/models/column_definition.rb', line 641 def thumbnail return @thumbnail end |
#thumbnail=(value) ⇒ Object
Sets the thumbnail property value. This column stores thumbnail values.
649 650 651 |
# File 'lib/models/column_definition.rb', line 649 def thumbnail=(value) @thumbnail = value end |
#type ⇒ Object
Gets the type property value. For site columns, the type of column. Read-only.
656 657 658 |
# File 'lib/models/column_definition.rb', line 656 def type return @type end |
#type=(value) ⇒ Object
Sets the type property value. For site columns, the type of column. Read-only.
664 665 666 |
# File 'lib/models/column_definition.rb', line 664 def type=(value) @type = value end |
#validation ⇒ Object
Gets the validation property value. This column stores validation formula and message for the column.
671 672 673 |
# File 'lib/models/column_definition.rb', line 671 def validation return @validation end |
#validation=(value) ⇒ Object
Sets the validation property value. This column stores validation formula and message for the column.
679 680 681 |
# File 'lib/models/column_definition.rb', line 679 def validation=(value) @validation = value end |