Class: MicrosoftGraph::Models::ConvertIdResult
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::ConvertIdResult
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/convert_id_result.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#error_details ⇒ Object
Gets the errorDetails property value.
-
#error_details=(value) ⇒ Object
Sets the errorDetails property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new convertIdResult and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#source_id ⇒ Object
Gets the sourceId property value.
-
#source_id=(value) ⇒ Object
Sets the sourceId property value.
-
#target_id ⇒ Object
Gets the targetId property value.
-
#target_id=(value) ⇒ Object
Sets the targetId property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new convertIdResult and sets the default values.
43 44 45 |
# File 'lib/models/convert_id_result.rb', line 43 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
51 52 53 54 |
# File 'lib/models/convert_id_result.rb', line 51 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ConvertIdResult.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
28 29 30 |
# File 'lib/models/convert_id_result.rb', line 28 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
36 37 38 |
# File 'lib/models/convert_id_result.rb', line 36 def additional_data=(value) @additional_data = value end |
#error_details ⇒ Object
Gets the errorDetails property value. An error object indicating the reason for the conversion failure. This value is not present if the conversion succeeded.
59 60 61 |
# File 'lib/models/convert_id_result.rb', line 59 def error_details return @error_details end |
#error_details=(value) ⇒ Object
Sets the errorDetails property value. An error object indicating the reason for the conversion failure. This value is not present if the conversion succeeded.
67 68 69 |
# File 'lib/models/convert_id_result.rb', line 67 def error_details=(value) @error_details = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
74 75 76 77 78 79 80 81 |
# File 'lib/models/convert_id_result.rb', line 74 def get_field_deserializers() return { "errorDetails" => lambda {|n| @error_details = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::GenericError.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "sourceId" => lambda {|n| @source_id = n.get_string_value() }, "targetId" => lambda {|n| @target_id = n.get_string_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
86 87 88 |
# File 'lib/models/convert_id_result.rb', line 86 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
94 95 96 |
# File 'lib/models/convert_id_result.rb', line 94 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
102 103 104 105 106 107 108 109 |
# File 'lib/models/convert_id_result.rb', line 102 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("errorDetails", @error_details) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("sourceId", @source_id) writer.write_string_value("targetId", @target_id) writer.write_additional_data(@additional_data) end |
#source_id ⇒ Object
Gets the sourceId property value. The identifier that was converted. This value is the original, un-converted identifier.
114 115 116 |
# File 'lib/models/convert_id_result.rb', line 114 def source_id return @source_id end |
#source_id=(value) ⇒ Object
Sets the sourceId property value. The identifier that was converted. This value is the original, un-converted identifier.
122 123 124 |
# File 'lib/models/convert_id_result.rb', line 122 def source_id=(value) @source_id = value end |
#target_id ⇒ Object
Gets the targetId property value. The converted identifier. This value is not present if the conversion failed.
129 130 131 |
# File 'lib/models/convert_id_result.rb', line 129 def target_id return @target_id end |
#target_id=(value) ⇒ Object
Sets the targetId property value. The converted identifier. This value is not present if the conversion failed.
137 138 139 |
# File 'lib/models/convert_id_result.rb', line 137 def target_id=(value) @target_id = value end |