Class: MicrosoftGraph::Models::CrossTenantAccessPolicyB2BSetting
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::CrossTenantAccessPolicyB2BSetting
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/cross_tenant_access_policy_b2_b_setting.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#applications ⇒ Object
Gets the applications property value.
-
#applications=(value) ⇒ Object
Sets the applications property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new crossTenantAccessPolicyB2BSetting and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#users_and_groups ⇒ Object
Gets the usersAndGroups property value.
-
#users_and_groups=(value) ⇒ Object
Sets the usersAndGroups property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new crossTenantAccessPolicyB2BSetting and sets the default values.
55 56 57 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 55 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
63 64 65 66 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 63 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CrossTenantAccessPolicyB2BSetting.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 33 def additional_data=(value) @additional_data = value end |
#applications ⇒ Object
Gets the applications property value. The list of applications targeted with your cross-tenant access policy.
40 41 42 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 40 def applications return @applications end |
#applications=(value) ⇒ Object
Sets the applications property value. The list of applications targeted with your cross-tenant access policy.
48 49 50 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 48 def applications=(value) @applications = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
71 72 73 74 75 76 77 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 71 def get_field_deserializers() return { "applications" => lambda {|n| @applications = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::CrossTenantAccessPolicyTargetConfiguration.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "usersAndGroups" => lambda {|n| @users_and_groups = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::CrossTenantAccessPolicyTargetConfiguration.create_from_discriminator_value(pn) }) }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
82 83 84 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 82 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
90 91 92 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 90 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
98 99 100 101 102 103 104 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 98 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("applications", @applications) writer.write_string_value("@odata.type", @odata_type) writer.write_object_value("usersAndGroups", @users_and_groups) writer.write_additional_data(@additional_data) end |
#users_and_groups ⇒ Object
Gets the usersAndGroups property value. The list of users and groups targeted with your cross-tenant access policy.
109 110 111 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 109 def users_and_groups return @users_and_groups end |
#users_and_groups=(value) ⇒ Object
Sets the usersAndGroups property value. The list of users and groups targeted with your cross-tenant access policy.
117 118 119 |
# File 'lib/models/cross_tenant_access_policy_b2_b_setting.rb', line 117 def users_and_groups=(value) @users_and_groups = value end |