Class: MicrosoftGraph::Models::CrossTenantAccessPolicyTarget
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::CrossTenantAccessPolicyTarget
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/cross_tenant_access_policy_target.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new crossTenantAccessPolicyTarget and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#target ⇒ Object
Gets the target property value.
-
#target=(value) ⇒ Object
Sets the target property value.
-
#target_type ⇒ Object
Gets the targetType property value.
-
#target_type=(value) ⇒ Object
Sets the targetType property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new crossTenantAccessPolicyTarget and sets the default values.
40 41 42 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 40 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CrossTenantAccessPolicyTarget.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 33 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
56 57 58 59 60 61 62 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 56 def get_field_deserializers() return { "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "target" => lambda {|n| @target = n.get_string_value() }, "targetType" => lambda {|n| @target_type = n.get_enum_value(MicrosoftGraph::Models::CrossTenantAccessPolicyTargetType) }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
67 68 69 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 67 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
75 76 77 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 75 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
83 84 85 86 87 88 89 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 83 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("target", @target) writer.write_enum_value("targetType", @target_type) writer.write_additional_data(@additional_data) end |
#target ⇒ Object
Gets the target property value. The unique identifier of the user, group, or application; one of the following keywords: AllUsers and AllApplications; or for targets that are applications, you may use reserved values.
94 95 96 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 94 def target return @target end |
#target=(value) ⇒ Object
Sets the target property value. The unique identifier of the user, group, or application; one of the following keywords: AllUsers and AllApplications; or for targets that are applications, you may use reserved values.
102 103 104 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 102 def target=(value) @target = value end |
#target_type ⇒ Object
Gets the targetType property value. The type of resource that you want to target. The possible values are: user, group, application, unknownFutureValue.
109 110 111 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 109 def target_type return @target_type end |
#target_type=(value) ⇒ Object
Sets the targetType property value. The type of resource that you want to target. The possible values are: user, group, application, unknownFutureValue.
117 118 119 |
# File 'lib/models/cross_tenant_access_policy_target.rb', line 117 def target_type=(value) @target_type = value end |