Class: MicrosoftGraph::Models::DeviceHealthAttestationState

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/device_health_attestation_state.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new deviceHealthAttestationState and sets the default values.



281
282
283
# File 'lib/models/device_health_attestation_state.rb', line 281

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a device_health_attestation_state

Raises:

  • (StandardError)


319
320
321
322
# File 'lib/models/device_health_attestation_state.rb', line 319

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return DeviceHealthAttestationState.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



116
117
118
# File 'lib/models/device_health_attestation_state.rb', line 116

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



124
125
126
# File 'lib/models/device_health_attestation_state.rb', line 124

def additional_data=(value)
    @additional_data = value
end

#attestation_identity_keyObject

Gets the attestationIdentityKey property value. TWhen an Attestation Identity Key (AIK) is present on a device, it indicates that the device has an endorsement key (EK) certificate.

Returns:

  • a string



131
132
133
# File 'lib/models/device_health_attestation_state.rb', line 131

def attestation_identity_key
    return @attestation_identity_key
end

#attestation_identity_key=(value) ⇒ Object

Sets the attestationIdentityKey property value. TWhen an Attestation Identity Key (AIK) is present on a device, it indicates that the device has an endorsement key (EK) certificate.

Parameters:

  • value

    Value to set for the attestationIdentityKey property.

Returns:

  • a void



139
140
141
# File 'lib/models/device_health_attestation_state.rb', line 139

def attestation_identity_key=(value)
    @attestation_identity_key = value
end

#bit_locker_statusObject

Gets the bitLockerStatus property value. On or Off of BitLocker Drive Encryption

Returns:

  • a string



146
147
148
# File 'lib/models/device_health_attestation_state.rb', line 146

def bit_locker_status
    return @bit_locker_status
end

#bit_locker_status=(value) ⇒ Object

Sets the bitLockerStatus property value. On or Off of BitLocker Drive Encryption

Parameters:

  • value

    Value to set for the bitLockerStatus property.

Returns:

  • a void



154
155
156
# File 'lib/models/device_health_attestation_state.rb', line 154

def bit_locker_status=(value)
    @bit_locker_status = value
end

#boot_app_security_versionObject

Gets the bootAppSecurityVersion property value. The security version number of the Boot Application

Returns:

  • a string



161
162
163
# File 'lib/models/device_health_attestation_state.rb', line 161

def boot_app_security_version
    return @boot_app_security_version
end

#boot_app_security_version=(value) ⇒ Object

Sets the bootAppSecurityVersion property value. The security version number of the Boot Application

Parameters:

  • value

    Value to set for the bootAppSecurityVersion property.

Returns:

  • a void



169
170
171
# File 'lib/models/device_health_attestation_state.rb', line 169

def boot_app_security_version=(value)
    @boot_app_security_version = value
end

#boot_debuggingObject

Gets the bootDebugging property value. When bootDebugging is enabled, the device is used in development and testing

Returns:

  • a string



176
177
178
# File 'lib/models/device_health_attestation_state.rb', line 176

def boot_debugging
    return @boot_debugging
end

#boot_debugging=(value) ⇒ Object

Sets the bootDebugging property value. When bootDebugging is enabled, the device is used in development and testing

Parameters:

  • value

    Value to set for the bootDebugging property.

Returns:

  • a void



184
185
186
# File 'lib/models/device_health_attestation_state.rb', line 184

def boot_debugging=(value)
    @boot_debugging = value
end

#boot_manager_security_versionObject

Gets the bootManagerSecurityVersion property value. The security version number of the Boot Application

Returns:

  • a string



191
192
193
# File 'lib/models/device_health_attestation_state.rb', line 191

def boot_manager_security_version
    return @boot_manager_security_version
end

#boot_manager_security_version=(value) ⇒ Object

Sets the bootManagerSecurityVersion property value. The security version number of the Boot Application

Parameters:

  • value

    Value to set for the bootManagerSecurityVersion property.

Returns:

  • a void



199
200
201
# File 'lib/models/device_health_attestation_state.rb', line 199

def boot_manager_security_version=(value)
    @boot_manager_security_version = value
end

#boot_manager_versionObject

Gets the bootManagerVersion property value. The version of the Boot Manager

Returns:

  • a string



206
207
208
# File 'lib/models/device_health_attestation_state.rb', line 206

def boot_manager_version
    return @boot_manager_version
end

#boot_manager_version=(value) ⇒ Object

Sets the bootManagerVersion property value. The version of the Boot Manager

Parameters:

  • value

    Value to set for the bootManagerVersion property.

Returns:

  • a void



214
215
216
# File 'lib/models/device_health_attestation_state.rb', line 214

def boot_manager_version=(value)
    @boot_manager_version = value
end

#boot_revision_list_infoObject

Gets the bootRevisionListInfo property value. The Boot Revision List that was loaded during initial boot on the attested device

Returns:

  • a string



221
222
223
# File 'lib/models/device_health_attestation_state.rb', line 221

def boot_revision_list_info
    return @boot_revision_list_info
end

#boot_revision_list_info=(value) ⇒ Object

Sets the bootRevisionListInfo property value. The Boot Revision List that was loaded during initial boot on the attested device

Parameters:

  • value

    Value to set for the bootRevisionListInfo property.

Returns:

  • a void



229
230
231
# File 'lib/models/device_health_attestation_state.rb', line 229

def boot_revision_list_info=(value)
    @boot_revision_list_info = value
end

#code_integrityObject

Gets the codeIntegrity property value. When code integrity is enabled, code execution is restricted to integrity verified code

Returns:

  • a string



236
237
238
# File 'lib/models/device_health_attestation_state.rb', line 236

def code_integrity
    return @code_integrity
end

#code_integrity=(value) ⇒ Object

Sets the codeIntegrity property value. When code integrity is enabled, code execution is restricted to integrity verified code

Parameters:

  • value

    Value to set for the codeIntegrity property.

Returns:

  • a void



244
245
246
# File 'lib/models/device_health_attestation_state.rb', line 244

def code_integrity=(value)
    @code_integrity = value
end

#code_integrity_check_versionObject

Gets the codeIntegrityCheckVersion property value. The version of the Boot Manager

Returns:

  • a string



251
252
253
# File 'lib/models/device_health_attestation_state.rb', line 251

def code_integrity_check_version
    return @code_integrity_check_version
end

#code_integrity_check_version=(value) ⇒ Object

Sets the codeIntegrityCheckVersion property value. The version of the Boot Manager

Parameters:

  • value

    Value to set for the codeIntegrityCheckVersion property.

Returns:

  • a void



259
260
261
# File 'lib/models/device_health_attestation_state.rb', line 259

def code_integrity_check_version=(value)
    @code_integrity_check_version = value
end

#code_integrity_policyObject

Gets the codeIntegrityPolicy property value. The Code Integrity policy that is controlling the security of the boot environment

Returns:

  • a string



266
267
268
# File 'lib/models/device_health_attestation_state.rb', line 266

def code_integrity_policy
    return @code_integrity_policy
end

#code_integrity_policy=(value) ⇒ Object

Sets the codeIntegrityPolicy property value. The Code Integrity policy that is controlling the security of the boot environment

Parameters:

  • value

    Value to set for the codeIntegrityPolicy property.

Returns:

  • a void



274
275
276
# File 'lib/models/device_health_attestation_state.rb', line 274

def code_integrity_policy=(value)
    @code_integrity_policy = value
end

#content_namespace_urlObject

Gets the contentNamespaceUrl property value. The DHA report version. (Namespace version)

Returns:

  • a string



288
289
290
# File 'lib/models/device_health_attestation_state.rb', line 288

def content_namespace_url
    return @content_namespace_url
end

#content_namespace_url=(value) ⇒ Object

Sets the contentNamespaceUrl property value. The DHA report version. (Namespace version)

Parameters:

  • value

    Value to set for the contentNamespaceUrl property.

Returns:

  • a void



296
297
298
# File 'lib/models/device_health_attestation_state.rb', line 296

def content_namespace_url=(value)
    @content_namespace_url = value
end

#content_versionObject

Gets the contentVersion property value. The HealthAttestation state schema version

Returns:

  • a string



303
304
305
# File 'lib/models/device_health_attestation_state.rb', line 303

def content_version
    return @content_version
end

#content_version=(value) ⇒ Object

Sets the contentVersion property value. The HealthAttestation state schema version

Parameters:

  • value

    Value to set for the contentVersion property.

Returns:

  • a void



311
312
313
# File 'lib/models/device_health_attestation_state.rb', line 311

def content_version=(value)
    @content_version = value
end

#data_excution_policyObject

Gets the dataExcutionPolicy property value. DEP Policy defines a set of hardware and software technologies that perform additional checks on memory

Returns:

  • a string



327
328
329
# File 'lib/models/device_health_attestation_state.rb', line 327

def data_excution_policy
    return @data_excution_policy
end

#data_excution_policy=(value) ⇒ Object

Sets the dataExcutionPolicy property value. DEP Policy defines a set of hardware and software technologies that perform additional checks on memory

Parameters:

  • value

    Value to set for the dataExcutionPolicy property.

Returns:

  • a void



335
336
337
# File 'lib/models/device_health_attestation_state.rb', line 335

def data_excution_policy=(value)
    @data_excution_policy = value
end

#device_health_attestation_statusObject

Gets the deviceHealthAttestationStatus property value. The DHA report version. (Namespace version)

Returns:

  • a string



342
343
344
# File 'lib/models/device_health_attestation_state.rb', line 342

def device_health_attestation_status
    return @device_health_attestation_status
end

#device_health_attestation_status=(value) ⇒ Object

Sets the deviceHealthAttestationStatus property value. The DHA report version. (Namespace version)

Parameters:

  • value

    Value to set for the deviceHealthAttestationStatus property.

Returns:

  • a void



350
351
352
# File 'lib/models/device_health_attestation_state.rb', line 350

def device_health_attestation_status=(value)
    @device_health_attestation_status = value
end

#early_launch_anti_malware_driver_protectionObject

Gets the earlyLaunchAntiMalwareDriverProtection property value. ELAM provides protection for the computers in your network when they start up

Returns:

  • a string



357
358
359
# File 'lib/models/device_health_attestation_state.rb', line 357

def early_launch_anti_malware_driver_protection
    return @early_launch_anti_malware_driver_protection
end

#early_launch_anti_malware_driver_protection=(value) ⇒ Object

Sets the earlyLaunchAntiMalwareDriverProtection property value. ELAM provides protection for the computers in your network when they start up

Parameters:

  • value

    Value to set for the earlyLaunchAntiMalwareDriverProtection property.

Returns:

  • a void



365
366
367
# File 'lib/models/device_health_attestation_state.rb', line 365

def early_launch_anti_malware_driver_protection=(value)
    @early_launch_anti_malware_driver_protection = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/models/device_health_attestation_state.rb', line 372

def get_field_deserializers()
    return {
        "attestationIdentityKey" => lambda {|n| @attestation_identity_key = n.get_string_value() },
        "bitLockerStatus" => lambda {|n| @bit_locker_status = n.get_string_value() },
        "bootAppSecurityVersion" => lambda {|n| @boot_app_security_version = n.get_string_value() },
        "bootDebugging" => lambda {|n| @boot_debugging = n.get_string_value() },
        "bootManagerSecurityVersion" => lambda {|n| @boot_manager_security_version = n.get_string_value() },
        "bootManagerVersion" => lambda {|n| @boot_manager_version = n.get_string_value() },
        "bootRevisionListInfo" => lambda {|n| @boot_revision_list_info = n.get_string_value() },
        "codeIntegrity" => lambda {|n| @code_integrity = n.get_string_value() },
        "codeIntegrityCheckVersion" => lambda {|n| @code_integrity_check_version = n.get_string_value() },
        "codeIntegrityPolicy" => lambda {|n| @code_integrity_policy = n.get_string_value() },
        "contentNamespaceUrl" => lambda {|n| @content_namespace_url = n.get_string_value() },
        "contentVersion" => lambda {|n| @content_version = n.get_string_value() },
        "dataExcutionPolicy" => lambda {|n| @data_excution_policy = n.get_string_value() },
        "deviceHealthAttestationStatus" => lambda {|n| @device_health_attestation_status = n.get_string_value() },
        "earlyLaunchAntiMalwareDriverProtection" => lambda {|n| @early_launch_anti_malware_driver_protection = n.get_string_value() },
        "healthAttestationSupportedStatus" => lambda {|n| @health_attestation_supported_status = n.get_string_value() },
        "healthStatusMismatchInfo" => lambda {|n| @health_status_mismatch_info = n.get_string_value() },
        "issuedDateTime" => lambda {|n| @issued_date_time = n.get_date_time_value() },
        "lastUpdateDateTime" => lambda {|n| @last_update_date_time = n.get_string_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "operatingSystemKernelDebugging" => lambda {|n| @operating_system_kernel_debugging = n.get_string_value() },
        "operatingSystemRevListInfo" => lambda {|n| @operating_system_rev_list_info = n.get_string_value() },
        "pcrHashAlgorithm" => lambda {|n| @pcr_hash_algorithm = n.get_string_value() },
        "pcr0" => lambda {|n| @pcr0 = n.get_string_value() },
        "resetCount" => lambda {|n| @reset_count = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) },
        "restartCount" => lambda {|n| @restart_count = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) },
        "safeMode" => lambda {|n| @safe_mode = n.get_string_value() },
        "secureBoot" => lambda {|n| @secure_boot = n.get_string_value() },
        "secureBootConfigurationPolicyFingerPrint" => lambda {|n| @secure_boot_configuration_policy_finger_print = n.get_string_value() },
        "testSigning" => lambda {|n| @test_signing = n.get_string_value() },
        "tpmVersion" => lambda {|n| @tpm_version = n.get_string_value() },
        "virtualSecureMode" => lambda {|n| @virtual_secure_mode = n.get_string_value() },
        "windowsPE" => lambda {|n| @windows_p_e = n.get_string_value() },
    }
end

#health_attestation_supported_statusObject

Gets the healthAttestationSupportedStatus property value. This attribute indicates if DHA is supported for the device

Returns:

  • a string



413
414
415
# File 'lib/models/device_health_attestation_state.rb', line 413

def health_attestation_supported_status
    return @health_attestation_supported_status
end

#health_attestation_supported_status=(value) ⇒ Object

Sets the healthAttestationSupportedStatus property value. This attribute indicates if DHA is supported for the device

Parameters:

  • value

    Value to set for the healthAttestationSupportedStatus property.

Returns:

  • a void



421
422
423
# File 'lib/models/device_health_attestation_state.rb', line 421

def health_attestation_supported_status=(value)
    @health_attestation_supported_status = value
end

#health_status_mismatch_infoObject

Gets the healthStatusMismatchInfo property value. This attribute appears if DHA-Service detects an integrity issue

Returns:

  • a string



428
429
430
# File 'lib/models/device_health_attestation_state.rb', line 428

def health_status_mismatch_info
    return @health_status_mismatch_info
end

#health_status_mismatch_info=(value) ⇒ Object

Sets the healthStatusMismatchInfo property value. This attribute appears if DHA-Service detects an integrity issue

Parameters:

  • value

    Value to set for the healthStatusMismatchInfo property.

Returns:

  • a void



436
437
438
# File 'lib/models/device_health_attestation_state.rb', line 436

def health_status_mismatch_info=(value)
    @health_status_mismatch_info = value
end

#issued_date_timeObject

Gets the issuedDateTime property value. The DateTime when device was evaluated or issued to MDM

Returns:

  • a date_time



443
444
445
# File 'lib/models/device_health_attestation_state.rb', line 443

def issued_date_time
    return @issued_date_time
end

#issued_date_time=(value) ⇒ Object

Sets the issuedDateTime property value. The DateTime when device was evaluated or issued to MDM

Parameters:

  • value

    Value to set for the issuedDateTime property.

Returns:

  • a void



451
452
453
# File 'lib/models/device_health_attestation_state.rb', line 451

def issued_date_time=(value)
    @issued_date_time = value
end

#last_update_date_timeObject

Gets the lastUpdateDateTime property value. The Timestamp of the last update.

Returns:

  • a string



458
459
460
# File 'lib/models/device_health_attestation_state.rb', line 458

def last_update_date_time
    return @last_update_date_time
end

#last_update_date_time=(value) ⇒ Object

Sets the lastUpdateDateTime property value. The Timestamp of the last update.

Parameters:

  • value

    Value to set for the lastUpdateDateTime property.

Returns:

  • a void



466
467
468
# File 'lib/models/device_health_attestation_state.rb', line 466

def last_update_date_time=(value)
    @last_update_date_time = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



473
474
475
# File 'lib/models/device_health_attestation_state.rb', line 473

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



481
482
483
# File 'lib/models/device_health_attestation_state.rb', line 481

def odata_type=(value)
    @odata_type = value
end

#operating_system_kernel_debuggingObject

Gets the operatingSystemKernelDebugging property value. When operatingSystemKernelDebugging is enabled, the device is used in development and testing

Returns:

  • a string



488
489
490
# File 'lib/models/device_health_attestation_state.rb', line 488

def operating_system_kernel_debugging
    return @operating_system_kernel_debugging
end

#operating_system_kernel_debugging=(value) ⇒ Object

Sets the operatingSystemKernelDebugging property value. When operatingSystemKernelDebugging is enabled, the device is used in development and testing

Parameters:

  • value

    Value to set for the operatingSystemKernelDebugging property.

Returns:

  • a void



496
497
498
# File 'lib/models/device_health_attestation_state.rb', line 496

def operating_system_kernel_debugging=(value)
    @operating_system_kernel_debugging = value
end

#operating_system_rev_list_infoObject

Gets the operatingSystemRevListInfo property value. The Operating System Revision List that was loaded during initial boot on the attested device

Returns:

  • a string



503
504
505
# File 'lib/models/device_health_attestation_state.rb', line 503

def operating_system_rev_list_info
    return @operating_system_rev_list_info
end

#operating_system_rev_list_info=(value) ⇒ Object

Sets the operatingSystemRevListInfo property value. The Operating System Revision List that was loaded during initial boot on the attested device

Parameters:

  • value

    Value to set for the operatingSystemRevListInfo property.

Returns:

  • a void



511
512
513
# File 'lib/models/device_health_attestation_state.rb', line 511

def operating_system_rev_list_info=(value)
    @operating_system_rev_list_info = value
end

#pcr0Object

Gets the pcr0 property value. The measurement that is captured in PCR

Returns:

  • a string



533
534
535
# File 'lib/models/device_health_attestation_state.rb', line 533

def pcr0
    return @pcr0
end

#pcr0=(value) ⇒ Object

Sets the pcr0 property value. The measurement that is captured in PCR

Parameters:

  • value

    Value to set for the pcr0 property.

Returns:

  • a void



541
542
543
# File 'lib/models/device_health_attestation_state.rb', line 541

def pcr0=(value)
    @pcr0 = value
end

#pcr_hash_algorithmObject

Gets the pcrHashAlgorithm property value. Informational attribute that identifies the HASH algorithm that was used by TPM

Returns:

  • a string



518
519
520
# File 'lib/models/device_health_attestation_state.rb', line 518

def pcr_hash_algorithm
    return @pcr_hash_algorithm
end

#pcr_hash_algorithm=(value) ⇒ Object

Sets the pcrHashAlgorithm property value. Informational attribute that identifies the HASH algorithm that was used by TPM

Parameters:

  • value

    Value to set for the pcrHashAlgorithm property.

Returns:

  • a void



526
527
528
# File 'lib/models/device_health_attestation_state.rb', line 526

def pcr_hash_algorithm=(value)
    @pcr_hash_algorithm = value
end

#reset_countObject

Gets the resetCount property value. The number of times a PC device has hibernated or resumed

Returns:

  • a int64



548
549
550
# File 'lib/models/device_health_attestation_state.rb', line 548

def reset_count
    return @reset_count
end

#reset_count=(value) ⇒ Object

Sets the resetCount property value. The number of times a PC device has hibernated or resumed

Parameters:

  • value

    Value to set for the resetCount property.

Returns:

  • a void



556
557
558
# File 'lib/models/device_health_attestation_state.rb', line 556

def reset_count=(value)
    @reset_count = value
end

#restart_countObject

Gets the restartCount property value. The number of times a PC device has rebooted

Returns:

  • a int64



563
564
565
# File 'lib/models/device_health_attestation_state.rb', line 563

def restart_count
    return @restart_count
end

#restart_count=(value) ⇒ Object

Sets the restartCount property value. The number of times a PC device has rebooted

Parameters:

  • value

    Value to set for the restartCount property.

Returns:

  • a void



571
572
573
# File 'lib/models/device_health_attestation_state.rb', line 571

def restart_count=(value)
    @restart_count = value
end

#safe_modeObject

Gets the safeMode property value. Safe mode is a troubleshooting option for Windows that starts your computer in a limited state

Returns:

  • a string



578
579
580
# File 'lib/models/device_health_attestation_state.rb', line 578

def safe_mode
    return @safe_mode
end

#safe_mode=(value) ⇒ Object

Sets the safeMode property value. Safe mode is a troubleshooting option for Windows that starts your computer in a limited state

Parameters:

  • value

    Value to set for the safeMode property.

Returns:

  • a void



586
587
588
# File 'lib/models/device_health_attestation_state.rb', line 586

def safe_mode=(value)
    @safe_mode = value
end

#secure_bootObject

Gets the secureBoot property value. When Secure Boot is enabled, the core components must have the correct cryptographic signatures

Returns:

  • a string



593
594
595
# File 'lib/models/device_health_attestation_state.rb', line 593

def secure_boot
    return @secure_boot
end

#secure_boot=(value) ⇒ Object

Sets the secureBoot property value. When Secure Boot is enabled, the core components must have the correct cryptographic signatures

Parameters:

  • value

    Value to set for the secureBoot property.

Returns:

  • a void



601
602
603
# File 'lib/models/device_health_attestation_state.rb', line 601

def secure_boot=(value)
    @secure_boot = value
end

#secure_boot_configuration_policy_finger_printObject

Gets the secureBootConfigurationPolicyFingerPrint property value. Fingerprint of the Custom Secure Boot Configuration Policy

Returns:

  • a string



608
609
610
# File 'lib/models/device_health_attestation_state.rb', line 608

def secure_boot_configuration_policy_finger_print
    return @secure_boot_configuration_policy_finger_print
end

#secure_boot_configuration_policy_finger_print=(value) ⇒ Object

Sets the secureBootConfigurationPolicyFingerPrint property value. Fingerprint of the Custom Secure Boot Configuration Policy

Parameters:

  • value

    Value to set for the secureBootConfigurationPolicyFingerPrint property.

Returns:

  • a void



616
617
618
# File 'lib/models/device_health_attestation_state.rb', line 616

def secure_boot_configuration_policy_finger_print=(value)
    @secure_boot_configuration_policy_finger_print = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/models/device_health_attestation_state.rb', line 624

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("attestationIdentityKey", @attestation_identity_key)
    writer.write_string_value("bitLockerStatus", @bit_locker_status)
    writer.write_string_value("bootAppSecurityVersion", @boot_app_security_version)
    writer.write_string_value("bootDebugging", @boot_debugging)
    writer.write_string_value("bootManagerSecurityVersion", @boot_manager_security_version)
    writer.write_string_value("bootManagerVersion", @boot_manager_version)
    writer.write_string_value("bootRevisionListInfo", @boot_revision_list_info)
    writer.write_string_value("codeIntegrity", @code_integrity)
    writer.write_string_value("codeIntegrityCheckVersion", @code_integrity_check_version)
    writer.write_string_value("codeIntegrityPolicy", @code_integrity_policy)
    writer.write_string_value("contentNamespaceUrl", @content_namespace_url)
    writer.write_string_value("contentVersion", @content_version)
    writer.write_string_value("dataExcutionPolicy", @data_excution_policy)
    writer.write_string_value("deviceHealthAttestationStatus", @device_health_attestation_status)
    writer.write_string_value("earlyLaunchAntiMalwareDriverProtection", @early_launch_anti_malware_driver_protection)
    writer.write_string_value("healthAttestationSupportedStatus", @health_attestation_supported_status)
    writer.write_string_value("healthStatusMismatchInfo", @health_status_mismatch_info)
    writer.write_date_time_value("issuedDateTime", @issued_date_time)
    writer.write_string_value("lastUpdateDateTime", @last_update_date_time)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_string_value("operatingSystemKernelDebugging", @operating_system_kernel_debugging)
    writer.write_string_value("operatingSystemRevListInfo", @operating_system_rev_list_info)
    writer.write_string_value("pcrHashAlgorithm", @pcr_hash_algorithm)
    writer.write_string_value("pcr0", @pcr0)
    writer.write_object_value("resetCount", @reset_count)
    writer.write_object_value("restartCount", @restart_count)
    writer.write_string_value("safeMode", @safe_mode)
    writer.write_string_value("secureBoot", @secure_boot)
    writer.write_string_value("secureBootConfigurationPolicyFingerPrint", @secure_boot_configuration_policy_finger_print)
    writer.write_string_value("testSigning", @test_signing)
    writer.write_string_value("tpmVersion", @tpm_version)
    writer.write_string_value("virtualSecureMode", @virtual_secure_mode)
    writer.write_string_value("windowsPE", @windows_p_e)
    writer.write_additional_data(@additional_data)
end

#test_signingObject

Gets the testSigning property value. When test signing is allowed, the device does not enforce signature validation during boot

Returns:

  • a string



665
666
667
# File 'lib/models/device_health_attestation_state.rb', line 665

def test_signing
    return @test_signing
end

#test_signing=(value) ⇒ Object

Sets the testSigning property value. When test signing is allowed, the device does not enforce signature validation during boot

Parameters:

  • value

    Value to set for the testSigning property.

Returns:

  • a void



673
674
675
# File 'lib/models/device_health_attestation_state.rb', line 673

def test_signing=(value)
    @test_signing = value
end

#tpm_versionObject

Gets the tpmVersion property value. The security version number of the Boot Application

Returns:

  • a string



680
681
682
# File 'lib/models/device_health_attestation_state.rb', line 680

def tpm_version
    return @tpm_version
end

#tpm_version=(value) ⇒ Object

Sets the tpmVersion property value. The security version number of the Boot Application

Parameters:

  • value

    Value to set for the tpmVersion property.

Returns:

  • a void



688
689
690
# File 'lib/models/device_health_attestation_state.rb', line 688

def tpm_version=(value)
    @tpm_version = value
end

#virtual_secure_modeObject

Gets the virtualSecureMode property value. VSM is a container that protects high value assets from a compromised kernel

Returns:

  • a string



695
696
697
# File 'lib/models/device_health_attestation_state.rb', line 695

def virtual_secure_mode
    return @virtual_secure_mode
end

#virtual_secure_mode=(value) ⇒ Object

Sets the virtualSecureMode property value. VSM is a container that protects high value assets from a compromised kernel

Parameters:

  • value

    Value to set for the virtualSecureMode property.

Returns:

  • a void



703
704
705
# File 'lib/models/device_health_attestation_state.rb', line 703

def virtual_secure_mode=(value)
    @virtual_secure_mode = value
end

#windows_p_eObject

Gets the windowsPE property value. Operating system running with limited services that is used to prepare a computer for Windows

Returns:

  • a string



710
711
712
# File 'lib/models/device_health_attestation_state.rb', line 710

def windows_p_e
    return @windows_p_e
end

#windows_p_e=(value) ⇒ Object

Sets the windowsPE property value. Operating system running with limited services that is used to prepare a computer for Windows

Parameters:

  • value

    Value to set for the windowsPE property.

Returns:

  • a void



718
719
720
# File 'lib/models/device_health_attestation_state.rb', line 718

def windows_p_e=(value)
    @windows_p_e = value
end