Class: MicrosoftGraph::Models::DisplayNameLocalization
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::DisplayNameLocalization
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/display_name_localization.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new displayNameLocalization and sets the default values.
-
#language_tag ⇒ Object
Gets the languageTag property value.
-
#language_tag=(value) ⇒ Object
Sets the languageTag property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new displayNameLocalization and sets the default values.
40 41 42 |
# File 'lib/models/display_name_localization.rb', line 40 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/models/display_name_localization.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return DisplayNameLocalization.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/models/display_name_localization.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/models/display_name_localization.rb', line 33 def additional_data=(value) @additional_data = value end |
#display_name ⇒ Object
Gets the displayName property value. If present, the value of this field contains the displayName string that has been set for the language present in the languageTag field.
56 57 58 |
# File 'lib/models/display_name_localization.rb', line 56 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. If present, the value of this field contains the displayName string that has been set for the language present in the languageTag field.
64 65 66 |
# File 'lib/models/display_name_localization.rb', line 64 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
71 72 73 74 75 76 77 |
# File 'lib/models/display_name_localization.rb', line 71 def get_field_deserializers() return { "displayName" => lambda {|n| @display_name = n.get_string_value() }, "languageTag" => lambda {|n| @language_tag = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, } end |
#language_tag ⇒ Object
Gets the languageTag property value. Provides the language culture-code and friendly name of the language that the displayName field has been provided in.
82 83 84 |
# File 'lib/models/display_name_localization.rb', line 82 def language_tag return @language_tag end |
#language_tag=(value) ⇒ Object
Sets the languageTag property value. Provides the language culture-code and friendly name of the language that the displayName field has been provided in.
90 91 92 |
# File 'lib/models/display_name_localization.rb', line 90 def language_tag=(value) @language_tag = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
97 98 99 |
# File 'lib/models/display_name_localization.rb', line 97 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
105 106 107 |
# File 'lib/models/display_name_localization.rb', line 105 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
113 114 115 116 117 118 119 |
# File 'lib/models/display_name_localization.rb', line 113 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("displayName", @display_name) writer.write_string_value("languageTag", @language_tag) writer.write_string_value("@odata.type", @odata_type) writer.write_additional_data(@additional_data) end |