Class: MicrosoftGraph::Models::EducationFeedback

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/education_feedback.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new educationFeedback and sets the default values.



44
45
46
# File 'lib/models/education_feedback.rb', line 44

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a education_feedback

Raises:

  • (StandardError)


52
53
54
55
# File 'lib/models/education_feedback.rb', line 52

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return EducationFeedback.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



29
30
31
# File 'lib/models/education_feedback.rb', line 29

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



37
38
39
# File 'lib/models/education_feedback.rb', line 37

def additional_data=(value)
    @additional_data = value
end

#feedback_byObject

Gets the feedbackBy property value. User who created the feedback.

Returns:

  • a identity_set



60
61
62
# File 'lib/models/education_feedback.rb', line 60

def feedback_by
    return @feedback_by
end

#feedback_by=(value) ⇒ Object

Sets the feedbackBy property value. User who created the feedback.

Parameters:

  • value

    Value to set for the feedbackBy property.

Returns:

  • a void



68
69
70
# File 'lib/models/education_feedback.rb', line 68

def feedback_by=(value)
    @feedback_by = value
end

#feedback_date_timeObject

Gets the feedbackDateTime property value. Moment in time when the feedback was given. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z

Returns:

  • a date_time



75
76
77
# File 'lib/models/education_feedback.rb', line 75

def feedback_date_time
    return @feedback_date_time
end

#feedback_date_time=(value) ⇒ Object

Sets the feedbackDateTime property value. Moment in time when the feedback was given. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z

Parameters:

  • value

    Value to set for the feedbackDateTime property.

Returns:

  • a void



83
84
85
# File 'lib/models/education_feedback.rb', line 83

def feedback_date_time=(value)
    @feedback_date_time = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



90
91
92
93
94
95
96
97
# File 'lib/models/education_feedback.rb', line 90

def get_field_deserializers()
    return {
        "feedbackBy" => lambda {|n| @feedback_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) },
        "feedbackDateTime" => lambda {|n| @feedback_date_time = n.get_date_time_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "text" => lambda {|n| @text = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::EducationItemBody.create_from_discriminator_value(pn) }) },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



102
103
104
# File 'lib/models/education_feedback.rb', line 102

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



110
111
112
# File 'lib/models/education_feedback.rb', line 110

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


118
119
120
121
122
123
124
125
# File 'lib/models/education_feedback.rb', line 118

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_object_value("feedbackBy", @feedback_by)
    writer.write_date_time_value("feedbackDateTime", @feedback_date_time)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_object_value("text", @text)
    writer.write_additional_data(@additional_data)
end

#textObject

Gets the text property value. Feedback.

Returns:

  • a education_item_body



130
131
132
# File 'lib/models/education_feedback.rb', line 130

def text
    return @text
end

#text=(value) ⇒ Object

Sets the text property value. Feedback.

Parameters:

  • value

    Value to set for the text property.

Returns:

  • a void



138
139
140
# File 'lib/models/education_feedback.rb', line 138

def text=(value)
    @text = value
end