Class: MicrosoftGraph::Models::EducationRubricOutcome

Inherits:
EducationOutcome show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/education_rubric_outcome.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from EducationOutcome

#last_modified_by, #last_modified_by=, #last_modified_date_time, #last_modified_date_time=

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new educationRubricOutcome and sets the default values.



25
26
27
28
# File 'lib/models/education_rubric_outcome.rb', line 25

def initialize()
    super
    @odata_type = "#microsoft.graph.educationRubricOutcome"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a education_rubric_outcome

Raises:

  • (StandardError)


34
35
36
37
# File 'lib/models/education_rubric_outcome.rb', line 34

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return EducationRubricOutcome.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



42
43
44
45
46
47
48
49
# File 'lib/models/education_rubric_outcome.rb', line 42

def get_field_deserializers()
    return super.merge({
        "publishedRubricQualityFeedback" => lambda {|n| @published_rubric_quality_feedback = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualityFeedbackModel.create_from_discriminator_value(pn) }) },
        "publishedRubricQualitySelectedLevels" => lambda {|n| @published_rubric_quality_selected_levels = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualitySelectedColumnModel.create_from_discriminator_value(pn) }) },
        "rubricQualityFeedback" => lambda {|n| @rubric_quality_feedback = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualityFeedbackModel.create_from_discriminator_value(pn) }) },
        "rubricQualitySelectedLevels" => lambda {|n| @rubric_quality_selected_levels = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualitySelectedColumnModel.create_from_discriminator_value(pn) }) },
    })
end

#published_rubric_quality_feedbackObject

Gets the publishedRubricQualityFeedback property value. A copy of the rubricQualityFeedback property that is made when the grade is released to the student.

Returns:

  • a rubric_quality_feedback_model



54
55
56
# File 'lib/models/education_rubric_outcome.rb', line 54

def published_rubric_quality_feedback
    return @published_rubric_quality_feedback
end

#published_rubric_quality_feedback=(value) ⇒ Object

Sets the publishedRubricQualityFeedback property value. A copy of the rubricQualityFeedback property that is made when the grade is released to the student.

Parameters:

  • value

    Value to set for the publishedRubricQualityFeedback property.

Returns:

  • a void



62
63
64
# File 'lib/models/education_rubric_outcome.rb', line 62

def published_rubric_quality_feedback=(value)
    @published_rubric_quality_feedback = value
end

#published_rubric_quality_selected_levelsObject

Gets the publishedRubricQualitySelectedLevels property value. A copy of the rubricQualitySelectedLevels property that is made when the grade is released to the student.

Returns:

  • a rubric_quality_selected_column_model



69
70
71
# File 'lib/models/education_rubric_outcome.rb', line 69

def published_rubric_quality_selected_levels
    return @published_rubric_quality_selected_levels
end

#published_rubric_quality_selected_levels=(value) ⇒ Object

Sets the publishedRubricQualitySelectedLevels property value. A copy of the rubricQualitySelectedLevels property that is made when the grade is released to the student.

Parameters:

  • value

    Value to set for the publishedRubricQualitySelectedLevels property.

Returns:

  • a void



77
78
79
# File 'lib/models/education_rubric_outcome.rb', line 77

def published_rubric_quality_selected_levels=(value)
    @published_rubric_quality_selected_levels = value
end

#rubric_quality_feedbackObject

Gets the rubricQualityFeedback property value. A collection of specific feedback for each quality of this rubric.

Returns:

  • a rubric_quality_feedback_model



84
85
86
# File 'lib/models/education_rubric_outcome.rb', line 84

def rubric_quality_feedback
    return @rubric_quality_feedback
end

#rubric_quality_feedback=(value) ⇒ Object

Sets the rubricQualityFeedback property value. A collection of specific feedback for each quality of this rubric.

Parameters:

  • value

    Value to set for the rubricQualityFeedback property.

Returns:

  • a void



92
93
94
# File 'lib/models/education_rubric_outcome.rb', line 92

def rubric_quality_feedback=(value)
    @rubric_quality_feedback = value
end

#rubric_quality_selected_levelsObject

Gets the rubricQualitySelectedLevels property value. The level that the teacher has selected for each quality while grading this assignment.

Returns:

  • a rubric_quality_selected_column_model



99
100
101
# File 'lib/models/education_rubric_outcome.rb', line 99

def rubric_quality_selected_levels
    return @rubric_quality_selected_levels
end

#rubric_quality_selected_levels=(value) ⇒ Object

Sets the rubricQualitySelectedLevels property value. The level that the teacher has selected for each quality while grading this assignment.

Parameters:

  • value

    Value to set for the rubricQualitySelectedLevels property.

Returns:

  • a void



107
108
109
# File 'lib/models/education_rubric_outcome.rb', line 107

def rubric_quality_selected_levels=(value)
    @rubric_quality_selected_levels = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


115
116
117
118
119
120
121
122
# File 'lib/models/education_rubric_outcome.rb', line 115

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("publishedRubricQualityFeedback", @published_rubric_quality_feedback)
    writer.write_collection_of_object_values("publishedRubricQualitySelectedLevels", @published_rubric_quality_selected_levels)
    writer.write_collection_of_object_values("rubricQualityFeedback", @rubric_quality_feedback)
    writer.write_collection_of_object_values("rubricQualitySelectedLevels", @rubric_quality_selected_levels)
end