Class: MicrosoftGraph::Models::EmailIdentity
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/email_identity.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#email ⇒ Object
Gets the email property value.
-
#email=(value) ⇒ Object
Sets the email property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new emailIdentity and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Identity
#additional_data, #additional_data=, #display_name, #display_name=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new emailIdentity and sets the default values.
16 17 18 19 |
# File 'lib/models/email_identity.rb', line 16 def initialize() super @odata_type = "#microsoft.graph.emailIdentity" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
25 26 27 28 |
# File 'lib/models/email_identity.rb', line 25 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return EmailIdentity.new end |
Instance Method Details
#email ⇒ Object
Gets the email property value. Email address of the user.
33 34 35 |
# File 'lib/models/email_identity.rb', line 33 def email return @email end |
#email=(value) ⇒ Object
Sets the email property value. Email address of the user.
41 42 43 |
# File 'lib/models/email_identity.rb', line 41 def email=(value) @email = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
48 49 50 51 52 |
# File 'lib/models/email_identity.rb', line 48 def get_field_deserializers() return super.merge({ "email" => lambda {|n| @email = n.get_string_value() }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
58 59 60 61 62 |
# File 'lib/models/email_identity.rb', line 58 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("email", @email) end |