Class: MicrosoftGraph::Models::ExpirationPattern

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/expiration_pattern.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new expirationPattern and sets the default values.



44
45
46
# File 'lib/models/expiration_pattern.rb', line 44

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Raises:

  • (StandardError)


52
53
54
55
# File 'lib/models/expiration_pattern.rb', line 52

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ExpirationPattern.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.



29
30
31
# File 'lib/models/expiration_pattern.rb', line 29

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.



37
38
39
# File 'lib/models/expiration_pattern.rb', line 37

def additional_data=(value)
    @additional_data = value
end

#durationObject

Gets the duration property value. The requestor’s desired duration of access represented in ISO 8601 format for durations. For example, PT3H refers to three hours. If specified in a request, endDateTime should not be present and the type property should be set to afterDuration.



60
61
62
# File 'lib/models/expiration_pattern.rb', line 60

def duration
    return @duration
end

#duration=(value) ⇒ Object

Sets the duration property value. The requestor’s desired duration of access represented in ISO 8601 format for durations. For example, PT3H refers to three hours. If specified in a request, endDateTime should not be present and the type property should be set to afterDuration.



68
69
70
# File 'lib/models/expiration_pattern.rb', line 68

def duration=(value)
    @duration = value
end

#end_date_timeObject

Gets the endDateTime property value. Timestamp of date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.



75
76
77
# File 'lib/models/expiration_pattern.rb', line 75

def end_date_time
    return @end_date_time
end

#end_date_time=(value) ⇒ Object

Sets the endDateTime property value. Timestamp of date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.



83
84
85
# File 'lib/models/expiration_pattern.rb', line 83

def end_date_time=(value)
    @end_date_time = value
end

#get_field_deserializersObject

The deserialization information for the current model



90
91
92
93
94
95
96
97
# File 'lib/models/expiration_pattern.rb', line 90

def get_field_deserializers()
    return {
        "duration" => lambda {|n| @duration = n.get_duration_value() },
        "endDateTime" => lambda {|n| @end_date_time = n.get_date_time_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "type" => lambda {|n| @type = n.get_enum_value(MicrosoftGraph::Models::ExpirationPatternType) },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property



102
103
104
# File 'lib/models/expiration_pattern.rb', line 102

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property



110
111
112
# File 'lib/models/expiration_pattern.rb', line 110

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Raises:

  • (StandardError)


118
119
120
121
122
123
124
125
# File 'lib/models/expiration_pattern.rb', line 118

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_duration_value("duration", @duration)
    writer.write_date_time_value("endDateTime", @end_date_time)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_enum_value("type", @type)
    writer.write_additional_data(@additional_data)
end

#typeObject

Gets the type property value. The requestor’s desired expiration pattern type. The possible values are: notSpecified, noExpiration, afterDateTime, afterDuration.



130
131
132
# File 'lib/models/expiration_pattern.rb', line 130

def type
    return @type
end

#type=(value) ⇒ Object

Sets the type property value. The requestor’s desired expiration pattern type. The possible values are: notSpecified, noExpiration, afterDateTime, afterDuration.



138
139
140
# File 'lib/models/expiration_pattern.rb', line 138

def type=(value)
    @type = value
end