Class: MicrosoftGraph::Models::ExternalConnectorsExternalConnection

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/external_connectors_external_connection.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new externalConnectorsExternalConnection and sets the default values.



73
74
75
# File 'lib/models/external_connectors_external_connection.rb', line 73

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a external_connectors_external_connection

Raises:

  • (StandardError)


81
82
83
84
# File 'lib/models/external_connectors_external_connection.rb', line 81

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ExternalConnectorsExternalConnection.new
end

Instance Method Details

#activity_settingsObject

Gets the activitySettings property value. Collects configurable settings related to activities involving connector content.

Returns:

  • a external_connectors_activity_settings



43
44
45
# File 'lib/models/external_connectors_external_connection.rb', line 43

def activity_settings
    return @activity_settings
end

#activity_settings=(value) ⇒ Object

Sets the activitySettings property value. Collects configurable settings related to activities involving connector content.

Parameters:

  • value

    Value to set for the activitySettings property.

Returns:

  • a void



51
52
53
# File 'lib/models/external_connectors_external_connection.rb', line 51

def activity_settings=(value)
    @activity_settings = value
end

#configurationObject

Gets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.

Returns:

  • a external_connectors_configuration



58
59
60
# File 'lib/models/external_connectors_external_connection.rb', line 58

def configuration
    return @configuration
end

#configuration=(value) ⇒ Object

Sets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.

Parameters:

  • value

    Value to set for the configuration property.

Returns:

  • a void



66
67
68
# File 'lib/models/external_connectors_external_connection.rb', line 66

def configuration=(value)
    @configuration = value
end

#descriptionObject

Gets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.

Returns:

  • a string



89
90
91
# File 'lib/models/external_connectors_external_connection.rb', line 89

def description
    return @description
end

#description=(value) ⇒ Object

Sets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.

Parameters:

  • value

    Value to set for the description property.

Returns:

  • a void



97
98
99
# File 'lib/models/external_connectors_external_connection.rb', line 97

def description=(value)
    @description = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/models/external_connectors_external_connection.rb', line 104

def get_field_deserializers()
    return super.merge({
        "activitySettings" => lambda {|n| @activity_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsActivitySettings.create_from_discriminator_value(pn) }) },
        "configuration" => lambda {|n| @configuration = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsConfiguration.create_from_discriminator_value(pn) }) },
        "description" => lambda {|n| @description = n.get_string_value() },
        "groups" => lambda {|n| @groups = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsExternalGroup.create_from_discriminator_value(pn) }) },
        "items" => lambda {|n| @items = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsExternalItem.create_from_discriminator_value(pn) }) },
        "name" => lambda {|n| @name = n.get_string_value() },
        "operations" => lambda {|n| @operations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsConnectionOperation.create_from_discriminator_value(pn) }) },
        "schema" => lambda {|n| @schema = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsSchema.create_from_discriminator_value(pn) }) },
        "searchSettings" => lambda {|n| @search_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsSearchSettings.create_from_discriminator_value(pn) }) },
        "state" => lambda {|n| @state = n.get_enum_value(MicrosoftGraph::Models::ExternalConnectorsConnectionState) },
    })
end

#groupsObject

Gets the groups property value. The groups property

Returns:

  • a external_connectors_external_group



122
123
124
# File 'lib/models/external_connectors_external_connection.rb', line 122

def groups
    return @groups
end

#groups=(value) ⇒ Object

Sets the groups property value. The groups property

Parameters:

  • value

    Value to set for the groups property.

Returns:

  • a void



130
131
132
# File 'lib/models/external_connectors_external_connection.rb', line 130

def groups=(value)
    @groups = value
end

#itemsObject

Gets the items property value. The items property

Returns:

  • a external_connectors_external_item



137
138
139
# File 'lib/models/external_connectors_external_connection.rb', line 137

def items
    return @items
end

#items=(value) ⇒ Object

Sets the items property value. The items property

Parameters:

  • value

    Value to set for the items property.

Returns:

  • a void



145
146
147
# File 'lib/models/external_connectors_external_connection.rb', line 145

def items=(value)
    @items = value
end

#nameObject

Gets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.

Returns:

  • a string



152
153
154
# File 'lib/models/external_connectors_external_connection.rb', line 152

def name
    return @name
end

#name=(value) ⇒ Object

Sets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.

Parameters:

  • value

    Value to set for the name property.

Returns:

  • a void



160
161
162
# File 'lib/models/external_connectors_external_connection.rb', line 160

def name=(value)
    @name = value
end

#operationsObject

Gets the operations property value. The operations property

Returns:

  • a external_connectors_connection_operation



167
168
169
# File 'lib/models/external_connectors_external_connection.rb', line 167

def operations
    return @operations
end

#operations=(value) ⇒ Object

Sets the operations property value. The operations property

Parameters:

  • value

    Value to set for the operations property.

Returns:

  • a void



175
176
177
# File 'lib/models/external_connectors_external_connection.rb', line 175

def operations=(value)
    @operations = value
end

#schemaObject

Gets the schema property value. The schema property

Returns:

  • a external_connectors_schema



182
183
184
# File 'lib/models/external_connectors_external_connection.rb', line 182

def schema
    return @schema
end

#schema=(value) ⇒ Object

Sets the schema property value. The schema property

Parameters:

  • value

    Value to set for the schema property.

Returns:

  • a void



190
191
192
# File 'lib/models/external_connectors_external_connection.rb', line 190

def schema=(value)
    @schema = value
end

#search_settingsObject

Gets the searchSettings property value. The settings configuring the search experience for content in this connection, such as the display templates for search results.

Returns:

  • a external_connectors_search_settings



197
198
199
# File 'lib/models/external_connectors_external_connection.rb', line 197

def search_settings
    return @search_settings
end

#search_settings=(value) ⇒ Object

Sets the searchSettings property value. The settings configuring the search experience for content in this connection, such as the display templates for search results.

Parameters:

  • value

    Value to set for the searchSettings property.

Returns:

  • a void



205
206
207
# File 'lib/models/external_connectors_external_connection.rb', line 205

def search_settings=(value)
    @search_settings = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/models/external_connectors_external_connection.rb', line 213

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("activitySettings", @activity_settings)
    writer.write_object_value("configuration", @configuration)
    writer.write_string_value("description", @description)
    writer.write_collection_of_object_values("groups", @groups)
    writer.write_collection_of_object_values("items", @items)
    writer.write_string_value("name", @name)
    writer.write_collection_of_object_values("operations", @operations)
    writer.write_object_value("schema", @schema)
    writer.write_object_value("searchSettings", @search_settings)
end

#stateObject

Gets the state property value. Indicates the current state of the connection. Possible values are: draft, ready, obsolete, limitExceeded, unknownFutureValue.

Returns:

  • a external_connectors_connection_state



230
231
232
# File 'lib/models/external_connectors_external_connection.rb', line 230

def state
    return @state
end

#state=(value) ⇒ Object

Sets the state property value. Indicates the current state of the connection. Possible values are: draft, ready, obsolete, limitExceeded, unknownFutureValue.

Parameters:

  • value

    Value to set for the state property.

Returns:

  • a void



238
239
240
# File 'lib/models/external_connectors_external_connection.rb', line 238

def state=(value)
    @state = value
end