Class: MicrosoftGraph::Models::ExternalConnectorsProperty

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/external_connectors_property.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new externalConnectorsProperty and sets the default values.



73
74
75
# File 'lib/models/external_connectors_property.rb', line 73

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a external_connectors_property

Raises:

  • (StandardError)


81
82
83
84
# File 'lib/models/external_connectors_property.rb', line 81

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ExternalConnectorsProperty.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



43
44
45
# File 'lib/models/external_connectors_property.rb', line 43

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



51
52
53
# File 'lib/models/external_connectors_property.rb', line 51

def additional_data=(value)
    @additional_data = value
end

#aliasesObject

Gets the aliases property value. A set of aliases or a friendly names for the property. Maximum 32 characters. Only alphanumeric characters allowed. For example, each string may not contain control characters, whitespace, or any of the following: :, ;, ,, (, ), [, ], {, }, %, $, +, !, *, =, &, ?, @, #, /, ~, ‘, ’, <, >, ‘, ^. Optional.

Returns:

  • a string



58
59
60
# File 'lib/models/external_connectors_property.rb', line 58

def aliases
    return @aliases
end

#aliases=(value) ⇒ Object

Sets the aliases property value. A set of aliases or a friendly names for the property. Maximum 32 characters. Only alphanumeric characters allowed. For example, each string may not contain control characters, whitespace, or any of the following: :, ;, ,, (, ), [, ], {, }, %, $, +, !, *, =, &, ?, @, #, /, ~, ‘, ’, <, >, ‘, ^. Optional.

Parameters:

  • value

    Value to set for the aliases property.

Returns:

  • a void



66
67
68
# File 'lib/models/external_connectors_property.rb', line 66

def aliases=(value)
    @aliases = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/models/external_connectors_property.rb', line 89

def get_field_deserializers()
    return {
        "aliases" => lambda {|n| @aliases = n.get_collection_of_primitive_values(String) },
        "isQueryable" => lambda {|n| @is_queryable = n.get_boolean_value() },
        "isRefinable" => lambda {|n| @is_refinable = n.get_boolean_value() },
        "isRetrievable" => lambda {|n| @is_retrievable = n.get_boolean_value() },
        "isSearchable" => lambda {|n| @is_searchable = n.get_boolean_value() },
        "labels" => lambda {|n| @labels = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsLabel.create_from_discriminator_value(pn) }) },
        "name" => lambda {|n| @name = n.get_string_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "type" => lambda {|n| @type = n.get_enum_value(MicrosoftGraph::Models::ExternalConnectorsPropertyType) },
    }
end

#is_queryableObject

Gets the isQueryable property value. Specifies if the property is queryable. Queryable properties can be used in Keyword Query Language (KQL) queries. Optional.

Returns:

  • a boolean



106
107
108
# File 'lib/models/external_connectors_property.rb', line 106

def is_queryable
    return @is_queryable
end

#is_queryable=(value) ⇒ Object

Sets the isQueryable property value. Specifies if the property is queryable. Queryable properties can be used in Keyword Query Language (KQL) queries. Optional.

Parameters:

  • value

    Value to set for the isQueryable property.

Returns:

  • a void



114
115
116
# File 'lib/models/external_connectors_property.rb', line 114

def is_queryable=(value)
    @is_queryable = value
end

#is_refinableObject

Gets the isRefinable property value. Specifies if the property is refinable. Refinable properties can be used to filter search results in the Search API and add a refiner control in the Microsoft Search user experience. Optional.

Returns:

  • a boolean



121
122
123
# File 'lib/models/external_connectors_property.rb', line 121

def is_refinable
    return @is_refinable
end

#is_refinable=(value) ⇒ Object

Sets the isRefinable property value. Specifies if the property is refinable. Refinable properties can be used to filter search results in the Search API and add a refiner control in the Microsoft Search user experience. Optional.

Parameters:

  • value

    Value to set for the isRefinable property.

Returns:

  • a void



129
130
131
# File 'lib/models/external_connectors_property.rb', line 129

def is_refinable=(value)
    @is_refinable = value
end

#is_retrievableObject

Gets the isRetrievable property value. Specifies if the property is retrievable. Retrievable properties are returned in the result set when items are returned by the search API. Retrievable properties are also available to add to the display template used to render search results. Optional.

Returns:

  • a boolean



136
137
138
# File 'lib/models/external_connectors_property.rb', line 136

def is_retrievable
    return @is_retrievable
end

#is_retrievable=(value) ⇒ Object

Sets the isRetrievable property value. Specifies if the property is retrievable. Retrievable properties are returned in the result set when items are returned by the search API. Retrievable properties are also available to add to the display template used to render search results. Optional.

Parameters:

  • value

    Value to set for the isRetrievable property.

Returns:

  • a void



144
145
146
# File 'lib/models/external_connectors_property.rb', line 144

def is_retrievable=(value)
    @is_retrievable = value
end

#is_searchableObject

Gets the isSearchable property value. Specifies if the property is searchable. Only properties of type String or StringCollection can be searchable. Non-searchable properties are not added to the search index. Optional.

Returns:

  • a boolean



151
152
153
# File 'lib/models/external_connectors_property.rb', line 151

def is_searchable
    return @is_searchable
end

#is_searchable=(value) ⇒ Object

Sets the isSearchable property value. Specifies if the property is searchable. Only properties of type String or StringCollection can be searchable. Non-searchable properties are not added to the search index. Optional.

Parameters:

  • value

    Value to set for the isSearchable property.

Returns:

  • a void



159
160
161
# File 'lib/models/external_connectors_property.rb', line 159

def is_searchable=(value)
    @is_searchable = value
end

#labelsObject

Gets the labels property value. Specifies one or more well-known tags added against a property. Labels help Microsoft Search understand the semantics of the data in the connection. Adding appropriate labels would result in an enhanced search experience (e.g. better relevance). The possible values are: title, url, createdBy, lastModifiedBy, authors, createdDateTime, lastModifiedDateTime, fileName, fileExtension, unknownFutureValue. Optional.

Returns:

  • a external_connectors_label



166
167
168
# File 'lib/models/external_connectors_property.rb', line 166

def labels
    return @labels
end

#labels=(value) ⇒ Object

Sets the labels property value. Specifies one or more well-known tags added against a property. Labels help Microsoft Search understand the semantics of the data in the connection. Adding appropriate labels would result in an enhanced search experience (e.g. better relevance). The possible values are: title, url, createdBy, lastModifiedBy, authors, createdDateTime, lastModifiedDateTime, fileName, fileExtension, unknownFutureValue. Optional.

Parameters:

  • value

    Value to set for the labels property.

Returns:

  • a void



174
175
176
# File 'lib/models/external_connectors_property.rb', line 174

def labels=(value)
    @labels = value
end

#nameObject

Gets the name property value. The name of the property. Maximum 32 characters. Only alphanumeric characters allowed. For example, each string may not contain control characters, whitespace, or any of the following: :, ;, ,, (, ), [, ], {, }, %, $, +, !, *, =, &, ?, @, #, /, ~, ‘, ’, <, >, ‘, ^. Required.

Returns:

  • a string



181
182
183
# File 'lib/models/external_connectors_property.rb', line 181

def name
    return @name
end

#name=(value) ⇒ Object

Sets the name property value. The name of the property. Maximum 32 characters. Only alphanumeric characters allowed. For example, each string may not contain control characters, whitespace, or any of the following: :, ;, ,, (, ), [, ], {, }, %, $, +, !, *, =, &, ?, @, #, /, ~, ‘, ’, <, >, ‘, ^. Required.

Parameters:

  • value

    Value to set for the name property.

Returns:

  • a void



189
190
191
# File 'lib/models/external_connectors_property.rb', line 189

def name=(value)
    @name = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



196
197
198
# File 'lib/models/external_connectors_property.rb', line 196

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



204
205
206
# File 'lib/models/external_connectors_property.rb', line 204

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/models/external_connectors_property.rb', line 212

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_primitive_values("aliases", @aliases)
    writer.write_boolean_value("isQueryable", @is_queryable)
    writer.write_boolean_value("isRefinable", @is_refinable)
    writer.write_boolean_value("isRetrievable", @is_retrievable)
    writer.write_boolean_value("isSearchable", @is_searchable)
    writer.write_collection_of_object_values("labels", @labels)
    writer.write_string_value("name", @name)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_enum_value("type", @type)
    writer.write_additional_data(@additional_data)
end

#typeObject

Gets the type property value. The type property

Returns:

  • a external_connectors_property_type



229
230
231
# File 'lib/models/external_connectors_property.rb', line 229

def type
    return @type
end

#type=(value) ⇒ Object

Sets the type property value. The type property

Parameters:

  • value

    Value to set for the type property.

Returns:

  • a void



237
238
239
# File 'lib/models/external_connectors_property.rb', line 237

def type=(value)
    @type = value
end