Class: MicrosoftGraph::Models::GroupMembers
- Inherits:
-
SubjectSet
- Object
- SubjectSet
- MicrosoftGraph::Models::GroupMembers
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/group_members.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#group_id ⇒ Object
Gets the groupId property value.
-
#group_id=(value) ⇒ Object
Sets the groupId property value.
-
#initialize ⇒ Object
constructor
Instantiates a new groupMembers and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from SubjectSet
#additional_data, #additional_data=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new groupMembers and sets the default values.
19 20 21 22 |
# File 'lib/models/group_members.rb', line 19 def initialize() super @odata_type = "#microsoft.graph.groupMembers" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
28 29 30 31 |
# File 'lib/models/group_members.rb', line 28 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GroupMembers.new end |
Instance Method Details
#description ⇒ Object
Gets the description property value. The name of the group in Azure AD. Read only.
36 37 38 |
# File 'lib/models/group_members.rb', line 36 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. The name of the group in Azure AD. Read only.
44 45 46 |
# File 'lib/models/group_members.rb', line 44 def description=(value) @description = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
51 52 53 54 55 56 |
# File 'lib/models/group_members.rb', line 51 def get_field_deserializers() return super.merge({ "description" => lambda {|n| @description = n.get_string_value() }, "groupId" => lambda {|n| @group_id = n.get_string_value() }, }) end |
#group_id ⇒ Object
Gets the groupId property value. The ID of the group in Azure AD.
61 62 63 |
# File 'lib/models/group_members.rb', line 61 def group_id return @group_id end |
#group_id=(value) ⇒ Object
Sets the groupId property value. The ID of the group in Azure AD.
69 70 71 |
# File 'lib/models/group_members.rb', line 69 def group_id=(value) @group_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
77 78 79 80 81 82 |
# File 'lib/models/group_members.rb', line 77 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("description", @description) writer.write_string_value("groupId", @group_id) end |