Class: MicrosoftGraph::Models::IdentityContainer

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/identity_container.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new identityContainer and sets the default values.



73
74
75
# File 'lib/models/identity_container.rb', line 73

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a identity_container

Raises:

  • (StandardError)


81
82
83
84
# File 'lib/models/identity_container.rb', line 81

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return IdentityContainer.new
end

Instance Method Details

#api_connectorsObject

Gets the apiConnectors property value. Represents entry point for API connectors.

Returns:

  • a identity_api_connector



28
29
30
# File 'lib/models/identity_container.rb', line 28

def api_connectors
    return @api_connectors
end

#api_connectors=(value) ⇒ Object

Sets the apiConnectors property value. Represents entry point for API connectors.

Parameters:

  • value

    Value to set for the apiConnectors property.

Returns:

  • a void



36
37
38
# File 'lib/models/identity_container.rb', line 36

def api_connectors=(value)
    @api_connectors = value
end

#b2x_user_flowsObject

Gets the b2xUserFlows property value. Represents entry point for B2X/self-service sign-up identity userflows.

Returns:

  • a b2x_identity_user_flow



43
44
45
# File 'lib/models/identity_container.rb', line 43

def b2x_user_flows
    return @b2x_user_flows
end

#b2x_user_flows=(value) ⇒ Object

Sets the b2xUserFlows property value. Represents entry point for B2X/self-service sign-up identity userflows.

Parameters:

  • value

    Value to set for the b2xUserFlows property.

Returns:

  • a void



51
52
53
# File 'lib/models/identity_container.rb', line 51

def b2x_user_flows=(value)
    @b2x_user_flows = value
end

#conditional_accessObject

Gets the conditionalAccess property value. the entry point for the Conditional Access (CA) object model.

Returns:

  • a conditional_access_root



58
59
60
# File 'lib/models/identity_container.rb', line 58

def conditional_access
    return @conditional_access
end

#conditional_access=(value) ⇒ Object

Sets the conditionalAccess property value. the entry point for the Conditional Access (CA) object model.

Parameters:

  • value

    Value to set for the conditionalAccess property.

Returns:

  • a void



66
67
68
# File 'lib/models/identity_container.rb', line 66

def conditional_access=(value)
    @conditional_access = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



89
90
91
92
93
94
95
96
97
# File 'lib/models/identity_container.rb', line 89

def get_field_deserializers()
    return super.merge({
        "apiConnectors" => lambda {|n| @api_connectors = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::IdentityApiConnector.create_from_discriminator_value(pn) }) },
        "b2xUserFlows" => lambda {|n| @b2x_user_flows = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::B2xIdentityUserFlow.create_from_discriminator_value(pn) }) },
        "conditionalAccess" => lambda {|n| @conditional_access = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ConditionalAccessRoot.create_from_discriminator_value(pn) }) },
        "identityProviders" => lambda {|n| @identity_providers = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::IdentityProviderBase.create_from_discriminator_value(pn) }) },
        "userFlowAttributes" => lambda {|n| @user_flow_attributes = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::IdentityUserFlowAttribute.create_from_discriminator_value(pn) }) },
    })
end

#identity_providersObject

Gets the identityProviders property value. The identityProviders property

Returns:

  • a identity_provider_base



102
103
104
# File 'lib/models/identity_container.rb', line 102

def identity_providers
    return @identity_providers
end

#identity_providers=(value) ⇒ Object

Sets the identityProviders property value. The identityProviders property

Parameters:

  • value

    Value to set for the identityProviders property.

Returns:

  • a void



110
111
112
# File 'lib/models/identity_container.rb', line 110

def identity_providers=(value)
    @identity_providers = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


118
119
120
121
122
123
124
125
126
# File 'lib/models/identity_container.rb', line 118

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("apiConnectors", @api_connectors)
    writer.write_collection_of_object_values("b2xUserFlows", @b2x_user_flows)
    writer.write_object_value("conditionalAccess", @conditional_access)
    writer.write_collection_of_object_values("identityProviders", @identity_providers)
    writer.write_collection_of_object_values("userFlowAttributes", @user_flow_attributes)
end

#user_flow_attributesObject

Gets the userFlowAttributes property value. Represents entry point for identity userflow attributes.

Returns:

  • a identity_user_flow_attribute



131
132
133
# File 'lib/models/identity_container.rb', line 131

def user_flow_attributes
    return @user_flow_attributes
end

#user_flow_attributes=(value) ⇒ Object

Sets the userFlowAttributes property value. Represents entry point for identity userflow attributes.

Parameters:

  • value

    Value to set for the userFlowAttributes property.

Returns:

  • a void



139
140
141
# File 'lib/models/identity_container.rb', line 139

def user_flow_attributes=(value)
    @user_flow_attributes = value
end