Class: MicrosoftGraph::Models::IdentityGovernanceModelModelModelModelModelModel
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::IdentityGovernanceModelModelModelModelModelModel
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/identity_governance_model_model_model_model_model_model.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#access_reviews ⇒ Object
Gets the accessReviews property value.
-
#access_reviews=(value) ⇒ Object
Sets the accessReviews property value.
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#app_consent ⇒ Object
Gets the appConsent property value.
-
#app_consent=(value) ⇒ Object
Sets the appConsent property value.
-
#entitlement_management ⇒ Object
Gets the entitlementManagement property value.
-
#entitlement_management=(value) ⇒ Object
Sets the entitlementManagement property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new identityGovernanceModelModelModelModelModelModel and sets the default values.
-
#lifecycle_workflows ⇒ Object
Gets the lifecycleWorkflows property value.
-
#lifecycle_workflows=(value) ⇒ Object
Sets the lifecycleWorkflows property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#terms_of_use ⇒ Object
Gets the termsOfUse property value.
-
#terms_of_use=(value) ⇒ Object
Sets the termsOfUse property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new identityGovernanceModelModelModelModelModelModel and sets the default values.
79 80 81 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 79 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
87 88 89 90 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 87 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return IdentityGovernanceModelModelModelModelModelModel.new end |
Instance Method Details
#access_reviews ⇒ Object
Gets the accessReviews property value. The accessReviews property
34 35 36 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 34 def access_reviews return @access_reviews end |
#access_reviews=(value) ⇒ Object
Sets the accessReviews property value. The accessReviews property
42 43 44 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 42 def access_reviews=(value) @access_reviews = value end |
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
49 50 51 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 49 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
57 58 59 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 57 def additional_data=(value) @additional_data = value end |
#app_consent ⇒ Object
Gets the appConsent property value. The appConsent property
64 65 66 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 64 def return end |
#app_consent=(value) ⇒ Object
Sets the appConsent property value. The appConsent property
72 73 74 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 72 def (value) = value end |
#entitlement_management ⇒ Object
Gets the entitlementManagement property value. The entitlementManagement property
95 96 97 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 95 def entitlement_management return @entitlement_management end |
#entitlement_management=(value) ⇒ Object
Sets the entitlementManagement property value. The entitlementManagement property
103 104 105 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 103 def entitlement_management=(value) @entitlement_management = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 110 def get_field_deserializers() return { "accessReviews" => lambda {|n| @access_reviews = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AccessReviewSet.create_from_discriminator_value(pn) }) }, "appConsent" => lambda {|n| = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AppConsentApprovalRoute.create_from_discriminator_value(pn) }) }, "entitlementManagement" => lambda {|n| @entitlement_management = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::EntitlementManagement.create_from_discriminator_value(pn) }) }, "lifecycleWorkflows" => lambda {|n| @lifecycle_workflows = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentityGovernanceLifecycleWorkflowsContainer.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "termsOfUse" => lambda {|n| @terms_of_use = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TermsOfUseContainer.create_from_discriminator_value(pn) }) }, } end |
#lifecycle_workflows ⇒ Object
Gets the lifecycleWorkflows property value. The lifecycleWorkflows property
124 125 126 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 124 def lifecycle_workflows return @lifecycle_workflows end |
#lifecycle_workflows=(value) ⇒ Object
Sets the lifecycleWorkflows property value. The lifecycleWorkflows property
132 133 134 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 132 def lifecycle_workflows=(value) @lifecycle_workflows = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
139 140 141 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 139 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
147 148 149 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 147 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 155 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("accessReviews", @access_reviews) writer.write_object_value("appConsent", ) writer.write_object_value("entitlementManagement", @entitlement_management) writer.write_object_value("lifecycleWorkflows", @lifecycle_workflows) writer.write_string_value("@odata.type", @odata_type) writer.write_object_value("termsOfUse", @terms_of_use) writer.write_additional_data(@additional_data) end |
#terms_of_use ⇒ Object
Gets the termsOfUse property value. The termsOfUse property
169 170 171 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 169 def terms_of_use return @terms_of_use end |
#terms_of_use=(value) ⇒ Object
Sets the termsOfUse property value. The termsOfUse property
177 178 179 |
# File 'lib/models/identity_governance_model_model_model_model_model_model.rb', line 177 def terms_of_use=(value) @terms_of_use = value end |