Class: MicrosoftGraph::Models::IdentityGovernanceRuleBasedSubjectSet

Inherits:
SubjectSet
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/identity_governance_rule_based_subject_set.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from SubjectSet

#additional_data, #additional_data=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new identityGovernanceRuleBasedSubjectSet and sets the default values.



16
17
18
19
# File 'lib/models/identity_governance_rule_based_subject_set.rb', line 16

def initialize()
    super
    @odata_type = "#microsoft.graph.identityGovernance.ruleBasedSubjectSet"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a identity_governance_rule_based_subject_set

Raises:

  • (StandardError)


25
26
27
28
# File 'lib/models/identity_governance_rule_based_subject_set.rb', line 25

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return IdentityGovernanceRuleBasedSubjectSet.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



33
34
35
36
37
# File 'lib/models/identity_governance_rule_based_subject_set.rb', line 33

def get_field_deserializers()
    return super.merge({
        "rule" => lambda {|n| @rule = n.get_string_value() },
    })
end

#ruleObject

Gets the rule property value. The rule for the subject set. Lifecycle Workflows supports a rich set of user properties for configuring the rules using $filter query expressions. For more information, see supported user and query parameters.

Returns:

  • a string



42
43
44
# File 'lib/models/identity_governance_rule_based_subject_set.rb', line 42

def rule
    return @rule
end

#rule=(value) ⇒ Object

Sets the rule property value. The rule for the subject set. Lifecycle Workflows supports a rich set of user properties for configuring the rules using $filter query expressions. For more information, see supported user and query parameters.

Parameters:

  • value

    Value to set for the rule property.

Returns:

  • a void



50
51
52
# File 'lib/models/identity_governance_rule_based_subject_set.rb', line 50

def rule=(value)
    @rule = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


58
59
60
61
62
# File 'lib/models/identity_governance_rule_based_subject_set.rb', line 58

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("rule", @rule)
end