Class: MicrosoftGraph::Models::IdentityGovernanceTriggerAndScopeBasedConditions

Inherits:
IdentityGovernanceWorkflowExecutionConditions show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/identity_governance_trigger_and_scope_based_conditions.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from IdentityGovernanceWorkflowExecutionConditions

#additional_data, #additional_data=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new identityGovernanceTriggerAndScopeBasedConditions and sets the default values.



19
20
21
22
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 19

def initialize()
    super
    @odata_type = "#microsoft.graph.identityGovernance.triggerAndScopeBasedConditions"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a identity_governance_trigger_and_scope_based_conditions

Raises:

  • (StandardError)


28
29
30
31
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 28

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return IdentityGovernanceTriggerAndScopeBasedConditions.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



36
37
38
39
40
41
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 36

def get_field_deserializers()
    return super.merge({
        "scope" => lambda {|n| @scope = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SubjectSet.create_from_discriminator_value(pn) }) },
        "trigger" => lambda {|n| @trigger = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentityGovernanceWorkflowExecutionTrigger.create_from_discriminator_value(pn) }) },
    })
end

#scopeObject

Gets the scope property value. Defines who the workflow runs for.

Returns:

  • a subject_set



46
47
48
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 46

def scope
    return @scope
end

#scope=(value) ⇒ Object

Sets the scope property value. Defines who the workflow runs for.

Parameters:

  • value

    Value to set for the scope property.

Returns:

  • a void



54
55
56
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 54

def scope=(value)
    @scope = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


62
63
64
65
66
67
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 62

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("scope", @scope)
    writer.write_object_value("trigger", @trigger)
end

#triggerObject

Gets the trigger property value. What triggers a workflow to run.

Returns:

  • a identity_governance_workflow_execution_trigger



72
73
74
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 72

def trigger
    return @trigger
end

#trigger=(value) ⇒ Object

Sets the trigger property value. What triggers a workflow to run.

Parameters:

  • value

    Value to set for the trigger property.

Returns:

  • a void



80
81
82
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 80

def trigger=(value)
    @trigger = value
end