Class: MicrosoftGraph::Models::IdleSessionSignOut

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/idle_session_sign_out.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new idleSessionSignOut and sets the default values.



43
44
45
# File 'lib/models/idle_session_sign_out.rb', line 43

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a idle_session_sign_out

Raises:

  • (StandardError)


51
52
53
54
# File 'lib/models/idle_session_sign_out.rb', line 51

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return IdleSessionSignOut.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



28
29
30
# File 'lib/models/idle_session_sign_out.rb', line 28

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



36
37
38
# File 'lib/models/idle_session_sign_out.rb', line 36

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



59
60
61
62
63
64
65
66
# File 'lib/models/idle_session_sign_out.rb', line 59

def get_field_deserializers()
    return {
        "isEnabled" => lambda {|n| @is_enabled = n.get_boolean_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "signOutAfterInSeconds" => lambda {|n| @sign_out_after_in_seconds = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) },
        "warnAfterInSeconds" => lambda {|n| @warn_after_in_seconds = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) },
    }
end

#is_enabledObject

Gets the isEnabled property value. Indicates whether the idle session sign-out policy is enabled.

Returns:

  • a boolean



71
72
73
# File 'lib/models/idle_session_sign_out.rb', line 71

def is_enabled
    return @is_enabled
end

#is_enabled=(value) ⇒ Object

Sets the isEnabled property value. Indicates whether the idle session sign-out policy is enabled.

Parameters:

  • value

    Value to set for the isEnabled property.

Returns:

  • a void



79
80
81
# File 'lib/models/idle_session_sign_out.rb', line 79

def is_enabled=(value)
    @is_enabled = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



86
87
88
# File 'lib/models/idle_session_sign_out.rb', line 86

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



94
95
96
# File 'lib/models/idle_session_sign_out.rb', line 94

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


102
103
104
105
106
107
108
109
# File 'lib/models/idle_session_sign_out.rb', line 102

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_boolean_value("isEnabled", @is_enabled)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_object_value("signOutAfterInSeconds", @sign_out_after_in_seconds)
    writer.write_object_value("warnAfterInSeconds", @warn_after_in_seconds)
    writer.write_additional_data(@additional_data)
end

#sign_out_after_in_secondsObject

Gets the signOutAfterInSeconds property value. Number of seconds of inactivity after which a user is signed out.

Returns:

  • a int64



114
115
116
# File 'lib/models/idle_session_sign_out.rb', line 114

def sign_out_after_in_seconds
    return @sign_out_after_in_seconds
end

#sign_out_after_in_seconds=(value) ⇒ Object

Sets the signOutAfterInSeconds property value. Number of seconds of inactivity after which a user is signed out.

Parameters:

  • value

    Value to set for the signOutAfterInSeconds property.

Returns:

  • a void



122
123
124
# File 'lib/models/idle_session_sign_out.rb', line 122

def sign_out_after_in_seconds=(value)
    @sign_out_after_in_seconds = value
end

#warn_after_in_secondsObject

Gets the warnAfterInSeconds property value. Number of seconds of inactivity after which a user is notified that they’ll be signed out.

Returns:

  • a int64



129
130
131
# File 'lib/models/idle_session_sign_out.rb', line 129

def warn_after_in_seconds
    return @warn_after_in_seconds
end

#warn_after_in_seconds=(value) ⇒ Object

Sets the warnAfterInSeconds property value. Number of seconds of inactivity after which a user is notified that they’ll be signed out.

Parameters:

  • value

    Value to set for the warnAfterInSeconds property.

Returns:

  • a void



137
138
139
# File 'lib/models/idle_session_sign_out.rb', line 137

def warn_after_in_seconds=(value)
    @warn_after_in_seconds = value
end