Class: MicrosoftGraph::Models::ImportedWindowsAutopilotDeviceIdentityState
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::ImportedWindowsAutopilotDeviceIdentityState
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/imported_windows_autopilot_device_identity_state.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#device_error_code ⇒ Object
Gets the deviceErrorCode property value.
-
#device_error_code=(value) ⇒ Object
Sets the deviceErrorCode property value.
-
#device_error_name ⇒ Object
Gets the deviceErrorName property value.
-
#device_error_name=(value) ⇒ Object
Sets the deviceErrorName property value.
-
#device_import_status ⇒ Object
Gets the deviceImportStatus property value.
-
#device_import_status=(value) ⇒ Object
Sets the deviceImportStatus property value.
-
#device_registration_id ⇒ Object
Gets the deviceRegistrationId property value.
-
#device_registration_id=(value) ⇒ Object
Sets the deviceRegistrationId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new importedWindowsAutopilotDeviceIdentityState and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new importedWindowsAutopilotDeviceIdentityState and sets the default values.
46 47 48 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 46 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
54 55 56 57 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 54 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ImportedWindowsAutopilotDeviceIdentityState.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 39 def additional_data=(value) @additional_data = value end |
#device_error_code ⇒ Object
Gets the deviceErrorCode property value. Device error code reported by Device Directory Service(DDS).
62 63 64 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 62 def device_error_code return @device_error_code end |
#device_error_code=(value) ⇒ Object
Sets the deviceErrorCode property value. Device error code reported by Device Directory Service(DDS).
70 71 72 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 70 def device_error_code=(value) @device_error_code = value end |
#device_error_name ⇒ Object
Gets the deviceErrorName property value. Device error name reported by Device Directory Service(DDS).
77 78 79 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 77 def device_error_name return @device_error_name end |
#device_error_name=(value) ⇒ Object
Sets the deviceErrorName property value. Device error name reported by Device Directory Service(DDS).
85 86 87 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 85 def device_error_name=(value) @device_error_name = value end |
#device_import_status ⇒ Object
Gets the deviceImportStatus property value. The deviceImportStatus property
92 93 94 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 92 def device_import_status return @device_import_status end |
#device_import_status=(value) ⇒ Object
Sets the deviceImportStatus property value. The deviceImportStatus property
100 101 102 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 100 def device_import_status=(value) @device_import_status = value end |
#device_registration_id ⇒ Object
Gets the deviceRegistrationId property value. Device Registration ID for successfully added device reported by Device Directory Service(DDS).
107 108 109 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 107 def device_registration_id return @device_registration_id end |
#device_registration_id=(value) ⇒ Object
Sets the deviceRegistrationId property value. Device Registration ID for successfully added device reported by Device Directory Service(DDS).
115 116 117 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 115 def device_registration_id=(value) @device_registration_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
122 123 124 125 126 127 128 129 130 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 122 def get_field_deserializers() return { "deviceErrorCode" => lambda {|n| @device_error_code = n.get_number_value() }, "deviceErrorName" => lambda {|n| @device_error_name = n.get_string_value() }, "deviceImportStatus" => lambda {|n| @device_import_status = n.get_enum_value(MicrosoftGraph::Models::ImportedWindowsAutopilotDeviceIdentityImportStatus) }, "deviceRegistrationId" => lambda {|n| @device_registration_id = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
135 136 137 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 135 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
143 144 145 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 143 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
151 152 153 154 155 156 157 158 159 |
# File 'lib/models/imported_windows_autopilot_device_identity_state.rb', line 151 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("deviceErrorCode", @device_error_code) writer.write_string_value("deviceErrorName", @device_error_name) writer.write_enum_value("deviceImportStatus", @device_import_status) writer.write_string_value("deviceRegistrationId", @device_registration_id) writer.write_string_value("@odata.type", @odata_type) writer.write_additional_data(@additional_data) end |