Class: MicrosoftGraph::Models::JoinMeetingIdMeetingInfo
- Inherits:
-
MeetingInfo
- Object
- MeetingInfo
- MicrosoftGraph::Models::JoinMeetingIdMeetingInfo
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/join_meeting_id_meeting_info.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new joinMeetingIdMeetingInfo and sets the default values.
-
#join_meeting_id ⇒ Object
Gets the joinMeetingId property value.
-
#join_meeting_id=(value) ⇒ Object
Sets the joinMeetingId property value.
-
#passcode ⇒ Object
Gets the passcode property value.
-
#passcode=(value) ⇒ Object
Sets the passcode property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from MeetingInfo
#additional_data, #additional_data=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new joinMeetingIdMeetingInfo and sets the default values.
19 20 21 22 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 19 def initialize() super @odata_type = "#microsoft.graph.joinMeetingIdMeetingInfo" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
28 29 30 31 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 28 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return JoinMeetingIdMeetingInfo.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
36 37 38 39 40 41 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 36 def get_field_deserializers() return super.merge({ "joinMeetingId" => lambda {|n| @join_meeting_id = n.get_string_value() }, "passcode" => lambda {|n| @passcode = n.get_string_value() }, }) end |
#join_meeting_id ⇒ Object
Gets the joinMeetingId property value. The ID used to join the meeting.
46 47 48 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 46 def join_meeting_id return @join_meeting_id end |
#join_meeting_id=(value) ⇒ Object
Sets the joinMeetingId property value. The ID used to join the meeting.
54 55 56 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 54 def join_meeting_id=(value) @join_meeting_id = value end |
#passcode ⇒ Object
Gets the passcode property value. The passcode used to join the meeting. Optional.
61 62 63 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 61 def passcode return @passcode end |
#passcode=(value) ⇒ Object
Sets the passcode property value. The passcode used to join the meeting. Optional.
69 70 71 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 69 def passcode=(value) @passcode = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
77 78 79 80 81 82 |
# File 'lib/models/join_meeting_id_meeting_info.rb', line 77 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("joinMeetingId", @join_meeting_id) writer.write_string_value("passcode", @passcode) end |