Class: MicrosoftGraph::Models::MacOSLobChildApp
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::MacOSLobChildApp
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/mac_o_s_lob_child_app.rb
Overview
Contains properties of a macOS .app in the package
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#build_number ⇒ Object
Gets the buildNumber property value.
-
#build_number=(value) ⇒ Object
Sets the buildNumber property value.
-
#bundle_id ⇒ Object
Gets the bundleId property value.
-
#bundle_id=(value) ⇒ Object
Sets the bundleId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new macOSLobChildApp and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#version_number ⇒ Object
Gets the versionNumber property value.
-
#version_number=(value) ⇒ Object
Sets the versionNumber property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new macOSLobChildApp and sets the default values.
75 76 77 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 75 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
83 84 85 86 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 83 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MacOSLobChildApp.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 30 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 38 def additional_data=(value) @additional_data = value end |
#build_number ⇒ Object
Gets the buildNumber property value. The build number of the app.
45 46 47 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 45 def build_number return @build_number end |
#build_number=(value) ⇒ Object
Sets the buildNumber property value. The build number of the app.
53 54 55 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 53 def build_number=(value) @build_number = value end |
#bundle_id ⇒ Object
Gets the bundleId property value. The bundleId of the app.
60 61 62 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 60 def bundle_id return @bundle_id end |
#bundle_id=(value) ⇒ Object
Sets the bundleId property value. The bundleId of the app.
68 69 70 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 68 def bundle_id=(value) @bundle_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
91 92 93 94 95 96 97 98 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 91 def get_field_deserializers() return { "buildNumber" => lambda {|n| @build_number = n.get_string_value() }, "bundleId" => lambda {|n| @bundle_id = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "versionNumber" => lambda {|n| @version_number = n.get_string_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
103 104 105 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 103 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
111 112 113 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 111 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
119 120 121 122 123 124 125 126 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 119 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("buildNumber", @build_number) writer.write_string_value("bundleId", @bundle_id) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("versionNumber", @version_number) writer.write_additional_data(@additional_data) end |
#version_number ⇒ Object
Gets the versionNumber property value. The version number of the app.
131 132 133 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 131 def version_number return @version_number end |
#version_number=(value) ⇒ Object
Sets the versionNumber property value. The version number of the app.
139 140 141 |
# File 'lib/models/mac_o_s_lob_child_app.rb', line 139 def version_number=(value) @version_number = value end |