Class: MicrosoftGraph::Models::ManagedAppDiagnosticStatus

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/managed_app_diagnostic_status.rb

Overview

Represents diagnostics status.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new managedAppDiagnosticStatus and sets the default values.



45
46
47
# File 'lib/models/managed_app_diagnostic_status.rb', line 45

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a managed_app_diagnostic_status

Raises:

  • (StandardError)


53
54
55
56
# File 'lib/models/managed_app_diagnostic_status.rb', line 53

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ManagedAppDiagnosticStatus.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



30
31
32
# File 'lib/models/managed_app_diagnostic_status.rb', line 30

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



38
39
40
# File 'lib/models/managed_app_diagnostic_status.rb', line 38

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



61
62
63
64
65
66
67
68
# File 'lib/models/managed_app_diagnostic_status.rb', line 61

def get_field_deserializers()
    return {
        "mitigationInstruction" => lambda {|n| @mitigation_instruction = n.get_string_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "state" => lambda {|n| @state = n.get_string_value() },
        "validationName" => lambda {|n| @validation_name = n.get_string_value() },
    }
end

#mitigation_instructionObject

Gets the mitigationInstruction property value. Instruction on how to mitigate a failed validation

Returns:

  • a string



73
74
75
# File 'lib/models/managed_app_diagnostic_status.rb', line 73

def mitigation_instruction
    return @mitigation_instruction
end

#mitigation_instruction=(value) ⇒ Object

Sets the mitigationInstruction property value. Instruction on how to mitigate a failed validation

Parameters:

  • value

    Value to set for the mitigationInstruction property.

Returns:

  • a void



81
82
83
# File 'lib/models/managed_app_diagnostic_status.rb', line 81

def mitigation_instruction=(value)
    @mitigation_instruction = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



88
89
90
# File 'lib/models/managed_app_diagnostic_status.rb', line 88

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



96
97
98
# File 'lib/models/managed_app_diagnostic_status.rb', line 96

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


104
105
106
107
108
109
110
111
# File 'lib/models/managed_app_diagnostic_status.rb', line 104

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("mitigationInstruction", @mitigation_instruction)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_string_value("state", @state)
    writer.write_string_value("validationName", @validation_name)
    writer.write_additional_data(@additional_data)
end

#stateObject

Gets the state property value. The state of the operation

Returns:

  • a string



116
117
118
# File 'lib/models/managed_app_diagnostic_status.rb', line 116

def state
    return @state
end

#state=(value) ⇒ Object

Sets the state property value. The state of the operation

Parameters:

  • value

    Value to set for the state property.

Returns:

  • a void



124
125
126
# File 'lib/models/managed_app_diagnostic_status.rb', line 124

def state=(value)
    @state = value
end

#validation_nameObject

Gets the validationName property value. The validation friendly name

Returns:

  • a string



131
132
133
# File 'lib/models/managed_app_diagnostic_status.rb', line 131

def validation_name
    return @validation_name
end

#validation_name=(value) ⇒ Object

Sets the validationName property value. The validation friendly name

Parameters:

  • value

    Value to set for the validationName property.

Returns:

  • a void



139
140
141
# File 'lib/models/managed_app_diagnostic_status.rb', line 139

def validation_name=(value)
    @validation_name = value
end