Class: MicrosoftGraph::Models::ManagedAppRegistration

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/managed_app_registration.rb

Overview

The ManagedAppEntity is the base entity type for all other entity types under app management workflow.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new managedAppRegistration and sets the default values.



106
107
108
# File 'lib/models/managed_app_registration.rb', line 106

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a managed_app_registration

Raises:

  • (StandardError)


129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/models/managed_app_registration.rb', line 129

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    mapping_value_node = parse_node.get_child_node("@odata.type")
    unless mapping_value_node.nil? then
        mapping_value = mapping_value_node.get_string_value
        case mapping_value
            when "#microsoft.graph.androidManagedAppRegistration"
                return AndroidManagedAppRegistration.new
            when "#microsoft.graph.iosManagedAppRegistration"
                return IosManagedAppRegistration.new
        end
    end
    return ManagedAppRegistration.new
end

Instance Method Details

#app_identifierObject

Gets the appIdentifier property value. The app package Identifier

Returns:

  • a mobile_app_identifier



61
62
63
# File 'lib/models/managed_app_registration.rb', line 61

def app_identifier
    return @app_identifier
end

#app_identifier=(value) ⇒ Object

Sets the appIdentifier property value. The app package Identifier

Parameters:

  • value

    Value to set for the appIdentifier property.

Returns:

  • a void



69
70
71
# File 'lib/models/managed_app_registration.rb', line 69

def app_identifier=(value)
    @app_identifier = value
end

#application_versionObject

Gets the applicationVersion property value. App version

Returns:

  • a string



76
77
78
# File 'lib/models/managed_app_registration.rb', line 76

def application_version
    return @application_version
end

#application_version=(value) ⇒ Object

Sets the applicationVersion property value. App version

Parameters:

  • value

    Value to set for the applicationVersion property.

Returns:

  • a void



84
85
86
# File 'lib/models/managed_app_registration.rb', line 84

def application_version=(value)
    @application_version = value
end

#applied_policiesObject

Gets the appliedPolicies property value. Zero or more policys already applied on the registered app when it last synchronized with managment service.

Returns:

  • a managed_app_policy



91
92
93
# File 'lib/models/managed_app_registration.rb', line 91

def applied_policies
    return @applied_policies
end

#applied_policies=(value) ⇒ Object

Sets the appliedPolicies property value. Zero or more policys already applied on the registered app when it last synchronized with managment service.

Parameters:

  • value

    Value to set for the appliedPolicies property.

Returns:

  • a void



99
100
101
# File 'lib/models/managed_app_registration.rb', line 99

def applied_policies=(value)
    @applied_policies = value
end

#created_date_timeObject

Gets the createdDateTime property value. Date and time of creation

Returns:

  • a date_time



113
114
115
# File 'lib/models/managed_app_registration.rb', line 113

def created_date_time
    return @created_date_time
end

#created_date_time=(value) ⇒ Object

Sets the createdDateTime property value. Date and time of creation

Parameters:

  • value

    Value to set for the createdDateTime property.

Returns:

  • a void



121
122
123
# File 'lib/models/managed_app_registration.rb', line 121

def created_date_time=(value)
    @created_date_time = value
end

#device_nameObject

Gets the deviceName property value. Host device name

Returns:

  • a string



147
148
149
# File 'lib/models/managed_app_registration.rb', line 147

def device_name
    return @device_name
end

#device_name=(value) ⇒ Object

Sets the deviceName property value. Host device name

Parameters:

  • value

    Value to set for the deviceName property.

Returns:

  • a void



155
156
157
# File 'lib/models/managed_app_registration.rb', line 155

def device_name=(value)
    @device_name = value
end

#device_tagObject

Gets the deviceTag property value. App management SDK generated tag, which helps relate apps hosted on the same device. Not guaranteed to relate apps in all conditions.

Returns:

  • a string



162
163
164
# File 'lib/models/managed_app_registration.rb', line 162

def device_tag
    return @device_tag
end

#device_tag=(value) ⇒ Object

Sets the deviceTag property value. App management SDK generated tag, which helps relate apps hosted on the same device. Not guaranteed to relate apps in all conditions.

Parameters:

  • value

    Value to set for the deviceTag property.

Returns:

  • a void



170
171
172
# File 'lib/models/managed_app_registration.rb', line 170

def device_tag=(value)
    @device_tag = value
end

#device_typeObject

Gets the deviceType property value. Host device type

Returns:

  • a string



177
178
179
# File 'lib/models/managed_app_registration.rb', line 177

def device_type
    return @device_type
end

#device_type=(value) ⇒ Object

Sets the deviceType property value. Host device type

Parameters:

  • value

    Value to set for the deviceType property.

Returns:

  • a void



185
186
187
# File 'lib/models/managed_app_registration.rb', line 185

def device_type=(value)
    @device_type = value
end

#flagged_reasonsObject

Gets the flaggedReasons property value. Zero or more reasons an app registration is flagged. E.g. app running on rooted device

Returns:

  • a managed_app_flagged_reason



192
193
194
# File 'lib/models/managed_app_registration.rb', line 192

def flagged_reasons
    return @flagged_reasons
end

#flagged_reasons=(value) ⇒ Object

Sets the flaggedReasons property value. Zero or more reasons an app registration is flagged. E.g. app running on rooted device

Parameters:

  • value

    Value to set for the flaggedReasons property.

Returns:

  • a void



200
201
202
# File 'lib/models/managed_app_registration.rb', line 200

def flagged_reasons=(value)
    @flagged_reasons = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/models/managed_app_registration.rb', line 207

def get_field_deserializers()
    return super.merge({
        "appIdentifier" => lambda {|n| @app_identifier = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::MobileAppIdentifier.create_from_discriminator_value(pn) }) },
        "applicationVersion" => lambda {|n| @application_version = n.get_string_value() },
        "appliedPolicies" => lambda {|n| @applied_policies = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ManagedAppPolicy.create_from_discriminator_value(pn) }) },
        "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() },
        "deviceName" => lambda {|n| @device_name = n.get_string_value() },
        "deviceTag" => lambda {|n| @device_tag = n.get_string_value() },
        "deviceType" => lambda {|n| @device_type = n.get_string_value() },
        "flaggedReasons" => lambda {|n| @flagged_reasons = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ManagedAppFlaggedReason.create_from_discriminator_value(pn) }) },
        "intendedPolicies" => lambda {|n| @intended_policies = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ManagedAppPolicy.create_from_discriminator_value(pn) }) },
        "lastSyncDateTime" => lambda {|n| @last_sync_date_time = n.get_date_time_value() },
        "managementSdkVersion" => lambda {|n| @management_sdk_version = n.get_string_value() },
        "operations" => lambda {|n| @operations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ManagedAppOperation.create_from_discriminator_value(pn) }) },
        "platformVersion" => lambda {|n| @platform_version = n.get_string_value() },
        "userId" => lambda {|n| @user_id = n.get_string_value() },
        "version" => lambda {|n| @version = n.get_string_value() },
    })
end

#intended_policiesObject

Gets the intendedPolicies property value. Zero or more policies admin intended for the app as of now.

Returns:

  • a managed_app_policy



230
231
232
# File 'lib/models/managed_app_registration.rb', line 230

def intended_policies
    return @intended_policies
end

#intended_policies=(value) ⇒ Object

Sets the intendedPolicies property value. Zero or more policies admin intended for the app as of now.

Parameters:

  • value

    Value to set for the intendedPolicies property.

Returns:

  • a void



238
239
240
# File 'lib/models/managed_app_registration.rb', line 238

def intended_policies=(value)
    @intended_policies = value
end

#last_sync_date_timeObject

Gets the lastSyncDateTime property value. Date and time of last the app synced with management service.

Returns:

  • a date_time



245
246
247
# File 'lib/models/managed_app_registration.rb', line 245

def last_sync_date_time
    return @last_sync_date_time
end

#last_sync_date_time=(value) ⇒ Object

Sets the lastSyncDateTime property value. Date and time of last the app synced with management service.

Parameters:

  • value

    Value to set for the lastSyncDateTime property.

Returns:

  • a void



253
254
255
# File 'lib/models/managed_app_registration.rb', line 253

def last_sync_date_time=(value)
    @last_sync_date_time = value
end

#management_sdk_versionObject

Gets the managementSdkVersion property value. App management SDK version

Returns:

  • a string



260
261
262
# File 'lib/models/managed_app_registration.rb', line 260

def management_sdk_version
    return @management_sdk_version
end

#management_sdk_version=(value) ⇒ Object

Sets the managementSdkVersion property value. App management SDK version

Parameters:

  • value

    Value to set for the managementSdkVersion property.

Returns:

  • a void



268
269
270
# File 'lib/models/managed_app_registration.rb', line 268

def management_sdk_version=(value)
    @management_sdk_version = value
end

#operationsObject

Gets the operations property value. Zero or more long running operations triggered on the app registration.

Returns:

  • a managed_app_operation



275
276
277
# File 'lib/models/managed_app_registration.rb', line 275

def operations
    return @operations
end

#operations=(value) ⇒ Object

Sets the operations property value. Zero or more long running operations triggered on the app registration.

Parameters:

  • value

    Value to set for the operations property.

Returns:

  • a void



283
284
285
# File 'lib/models/managed_app_registration.rb', line 283

def operations=(value)
    @operations = value
end

#platform_versionObject

Gets the platformVersion property value. Operating System version

Returns:

  • a string



290
291
292
# File 'lib/models/managed_app_registration.rb', line 290

def platform_version
    return @platform_version
end

#platform_version=(value) ⇒ Object

Sets the platformVersion property value. Operating System version

Parameters:

  • value

    Value to set for the platformVersion property.

Returns:

  • a void



298
299
300
# File 'lib/models/managed_app_registration.rb', line 298

def platform_version=(value)
    @platform_version = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/models/managed_app_registration.rb', line 306

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("appIdentifier", @app_identifier)
    writer.write_string_value("applicationVersion", @application_version)
    writer.write_collection_of_object_values("appliedPolicies", @applied_policies)
    writer.write_date_time_value("createdDateTime", @created_date_time)
    writer.write_string_value("deviceName", @device_name)
    writer.write_string_value("deviceTag", @device_tag)
    writer.write_string_value("deviceType", @device_type)
    writer.write_collection_of_object_values("flaggedReasons", @flagged_reasons)
    writer.write_collection_of_object_values("intendedPolicies", @intended_policies)
    writer.write_date_time_value("lastSyncDateTime", @last_sync_date_time)
    writer.write_string_value("managementSdkVersion", @management_sdk_version)
    writer.write_collection_of_object_values("operations", @operations)
    writer.write_string_value("platformVersion", @platform_version)
    writer.write_string_value("userId", @user_id)
    writer.write_string_value("version", @version)
end

#user_idObject

Gets the userId property value. The user Id to who this app registration belongs.

Returns:

  • a string



329
330
331
# File 'lib/models/managed_app_registration.rb', line 329

def user_id
    return @user_id
end

#user_id=(value) ⇒ Object

Sets the userId property value. The user Id to who this app registration belongs.

Parameters:

  • value

    Value to set for the userId property.

Returns:

  • a void



337
338
339
# File 'lib/models/managed_app_registration.rb', line 337

def user_id=(value)
    @user_id = value
end

#versionObject

Gets the version property value. Version of the entity.

Returns:

  • a string



344
345
346
# File 'lib/models/managed_app_registration.rb', line 344

def version
    return @version
end

#version=(value) ⇒ Object

Sets the version property value. Version of the entity.

Parameters:

  • value

    Value to set for the version property.

Returns:

  • a void



352
353
354
# File 'lib/models/managed_app_registration.rb', line 352

def version=(value)
    @version = value
end