Class: MicrosoftGraph::Models::MeetingAttendanceReport

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/meeting_attendance_report.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new meetingAttendanceReport and sets the default values.



41
42
43
# File 'lib/models/meeting_attendance_report.rb', line 41

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a meeting_attendance_report

Raises:

  • (StandardError)


49
50
51
52
# File 'lib/models/meeting_attendance_report.rb', line 49

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return MeetingAttendanceReport.new
end

Instance Method Details

#attendance_recordsObject

Gets the attendanceRecords property value. List of attendance records of an attendance report. Read-only.

Returns:

  • a attendance_record



26
27
28
# File 'lib/models/meeting_attendance_report.rb', line 26

def attendance_records
    return @attendance_records
end

#attendance_records=(value) ⇒ Object

Sets the attendanceRecords property value. List of attendance records of an attendance report. Read-only.

Parameters:

  • value

    Value to set for the attendanceRecords property.

Returns:

  • a void



34
35
36
# File 'lib/models/meeting_attendance_report.rb', line 34

def attendance_records=(value)
    @attendance_records = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



57
58
59
60
61
62
63
64
# File 'lib/models/meeting_attendance_report.rb', line 57

def get_field_deserializers()
    return super.merge({
        "attendanceRecords" => lambda {|n| @attendance_records = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AttendanceRecord.create_from_discriminator_value(pn) }) },
        "meetingEndDateTime" => lambda {|n| @meeting_end_date_time = n.get_date_time_value() },
        "meetingStartDateTime" => lambda {|n| @meeting_start_date_time = n.get_date_time_value() },
        "totalParticipantCount" => lambda {|n| @total_participant_count = n.get_number_value() },
    })
end

#meeting_end_date_timeObject

Gets the meetingEndDateTime property value. UTC time when the meeting ended. Read-only.

Returns:

  • a date_time



69
70
71
# File 'lib/models/meeting_attendance_report.rb', line 69

def meeting_end_date_time
    return @meeting_end_date_time
end

#meeting_end_date_time=(value) ⇒ Object

Sets the meetingEndDateTime property value. UTC time when the meeting ended. Read-only.

Parameters:

  • value

    Value to set for the meetingEndDateTime property.

Returns:

  • a void



77
78
79
# File 'lib/models/meeting_attendance_report.rb', line 77

def meeting_end_date_time=(value)
    @meeting_end_date_time = value
end

#meeting_start_date_timeObject

Gets the meetingStartDateTime property value. UTC time when the meeting started. Read-only.

Returns:

  • a date_time



84
85
86
# File 'lib/models/meeting_attendance_report.rb', line 84

def meeting_start_date_time
    return @meeting_start_date_time
end

#meeting_start_date_time=(value) ⇒ Object

Sets the meetingStartDateTime property value. UTC time when the meeting started. Read-only.

Parameters:

  • value

    Value to set for the meetingStartDateTime property.

Returns:

  • a void



92
93
94
# File 'lib/models/meeting_attendance_report.rb', line 92

def meeting_start_date_time=(value)
    @meeting_start_date_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


100
101
102
103
104
105
106
107
# File 'lib/models/meeting_attendance_report.rb', line 100

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("attendanceRecords", @attendance_records)
    writer.write_date_time_value("meetingEndDateTime", @meeting_end_date_time)
    writer.write_date_time_value("meetingStartDateTime", @meeting_start_date_time)
    writer.write_number_value("totalParticipantCount", @total_participant_count)
end

#total_participant_countObject

Gets the totalParticipantCount property value. Total number of participants. Read-only.

Returns:

  • a integer



112
113
114
# File 'lib/models/meeting_attendance_report.rb', line 112

def total_participant_count
    return @total_participant_count
end

#total_participant_count=(value) ⇒ Object

Sets the totalParticipantCount property value. Total number of participants. Read-only.

Parameters:

  • value

    Value to set for the totalParticipantCount property.

Returns:

  • a void



120
121
122
# File 'lib/models/meeting_attendance_report.rb', line 120

def total_participant_count=(value)
    @total_participant_count = value
end