Class: MicrosoftGraph::Models::MeetingParticipants

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/meeting_participants.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new meetingParticipants and sets the default values.



55
56
57
# File 'lib/models/meeting_participants.rb', line 55

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a meeting_participants

Raises:

  • (StandardError)


63
64
65
66
# File 'lib/models/meeting_participants.rb', line 63

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return MeetingParticipants.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



25
26
27
# File 'lib/models/meeting_participants.rb', line 25

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



33
34
35
# File 'lib/models/meeting_participants.rb', line 33

def additional_data=(value)
    @additional_data = value
end

#attendeesObject

Gets the attendees property value. The attendees property

Returns:

  • a meeting_participant_info



40
41
42
# File 'lib/models/meeting_participants.rb', line 40

def attendees
    return @attendees
end

#attendees=(value) ⇒ Object

Sets the attendees property value. The attendees property

Parameters:

  • value

    Value to set for the attendees property.

Returns:

  • a void



48
49
50
# File 'lib/models/meeting_participants.rb', line 48

def attendees=(value)
    @attendees = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



71
72
73
74
75
76
77
# File 'lib/models/meeting_participants.rb', line 71

def get_field_deserializers()
    return {
        "attendees" => lambda {|n| @attendees = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::MeetingParticipantInfo.create_from_discriminator_value(pn) }) },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "organizer" => lambda {|n| @organizer = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::MeetingParticipantInfo.create_from_discriminator_value(pn) }) },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



82
83
84
# File 'lib/models/meeting_participants.rb', line 82

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



90
91
92
# File 'lib/models/meeting_participants.rb', line 90

def odata_type=(value)
    @odata_type = value
end

#organizerObject

Gets the organizer property value. The organizer property

Returns:

  • a meeting_participant_info



97
98
99
# File 'lib/models/meeting_participants.rb', line 97

def organizer
    return @organizer
end

#organizer=(value) ⇒ Object

Sets the organizer property value. The organizer property

Parameters:

  • value

    Value to set for the organizer property.

Returns:

  • a void



105
106
107
# File 'lib/models/meeting_participants.rb', line 105

def organizer=(value)
    @organizer = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


113
114
115
116
117
118
119
# File 'lib/models/meeting_participants.rb', line 113

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_object_values("attendees", @attendees)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_object_value("organizer", @organizer)
    writer.write_additional_data(@additional_data)
end