Class: MicrosoftGraph::Models::MeetingTimeSuggestionsResult
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::MeetingTimeSuggestionsResult
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/meeting_time_suggestions_result.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#empty_suggestions_reason ⇒ Object
Gets the emptySuggestionsReason property value.
-
#empty_suggestions_reason=(value) ⇒ Object
Sets the emptySuggestionsReason property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new meetingTimeSuggestionsResult and sets the default values.
-
#meeting_time_suggestions ⇒ Object
Gets the meetingTimeSuggestions property value.
-
#meeting_time_suggestions=(value) ⇒ Object
Sets the meetingTimeSuggestions property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new meetingTimeSuggestionsResult and sets the default values.
40 41 42 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 40 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MeetingTimeSuggestionsResult.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 33 def additional_data=(value) @additional_data = value end |
#empty_suggestions_reason ⇒ Object
Gets the emptySuggestionsReason property value. A reason for not returning any meeting suggestions. The possible values are: attendeesUnavailable, attendeesUnavailableOrUnknown, locationsUnavailable, organizerUnavailable, or unknown. This property is an empty string if the meetingTimeSuggestions property does include any meeting suggestions.
56 57 58 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 56 def empty_suggestions_reason return @empty_suggestions_reason end |
#empty_suggestions_reason=(value) ⇒ Object
Sets the emptySuggestionsReason property value. A reason for not returning any meeting suggestions. The possible values are: attendeesUnavailable, attendeesUnavailableOrUnknown, locationsUnavailable, organizerUnavailable, or unknown. This property is an empty string if the meetingTimeSuggestions property does include any meeting suggestions.
64 65 66 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 64 def empty_suggestions_reason=(value) @empty_suggestions_reason = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
71 72 73 74 75 76 77 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 71 def get_field_deserializers() return { "emptySuggestionsReason" => lambda {|n| @empty_suggestions_reason = n.get_string_value() }, "meetingTimeSuggestions" => lambda {|n| @meeting_time_suggestions = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::MeetingTimeSuggestion.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, } end |
#meeting_time_suggestions ⇒ Object
Gets the meetingTimeSuggestions property value. An array of meeting suggestions.
82 83 84 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 82 def meeting_time_suggestions return @meeting_time_suggestions end |
#meeting_time_suggestions=(value) ⇒ Object
Sets the meetingTimeSuggestions property value. An array of meeting suggestions.
90 91 92 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 90 def meeting_time_suggestions=(value) @meeting_time_suggestions = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
97 98 99 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 97 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
105 106 107 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 105 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
113 114 115 116 117 118 119 |
# File 'lib/models/meeting_time_suggestions_result.rb', line 113 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("emptySuggestionsReason", @empty_suggestions_reason) writer.write_collection_of_object_values("meetingTimeSuggestions", @meeting_time_suggestions) writer.write_string_value("@odata.type", @odata_type) writer.write_additional_data(@additional_data) end |