Class: MicrosoftGraph::Models::MicrosoftAuthenticatorAuthenticationMethodConfiguration

Inherits:
AuthenticationMethodConfiguration show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/microsoft_authenticator_authentication_method_configuration.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AuthenticationMethodConfiguration

#exclude_targets, #exclude_targets=, #state, #state=

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new microsoftAuthenticatorAuthenticationMethodConfiguration and sets the default values.



22
23
24
25
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 22

def initialize()
    super
    @odata_type = "#microsoft.graph.microsoftAuthenticatorAuthenticationMethodConfiguration"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a microsoft_authenticator_authentication_method_configuration

Raises:

  • (StandardError)


31
32
33
34
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 31

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return MicrosoftAuthenticatorAuthenticationMethodConfiguration.new
end

Instance Method Details

#feature_settingsObject

Gets the featureSettings property value. A collection of Microsoft Authenticator settings such as application context and location context, and whether they are enabled for all users or specific users only.

Returns:

  • a microsoft_authenticator_feature_settings



39
40
41
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 39

def feature_settings
    return @feature_settings
end

#feature_settings=(value) ⇒ Object

Sets the featureSettings property value. A collection of Microsoft Authenticator settings such as application context and location context, and whether they are enabled for all users or specific users only.

Parameters:

  • value

    Value to set for the featureSettings property.

Returns:

  • a void



47
48
49
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 47

def feature_settings=(value)
    @feature_settings = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



54
55
56
57
58
59
60
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 54

def get_field_deserializers()
    return super.merge({
        "featureSettings" => lambda {|n| @feature_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::MicrosoftAuthenticatorFeatureSettings.create_from_discriminator_value(pn) }) },
        "includeTargets" => lambda {|n| @include_targets = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::MicrosoftAuthenticatorAuthenticationMethodTarget.create_from_discriminator_value(pn) }) },
        "isSoftwareOathEnabled" => lambda {|n| @is_software_oath_enabled = n.get_boolean_value() },
    })
end

#include_targetsObject

Gets the includeTargets property value. A collection of groups that are enabled to use the authentication method. Expanded by default.

Returns:

  • a microsoft_authenticator_authentication_method_target



65
66
67
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 65

def include_targets
    return @include_targets
end

#include_targets=(value) ⇒ Object

Sets the includeTargets property value. A collection of groups that are enabled to use the authentication method. Expanded by default.

Parameters:

  • value

    Value to set for the includeTargets property.

Returns:

  • a void



73
74
75
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 73

def include_targets=(value)
    @include_targets = value
end

#is_software_oath_enabledObject

Gets the isSoftwareOathEnabled property value. The isSoftwareOathEnabled property

Returns:

  • a boolean



80
81
82
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 80

def is_software_oath_enabled
    return @is_software_oath_enabled
end

#is_software_oath_enabled=(value) ⇒ Object

Sets the isSoftwareOathEnabled property value. The isSoftwareOathEnabled property

Parameters:

  • value

    Value to set for the isSoftwareOathEnabled property.

Returns:

  • a void



88
89
90
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 88

def is_software_oath_enabled=(value)
    @is_software_oath_enabled = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


96
97
98
99
100
101
102
# File 'lib/models/microsoft_authenticator_authentication_method_configuration.rb', line 96

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("featureSettings", @feature_settings)
    writer.write_collection_of_object_values("includeTargets", @include_targets)
    writer.write_boolean_value("isSoftwareOathEnabled", @is_software_oath_enabled)
end