Class: MicrosoftGraph::Models::MicrosoftStoreForBusinessApp

Inherits:
MobileApp
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/microsoft_store_for_business_app.rb

Overview

Microsoft Store for Business Apps. This class does not support Create, Delete, or Update.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MobileApp

#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new microsoftStoreForBusinessApp and sets the default values.



30
31
32
33
# File 'lib/models/microsoft_store_for_business_app.rb', line 30

def initialize()
    super
    @odata_type = "#microsoft.graph.microsoftStoreForBusinessApp"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a microsoft_store_for_business_app

Raises:

  • (StandardError)


39
40
41
42
# File 'lib/models/microsoft_store_for_business_app.rb', line 39

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return MicrosoftStoreForBusinessApp.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



47
48
49
50
51
52
53
54
55
# File 'lib/models/microsoft_store_for_business_app.rb', line 47

def get_field_deserializers()
    return super.merge({
        "licenseType" => lambda {|n| @license_type = n.get_enum_value(MicrosoftGraph::Models::MicrosoftStoreForBusinessLicenseType) },
        "packageIdentityName" => lambda {|n| @package_identity_name = n.get_string_value() },
        "productKey" => lambda {|n| @product_key = n.get_string_value() },
        "totalLicenseCount" => lambda {|n| @total_license_count = n.get_number_value() },
        "usedLicenseCount" => lambda {|n| @used_license_count = n.get_number_value() },
    })
end

#license_typeObject

Gets the licenseType property value. The licenseType property

Returns:

  • a microsoft_store_for_business_license_type



60
61
62
# File 'lib/models/microsoft_store_for_business_app.rb', line 60

def license_type
    return @license_type
end

#license_type=(value) ⇒ Object

Sets the licenseType property value. The licenseType property

Parameters:

  • value

    Value to set for the licenseType property.

Returns:

  • a void



68
69
70
# File 'lib/models/microsoft_store_for_business_app.rb', line 68

def license_type=(value)
    @license_type = value
end

#package_identity_nameObject

Gets the packageIdentityName property value. The app package identifier

Returns:

  • a string



75
76
77
# File 'lib/models/microsoft_store_for_business_app.rb', line 75

def package_identity_name
    return @package_identity_name
end

#package_identity_name=(value) ⇒ Object

Sets the packageIdentityName property value. The app package identifier

Parameters:

  • value

    Value to set for the packageIdentityName property.

Returns:

  • a void



83
84
85
# File 'lib/models/microsoft_store_for_business_app.rb', line 83

def package_identity_name=(value)
    @package_identity_name = value
end

#product_keyObject

Gets the productKey property value. The app product key

Returns:

  • a string



90
91
92
# File 'lib/models/microsoft_store_for_business_app.rb', line 90

def product_key
    return @product_key
end

#product_key=(value) ⇒ Object

Sets the productKey property value. The app product key

Parameters:

  • value

    Value to set for the productKey property.

Returns:

  • a void



98
99
100
# File 'lib/models/microsoft_store_for_business_app.rb', line 98

def product_key=(value)
    @product_key = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


106
107
108
109
110
111
112
113
114
# File 'lib/models/microsoft_store_for_business_app.rb', line 106

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_enum_value("licenseType", @license_type)
    writer.write_string_value("packageIdentityName", @package_identity_name)
    writer.write_string_value("productKey", @product_key)
    writer.write_number_value("totalLicenseCount", @total_license_count)
    writer.write_number_value("usedLicenseCount", @used_license_count)
end

#total_license_countObject

Gets the totalLicenseCount property value. The total number of Microsoft Store for Business licenses.

Returns:

  • a integer



119
120
121
# File 'lib/models/microsoft_store_for_business_app.rb', line 119

def total_license_count
    return @total_license_count
end

#total_license_count=(value) ⇒ Object

Sets the totalLicenseCount property value. The total number of Microsoft Store for Business licenses.

Parameters:

  • value

    Value to set for the totalLicenseCount property.

Returns:

  • a void



127
128
129
# File 'lib/models/microsoft_store_for_business_app.rb', line 127

def total_license_count=(value)
    @total_license_count = value
end

#used_license_countObject

Gets the usedLicenseCount property value. The number of Microsoft Store for Business licenses in use.

Returns:

  • a integer



134
135
136
# File 'lib/models/microsoft_store_for_business_app.rb', line 134

def used_license_count
    return @used_license_count
end

#used_license_count=(value) ⇒ Object

Sets the usedLicenseCount property value. The number of Microsoft Store for Business licenses in use.

Parameters:

  • value

    Value to set for the usedLicenseCount property.

Returns:

  • a void



142
143
144
# File 'lib/models/microsoft_store_for_business_app.rb', line 142

def used_license_count=(value)
    @used_license_count = value
end