Class: MicrosoftGraph::Models::OnPremisesConditionalAccessSettings

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/on_premises_conditional_access_settings.rb

Overview

Singleton entity which represents the Exchange OnPremises Conditional Access Settings for a tenant.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new onPremisesConditionalAccessSettings and sets the default values.



27
28
29
# File 'lib/models/on_premises_conditional_access_settings.rb', line 27

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a on_premises_conditional_access_settings

Raises:

  • (StandardError)


35
36
37
38
# File 'lib/models/on_premises_conditional_access_settings.rb', line 35

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return OnPremisesConditionalAccessSettings.new
end

Instance Method Details

#enabledObject

Gets the enabled property value. Indicates if on premises conditional access is enabled for this organization

Returns:

  • a boolean



43
44
45
# File 'lib/models/on_premises_conditional_access_settings.rb', line 43

def enabled
    return @enabled
end

#enabled=(value) ⇒ Object

Sets the enabled property value. Indicates if on premises conditional access is enabled for this organization

Parameters:

  • value

    Value to set for the enabled property.

Returns:

  • a void



51
52
53
# File 'lib/models/on_premises_conditional_access_settings.rb', line 51

def enabled=(value)
    @enabled = value
end

#excluded_groupsObject

Gets the excludedGroups property value. User groups that will be exempt by on premises conditional access. All users in these groups will be exempt from the conditional access policy.

Returns:

  • a guid



58
59
60
# File 'lib/models/on_premises_conditional_access_settings.rb', line 58

def excluded_groups
    return @excluded_groups
end

#excluded_groups=(value) ⇒ Object

Sets the excludedGroups property value. User groups that will be exempt by on premises conditional access. All users in these groups will be exempt from the conditional access policy.

Parameters:

  • value

    Value to set for the excludedGroups property.

Returns:

  • a void



66
67
68
# File 'lib/models/on_premises_conditional_access_settings.rb', line 66

def excluded_groups=(value)
    @excluded_groups = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



73
74
75
76
77
78
79
80
# File 'lib/models/on_premises_conditional_access_settings.rb', line 73

def get_field_deserializers()
    return super.merge({
        "enabled" => lambda {|n| @enabled = n.get_boolean_value() },
        "excludedGroups" => lambda {|n| @excluded_groups = n.get_collection_of_primitive_values(UUIDTools::UUID) },
        "includedGroups" => lambda {|n| @included_groups = n.get_collection_of_primitive_values(UUIDTools::UUID) },
        "overrideDefaultRule" => lambda {|n| @override_default_rule = n.get_boolean_value() },
    })
end

#included_groupsObject

Gets the includedGroups property value. User groups that will be targeted by on premises conditional access. All users in these groups will be required to have mobile device managed and compliant for mail access.

Returns:

  • a guid



85
86
87
# File 'lib/models/on_premises_conditional_access_settings.rb', line 85

def included_groups
    return @included_groups
end

#included_groups=(value) ⇒ Object

Sets the includedGroups property value. User groups that will be targeted by on premises conditional access. All users in these groups will be required to have mobile device managed and compliant for mail access.

Parameters:

  • value

    Value to set for the includedGroups property.

Returns:

  • a void



93
94
95
# File 'lib/models/on_premises_conditional_access_settings.rb', line 93

def included_groups=(value)
    @included_groups = value
end

#override_default_ruleObject

Gets the overrideDefaultRule property value. Override the default access rule when allowing a device to ensure access is granted.

Returns:

  • a boolean



100
101
102
# File 'lib/models/on_premises_conditional_access_settings.rb', line 100

def override_default_rule
    return @override_default_rule
end

#override_default_rule=(value) ⇒ Object

Sets the overrideDefaultRule property value. Override the default access rule when allowing a device to ensure access is granted.

Parameters:

  • value

    Value to set for the overrideDefaultRule property.

Returns:

  • a void



108
109
110
# File 'lib/models/on_premises_conditional_access_settings.rb', line 108

def override_default_rule=(value)
    @override_default_rule = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


116
117
118
119
120
121
122
123
# File 'lib/models/on_premises_conditional_access_settings.rb', line 116

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_boolean_value("enabled", @enabled)
    writer.write_collection_of_primitive_values("excludedGroups", @excluded_groups)
    writer.write_collection_of_primitive_values("includedGroups", @included_groups)
    writer.write_boolean_value("overrideDefaultRule", @override_default_rule)
end