Class: MicrosoftGraph::Models::OnPremisesProvisioningError

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/on_premises_provisioning_error.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new onPremisesProvisioningError and sets the default values.



62
63
64
# File 'lib/models/on_premises_provisioning_error.rb', line 62

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a on_premises_provisioning_error

Raises:

  • (StandardError)


70
71
72
73
# File 'lib/models/on_premises_provisioning_error.rb', line 70

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return OnPremisesProvisioningError.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



32
33
34
# File 'lib/models/on_premises_provisioning_error.rb', line 32

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



40
41
42
# File 'lib/models/on_premises_provisioning_error.rb', line 40

def additional_data=(value)
    @additional_data = value
end

#categoryObject

Gets the category property value. Category of the provisioning error. Note: Currently, there is only one possible value. Possible value: PropertyConflict - indicates a property value is not unique. Other objects contain the same value for the property.

Returns:

  • a string



47
48
49
# File 'lib/models/on_premises_provisioning_error.rb', line 47

def category
    return @category
end

#category=(value) ⇒ Object

Sets the category property value. Category of the provisioning error. Note: Currently, there is only one possible value. Possible value: PropertyConflict - indicates a property value is not unique. Other objects contain the same value for the property.

Parameters:

  • value

    Value to set for the category property.

Returns:

  • a void



55
56
57
# File 'lib/models/on_premises_provisioning_error.rb', line 55

def category=(value)
    @category = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



78
79
80
81
82
83
84
85
86
# File 'lib/models/on_premises_provisioning_error.rb', line 78

def get_field_deserializers()
    return {
        "category" => lambda {|n| @category = n.get_string_value() },
        "occurredDateTime" => lambda {|n| @occurred_date_time = n.get_date_time_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "propertyCausingError" => lambda {|n| @property_causing_error = n.get_string_value() },
        "value" => lambda {|n| @value = n.get_string_value() },
    }
end

#occurred_date_timeObject

Gets the occurredDateTime property value. The date and time at which the error occurred.

Returns:

  • a date_time



91
92
93
# File 'lib/models/on_premises_provisioning_error.rb', line 91

def occurred_date_time
    return @occurred_date_time
end

#occurred_date_time=(value) ⇒ Object

Sets the occurredDateTime property value. The date and time at which the error occurred.

Parameters:

  • value

    Value to set for the occurredDateTime property.

Returns:

  • a void



99
100
101
# File 'lib/models/on_premises_provisioning_error.rb', line 99

def occurred_date_time=(value)
    @occurred_date_time = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



106
107
108
# File 'lib/models/on_premises_provisioning_error.rb', line 106

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



114
115
116
# File 'lib/models/on_premises_provisioning_error.rb', line 114

def odata_type=(value)
    @odata_type = value
end

#property_causing_errorObject

Gets the propertyCausingError property value. Name of the directory property causing the error. Current possible values: UserPrincipalName or ProxyAddress

Returns:

  • a string



121
122
123
# File 'lib/models/on_premises_provisioning_error.rb', line 121

def property_causing_error
    return @property_causing_error
end

#property_causing_error=(value) ⇒ Object

Sets the propertyCausingError property value. Name of the directory property causing the error. Current possible values: UserPrincipalName or ProxyAddress

Parameters:

  • value

    Value to set for the propertyCausingError property.

Returns:

  • a void



129
130
131
# File 'lib/models/on_premises_provisioning_error.rb', line 129

def property_causing_error=(value)
    @property_causing_error = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


137
138
139
140
141
142
143
144
145
# File 'lib/models/on_premises_provisioning_error.rb', line 137

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("category", @category)
    writer.write_date_time_value("occurredDateTime", @occurred_date_time)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_string_value("propertyCausingError", @property_causing_error)
    writer.write_string_value("value", @value)
    writer.write_additional_data(@additional_data)
end

#valueObject

Gets the value property value. Value of the property causing the error.

Returns:

  • a string



150
151
152
# File 'lib/models/on_premises_provisioning_error.rb', line 150

def value
    return @value
end

#value=(value) ⇒ Object

Sets the value property value. Value of the property causing the error.

Parameters:

  • value

    Value to set for the value property.

Returns:

  • a void



158
159
160
# File 'lib/models/on_premises_provisioning_error.rb', line 158

def value=(value)
    @value = value
end