Class: MicrosoftGraph::Models::Operation

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/operation.rb

Direct Known Subclasses

OnenoteOperation

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new operation and sets the default values.



23
24
25
# File 'lib/models/operation.rb', line 23

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a operation

Raises:

  • (StandardError)


46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/models/operation.rb', line 46

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    mapping_value_node = parse_node.get_child_node("@odata.type")
    unless mapping_value_node.nil? then
        mapping_value = mapping_value_node.get_string_value
        case mapping_value
            when "#microsoft.graph.onenoteOperation"
                return OnenoteOperation.new
        end
    end
    return Operation.new
end

Instance Method Details

#created_date_timeObject

Gets the createdDateTime property value. The start time of the operation.

Returns:

  • a date_time



30
31
32
# File 'lib/models/operation.rb', line 30

def created_date_time
    return @created_date_time
end

#created_date_time=(value) ⇒ Object

Sets the createdDateTime property value. The start time of the operation.

Parameters:

  • value

    Value to set for the createdDateTime property.

Returns:

  • a void



38
39
40
# File 'lib/models/operation.rb', line 38

def created_date_time=(value)
    @created_date_time = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



62
63
64
65
66
67
68
# File 'lib/models/operation.rb', line 62

def get_field_deserializers()
    return super.merge({
        "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() },
        "lastActionDateTime" => lambda {|n| @last_action_date_time = n.get_date_time_value() },
        "status" => lambda {|n| @status = n.get_enum_value(MicrosoftGraph::Models::OperationStatus) },
    })
end

#last_action_date_timeObject

Gets the lastActionDateTime property value. The time of the last action of the operation.

Returns:

  • a date_time



73
74
75
# File 'lib/models/operation.rb', line 73

def last_action_date_time
    return @last_action_date_time
end

#last_action_date_time=(value) ⇒ Object

Sets the lastActionDateTime property value. The time of the last action of the operation.

Parameters:

  • value

    Value to set for the lastActionDateTime property.

Returns:

  • a void



81
82
83
# File 'lib/models/operation.rb', line 81

def last_action_date_time=(value)
    @last_action_date_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


89
90
91
92
93
94
95
# File 'lib/models/operation.rb', line 89

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_date_time_value("createdDateTime", @created_date_time)
    writer.write_date_time_value("lastActionDateTime", @last_action_date_time)
    writer.write_enum_value("status", @status)
end

#statusObject

Gets the status property value. The current status of the operation: notStarted, running, completed, failed

Returns:

  • a operation_status



100
101
102
# File 'lib/models/operation.rb', line 100

def status
    return @status
end

#status=(value) ⇒ Object

Sets the status property value. The current status of the operation: notStarted, running, completed, failed

Parameters:

  • value

    Value to set for the status property.

Returns:

  • a void



108
109
110
# File 'lib/models/operation.rb', line 108

def status=(value)
    @status = value
end