Class: MicrosoftGraph::Models::OrganizationalBrandingProperties

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/organizational_branding_properties.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new organizationalBrandingProperties and sets the default values.



193
194
195
# File 'lib/models/organizational_branding_properties.rb', line 193

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a organizational_branding_properties

Raises:

  • (StandardError)


201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/models/organizational_branding_properties.rb', line 201

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    mapping_value_node = parse_node.get_child_node("@odata.type")
    unless mapping_value_node.nil? then
        mapping_value = mapping_value_node.get_string_value
        case mapping_value
            when "#microsoft.graph.organizationalBranding"
                return OrganizationalBranding.new
            when "#microsoft.graph.organizationalBrandingLocalization"
                return OrganizationalBrandingLocalization.new
        end
    end
    return OrganizationalBrandingProperties.new
end

Instance Method Details

#background_colorObject

Gets the backgroundColor property value. Color that appears in place of the background image in low-bandwidth connections. We recommend that you use the primary color of your banner logo or your organization color. Specify this in hexadecimal format, for example, white is #FFFFFF.

Returns:

  • a string



103
104
105
# File 'lib/models/organizational_branding_properties.rb', line 103

def background_color
    return @background_color
end

#background_color=(value) ⇒ Object

Sets the backgroundColor property value. Color that appears in place of the background image in low-bandwidth connections. We recommend that you use the primary color of your banner logo or your organization color. Specify this in hexadecimal format, for example, white is #FFFFFF.

Parameters:

  • value

    Value to set for the backgroundColor property.

Returns:

  • a void



111
112
113
# File 'lib/models/organizational_branding_properties.rb', line 111

def background_color=(value)
    @background_color = value
end

#background_imageObject

Gets the backgroundImage property value. Image that appears as the background of the sign-in page. The allowed types are PNG or JPEG not smaller than 300 KB and not larger than 1920 × 1080 pixels. A smaller image will reduce bandwidth requirements and make the page load faster.

Returns:

  • a base64url



118
119
120
# File 'lib/models/organizational_branding_properties.rb', line 118

def background_image
    return @background_image
end

#background_image=(value) ⇒ Object

Sets the backgroundImage property value. Image that appears as the background of the sign-in page. The allowed types are PNG or JPEG not smaller than 300 KB and not larger than 1920 × 1080 pixels. A smaller image will reduce bandwidth requirements and make the page load faster.

Parameters:

  • value

    Value to set for the backgroundImage property.

Returns:

  • a void



126
127
128
# File 'lib/models/organizational_branding_properties.rb', line 126

def background_image=(value)
    @background_image = value
end

#background_image_relative_urlObject

Gets the backgroundImageRelativeUrl property value. A relative URL for the backgroundImage property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Returns:

  • a string



133
134
135
# File 'lib/models/organizational_branding_properties.rb', line 133

def background_image_relative_url
    return @background_image_relative_url
end

#background_image_relative_url=(value) ⇒ Object

Sets the backgroundImageRelativeUrl property value. A relative URL for the backgroundImage property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Parameters:

  • value

    Value to set for the backgroundImageRelativeUrl property.

Returns:

  • a void



141
142
143
# File 'lib/models/organizational_branding_properties.rb', line 141

def background_image_relative_url=(value)
    @background_image_relative_url = value
end

Gets the bannerLogo property value. A banner version of your company logo that appears on the sign-in page. The allowed types are PNG or JPEG not larger than 36 × 245 pixels. We recommend using a transparent image with no padding around the logo.

Returns:

  • a base64url



148
149
150
# File 'lib/models/organizational_branding_properties.rb', line 148

def 
    return 
end

Sets the bannerLogo property value. A banner version of your company logo that appears on the sign-in page. The allowed types are PNG or JPEG not larger than 36 × 245 pixels. We recommend using a transparent image with no padding around the logo.

Parameters:

  • value

    Value to set for the bannerLogo property.

Returns:

  • a void



156
157
158
# File 'lib/models/organizational_branding_properties.rb', line 156

def banner_logo=(value)
     = value
end

Gets the bannerLogoRelativeUrl property value. A relative URL for the bannerLogo property that is combined with a CDN base URL from the cdnList to provide the read-only version served by a CDN. Read-only.

Returns:

  • a string



163
164
165
# File 'lib/models/organizational_branding_properties.rb', line 163

def banner_logo_relative_url
    return @banner_logo_relative_url
end

Sets the bannerLogoRelativeUrl property value. A relative URL for the bannerLogo property that is combined with a CDN base URL from the cdnList to provide the read-only version served by a CDN. Read-only.

Parameters:

  • value

    Value to set for the bannerLogoRelativeUrl property.

Returns:

  • a void



171
172
173
# File 'lib/models/organizational_branding_properties.rb', line 171

def banner_logo_relative_url=(value)
    @banner_logo_relative_url = value
end

#cdn_listObject

Gets the cdnList property value. A list of base URLs for all available CDN providers that are serving the assets of the current resource. Several CDN providers are used at the same time for high availability of read requests. Read-only.

Returns:

  • a string



178
179
180
# File 'lib/models/organizational_branding_properties.rb', line 178

def cdn_list
    return @cdn_list
end

#cdn_list=(value) ⇒ Object

Sets the cdnList property value. A list of base URLs for all available CDN providers that are serving the assets of the current resource. Several CDN providers are used at the same time for high availability of read requests. Read-only.

Parameters:

  • value

    Value to set for the cdnList property.

Returns:

  • a void



186
187
188
# File 'lib/models/organizational_branding_properties.rb', line 186

def cdn_list=(value)
    @cdn_list = value
end

#custom_account_reset_credentials_urlObject

Gets the customAccountResetCredentialsUrl property value. A custom URL for resetting account credentials. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128 characters.

Returns:

  • a string



219
220
221
# File 'lib/models/organizational_branding_properties.rb', line 219

def 
    return 
end

#custom_account_reset_credentials_url=(value) ⇒ Object

Sets the customAccountResetCredentialsUrl property value. A custom URL for resetting account credentials. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128 characters.

Parameters:

  • value

    Value to set for the customAccountResetCredentialsUrl property.

Returns:

  • a void



227
228
229
# File 'lib/models/organizational_branding_properties.rb', line 227

def (value)
     = value
end

#custom_c_s_sObject

Gets the customCSS property value. CSS styling that appears on the sign-in page. The allowed format is .css format only and not larger than 25 KB.

Returns:

  • a base64url



234
235
236
# File 'lib/models/organizational_branding_properties.rb', line 234

def custom_c_s_s
    return @custom_c_s_s
end

#custom_c_s_s=(value) ⇒ Object

Sets the customCSS property value. CSS styling that appears on the sign-in page. The allowed format is .css format only and not larger than 25 KB.

Parameters:

  • value

    Value to set for the customCSS property.

Returns:

  • a void



242
243
244
# File 'lib/models/organizational_branding_properties.rb', line 242

def custom_c_s_s=(value)
    @custom_c_s_s = value
end

#custom_c_s_s_relative_urlObject

Gets the customCSSRelativeUrl property value. A relative URL for the customCSS property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Returns:

  • a string



249
250
251
# File 'lib/models/organizational_branding_properties.rb', line 249

def custom_c_s_s_relative_url
    return @custom_c_s_s_relative_url
end

#custom_c_s_s_relative_url=(value) ⇒ Object

Sets the customCSSRelativeUrl property value. A relative URL for the customCSS property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Parameters:

  • value

    Value to set for the customCSSRelativeUrl property.

Returns:

  • a void



257
258
259
# File 'lib/models/organizational_branding_properties.rb', line 257

def custom_c_s_s_relative_url=(value)
    @custom_c_s_s_relative_url = value
end

#custom_cannot_access_your_account_textObject

Gets the customCannotAccessYourAccountText property value. A string to replace the default ‘Can’t access your account?‘ self-service password reset (SSPR) hyperlink text on the sign-in page. This text must be in Unicode format and not exceed 256 characters.

Returns:

  • a string



264
265
266
# File 'lib/models/organizational_branding_properties.rb', line 264

def 
    return 
end

#custom_cannot_access_your_account_text=(value) ⇒ Object

Sets the customCannotAccessYourAccountText property value. A string to replace the default ‘Can’t access your account?‘ self-service password reset (SSPR) hyperlink text on the sign-in page. This text must be in Unicode format and not exceed 256 characters.

Parameters:

  • value

    Value to set for the customCannotAccessYourAccountText property.

Returns:

  • a void



272
273
274
# File 'lib/models/organizational_branding_properties.rb', line 272

def (value)
     = value
end

#custom_cannot_access_your_account_urlObject

Gets the customCannotAccessYourAccountUrl property value. A custom URL to replace the default URL of the self-service password reset (SSPR) ‘Can’t access your account?‘ hyperlink on the sign-in page. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128 characters. DO NOT USE. Use customAccountResetCredentialsUrl instead.

Returns:

  • a string



279
280
281
# File 'lib/models/organizational_branding_properties.rb', line 279

def 
    return 
end

#custom_cannot_access_your_account_url=(value) ⇒ Object

Sets the customCannotAccessYourAccountUrl property value. A custom URL to replace the default URL of the self-service password reset (SSPR) ‘Can’t access your account?‘ hyperlink on the sign-in page. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128 characters. DO NOT USE. Use customAccountResetCredentialsUrl instead.

Parameters:

  • value

    Value to set for the customCannotAccessYourAccountUrl property.

Returns:

  • a void



287
288
289
# File 'lib/models/organizational_branding_properties.rb', line 287

def (value)
     = value
end

#custom_forgot_my_password_textObject

Gets the customForgotMyPasswordText property value. A string to replace the default ‘Forgot my password’ hyperlink text on the sign-in form. This text must be in Unicode format and not exceed 256 characters.

Returns:

  • a string



294
295
296
# File 'lib/models/organizational_branding_properties.rb', line 294

def custom_forgot_my_password_text
    return @custom_forgot_my_password_text
end

#custom_forgot_my_password_text=(value) ⇒ Object

Sets the customForgotMyPasswordText property value. A string to replace the default ‘Forgot my password’ hyperlink text on the sign-in form. This text must be in Unicode format and not exceed 256 characters.

Parameters:

  • value

    Value to set for the customForgotMyPasswordText property.

Returns:

  • a void



302
303
304
# File 'lib/models/organizational_branding_properties.rb', line 302

def custom_forgot_my_password_text=(value)
    @custom_forgot_my_password_text = value
end

#custom_privacy_and_cookies_textObject

Gets the customPrivacyAndCookiesText property value. A string to replace the default ‘Privacy and Cookies’ hyperlink text in the footer. This text must be in Unicode format and not exceed 256 characters.

Returns:

  • a string



309
310
311
# File 'lib/models/organizational_branding_properties.rb', line 309

def custom_privacy_and_cookies_text
    return @custom_privacy_and_cookies_text
end

#custom_privacy_and_cookies_text=(value) ⇒ Object

Sets the customPrivacyAndCookiesText property value. A string to replace the default ‘Privacy and Cookies’ hyperlink text in the footer. This text must be in Unicode format and not exceed 256 characters.

Parameters:

  • value

    Value to set for the customPrivacyAndCookiesText property.

Returns:

  • a void



317
318
319
# File 'lib/models/organizational_branding_properties.rb', line 317

def custom_privacy_and_cookies_text=(value)
    @custom_privacy_and_cookies_text = value
end

#custom_privacy_and_cookies_urlObject

Gets the customPrivacyAndCookiesUrl property value. A custom URL to replace the default URL of the ‘Privacy and Cookies’ hyperlink in the footer. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128 characters.

Returns:

  • a string



324
325
326
# File 'lib/models/organizational_branding_properties.rb', line 324

def custom_privacy_and_cookies_url
    return @custom_privacy_and_cookies_url
end

#custom_privacy_and_cookies_url=(value) ⇒ Object

Sets the customPrivacyAndCookiesUrl property value. A custom URL to replace the default URL of the ‘Privacy and Cookies’ hyperlink in the footer. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128 characters.

Parameters:

  • value

    Value to set for the customPrivacyAndCookiesUrl property.

Returns:

  • a void



332
333
334
# File 'lib/models/organizational_branding_properties.rb', line 332

def custom_privacy_and_cookies_url=(value)
    @custom_privacy_and_cookies_url = value
end

#custom_reset_it_now_textObject

Gets the customResetItNowText property value. A string to replace the default ‘reset it now’ hyperlink text on the sign-in form. This text must be in Unicode format and not exceed 256 characters. DO NOT USE: Customization of the ‘reset it now’ hyperlink text is currently not supported.

Returns:

  • a string



339
340
341
# File 'lib/models/organizational_branding_properties.rb', line 339

def custom_reset_it_now_text
    return @custom_reset_it_now_text
end

#custom_reset_it_now_text=(value) ⇒ Object

Sets the customResetItNowText property value. A string to replace the default ‘reset it now’ hyperlink text on the sign-in form. This text must be in Unicode format and not exceed 256 characters. DO NOT USE: Customization of the ‘reset it now’ hyperlink text is currently not supported.

Parameters:

  • value

    Value to set for the customResetItNowText property.

Returns:

  • a void



347
348
349
# File 'lib/models/organizational_branding_properties.rb', line 347

def custom_reset_it_now_text=(value)
    @custom_reset_it_now_text = value
end

#custom_terms_of_use_textObject

Gets the customTermsOfUseText property value. A string to replace the the default ‘Terms of Use’ hyperlink text in the footer. This text must be in Unicode format and not exceed 256 characters.

Returns:

  • a string



354
355
356
# File 'lib/models/organizational_branding_properties.rb', line 354

def custom_terms_of_use_text
    return @custom_terms_of_use_text
end

#custom_terms_of_use_text=(value) ⇒ Object

Sets the customTermsOfUseText property value. A string to replace the the default ‘Terms of Use’ hyperlink text in the footer. This text must be in Unicode format and not exceed 256 characters.

Parameters:

  • value

    Value to set for the customTermsOfUseText property.

Returns:

  • a void



362
363
364
# File 'lib/models/organizational_branding_properties.rb', line 362

def custom_terms_of_use_text=(value)
    @custom_terms_of_use_text = value
end

#custom_terms_of_use_urlObject

Gets the customTermsOfUseUrl property value. A custom URL to replace the default URL of the ‘Terms of Use’ hyperlink in the footer. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128characters.

Returns:

  • a string



369
370
371
# File 'lib/models/organizational_branding_properties.rb', line 369

def custom_terms_of_use_url
    return @custom_terms_of_use_url
end

#custom_terms_of_use_url=(value) ⇒ Object

Sets the customTermsOfUseUrl property value. A custom URL to replace the default URL of the ‘Terms of Use’ hyperlink in the footer. This URL must be in ASCII format or non-ASCII characters must be URL encoded, and not exceed 128characters.

Parameters:

  • value

    Value to set for the customTermsOfUseUrl property.

Returns:

  • a void



377
378
379
# File 'lib/models/organizational_branding_properties.rb', line 377

def custom_terms_of_use_url=(value)
    @custom_terms_of_use_url = value
end

#faviconObject

Gets the favicon property value. A custom icon (favicon) to replace a default Microsoft product favicon on an Azure AD tenant.

Returns:

  • a base64url



384
385
386
# File 'lib/models/organizational_branding_properties.rb', line 384

def favicon
    return @favicon
end

#favicon=(value) ⇒ Object

Sets the favicon property value. A custom icon (favicon) to replace a default Microsoft product favicon on an Azure AD tenant.

Parameters:

  • value

    Value to set for the favicon property.

Returns:

  • a void



392
393
394
# File 'lib/models/organizational_branding_properties.rb', line 392

def favicon=(value)
    @favicon = value
end

#favicon_relative_urlObject

Gets the faviconRelativeUrl property value. A relative url for the favicon above that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Returns:

  • a string



399
400
401
# File 'lib/models/organizational_branding_properties.rb', line 399

def favicon_relative_url
    return @favicon_relative_url
end

#favicon_relative_url=(value) ⇒ Object

Sets the faviconRelativeUrl property value. A relative url for the favicon above that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Parameters:

  • value

    Value to set for the faviconRelativeUrl property.

Returns:

  • a void



407
408
409
# File 'lib/models/organizational_branding_properties.rb', line 407

def favicon_relative_url=(value)
    @favicon_relative_url = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/models/organizational_branding_properties.rb', line 414

def get_field_deserializers()
    return super.merge({
        "backgroundColor" => lambda {|n| @background_color = n.get_string_value() },
        "backgroundImage" => lambda {|n| @background_image = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) },
        "backgroundImageRelativeUrl" => lambda {|n| @background_image_relative_url = n.get_string_value() },
        "bannerLogo" => lambda {|n|  = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) },
        "bannerLogoRelativeUrl" => lambda {|n| @banner_logo_relative_url = n.get_string_value() },
        "cdnList" => lambda {|n| @cdn_list = n.get_collection_of_primitive_values(String) },
        "customAccountResetCredentialsUrl" => lambda {|n|  = n.get_string_value() },
        "customCSS" => lambda {|n| @custom_c_s_s = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) },
        "customCSSRelativeUrl" => lambda {|n| @custom_c_s_s_relative_url = n.get_string_value() },
        "customCannotAccessYourAccountText" => lambda {|n|  = n.get_string_value() },
        "customCannotAccessYourAccountUrl" => lambda {|n|  = n.get_string_value() },
        "customForgotMyPasswordText" => lambda {|n| @custom_forgot_my_password_text = n.get_string_value() },
        "customPrivacyAndCookiesText" => lambda {|n| @custom_privacy_and_cookies_text = n.get_string_value() },
        "customPrivacyAndCookiesUrl" => lambda {|n| @custom_privacy_and_cookies_url = n.get_string_value() },
        "customResetItNowText" => lambda {|n| @custom_reset_it_now_text = n.get_string_value() },
        "customTermsOfUseText" => lambda {|n| @custom_terms_of_use_text = n.get_string_value() },
        "customTermsOfUseUrl" => lambda {|n| @custom_terms_of_use_url = n.get_string_value() },
        "favicon" => lambda {|n| @favicon = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) },
        "faviconRelativeUrl" => lambda {|n| @favicon_relative_url = n.get_string_value() },
        "headerBackgroundColor" => lambda {|n| @header_background_color = n.get_string_value() },
        "headerLogo" => lambda {|n|  = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) },
        "headerLogoRelativeUrl" => lambda {|n| @header_logo_relative_url = n.get_string_value() },
        "loginPageLayoutConfiguration" => lambda {|n| @login_page_layout_configuration = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::LoginPageLayoutConfiguration.create_from_discriminator_value(pn) }) },
        "loginPageTextVisibilitySettings" => lambda {|n| @login_page_text_visibility_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::LoginPageTextVisibilitySettings.create_from_discriminator_value(pn) }) },
        "signInPageText" => lambda {|n| @sign_in_page_text = n.get_string_value() },
        "squareLogo" => lambda {|n|  = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) },
        "squareLogoDark" => lambda {|n| @square_logo_dark = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) },
        "squareLogoDarkRelativeUrl" => lambda {|n| @square_logo_dark_relative_url = n.get_string_value() },
        "squareLogoRelativeUrl" => lambda {|n| @square_logo_relative_url = n.get_string_value() },
        "usernameHintText" => lambda {|n| @username_hint_text = n.get_string_value() },
    })
end

#header_background_colorObject

Gets the headerBackgroundColor property value. The RGB color to apply to customize the color of the header.

Returns:

  • a string



452
453
454
# File 'lib/models/organizational_branding_properties.rb', line 452

def header_background_color
    return @header_background_color
end

#header_background_color=(value) ⇒ Object

Sets the headerBackgroundColor property value. The RGB color to apply to customize the color of the header.

Parameters:

  • value

    Value to set for the headerBackgroundColor property.

Returns:

  • a void



460
461
462
# File 'lib/models/organizational_branding_properties.rb', line 460

def header_background_color=(value)
    @header_background_color = value
end

#header_logoObject

Gets the headerLogo property value. A company logo that appears in the header of the sign-in page. The allowed types are PNG or JPEG not larger than 36 × 245 pixels. We recommend using a transparent image with no padding around the logo.

Returns:

  • a base64url



467
468
469
# File 'lib/models/organizational_branding_properties.rb', line 467

def 
    return 
end

#header_logo=(value) ⇒ Object

Sets the headerLogo property value. A company logo that appears in the header of the sign-in page. The allowed types are PNG or JPEG not larger than 36 × 245 pixels. We recommend using a transparent image with no padding around the logo.

Parameters:

  • value

    Value to set for the headerLogo property.

Returns:

  • a void



475
476
477
# File 'lib/models/organizational_branding_properties.rb', line 475

def header_logo=(value)
     = value
end

#header_logo_relative_urlObject

Gets the headerLogoRelativeUrl property value. A relative URL for the headerLogo property that is combined with a CDN base URL from the cdnList to provide the read-only version served by a CDN. Read-only.

Returns:

  • a string



482
483
484
# File 'lib/models/organizational_branding_properties.rb', line 482

def header_logo_relative_url
    return @header_logo_relative_url
end

#header_logo_relative_url=(value) ⇒ Object

Sets the headerLogoRelativeUrl property value. A relative URL for the headerLogo property that is combined with a CDN base URL from the cdnList to provide the read-only version served by a CDN. Read-only.

Parameters:

  • value

    Value to set for the headerLogoRelativeUrl property.

Returns:

  • a void



490
491
492
# File 'lib/models/organizational_branding_properties.rb', line 490

def header_logo_relative_url=(value)
    @header_logo_relative_url = value
end

#login_page_layout_configurationObject

Gets the loginPageLayoutConfiguration property value. Represents the layout configuration to be displayed on the login page for a tenant.

Returns:

  • a login_page_layout_configuration



497
498
499
# File 'lib/models/organizational_branding_properties.rb', line 497

def 
    return @login_page_layout_configuration
end

#login_page_layout_configuration=(value) ⇒ Object

Sets the loginPageLayoutConfiguration property value. Represents the layout configuration to be displayed on the login page for a tenant.

Parameters:

  • value

    Value to set for the loginPageLayoutConfiguration property.

Returns:

  • a void



505
506
507
# File 'lib/models/organizational_branding_properties.rb', line 505

def (value)
    @login_page_layout_configuration = value
end

#login_page_text_visibility_settingsObject

Gets the loginPageTextVisibilitySettings property value. Represents the various texts that can be hidden on the login page for a tenant.

Returns:

  • a login_page_text_visibility_settings



512
513
514
# File 'lib/models/organizational_branding_properties.rb', line 512

def 
    return @login_page_text_visibility_settings
end

#login_page_text_visibility_settings=(value) ⇒ Object

Sets the loginPageTextVisibilitySettings property value. Represents the various texts that can be hidden on the login page for a tenant.

Parameters:

  • value

    Value to set for the loginPageTextVisibilitySettings property.

Returns:

  • a void



520
521
522
# File 'lib/models/organizational_branding_properties.rb', line 520

def (value)
    @login_page_text_visibility_settings = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
# File 'lib/models/organizational_branding_properties.rb', line 528

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("backgroundColor", @background_color)
    writer.write_object_value("backgroundImage", @background_image)
    writer.write_string_value("backgroundImageRelativeUrl", @background_image_relative_url)
    writer.write_object_value("bannerLogo", )
    writer.write_string_value("bannerLogoRelativeUrl", @banner_logo_relative_url)
    writer.write_collection_of_primitive_values("cdnList", @cdn_list)
    writer.write_string_value("customAccountResetCredentialsUrl", )
    writer.write_object_value("customCSS", @custom_c_s_s)
    writer.write_string_value("customCSSRelativeUrl", @custom_c_s_s_relative_url)
    writer.write_string_value("customCannotAccessYourAccountText", )
    writer.write_string_value("customCannotAccessYourAccountUrl", )
    writer.write_string_value("customForgotMyPasswordText", @custom_forgot_my_password_text)
    writer.write_string_value("customPrivacyAndCookiesText", @custom_privacy_and_cookies_text)
    writer.write_string_value("customPrivacyAndCookiesUrl", @custom_privacy_and_cookies_url)
    writer.write_string_value("customResetItNowText", @custom_reset_it_now_text)
    writer.write_string_value("customTermsOfUseText", @custom_terms_of_use_text)
    writer.write_string_value("customTermsOfUseUrl", @custom_terms_of_use_url)
    writer.write_object_value("favicon", @favicon)
    writer.write_string_value("faviconRelativeUrl", @favicon_relative_url)
    writer.write_string_value("headerBackgroundColor", @header_background_color)
    writer.write_object_value("headerLogo", )
    writer.write_string_value("headerLogoRelativeUrl", @header_logo_relative_url)
    writer.write_object_value("loginPageLayoutConfiguration", @login_page_layout_configuration)
    writer.write_object_value("loginPageTextVisibilitySettings", @login_page_text_visibility_settings)
    writer.write_string_value("signInPageText", @sign_in_page_text)
    writer.write_object_value("squareLogo", )
    writer.write_object_value("squareLogoDark", @square_logo_dark)
    writer.write_string_value("squareLogoDarkRelativeUrl", @square_logo_dark_relative_url)
    writer.write_string_value("squareLogoRelativeUrl", @square_logo_relative_url)
    writer.write_string_value("usernameHintText", @username_hint_text)
end

#sign_in_page_textObject

Gets the signInPageText property value. Text that appears at the bottom of the sign-in box. Use this to communicate additional information, such as the phone number to your help desk or a legal statement. This text must be in Unicode format and not exceed 1024 characters.

Returns:

  • a string



566
567
568
# File 'lib/models/organizational_branding_properties.rb', line 566

def 
    return @sign_in_page_text
end

#sign_in_page_text=(value) ⇒ Object

Sets the signInPageText property value. Text that appears at the bottom of the sign-in box. Use this to communicate additional information, such as the phone number to your help desk or a legal statement. This text must be in Unicode format and not exceed 1024 characters.

Parameters:

  • value

    Value to set for the signInPageText property.

Returns:

  • a void



574
575
576
# File 'lib/models/organizational_branding_properties.rb', line 574

def (value)
    @sign_in_page_text = value
end

#square_logoObject

Gets the squareLogo property value. A square version of your company logo that appears in Windows 10 out-of-box experiences (OOBE) and when Windows Autopilot is enabled for deployment. Allowed types are PNG or JPEG not larger than 240 x 240 pixels and not more than 10 KB in size. We recommend using a transparent image with no padding around the logo.

Returns:

  • a base64url



581
582
583
# File 'lib/models/organizational_branding_properties.rb', line 581

def 
    return 
end

#square_logo=(value) ⇒ Object

Sets the squareLogo property value. A square version of your company logo that appears in Windows 10 out-of-box experiences (OOBE) and when Windows Autopilot is enabled for deployment. Allowed types are PNG or JPEG not larger than 240 x 240 pixels and not more than 10 KB in size. We recommend using a transparent image with no padding around the logo.

Parameters:

  • value

    Value to set for the squareLogo property.

Returns:

  • a void



589
590
591
# File 'lib/models/organizational_branding_properties.rb', line 589

def square_logo=(value)
     = value
end

#square_logo_darkObject

Gets the squareLogoDark property value. A square dark version of your company logo that appears in Windows 10 out-of-box experiences (OOBE) and when Windows Autopilot is enabled for deployment. Allowed types are PNG or JPEG not larger than 240 x 240 pixels and not more than 10 KB in size. We recommend using a transparent image with no padding around the logo.

Returns:

  • a base64url



596
597
598
# File 'lib/models/organizational_branding_properties.rb', line 596

def square_logo_dark
    return @square_logo_dark
end

#square_logo_dark=(value) ⇒ Object

Sets the squareLogoDark property value. A square dark version of your company logo that appears in Windows 10 out-of-box experiences (OOBE) and when Windows Autopilot is enabled for deployment. Allowed types are PNG or JPEG not larger than 240 x 240 pixels and not more than 10 KB in size. We recommend using a transparent image with no padding around the logo.

Parameters:

  • value

    Value to set for the squareLogoDark property.

Returns:

  • a void



604
605
606
# File 'lib/models/organizational_branding_properties.rb', line 604

def square_logo_dark=(value)
    @square_logo_dark = value
end

#square_logo_dark_relative_urlObject

Gets the squareLogoDarkRelativeUrl property value. A relative URL for the squareLogoDark property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Returns:

  • a string



611
612
613
# File 'lib/models/organizational_branding_properties.rb', line 611

def square_logo_dark_relative_url
    return @square_logo_dark_relative_url
end

#square_logo_dark_relative_url=(value) ⇒ Object

Sets the squareLogoDarkRelativeUrl property value. A relative URL for the squareLogoDark property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Parameters:

  • value

    Value to set for the squareLogoDarkRelativeUrl property.

Returns:

  • a void



619
620
621
# File 'lib/models/organizational_branding_properties.rb', line 619

def square_logo_dark_relative_url=(value)
    @square_logo_dark_relative_url = value
end

#square_logo_relative_urlObject

Gets the squareLogoRelativeUrl property value. A relative URL for the squareLogo property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Returns:

  • a string



626
627
628
# File 'lib/models/organizational_branding_properties.rb', line 626

def square_logo_relative_url
    return @square_logo_relative_url
end

#square_logo_relative_url=(value) ⇒ Object

Sets the squareLogoRelativeUrl property value. A relative URL for the squareLogo property that is combined with a CDN base URL from the cdnList to provide the version served by a CDN. Read-only.

Parameters:

  • value

    Value to set for the squareLogoRelativeUrl property.

Returns:

  • a void



634
635
636
# File 'lib/models/organizational_branding_properties.rb', line 634

def square_logo_relative_url=(value)
    @square_logo_relative_url = value
end

#username_hint_textObject

Gets the usernameHintText property value. A string that shows as the hint in the username textbox on the sign-in screen. This text must be a Unicode, without links or code, and can’t exceed 64 characters.

Returns:

  • a string



641
642
643
# File 'lib/models/organizational_branding_properties.rb', line 641

def username_hint_text
    return @username_hint_text
end

#username_hint_text=(value) ⇒ Object

Sets the usernameHintText property value. A string that shows as the hint in the username textbox on the sign-in screen. This text must be a Unicode, without links or code, and can’t exceed 64 characters.

Parameters:

  • value

    Value to set for the usernameHintText property.

Returns:

  • a void



649
650
651
# File 'lib/models/organizational_branding_properties.rb', line 649

def username_hint_text=(value)
    @username_hint_text = value
end