Class: MicrosoftGraph::Models::PlannerTaskDetails
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/planner_task_details.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#checklist ⇒ Object
Gets the checklist property value.
-
#checklist=(value) ⇒ Object
Sets the checklist property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new plannerTaskDetails and sets the default values.
-
#preview_type ⇒ Object
Gets the previewType property value.
-
#preview_type=(value) ⇒ Object
Sets the previewType property value.
-
#references ⇒ Object
Gets the references property value.
-
#references=(value) ⇒ Object
Sets the references property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new plannerTaskDetails and sets the default values.
40 41 42 |
# File 'lib/models/planner_task_details.rb', line 40 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/models/planner_task_details.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return PlannerTaskDetails.new end |
Instance Method Details
#checklist ⇒ Object
Gets the checklist property value. The collection of checklist items on the task.
25 26 27 |
# File 'lib/models/planner_task_details.rb', line 25 def checklist return @checklist end |
#checklist=(value) ⇒ Object
Sets the checklist property value. The collection of checklist items on the task.
33 34 35 |
# File 'lib/models/planner_task_details.rb', line 33 def checklist=(value) @checklist = value end |
#description ⇒ Object
Gets the description property value. Description of the task.
56 57 58 |
# File 'lib/models/planner_task_details.rb', line 56 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. Description of the task.
64 65 66 |
# File 'lib/models/planner_task_details.rb', line 64 def description=(value) @description = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
71 72 73 74 75 76 77 78 |
# File 'lib/models/planner_task_details.rb', line 71 def get_field_deserializers() return super.merge({ "checklist" => lambda {|n| @checklist = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::PlannerChecklistItems.create_from_discriminator_value(pn) }) }, "description" => lambda {|n| @description = n.get_string_value() }, "previewType" => lambda {|n| @preview_type = n.get_enum_value(MicrosoftGraph::Models::PlannerPreviewType) }, "references" => lambda {|n| @references = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::PlannerExternalReferences.create_from_discriminator_value(pn) }) }, }) end |
#preview_type ⇒ Object
Gets the previewType property value. This sets the type of preview that shows up on the task. The possible values are: automatic, noPreview, checklist, description, reference. When set to automatic the displayed preview is chosen by the app viewing the task.
83 84 85 |
# File 'lib/models/planner_task_details.rb', line 83 def preview_type return @preview_type end |
#preview_type=(value) ⇒ Object
Sets the previewType property value. This sets the type of preview that shows up on the task. The possible values are: automatic, noPreview, checklist, description, reference. When set to automatic the displayed preview is chosen by the app viewing the task.
91 92 93 |
# File 'lib/models/planner_task_details.rb', line 91 def preview_type=(value) @preview_type = value end |
#references ⇒ Object
Gets the references property value. The collection of references on the task.
98 99 100 |
# File 'lib/models/planner_task_details.rb', line 98 def references return @references end |
#references=(value) ⇒ Object
Sets the references property value. The collection of references on the task.
106 107 108 |
# File 'lib/models/planner_task_details.rb', line 106 def references=(value) @references = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
114 115 116 117 118 119 120 121 |
# File 'lib/models/planner_task_details.rb', line 114 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("checklist", @checklist) writer.write_string_value("description", @description) writer.write_enum_value("previewType", @preview_type) writer.write_object_value("references", @references) end |