Class: MicrosoftGraph::Models::PrintMargin
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::PrintMargin
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/print_margin.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#bottom ⇒ Object
Gets the bottom property value.
-
#bottom=(value) ⇒ Object
Sets the bottom property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new printMargin and sets the default values.
-
#left ⇒ Object
Gets the left property value.
-
#left=(value) ⇒ Object
Sets the left property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#right ⇒ Object
Gets the right property value.
-
#right=(value) ⇒ Object
Sets the right property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#top ⇒ Object
Gets the top property value.
-
#top=(value) ⇒ Object
Sets the top property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new printMargin and sets the default values.
61 62 63 |
# File 'lib/models/print_margin.rb', line 61 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
69 70 71 72 |
# File 'lib/models/print_margin.rb', line 69 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return PrintMargin.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/models/print_margin.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/models/print_margin.rb', line 39 def additional_data=(value) @additional_data = value end |
#bottom ⇒ Object
Gets the bottom property value. The margin in microns from the bottom edge.
46 47 48 |
# File 'lib/models/print_margin.rb', line 46 def bottom return @bottom end |
#bottom=(value) ⇒ Object
Sets the bottom property value. The margin in microns from the bottom edge.
54 55 56 |
# File 'lib/models/print_margin.rb', line 54 def bottom=(value) @bottom = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
77 78 79 80 81 82 83 84 85 |
# File 'lib/models/print_margin.rb', line 77 def get_field_deserializers() return { "bottom" => lambda {|n| @bottom = n.get_number_value() }, "left" => lambda {|n| @left = n.get_number_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "right" => lambda {|n| @right = n.get_number_value() }, "top" => lambda {|n| @top = n.get_number_value() }, } end |
#left ⇒ Object
Gets the left property value. The margin in microns from the left edge.
90 91 92 |
# File 'lib/models/print_margin.rb', line 90 def left return @left end |
#left=(value) ⇒ Object
Sets the left property value. The margin in microns from the left edge.
98 99 100 |
# File 'lib/models/print_margin.rb', line 98 def left=(value) @left = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
105 106 107 |
# File 'lib/models/print_margin.rb', line 105 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
113 114 115 |
# File 'lib/models/print_margin.rb', line 113 def odata_type=(value) @odata_type = value end |
#right ⇒ Object
Gets the right property value. The margin in microns from the right edge.
120 121 122 |
# File 'lib/models/print_margin.rb', line 120 def right return @right end |
#right=(value) ⇒ Object
Sets the right property value. The margin in microns from the right edge.
128 129 130 |
# File 'lib/models/print_margin.rb', line 128 def right=(value) @right = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
136 137 138 139 140 141 142 143 144 |
# File 'lib/models/print_margin.rb', line 136 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("bottom", @bottom) writer.write_number_value("left", @left) writer.write_string_value("@odata.type", @odata_type) writer.write_number_value("right", @right) writer.write_number_value("top", @top) writer.write_additional_data(@additional_data) end |
#top ⇒ Object
Gets the top property value. The margin in microns from the top edge.
149 150 151 |
# File 'lib/models/print_margin.rb', line 149 def top return @top end |
#top=(value) ⇒ Object
Sets the top property value. The margin in microns from the top edge.
157 158 159 |
# File 'lib/models/print_margin.rb', line 157 def top=(value) @top = value end |