Class: MicrosoftGraph::Models::ReportRoot

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/report_root.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new reportRoot and sets the default values.



67
68
69
# File 'lib/models/report_root.rb', line 67

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a report_root

Raises:

  • (StandardError)


75
76
77
78
# File 'lib/models/report_root.rb', line 75

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ReportRoot.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



37
38
39
# File 'lib/models/report_root.rb', line 37

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



45
46
47
# File 'lib/models/report_root.rb', line 45

def additional_data=(value)
    @additional_data = value
end

#authentication_methodsObject

Gets the authenticationMethods property value. Container for navigation properties for Azure AD authentication methods resources.

Returns:

  • a authentication_methods_root



52
53
54
# File 'lib/models/report_root.rb', line 52

def authentication_methods
    return @authentication_methods
end

#authentication_methods=(value) ⇒ Object

Sets the authenticationMethods property value. Container for navigation properties for Azure AD authentication methods resources.

Parameters:

  • value

    Value to set for the authenticationMethods property.

Returns:

  • a void



60
61
62
# File 'lib/models/report_root.rb', line 60

def authentication_methods=(value)
    @authentication_methods = value
end

#daily_print_usage_by_printerObject

Gets the dailyPrintUsageByPrinter property value. Retrieve a list of daily print usage summaries, grouped by printer.

Returns:

  • a print_usage_by_printer



83
84
85
# File 'lib/models/report_root.rb', line 83

def daily_print_usage_by_printer
    return @daily_print_usage_by_printer
end

#daily_print_usage_by_printer=(value) ⇒ Object

Sets the dailyPrintUsageByPrinter property value. Retrieve a list of daily print usage summaries, grouped by printer.

Parameters:

  • value

    Value to set for the dailyPrintUsageByPrinter property.

Returns:

  • a void



91
92
93
# File 'lib/models/report_root.rb', line 91

def daily_print_usage_by_printer=(value)
    @daily_print_usage_by_printer = value
end

#daily_print_usage_by_userObject

Gets the dailyPrintUsageByUser property value. Retrieve a list of daily print usage summaries, grouped by user.

Returns:

  • a print_usage_by_user



98
99
100
# File 'lib/models/report_root.rb', line 98

def daily_print_usage_by_user
    return @daily_print_usage_by_user
end

#daily_print_usage_by_user=(value) ⇒ Object

Sets the dailyPrintUsageByUser property value. Retrieve a list of daily print usage summaries, grouped by user.

Parameters:

  • value

    Value to set for the dailyPrintUsageByUser property.

Returns:

  • a void



106
107
108
# File 'lib/models/report_root.rb', line 106

def daily_print_usage_by_user=(value)
    @daily_print_usage_by_user = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



113
114
115
116
117
118
119
120
121
122
123
# File 'lib/models/report_root.rb', line 113

def get_field_deserializers()
    return {
        "authenticationMethods" => lambda {|n| @authentication_methods = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AuthenticationMethodsRoot.create_from_discriminator_value(pn) }) },
        "dailyPrintUsageByPrinter" => lambda {|n| @daily_print_usage_by_printer = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByPrinter.create_from_discriminator_value(pn) }) },
        "dailyPrintUsageByUser" => lambda {|n| @daily_print_usage_by_user = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByUser.create_from_discriminator_value(pn) }) },
        "monthlyPrintUsageByPrinter" => lambda {|n| @monthly_print_usage_by_printer = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByPrinter.create_from_discriminator_value(pn) }) },
        "monthlyPrintUsageByUser" => lambda {|n| @monthly_print_usage_by_user = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByUser.create_from_discriminator_value(pn) }) },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "security" => lambda {|n| @security = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SecurityReportsRoot.create_from_discriminator_value(pn) }) },
    }
end

#monthly_print_usage_by_printerObject

Gets the monthlyPrintUsageByPrinter property value. Retrieve a list of monthly print usage summaries, grouped by printer.

Returns:

  • a print_usage_by_printer



128
129
130
# File 'lib/models/report_root.rb', line 128

def monthly_print_usage_by_printer
    return @monthly_print_usage_by_printer
end

#monthly_print_usage_by_printer=(value) ⇒ Object

Sets the monthlyPrintUsageByPrinter property value. Retrieve a list of monthly print usage summaries, grouped by printer.

Parameters:

  • value

    Value to set for the monthlyPrintUsageByPrinter property.

Returns:

  • a void



136
137
138
# File 'lib/models/report_root.rb', line 136

def monthly_print_usage_by_printer=(value)
    @monthly_print_usage_by_printer = value
end

#monthly_print_usage_by_userObject

Gets the monthlyPrintUsageByUser property value. Retrieve a list of monthly print usage summaries, grouped by user.

Returns:

  • a print_usage_by_user



143
144
145
# File 'lib/models/report_root.rb', line 143

def monthly_print_usage_by_user
    return @monthly_print_usage_by_user
end

#monthly_print_usage_by_user=(value) ⇒ Object

Sets the monthlyPrintUsageByUser property value. Retrieve a list of monthly print usage summaries, grouped by user.

Parameters:

  • value

    Value to set for the monthlyPrintUsageByUser property.

Returns:

  • a void



151
152
153
# File 'lib/models/report_root.rb', line 151

def monthly_print_usage_by_user=(value)
    @monthly_print_usage_by_user = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



158
159
160
# File 'lib/models/report_root.rb', line 158

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



166
167
168
# File 'lib/models/report_root.rb', line 166

def odata_type=(value)
    @odata_type = value
end

#securityObject

Gets the security property value. Represents an abstract type that contains resources for attack simulation and training reports.

Returns:

  • a security_reports_root



173
174
175
# File 'lib/models/report_root.rb', line 173

def security
    return @security
end

#security=(value) ⇒ Object

Sets the security property value. Represents an abstract type that contains resources for attack simulation and training reports.

Parameters:

  • value

    Value to set for the security property.

Returns:

  • a void



181
182
183
# File 'lib/models/report_root.rb', line 181

def security=(value)
    @security = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


189
190
191
192
193
194
195
196
197
198
199
# File 'lib/models/report_root.rb', line 189

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_object_value("authenticationMethods", @authentication_methods)
    writer.write_collection_of_object_values("dailyPrintUsageByPrinter", @daily_print_usage_by_printer)
    writer.write_collection_of_object_values("dailyPrintUsageByUser", @daily_print_usage_by_user)
    writer.write_collection_of_object_values("monthlyPrintUsageByPrinter", @monthly_print_usage_by_printer)
    writer.write_collection_of_object_values("monthlyPrintUsageByUser", @monthly_print_usage_by_user)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_object_value("security", @security)
    writer.write_additional_data(@additional_data)
end