Class: MicrosoftGraph::Models::SecurityBlobEvidence

Inherits:
SecurityAlertEvidence show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/security_blob_evidence.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from SecurityAlertEvidence

#additional_data, #additional_data=, #created_date_time, #created_date_time=, #detailed_roles, #detailed_roles=, #odata_type, #odata_type=, #remediation_status, #remediation_status=, #remediation_status_details, #remediation_status_details=, #roles, #roles=, #tags, #tags=, #verdict, #verdict=

Constructor Details

#initializeObject

Instantiates a new securityBlobEvidence and sets the default values.



43
44
45
46
# File 'lib/models/security_blob_evidence.rb', line 43

def initialize()
    super
    @odata_type = "#microsoft.graph.security.blobEvidence"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a security_blob_evidence

Raises:

  • (StandardError)


52
53
54
55
# File 'lib/models/security_blob_evidence.rb', line 52

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return SecurityBlobEvidence.new
end

Instance Method Details

#blob_containerObject

Gets the blobContainer property value. The container which the blob belongs to.

Returns:

  • a security_blob_container_evidence



28
29
30
# File 'lib/models/security_blob_evidence.rb', line 28

def blob_container
    return @blob_container
end

#blob_container=(value) ⇒ Object

Sets the blobContainer property value. The container which the blob belongs to.

Parameters:

  • value

    Value to set for the blobContainer property.

Returns:

  • a void



36
37
38
# File 'lib/models/security_blob_evidence.rb', line 36

def blob_container=(value)
    @blob_container = value
end

#etagObject

Gets the etag property value. The Etag associated with this blob.

Returns:

  • a string



60
61
62
# File 'lib/models/security_blob_evidence.rb', line 60

def etag
    return @etag
end

#etag=(value) ⇒ Object

Sets the etag property value. The Etag associated with this blob.

Parameters:

  • value

    Value to set for the etag property.

Returns:

  • a void



68
69
70
# File 'lib/models/security_blob_evidence.rb', line 68

def etag=(value)
    @etag = value
end

#file_hashesObject

Gets the fileHashes property value. The file hashes associated with this blob.

Returns:

  • a security_file_hash



75
76
77
# File 'lib/models/security_blob_evidence.rb', line 75

def file_hashes
    return @file_hashes
end

#file_hashes=(value) ⇒ Object

Sets the fileHashes property value. The file hashes associated with this blob.

Parameters:

  • value

    Value to set for the fileHashes property.

Returns:

  • a void



83
84
85
# File 'lib/models/security_blob_evidence.rb', line 83

def file_hashes=(value)
    @file_hashes = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



90
91
92
93
94
95
96
97
98
# File 'lib/models/security_blob_evidence.rb', line 90

def get_field_deserializers()
    return super.merge({
        "blobContainer" => lambda {|n| @blob_container = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SecurityBlobContainerEvidence.create_from_discriminator_value(pn) }) },
        "etag" => lambda {|n| @etag = n.get_string_value() },
        "fileHashes" => lambda {|n| @file_hashes = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::SecurityFileHash.create_from_discriminator_value(pn) }) },
        "name" => lambda {|n| @name = n.get_string_value() },
        "url" => lambda {|n| @url = n.get_string_value() },
    })
end

#nameObject

Gets the name property value. The name of the blob.

Returns:

  • a string



103
104
105
# File 'lib/models/security_blob_evidence.rb', line 103

def name
    return @name
end

#name=(value) ⇒ Object

Sets the name property value. The name of the blob.

Parameters:

  • value

    Value to set for the name property.

Returns:

  • a void



111
112
113
# File 'lib/models/security_blob_evidence.rb', line 111

def name=(value)
    @name = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


119
120
121
122
123
124
125
126
127
# File 'lib/models/security_blob_evidence.rb', line 119

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("blobContainer", @blob_container)
    writer.write_string_value("etag", @etag)
    writer.write_collection_of_object_values("fileHashes", @file_hashes)
    writer.write_string_value("name", @name)
    writer.write_string_value("url", @url)
end

#urlObject

Gets the url property value. The full URL representation of the blob.

Returns:

  • a string



132
133
134
# File 'lib/models/security_blob_evidence.rb', line 132

def url
    return @url
end

#url=(value) ⇒ Object

Sets the url property value. The full URL representation of the blob.

Parameters:

  • value

    Value to set for the url property.

Returns:

  • a void



140
141
142
# File 'lib/models/security_blob_evidence.rb', line 140

def url=(value)
    @url = value
end