Class: MicrosoftGraph::Models::SecurityCvssSummary

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/security_cvss_summary.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new securityCvssSummary and sets the default values.



43
44
45
# File 'lib/models/security_cvss_summary.rb', line 43

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a security_cvss_summary

Raises:

  • (StandardError)


51
52
53
54
# File 'lib/models/security_cvss_summary.rb', line 51

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return SecurityCvssSummary.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



28
29
30
# File 'lib/models/security_cvss_summary.rb', line 28

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



36
37
38
# File 'lib/models/security_cvss_summary.rb', line 36

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



59
60
61
62
63
64
65
66
# File 'lib/models/security_cvss_summary.rb', line 59

def get_field_deserializers()
    return {
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "score" => lambda {|n| @score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "severity" => lambda {|n| @severity = n.get_enum_value(MicrosoftGraph::Models::SecurityVulnerabilitySeverity) },
        "vectorString" => lambda {|n| @vector_string = n.get_string_value() },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



71
72
73
# File 'lib/models/security_cvss_summary.rb', line 71

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



79
80
81
# File 'lib/models/security_cvss_summary.rb', line 79

def odata_type=(value)
    @odata_type = value
end

#scoreObject

Gets the score property value. The CVSS score about this vulnerability.

Returns:

  • a double



86
87
88
# File 'lib/models/security_cvss_summary.rb', line 86

def score
    return @score
end

#score=(value) ⇒ Object

Sets the score property value. The CVSS score about this vulnerability.

Parameters:

  • value

    Value to set for the score property.

Returns:

  • a void



94
95
96
# File 'lib/models/security_cvss_summary.rb', line 94

def score=(value)
    @score = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


102
103
104
105
106
107
108
109
# File 'lib/models/security_cvss_summary.rb', line 102

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_object_value("score", @score)
    writer.write_enum_value("severity", @severity)
    writer.write_string_value("vectorString", @vector_string)
    writer.write_additional_data(@additional_data)
end

#severityObject

Gets the severity property value. The CVSS severity rating for this vulnerability. The possible values are: none, low, medium, high, critical, unknownFutureValue.

Returns:

  • a security_vulnerability_severity



114
115
116
# File 'lib/models/security_cvss_summary.rb', line 114

def severity
    return @severity
end

#severity=(value) ⇒ Object

Sets the severity property value. The CVSS severity rating for this vulnerability. The possible values are: none, low, medium, high, critical, unknownFutureValue.

Parameters:

  • value

    Value to set for the severity property.

Returns:

  • a void



122
123
124
# File 'lib/models/security_cvss_summary.rb', line 122

def severity=(value)
    @severity = value
end

#vector_stringObject

Gets the vectorString property value. The CVSS vector string for this vulnerability.

Returns:

  • a string



129
130
131
# File 'lib/models/security_cvss_summary.rb', line 129

def vector_string
    return @vector_string
end

#vector_string=(value) ⇒ Object

Sets the vectorString property value. The CVSS vector string for this vulnerability.

Parameters:

  • value

    Value to set for the vectorString property.

Returns:

  • a void



137
138
139
# File 'lib/models/security_cvss_summary.rb', line 137

def vector_string=(value)
    @vector_string = value
end