Class: MicrosoftGraph::Models::SecurityIpEvidence
- Inherits:
-
SecurityAlertEvidence
- Object
- SecurityAlertEvidence
- MicrosoftGraph::Models::SecurityIpEvidence
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/security_ip_evidence.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#country_letter_code ⇒ Object
Gets the countryLetterCode property value.
-
#country_letter_code=(value) ⇒ Object
Sets the countryLetterCode property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new securityIpEvidence and sets the default values.
-
#ip_address ⇒ Object
Gets the ipAddress property value.
-
#ip_address=(value) ⇒ Object
Sets the ipAddress property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from SecurityAlertEvidence
#additional_data, #additional_data=, #created_date_time, #created_date_time=, #detailed_roles, #detailed_roles=, #odata_type, #odata_type=, #remediation_status, #remediation_status=, #remediation_status_details, #remediation_status_details=, #roles, #roles=, #tags, #tags=, #verdict, #verdict=
Constructor Details
#initialize ⇒ Object
Instantiates a new securityIpEvidence and sets the default values.
19 20 21 22 |
# File 'lib/models/security_ip_evidence.rb', line 19 def initialize() super @odata_type = "#microsoft.graph.security.ipEvidence" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
43 44 45 46 |
# File 'lib/models/security_ip_evidence.rb', line 43 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SecurityIpEvidence.new end |
Instance Method Details
#country_letter_code ⇒ Object
Gets the countryLetterCode property value. The two-letter country code according to ISO 3166 format, for example: US, UK, CA, etc..).
27 28 29 |
# File 'lib/models/security_ip_evidence.rb', line 27 def country_letter_code return @country_letter_code end |
#country_letter_code=(value) ⇒ Object
Sets the countryLetterCode property value. The two-letter country code according to ISO 3166 format, for example: US, UK, CA, etc..).
35 36 37 |
# File 'lib/models/security_ip_evidence.rb', line 35 def country_letter_code=(value) @country_letter_code = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
51 52 53 54 55 56 |
# File 'lib/models/security_ip_evidence.rb', line 51 def get_field_deserializers() return super.merge({ "countryLetterCode" => lambda {|n| @country_letter_code = n.get_string_value() }, "ipAddress" => lambda {|n| @ip_address = n.get_string_value() }, }) end |
#ip_address ⇒ Object
Gets the ipAddress property value. The value of the IP Address, can be either in V4 address or V6 address format.
61 62 63 |
# File 'lib/models/security_ip_evidence.rb', line 61 def ip_address return @ip_address end |
#ip_address=(value) ⇒ Object
Sets the ipAddress property value. The value of the IP Address, can be either in V4 address or V6 address format.
69 70 71 |
# File 'lib/models/security_ip_evidence.rb', line 69 def ip_address=(value) @ip_address = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
77 78 79 80 81 82 |
# File 'lib/models/security_ip_evidence.rb', line 77 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("countryLetterCode", @country_letter_code) writer.write_string_value("ipAddress", @ip_address) end |