Class: MicrosoftGraph::Models::SecurityKubernetesSecretEvidence
- Inherits:
-
SecurityAlertEvidence
- Object
- SecurityAlertEvidence
- MicrosoftGraph::Models::SecurityKubernetesSecretEvidence
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/security_kubernetes_secret_evidence.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new securityKubernetesSecretEvidence and sets the default values.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#namespace ⇒ Object
Gets the namespace property value.
-
#namespace=(value) ⇒ Object
Sets the namespace property value.
-
#secret_type ⇒ Object
Gets the secretType property value.
-
#secret_type=(value) ⇒ Object
Sets the secretType property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from SecurityAlertEvidence
#additional_data, #additional_data=, #created_date_time, #created_date_time=, #detailed_roles, #detailed_roles=, #odata_type, #odata_type=, #remediation_status, #remediation_status=, #remediation_status_details, #remediation_status_details=, #roles, #roles=, #tags, #tags=, #verdict, #verdict=
Constructor Details
#initialize ⇒ Object
Instantiates a new securityKubernetesSecretEvidence and sets the default values.
22 23 24 25 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 22 def initialize() super @odata_type = "#microsoft.graph.security.kubernetesSecretEvidence" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
31 32 33 34 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 31 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SecurityKubernetesSecretEvidence.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
39 40 41 42 43 44 45 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 39 def get_field_deserializers() return super.merge({ "name" => lambda {|n| @name = n.get_string_value() }, "namespace" => lambda {|n| @namespace = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SecurityKubernetesNamespaceEvidence.create_from_discriminator_value(pn) }) }, "secretType" => lambda {|n| @secret_type = n.get_string_value() }, }) end |
#name ⇒ Object
Gets the name property value. The secret name.
50 51 52 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 50 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. The secret name.
58 59 60 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 58 def name=(value) @name = value end |
#namespace ⇒ Object
Gets the namespace property value. The secret namespace.
65 66 67 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 65 def namespace return @namespace end |
#namespace=(value) ⇒ Object
Sets the namespace property value. The secret namespace.
73 74 75 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 73 def namespace=(value) @namespace = value end |
#secret_type ⇒ Object
Gets the secretType property value. The secret type can include both built-in types and custom ones. Examples of built-in types are: Opaque, kubernetes.io/service-account-token, kubernetes.io/dockercfg, kubernetes.io/dockerconfigjson, kubernetes.io/basic-auth, kubernetes.io/ssh-auth, kubernetes.io/tls, bootstrap.kubernetes.io/token.
80 81 82 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 80 def secret_type return @secret_type end |
#secret_type=(value) ⇒ Object
Sets the secretType property value. The secret type can include both built-in types and custom ones. Examples of built-in types are: Opaque, kubernetes.io/service-account-token, kubernetes.io/dockercfg, kubernetes.io/dockerconfigjson, kubernetes.io/basic-auth, kubernetes.io/ssh-auth, kubernetes.io/tls, bootstrap.kubernetes.io/token.
88 89 90 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 88 def secret_type=(value) @secret_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
96 97 98 99 100 101 102 |
# File 'lib/models/security_kubernetes_secret_evidence.rb', line 96 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("name", @name) writer.write_object_value("namespace", @namespace) writer.write_string_value("secretType", @secret_type) end |