Class: MicrosoftGraph::Models::ServiceUpdateMessageViewpoint

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/service_update_message_viewpoint.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new serviceUpdateMessageViewpoint and sets the default values.



43
44
45
# File 'lib/models/service_update_message_viewpoint.rb', line 43

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a service_update_message_viewpoint

Raises:

  • (StandardError)


51
52
53
54
# File 'lib/models/service_update_message_viewpoint.rb', line 51

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ServiceUpdateMessageViewpoint.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



28
29
30
# File 'lib/models/service_update_message_viewpoint.rb', line 28

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



36
37
38
# File 'lib/models/service_update_message_viewpoint.rb', line 36

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



59
60
61
62
63
64
65
66
# File 'lib/models/service_update_message_viewpoint.rb', line 59

def get_field_deserializers()
    return {
        "isArchived" => lambda {|n| @is_archived = n.get_boolean_value() },
        "isFavorited" => lambda {|n| @is_favorited = n.get_boolean_value() },
        "isRead" => lambda {|n| @is_read = n.get_boolean_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
    }
end

#is_archivedObject

Gets the isArchived property value. Indicates whether the user archived the message.

Returns:

  • a boolean



71
72
73
# File 'lib/models/service_update_message_viewpoint.rb', line 71

def is_archived
    return @is_archived
end

#is_archived=(value) ⇒ Object

Sets the isArchived property value. Indicates whether the user archived the message.

Parameters:

  • value

    Value to set for the isArchived property.

Returns:

  • a void



79
80
81
# File 'lib/models/service_update_message_viewpoint.rb', line 79

def is_archived=(value)
    @is_archived = value
end

#is_favoritedObject

Gets the isFavorited property value. Indicates whether the user marked the message as favorite.

Returns:

  • a boolean



86
87
88
# File 'lib/models/service_update_message_viewpoint.rb', line 86

def is_favorited
    return @is_favorited
end

#is_favorited=(value) ⇒ Object

Sets the isFavorited property value. Indicates whether the user marked the message as favorite.

Parameters:

  • value

    Value to set for the isFavorited property.

Returns:

  • a void



94
95
96
# File 'lib/models/service_update_message_viewpoint.rb', line 94

def is_favorited=(value)
    @is_favorited = value
end

#is_readObject

Gets the isRead property value. Indicates whether the user read the message.

Returns:

  • a boolean



101
102
103
# File 'lib/models/service_update_message_viewpoint.rb', line 101

def is_read
    return @is_read
end

#is_read=(value) ⇒ Object

Sets the isRead property value. Indicates whether the user read the message.

Parameters:

  • value

    Value to set for the isRead property.

Returns:

  • a void



109
110
111
# File 'lib/models/service_update_message_viewpoint.rb', line 109

def is_read=(value)
    @is_read = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



116
117
118
# File 'lib/models/service_update_message_viewpoint.rb', line 116

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



124
125
126
# File 'lib/models/service_update_message_viewpoint.rb', line 124

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


132
133
134
135
136
137
138
139
# File 'lib/models/service_update_message_viewpoint.rb', line 132

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_boolean_value("isArchived", @is_archived)
    writer.write_boolean_value("isFavorited", @is_favorited)
    writer.write_boolean_value("isRead", @is_read)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_additional_data(@additional_data)
end