Class: MicrosoftGraph::Models::Site

Inherits:
BaseItem show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/site.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseItem

#created_by, #created_by=, #created_by_user, #created_by_user=, #created_date_time, #created_date_time=, #description, #description=, #e_tag, #e_tag=, #last_modified_by, #last_modified_by=, #last_modified_by_user, #last_modified_by_user=, #last_modified_date_time, #last_modified_date_time=, #name, #name=, #parent_reference, #parent_reference=, #web_url, #web_url=

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new site and sets the default values.



100
101
102
103
# File 'lib/models/site.rb', line 100

def initialize()
    super
    @odata_type = "#microsoft.graph.site"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Raises:

  • (StandardError)


124
125
126
127
# File 'lib/models/site.rb', line 124

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return Site.new
end

Instance Method Details

#analyticsObject

Gets the analytics property value. Analytics about the view activities that took place in this site.



70
71
72
# File 'lib/models/site.rb', line 70

def analytics
    return @analytics
end

#analytics=(value) ⇒ Object

Sets the analytics property value. Analytics about the view activities that took place in this site.



78
79
80
# File 'lib/models/site.rb', line 78

def analytics=(value)
    @analytics = value
end

#columnsObject

Gets the columns property value. The collection of column definitions reusable across lists under this site.



85
86
87
# File 'lib/models/site.rb', line 85

def columns
    return @columns
end

#columns=(value) ⇒ Object

Sets the columns property value. The collection of column definitions reusable across lists under this site.



93
94
95
# File 'lib/models/site.rb', line 93

def columns=(value)
    @columns = value
end

#content_typesObject

Gets the contentTypes property value. The collection of content types defined for this site.



108
109
110
# File 'lib/models/site.rb', line 108

def content_types
    return @content_types
end

#content_types=(value) ⇒ Object

Sets the contentTypes property value. The collection of content types defined for this site.



116
117
118
# File 'lib/models/site.rb', line 116

def content_types=(value)
    @content_types = value
end

#display_nameObject

Gets the displayName property value. The full title for the site. Read-only.



132
133
134
# File 'lib/models/site.rb', line 132

def display_name
    return @display_name
end

#display_name=(value) ⇒ Object

Sets the displayName property value. The full title for the site. Read-only.



140
141
142
# File 'lib/models/site.rb', line 140

def display_name=(value)
    @display_name = value
end

#driveObject

Gets the drive property value. The default drive (document library) for this site.



147
148
149
# File 'lib/models/site.rb', line 147

def drive
    return @drive
end

#drive=(value) ⇒ Object

Sets the drive property value. The default drive (document library) for this site.



155
156
157
# File 'lib/models/site.rb', line 155

def drive=(value)
    @drive = value
end

#drivesObject

Gets the drives property value. The collection of drives (document libraries) under this site.



162
163
164
# File 'lib/models/site.rb', line 162

def drives
    return @drives
end

#drives=(value) ⇒ Object

Sets the drives property value. The collection of drives (document libraries) under this site.



170
171
172
# File 'lib/models/site.rb', line 170

def drives=(value)
    @drives = value
end

#errorObject

Gets the error property value. The error property



177
178
179
# File 'lib/models/site.rb', line 177

def error
    return @error
end

#error=(value) ⇒ Object

Sets the error property value. The error property



185
186
187
# File 'lib/models/site.rb', line 185

def error=(value)
    @error = value
end

#external_columnsObject

Gets the externalColumns property value. The externalColumns property



192
193
194
# File 'lib/models/site.rb', line 192

def external_columns
    return @external_columns
end

#external_columns=(value) ⇒ Object

Sets the externalColumns property value. The externalColumns property



200
201
202
# File 'lib/models/site.rb', line 200

def external_columns=(value)
    @external_columns = value
end

#get_field_deserializersObject

The deserialization information for the current model



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/models/site.rb', line 207

def get_field_deserializers()
    return super.merge({
        "analytics" => lambda {|n| @analytics = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ItemAnalytics.create_from_discriminator_value(pn) }) },
        "columns" => lambda {|n| @columns = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ColumnDefinition.create_from_discriminator_value(pn) }) },
        "contentTypes" => lambda {|n| @content_types = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ContentType.create_from_discriminator_value(pn) }) },
        "displayName" => lambda {|n| @display_name = n.get_string_value() },
        "drive" => lambda {|n| @drive = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Drive.create_from_discriminator_value(pn) }) },
        "drives" => lambda {|n| @drives = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Drive.create_from_discriminator_value(pn) }) },
        "error" => lambda {|n| @error = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::PublicError.create_from_discriminator_value(pn) }) },
        "externalColumns" => lambda {|n| @external_columns = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ColumnDefinition.create_from_discriminator_value(pn) }) },
        "items" => lambda {|n| @items = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::BaseItem.create_from_discriminator_value(pn) }) },
        "lists" => lambda {|n| @lists = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::List.create_from_discriminator_value(pn) }) },
        "onenote" => lambda {|n| @onenote = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Onenote.create_from_discriminator_value(pn) }) },
        "operations" => lambda {|n| @operations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RichLongRunningOperation.create_from_discriminator_value(pn) }) },
        "permissions" => lambda {|n| @permissions = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Permission.create_from_discriminator_value(pn) }) },
        "root" => lambda {|n| @root = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Root.create_from_discriminator_value(pn) }) },
        "sharepointIds" => lambda {|n| @sharepoint_ids = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SharepointIds.create_from_discriminator_value(pn) }) },
        "siteCollection" => lambda {|n| @site_collection = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SiteCollection.create_from_discriminator_value(pn) }) },
        "sites" => lambda {|n| @sites = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Site.create_from_discriminator_value(pn) }) },
        "termStore" => lambda {|n| @term_store = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TermStoreStore.create_from_discriminator_value(pn) }) },
        "termStores" => lambda {|n| @term_stores = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreStore.create_from_discriminator_value(pn) }) },
    })
end

#itemsObject

Gets the items property value. Used to address any item contained in this site. This collection can’t be enumerated.



234
235
236
# File 'lib/models/site.rb', line 234

def items
    return @items
end

#items=(value) ⇒ Object

Sets the items property value. Used to address any item contained in this site. This collection can’t be enumerated.



242
243
244
# File 'lib/models/site.rb', line 242

def items=(value)
    @items = value
end

#listsObject

Gets the lists property value. The collection of lists under this site.



249
250
251
# File 'lib/models/site.rb', line 249

def lists
    return @lists
end

#lists=(value) ⇒ Object

Sets the lists property value. The collection of lists under this site.



257
258
259
# File 'lib/models/site.rb', line 257

def lists=(value)
    @lists = value
end

#onenoteObject

Gets the onenote property value. Calls the OneNote service for notebook related operations.



264
265
266
# File 'lib/models/site.rb', line 264

def onenote
    return @onenote
end

#onenote=(value) ⇒ Object

Sets the onenote property value. Calls the OneNote service for notebook related operations.



272
273
274
# File 'lib/models/site.rb', line 272

def onenote=(value)
    @onenote = value
end

#operationsObject

Gets the operations property value. The collection of long-running operations on the site.



279
280
281
# File 'lib/models/site.rb', line 279

def operations
    return @operations
end

#operations=(value) ⇒ Object

Sets the operations property value. The collection of long-running operations on the site.



287
288
289
# File 'lib/models/site.rb', line 287

def operations=(value)
    @operations = value
end

#permissionsObject

Gets the permissions property value. The permissions associated with the site. Nullable.



294
295
296
# File 'lib/models/site.rb', line 294

def permissions
    return @permissions
end

#permissions=(value) ⇒ Object

Sets the permissions property value. The permissions associated with the site. Nullable.



302
303
304
# File 'lib/models/site.rb', line 302

def permissions=(value)
    @permissions = value
end

#rootObject

Gets the root property value. If present, indicates that this is the root site in the site collection. Read-only.



309
310
311
# File 'lib/models/site.rb', line 309

def root
    return @root
end

#root=(value) ⇒ Object

Sets the root property value. If present, indicates that this is the root site in the site collection. Read-only.



317
318
319
# File 'lib/models/site.rb', line 317

def root=(value)
    @root = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Raises:

  • (StandardError)


325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/models/site.rb', line 325

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("analytics", @analytics)
    writer.write_collection_of_object_values("columns", @columns)
    writer.write_collection_of_object_values("contentTypes", @content_types)
    writer.write_string_value("displayName", @display_name)
    writer.write_object_value("drive", @drive)
    writer.write_collection_of_object_values("drives", @drives)
    writer.write_object_value("error", @error)
    writer.write_collection_of_object_values("externalColumns", @external_columns)
    writer.write_collection_of_object_values("items", @items)
    writer.write_collection_of_object_values("lists", @lists)
    writer.write_object_value("onenote", @onenote)
    writer.write_collection_of_object_values("operations", @operations)
    writer.write_collection_of_object_values("permissions", @permissions)
    writer.write_object_value("root", @root)
    writer.write_object_value("sharepointIds", @sharepoint_ids)
    writer.write_object_value("siteCollection", @site_collection)
    writer.write_collection_of_object_values("sites", @sites)
    writer.write_object_value("termStore", @term_store)
    writer.write_collection_of_object_values("termStores", @term_stores)
end

#sharepoint_idsObject

Gets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.



352
353
354
# File 'lib/models/site.rb', line 352

def sharepoint_ids
    return @sharepoint_ids
end

#sharepoint_ids=(value) ⇒ Object

Sets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.



360
361
362
# File 'lib/models/site.rb', line 360

def sharepoint_ids=(value)
    @sharepoint_ids = value
end

#site_collectionObject

Gets the siteCollection property value. Provides details about the site’s site collection. Available only on the root site. Read-only.



367
368
369
# File 'lib/models/site.rb', line 367

def site_collection
    return @site_collection
end

#site_collection=(value) ⇒ Object

Sets the siteCollection property value. Provides details about the site’s site collection. Available only on the root site. Read-only.



375
376
377
# File 'lib/models/site.rb', line 375

def site_collection=(value)
    @site_collection = value
end

#sitesObject

Gets the sites property value. The collection of the sub-sites under this site.



382
383
384
# File 'lib/models/site.rb', line 382

def sites
    return @sites
end

#sites=(value) ⇒ Object

Sets the sites property value. The collection of the sub-sites under this site.



390
391
392
# File 'lib/models/site.rb', line 390

def sites=(value)
    @sites = value
end

#term_storeObject

Gets the termStore property value. The default termStore under this site.



397
398
399
# File 'lib/models/site.rb', line 397

def term_store
    return @term_store
end

#term_store=(value) ⇒ Object

Sets the termStore property value. The default termStore under this site.



405
406
407
# File 'lib/models/site.rb', line 405

def term_store=(value)
    @term_store = value
end

#term_storesObject

Gets the termStores property value. The collection of termStores under this site.



412
413
414
# File 'lib/models/site.rb', line 412

def term_stores
    return @term_stores
end

#term_stores=(value) ⇒ Object

Sets the termStores property value. The collection of termStores under this site.



420
421
422
# File 'lib/models/site.rb', line 420

def term_stores=(value)
    @term_stores = value
end