Class: MicrosoftGraph::Models::TeamsApp

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/teams_app.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new teamsApp and sets the default values.



40
41
42
# File 'lib/models/teams_app.rb', line 40

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a teams_app

Raises:

  • (StandardError)


48
49
50
51
# File 'lib/models/teams_app.rb', line 48

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return TeamsApp.new
end

Instance Method Details

#app_definitionsObject

Gets the appDefinitions property value. The details for each version of the app.

Returns:

  • a teams_app_definition



25
26
27
# File 'lib/models/teams_app.rb', line 25

def app_definitions
    return @app_definitions
end

#app_definitions=(value) ⇒ Object

Sets the appDefinitions property value. The details for each version of the app.

Parameters:

  • value

    Value to set for the appDefinitions property.

Returns:

  • a void



33
34
35
# File 'lib/models/teams_app.rb', line 33

def app_definitions=(value)
    @app_definitions = value
end

#display_nameObject

Gets the displayName property value. The name of the catalog app provided by the app developer in the Microsoft Teams zip app package.

Returns:

  • a string



56
57
58
# File 'lib/models/teams_app.rb', line 56

def display_name
    return @display_name
end

#display_name=(value) ⇒ Object

Sets the displayName property value. The name of the catalog app provided by the app developer in the Microsoft Teams zip app package.

Parameters:

  • value

    Value to set for the displayName property.

Returns:

  • a void



64
65
66
# File 'lib/models/teams_app.rb', line 64

def display_name=(value)
    @display_name = value
end

#distribution_methodObject

Gets the distributionMethod property value. The method of distribution for the app. Read-only.

Returns:

  • a teams_app_distribution_method



71
72
73
# File 'lib/models/teams_app.rb', line 71

def distribution_method
    return @distribution_method
end

#distribution_method=(value) ⇒ Object

Sets the distributionMethod property value. The method of distribution for the app. Read-only.

Parameters:

  • value

    Value to set for the distributionMethod property.

Returns:

  • a void



79
80
81
# File 'lib/models/teams_app.rb', line 79

def distribution_method=(value)
    @distribution_method = value
end

#external_idObject

Gets the externalId property value. The ID of the catalog provided by the app developer in the Microsoft Teams zip app package.

Returns:

  • a string



86
87
88
# File 'lib/models/teams_app.rb', line 86

def external_id
    return @external_id
end

#external_id=(value) ⇒ Object

Sets the externalId property value. The ID of the catalog provided by the app developer in the Microsoft Teams zip app package.

Parameters:

  • value

    Value to set for the externalId property.

Returns:

  • a void



94
95
96
# File 'lib/models/teams_app.rb', line 94

def external_id=(value)
    @external_id = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



101
102
103
104
105
106
107
108
# File 'lib/models/teams_app.rb', line 101

def get_field_deserializers()
    return super.merge({
        "appDefinitions" => lambda {|n| @app_definitions = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TeamsAppDefinition.create_from_discriminator_value(pn) }) },
        "displayName" => lambda {|n| @display_name = n.get_string_value() },
        "distributionMethod" => lambda {|n| @distribution_method = n.get_enum_value(MicrosoftGraph::Models::TeamsAppDistributionMethod) },
        "externalId" => lambda {|n| @external_id = n.get_string_value() },
    })
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


114
115
116
117
118
119
120
121
# File 'lib/models/teams_app.rb', line 114

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("appDefinitions", @app_definitions)
    writer.write_string_value("displayName", @display_name)
    writer.write_enum_value("distributionMethod", @distribution_method)
    writer.write_string_value("externalId", @external_id)
end