Class: MicrosoftGraph::Models::TermStoreSet

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/term_store_set.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new termStoreSet and sets the default values.



53
54
55
# File 'lib/models/term_store_set.rb', line 53

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a term_store_set

Raises:

  • (StandardError)


76
77
78
79
# File 'lib/models/term_store_set.rb', line 76

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return TermStoreSet.new
end

Instance Method Details

#childrenObject

Gets the children property value. Children terms of set in term [store].

Returns:

  • a term_store_term



38
39
40
# File 'lib/models/term_store_set.rb', line 38

def children
    return @children
end

#children=(value) ⇒ Object

Sets the children property value. Children terms of set in term [store].

Parameters:

  • value

    Value to set for the children property.

Returns:

  • a void



46
47
48
# File 'lib/models/term_store_set.rb', line 46

def children=(value)
    @children = value
end

#created_date_timeObject

Gets the createdDateTime property value. Date and time of set creation. Read-only.

Returns:

  • a date_time



60
61
62
# File 'lib/models/term_store_set.rb', line 60

def created_date_time
    return @created_date_time
end

#created_date_time=(value) ⇒ Object

Sets the createdDateTime property value. Date and time of set creation. Read-only.

Parameters:

  • value

    Value to set for the createdDateTime property.

Returns:

  • a void



68
69
70
# File 'lib/models/term_store_set.rb', line 68

def created_date_time=(value)
    @created_date_time = value
end

#descriptionObject

Gets the description property value. Description that gives details on the term usage.

Returns:

  • a string



84
85
86
# File 'lib/models/term_store_set.rb', line 84

def description
    return @description
end

#description=(value) ⇒ Object

Sets the description property value. Description that gives details on the term usage.

Parameters:

  • value

    Value to set for the description property.

Returns:

  • a void



92
93
94
# File 'lib/models/term_store_set.rb', line 92

def description=(value)
    @description = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/models/term_store_set.rb', line 99

def get_field_deserializers()
    return super.merge({
        "children" => lambda {|n| @children = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreTerm.create_from_discriminator_value(pn) }) },
        "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() },
        "description" => lambda {|n| @description = n.get_string_value() },
        "localizedNames" => lambda {|n| @localized_names = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreLocalizedName.create_from_discriminator_value(pn) }) },
        "parentGroup" => lambda {|n| @parent_group = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TermStoreGroup.create_from_discriminator_value(pn) }) },
        "properties" => lambda {|n| @properties = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::KeyValue.create_from_discriminator_value(pn) }) },
        "relations" => lambda {|n| @relations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreRelation.create_from_discriminator_value(pn) }) },
        "terms" => lambda {|n| @terms = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreTerm.create_from_discriminator_value(pn) }) },
    })
end

#localized_namesObject

Gets the localizedNames property value. Name of the set for each languageTag.

Returns:

  • a term_store_localized_name



115
116
117
# File 'lib/models/term_store_set.rb', line 115

def localized_names
    return @localized_names
end

#localized_names=(value) ⇒ Object

Sets the localizedNames property value. Name of the set for each languageTag.

Parameters:

  • value

    Value to set for the localizedNames property.

Returns:

  • a void



123
124
125
# File 'lib/models/term_store_set.rb', line 123

def localized_names=(value)
    @localized_names = value
end

#parent_groupObject

Gets the parentGroup property value. The parentGroup property

Returns:

  • a term_store_group



130
131
132
# File 'lib/models/term_store_set.rb', line 130

def parent_group
    return @parent_group
end

#parent_group=(value) ⇒ Object

Sets the parentGroup property value. The parentGroup property

Parameters:

  • value

    Value to set for the parentGroup property.

Returns:

  • a void



138
139
140
# File 'lib/models/term_store_set.rb', line 138

def parent_group=(value)
    @parent_group = value
end

#propertiesObject

Gets the properties property value. Custom properties for the set.

Returns:

  • a key_value



145
146
147
# File 'lib/models/term_store_set.rb', line 145

def properties
    return @properties
end

#properties=(value) ⇒ Object

Sets the properties property value. Custom properties for the set.

Parameters:

  • value

    Value to set for the properties property.

Returns:

  • a void



153
154
155
# File 'lib/models/term_store_set.rb', line 153

def properties=(value)
    @properties = value
end

#relationsObject

Gets the relations property value. Indicates which terms have been pinned or reused directly under the set.

Returns:

  • a term_store_relation



160
161
162
# File 'lib/models/term_store_set.rb', line 160

def relations
    return @relations
end

#relations=(value) ⇒ Object

Sets the relations property value. Indicates which terms have been pinned or reused directly under the set.

Parameters:

  • value

    Value to set for the relations property.

Returns:

  • a void



168
169
170
# File 'lib/models/term_store_set.rb', line 168

def relations=(value)
    @relations = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/models/term_store_set.rb', line 176

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("children", @children)
    writer.write_date_time_value("createdDateTime", @created_date_time)
    writer.write_string_value("description", @description)
    writer.write_collection_of_object_values("localizedNames", @localized_names)
    writer.write_object_value("parentGroup", @parent_group)
    writer.write_collection_of_object_values("properties", @properties)
    writer.write_collection_of_object_values("relations", @relations)
    writer.write_collection_of_object_values("terms", @terms)
end

#termsObject

Gets the terms property value. All the terms under the set.

Returns:

  • a term_store_term



192
193
194
# File 'lib/models/term_store_set.rb', line 192

def terms
    return @terms
end

#terms=(value) ⇒ Object

Sets the terms property value. All the terms under the set.

Parameters:

  • value

    Value to set for the terms property.

Returns:

  • a void



200
201
202
# File 'lib/models/term_store_set.rb', line 200

def terms=(value)
    @terms = value
end