Class: MicrosoftGraph::Models::TermStoreTerm

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/term_store_term.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new termStoreTerm and sets the default values.



53
54
55
# File 'lib/models/term_store_term.rb', line 53

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Raises:

  • (StandardError)


76
77
78
79
# File 'lib/models/term_store_term.rb', line 76

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return TermStoreTerm.new
end

Instance Method Details

#childrenObject

Gets the children property value. Children of current term.



38
39
40
# File 'lib/models/term_store_term.rb', line 38

def children
    return @children
end

#children=(value) ⇒ Object

Sets the children property value. Children of current term.



46
47
48
# File 'lib/models/term_store_term.rb', line 46

def children=(value)
    @children = value
end

#created_date_timeObject

Gets the createdDateTime property value. Date and time of term creation. Read-only.



60
61
62
# File 'lib/models/term_store_term.rb', line 60

def created_date_time
    return @created_date_time
end

#created_date_time=(value) ⇒ Object

Sets the createdDateTime property value. Date and time of term creation. Read-only.



68
69
70
# File 'lib/models/term_store_term.rb', line 68

def created_date_time=(value)
    @created_date_time = value
end

#descriptionsObject

Gets the descriptions property value. Description about term that is dependent on the languageTag.



84
85
86
# File 'lib/models/term_store_term.rb', line 84

def descriptions
    return @descriptions
end

#descriptions=(value) ⇒ Object

Sets the descriptions property value. Description about term that is dependent on the languageTag.



92
93
94
# File 'lib/models/term_store_term.rb', line 92

def descriptions=(value)
    @descriptions = value
end

#get_field_deserializersObject

The deserialization information for the current model



99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/models/term_store_term.rb', line 99

def get_field_deserializers()
    return super.merge({
        "children" => lambda {|n| @children = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreTerm.create_from_discriminator_value(pn) }) },
        "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() },
        "descriptions" => lambda {|n| @descriptions = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreLocalizedDescription.create_from_discriminator_value(pn) }) },
        "labels" => lambda {|n| @labels = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreLocalizedLabel.create_from_discriminator_value(pn) }) },
        "lastModifiedDateTime" => lambda {|n| @last_modified_date_time = n.get_date_time_value() },
        "properties" => lambda {|n| @properties = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::KeyValue.create_from_discriminator_value(pn) }) },
        "relations" => lambda {|n| @relations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreRelation.create_from_discriminator_value(pn) }) },
        "set" => lambda {|n| @set = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TermStoreSet.create_from_discriminator_value(pn) }) },
    })
end

#labelsObject

Gets the labels property value. Label metadata for a term.



115
116
117
# File 'lib/models/term_store_term.rb', line 115

def labels
    return @labels
end

#labels=(value) ⇒ Object

Sets the labels property value. Label metadata for a term.



123
124
125
# File 'lib/models/term_store_term.rb', line 123

def labels=(value)
    @labels = value
end

#last_modified_date_timeObject

Gets the lastModifiedDateTime property value. Last date and time of term modification. Read-only.



130
131
132
# File 'lib/models/term_store_term.rb', line 130

def last_modified_date_time
    return @last_modified_date_time
end

#last_modified_date_time=(value) ⇒ Object

Sets the lastModifiedDateTime property value. Last date and time of term modification. Read-only.



138
139
140
# File 'lib/models/term_store_term.rb', line 138

def last_modified_date_time=(value)
    @last_modified_date_time = value
end

#propertiesObject

Gets the properties property value. Collection of properties on the term.



145
146
147
# File 'lib/models/term_store_term.rb', line 145

def properties
    return @properties
end

#properties=(value) ⇒ Object

Sets the properties property value. Collection of properties on the term.



153
154
155
# File 'lib/models/term_store_term.rb', line 153

def properties=(value)
    @properties = value
end

#relationsObject

Gets the relations property value. To indicate which terms are related to the current term as either pinned or reused.



160
161
162
# File 'lib/models/term_store_term.rb', line 160

def relations
    return @relations
end

#relations=(value) ⇒ Object

Sets the relations property value. To indicate which terms are related to the current term as either pinned or reused.



168
169
170
# File 'lib/models/term_store_term.rb', line 168

def relations=(value)
    @relations = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Raises:

  • (StandardError)


176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/models/term_store_term.rb', line 176

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("children", @children)
    writer.write_date_time_value("createdDateTime", @created_date_time)
    writer.write_collection_of_object_values("descriptions", @descriptions)
    writer.write_collection_of_object_values("labels", @labels)
    writer.write_date_time_value("lastModifiedDateTime", @last_modified_date_time)
    writer.write_collection_of_object_values("properties", @properties)
    writer.write_collection_of_object_values("relations", @relations)
    writer.write_object_value("set", @set)
end

#setObject

Gets the set property value. The [set] in which the term is created.



192
193
194
# File 'lib/models/term_store_term.rb', line 192

def set
    return @set
end

#set=(value) ⇒ Object

Sets the set property value. The [set] in which the term is created.



200
201
202
# File 'lib/models/term_store_term.rb', line 200

def set=(value)
    @set = value
end