Class: MicrosoftGraph::Models::ThumbnailSet

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/thumbnail_set.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new thumbnailSet and sets the default values.



25
26
27
# File 'lib/models/thumbnail_set.rb', line 25

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a thumbnail_set

Raises:

  • (StandardError)


33
34
35
36
# File 'lib/models/thumbnail_set.rb', line 33

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ThumbnailSet.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



41
42
43
44
45
46
47
48
# File 'lib/models/thumbnail_set.rb', line 41

def get_field_deserializers()
    return super.merge({
        "large" => lambda {|n| @large = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) },
        "medium" => lambda {|n| @medium = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) },
        "small" => lambda {|n| @small = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) },
        "source" => lambda {|n| @source = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) },
    })
end

#largeObject

Gets the large property value. A 1920x1920 scaled thumbnail.

Returns:

  • a thumbnail



53
54
55
# File 'lib/models/thumbnail_set.rb', line 53

def large
    return @large
end

#large=(value) ⇒ Object

Sets the large property value. A 1920x1920 scaled thumbnail.

Parameters:

  • value

    Value to set for the large property.

Returns:

  • a void



61
62
63
# File 'lib/models/thumbnail_set.rb', line 61

def large=(value)
    @large = value
end

#mediumObject

Gets the medium property value. A 176x176 scaled thumbnail.

Returns:

  • a thumbnail



68
69
70
# File 'lib/models/thumbnail_set.rb', line 68

def medium
    return @medium
end

#medium=(value) ⇒ Object

Sets the medium property value. A 176x176 scaled thumbnail.

Parameters:

  • value

    Value to set for the medium property.

Returns:

  • a void



76
77
78
# File 'lib/models/thumbnail_set.rb', line 76

def medium=(value)
    @medium = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


84
85
86
87
88
89
90
91
# File 'lib/models/thumbnail_set.rb', line 84

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("large", @large)
    writer.write_object_value("medium", @medium)
    writer.write_object_value("small", @small)
    writer.write_object_value("source", @source)
end

#smallObject

Gets the small property value. A 48x48 cropped thumbnail.

Returns:

  • a thumbnail



96
97
98
# File 'lib/models/thumbnail_set.rb', line 96

def small
    return @small
end

#small=(value) ⇒ Object

Sets the small property value. A 48x48 cropped thumbnail.

Parameters:

  • value

    Value to set for the small property.

Returns:

  • a void



104
105
106
# File 'lib/models/thumbnail_set.rb', line 104

def small=(value)
    @small = value
end

#sourceObject

Gets the source property value. A custom thumbnail image or the original image used to generate other thumbnails.

Returns:

  • a thumbnail



111
112
113
# File 'lib/models/thumbnail_set.rb', line 111

def source
    return @source
end

#source=(value) ⇒ Object

Sets the source property value. A custom thumbnail image or the original image used to generate other thumbnails.

Parameters:

  • value

    Value to set for the source property.

Returns:

  • a void



119
120
121
# File 'lib/models/thumbnail_set.rb', line 119

def source=(value)
    @source = value
end