Class: MicrosoftGraph::Models::Todo

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/todo.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new todo and sets the default values.



16
17
18
# File 'lib/models/todo.rb', line 16

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • The parse node to use to read the discriminator value and create the object

Returns:

  • a todo

Raises:



24
25
26
27
# File 'lib/models/todo.rb', line 24

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return Todo.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



32
33
34
35
36
# File 'lib/models/todo.rb', line 32

def get_field_deserializers()
    return super.merge({
        "lists" => lambda {|n| @lists = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TodoTaskList.create_from_discriminator_value(pn) }) },
    })
end

#listsObject

Gets the lists property value. The task lists in the users mailbox.

Returns:

  • a todo_task_list



41
42
43
# File 'lib/models/todo.rb', line 41

def lists
    return @lists
end

#lists=(value) ⇒ Object

Sets the lists property value. The task lists in the users mailbox.

Parameters:

  • Value to set for the lists property.

Returns:

  • a void



49
50
51
# File 'lib/models/todo.rb', line 49

def lists=(value)
    @lists = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • Serialization writer to use to serialize this model

Returns:

  • a void

Raises:



57
58
59
60
61
# File 'lib/models/todo.rb', line 57

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_collection_of_object_values("lists", @lists)
end