Class: MicrosoftGraph::Models::UnifiedRoleManagementPolicyEnablementRule
- Inherits:
-
UnifiedRoleManagementPolicyRule
- Object
- Entity
- UnifiedRoleManagementPolicyRule
- MicrosoftGraph::Models::UnifiedRoleManagementPolicyEnablementRule
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/unified_role_management_policy_enablement_rule.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#enabled_rules ⇒ Object
Gets the enabledRules property value.
-
#enabled_rules=(value) ⇒ Object
Sets the enabledRules property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new unifiedRoleManagementPolicyEnablementRule and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from UnifiedRoleManagementPolicyRule
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new unifiedRoleManagementPolicyEnablementRule and sets the default values.
16 17 18 19 |
# File 'lib/models/unified_role_management_policy_enablement_rule.rb', line 16 def initialize() super @odata_type = "#microsoft.graph.unifiedRoleManagementPolicyEnablementRule" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
25 26 27 28 |
# File 'lib/models/unified_role_management_policy_enablement_rule.rb', line 25 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UnifiedRoleManagementPolicyEnablementRule.new end |
Instance Method Details
#enabled_rules ⇒ Object
Gets the enabledRules property value. The collection of rules that are enabled for this policy rule. For example, MultiFactorAuthentication, Ticketing, and Justification.
33 34 35 |
# File 'lib/models/unified_role_management_policy_enablement_rule.rb', line 33 def enabled_rules return @enabled_rules end |
#enabled_rules=(value) ⇒ Object
Sets the enabledRules property value. The collection of rules that are enabled for this policy rule. For example, MultiFactorAuthentication, Ticketing, and Justification.
41 42 43 |
# File 'lib/models/unified_role_management_policy_enablement_rule.rb', line 41 def enabled_rules=(value) @enabled_rules = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
48 49 50 51 52 |
# File 'lib/models/unified_role_management_policy_enablement_rule.rb', line 48 def get_field_deserializers() return super.merge({ "enabledRules" => lambda {|n| @enabled_rules = n.get_collection_of_primitive_values(String) }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
58 59 60 61 62 |
# File 'lib/models/unified_role_management_policy_enablement_rule.rb', line 58 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_collection_of_primitive_values("enabledRules", @enabled_rules) end |