Class: MicrosoftGraph::Models::UriClickSecurityState
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::UriClickSecurityState
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/uri_click_security_state.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#click_action ⇒ Object
Gets the clickAction property value.
-
#click_action=(value) ⇒ Object
Sets the clickAction property value.
-
#click_date_time ⇒ Object
Gets the clickDateTime property value.
-
#click_date_time=(value) ⇒ Object
Sets the clickDateTime property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new uriClickSecurityState and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#source_id ⇒ Object
Gets the sourceId property value.
-
#source_id=(value) ⇒ Object
Sets the sourceId property value.
-
#uri_domain ⇒ Object
Gets the uriDomain property value.
-
#uri_domain=(value) ⇒ Object
Sets the uriDomain property value.
-
#verdict ⇒ Object
Gets the verdict property value.
-
#verdict=(value) ⇒ Object
Sets the verdict property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new uriClickSecurityState and sets the default values.
83 84 85 |
# File 'lib/models/uri_click_security_state.rb', line 83 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
91 92 93 94 |
# File 'lib/models/uri_click_security_state.rb', line 91 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UriClickSecurityState.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/models/uri_click_security_state.rb', line 38 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
46 47 48 |
# File 'lib/models/uri_click_security_state.rb', line 46 def additional_data=(value) @additional_data = value end |
#click_action ⇒ Object
Gets the clickAction property value. The clickAction property
53 54 55 |
# File 'lib/models/uri_click_security_state.rb', line 53 def click_action return @click_action end |
#click_action=(value) ⇒ Object
Sets the clickAction property value. The clickAction property
61 62 63 |
# File 'lib/models/uri_click_security_state.rb', line 61 def click_action=(value) @click_action = value end |
#click_date_time ⇒ Object
Gets the clickDateTime property value. The clickDateTime property
68 69 70 |
# File 'lib/models/uri_click_security_state.rb', line 68 def click_date_time return @click_date_time end |
#click_date_time=(value) ⇒ Object
Sets the clickDateTime property value. The clickDateTime property
76 77 78 |
# File 'lib/models/uri_click_security_state.rb', line 76 def click_date_time=(value) @click_date_time = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/models/uri_click_security_state.rb', line 99 def get_field_deserializers() return { "clickAction" => lambda {|n| @click_action = n.get_string_value() }, "clickDateTime" => lambda {|n| @click_date_time = n.get_date_time_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "sourceId" => lambda {|n| @source_id = n.get_string_value() }, "uriDomain" => lambda {|n| @uri_domain = n.get_string_value() }, "verdict" => lambda {|n| @verdict = n.get_string_value() }, } end |
#id ⇒ Object
Gets the id property value. The id property
114 115 116 |
# File 'lib/models/uri_click_security_state.rb', line 114 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
122 123 124 |
# File 'lib/models/uri_click_security_state.rb', line 122 def id=(value) @id = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
129 130 131 |
# File 'lib/models/uri_click_security_state.rb', line 129 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
137 138 139 |
# File 'lib/models/uri_click_security_state.rb', line 137 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/models/uri_click_security_state.rb', line 145 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("clickAction", @click_action) writer.write_date_time_value("clickDateTime", @click_date_time) writer.write_string_value("id", @id) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("sourceId", @source_id) writer.write_string_value("uriDomain", @uri_domain) writer.write_string_value("verdict", @verdict) writer.write_additional_data(@additional_data) end |
#source_id ⇒ Object
Gets the sourceId property value. The sourceId property
160 161 162 |
# File 'lib/models/uri_click_security_state.rb', line 160 def source_id return @source_id end |
#source_id=(value) ⇒ Object
Sets the sourceId property value. The sourceId property
168 169 170 |
# File 'lib/models/uri_click_security_state.rb', line 168 def source_id=(value) @source_id = value end |
#uri_domain ⇒ Object
Gets the uriDomain property value. The uriDomain property
175 176 177 |
# File 'lib/models/uri_click_security_state.rb', line 175 def uri_domain return @uri_domain end |
#uri_domain=(value) ⇒ Object
Sets the uriDomain property value. The uriDomain property
183 184 185 |
# File 'lib/models/uri_click_security_state.rb', line 183 def uri_domain=(value) @uri_domain = value end |
#verdict ⇒ Object
Gets the verdict property value. The verdict property
190 191 192 |
# File 'lib/models/uri_click_security_state.rb', line 190 def verdict return @verdict end |
#verdict=(value) ⇒ Object
Sets the verdict property value. The verdict property
198 199 200 |
# File 'lib/models/uri_click_security_state.rb', line 198 def verdict=(value) @verdict = value end |