Class: MicrosoftGraph::Models::UserExperienceAnalyticsAppHealthDeviceModelPerformance

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/user_experience_analytics_app_health_device_model_performance.rb

Overview

The user experience analytics device model performance entity contains device model performance details.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new userExperienceAnalyticsAppHealthDeviceModelPerformance and sets the default values.



48
49
50
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 48

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a user_experience_analytics_app_health_device_model_performance

Raises:

  • (StandardError)


56
57
58
59
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 56

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UserExperienceAnalyticsAppHealthDeviceModelPerformance.new
end

Instance Method Details

#active_device_countObject

Gets the activeDeviceCount property value. The number of active devices for the model. Valid values 0 to 2147483647. Supports: $filter, $select, $OrderBy. Read-only. Valid values -2147483648 to 2147483647

Returns:

  • a integer



33
34
35
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 33

def active_device_count
    return @active_device_count
end

#active_device_count=(value) ⇒ Object

Sets the activeDeviceCount property value. The number of active devices for the model. Valid values 0 to 2147483647. Supports: $filter, $select, $OrderBy. Read-only. Valid values -2147483648 to 2147483647

Parameters:

  • value

    Value to set for the activeDeviceCount property.

Returns:

  • a void



41
42
43
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 41

def active_device_count=(value)
    @active_device_count = value
end

#device_manufacturerObject

Gets the deviceManufacturer property value. The manufacturer name of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



64
65
66
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 64

def device_manufacturer
    return @device_manufacturer
end

#device_manufacturer=(value) ⇒ Object

Sets the deviceManufacturer property value. The manufacturer name of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the deviceManufacturer property.

Returns:

  • a void



72
73
74
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 72

def device_manufacturer=(value)
    @device_manufacturer = value
end

#device_modelObject

Gets the deviceModel property value. The model name of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



79
80
81
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 79

def device_model
    return @device_model
end

#device_model=(value) ⇒ Object

Sets the deviceModel property value. The model name of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the deviceModel property.

Returns:

  • a void



87
88
89
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 87

def device_model=(value)
    @device_model = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



94
95
96
97
98
99
100
101
102
103
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 94

def get_field_deserializers()
    return super.merge({
        "activeDeviceCount" => lambda {|n| @active_device_count = n.get_number_value() },
        "deviceManufacturer" => lambda {|n| @device_manufacturer = n.get_string_value() },
        "deviceModel" => lambda {|n| @device_model = n.get_string_value() },
        "healthStatus" => lambda {|n| @health_status = n.get_enum_value(MicrosoftGraph::Models::UserExperienceAnalyticsHealthState) },
        "meanTimeToFailureInMinutes" => lambda {|n| @mean_time_to_failure_in_minutes = n.get_number_value() },
        "modelAppHealthScore" => lambda {|n| @model_app_health_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
    })
end

#health_statusObject

Gets the healthStatus property value. The healthStatus property

Returns:

  • a user_experience_analytics_health_state



108
109
110
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 108

def health_status
    return @health_status
end

#health_status=(value) ⇒ Object

Sets the healthStatus property value. The healthStatus property

Parameters:

  • value

    Value to set for the healthStatus property.

Returns:

  • a void



116
117
118
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 116

def health_status=(value)
    @health_status = value
end

#mean_time_to_failure_in_minutesObject

Gets the meanTimeToFailureInMinutes property value. The mean time to failure for the application in minutes. Valid values 0 to 2147483647. Supports: $filter, $select, $OrderBy. Read-only. Valid values -2147483648 to 2147483647

Returns:

  • a integer



123
124
125
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 123

def mean_time_to_failure_in_minutes
    return @mean_time_to_failure_in_minutes
end

#mean_time_to_failure_in_minutes=(value) ⇒ Object

Sets the meanTimeToFailureInMinutes property value. The mean time to failure for the application in minutes. Valid values 0 to 2147483647. Supports: $filter, $select, $OrderBy. Read-only. Valid values -2147483648 to 2147483647

Parameters:

  • value

    Value to set for the meanTimeToFailureInMinutes property.

Returns:

  • a void



131
132
133
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 131

def mean_time_to_failure_in_minutes=(value)
    @mean_time_to_failure_in_minutes = value
end

#model_app_health_scoreObject

Gets the modelAppHealthScore property value. The application health score of the device model. Valid values 0 to 100. Supports: $filter, $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



138
139
140
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 138

def model_app_health_score
    return @model_app_health_score
end

#model_app_health_score=(value) ⇒ Object

Sets the modelAppHealthScore property value. The application health score of the device model. Valid values 0 to 100. Supports: $filter, $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the modelAppHealthScore property.

Returns:

  • a void



146
147
148
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 146

def model_app_health_score=(value)
    @model_app_health_score = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


154
155
156
157
158
159
160
161
162
163
# File 'lib/models/user_experience_analytics_app_health_device_model_performance.rb', line 154

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_number_value("activeDeviceCount", @active_device_count)
    writer.write_string_value("deviceManufacturer", @device_manufacturer)
    writer.write_string_value("deviceModel", @device_model)
    writer.write_enum_value("healthStatus", @health_status)
    writer.write_number_value("meanTimeToFailureInMinutes", @mean_time_to_failure_in_minutes)
    writer.write_object_value("modelAppHealthScore", @model_app_health_score)
end