Class: MicrosoftGraph::Models::UserExperienceAnalyticsAutopilotDevicesSummary

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/user_experience_analytics_autopilot_devices_summary.rb

Overview

The user experience analytics summary of Devices not windows autopilot ready.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new userExperienceAnalyticsAutopilotDevicesSummary and sets the default values.



45
46
47
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 45

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a user_experience_analytics_autopilot_devices_summary

Raises:

  • (StandardError)


53
54
55
56
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 53

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UserExperienceAnalyticsAutopilotDevicesSummary.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



30
31
32
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 30

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



38
39
40
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 38

def additional_data=(value)
    @additional_data = value
end

#devices_not_autopilot_registeredObject

Gets the devicesNotAutopilotRegistered property value. The count of intune devices that are not autopilot registerd. Read-only.

Returns:

  • a integer



61
62
63
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 61

def devices_not_autopilot_registered
    return @devices_not_autopilot_registered
end

#devices_not_autopilot_registered=(value) ⇒ Object

Sets the devicesNotAutopilotRegistered property value. The count of intune devices that are not autopilot registerd. Read-only.

Parameters:

  • value

    Value to set for the devicesNotAutopilotRegistered property.

Returns:

  • a void



69
70
71
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 69

def devices_not_autopilot_registered=(value)
    @devices_not_autopilot_registered = value
end

#devices_without_autopilot_profile_assignedObject

Gets the devicesWithoutAutopilotProfileAssigned property value. The count of intune devices not autopilot profile assigned. Read-only.

Returns:

  • a integer



76
77
78
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 76

def devices_without_autopilot_profile_assigned
    return @devices_without_autopilot_profile_assigned
end

#devices_without_autopilot_profile_assigned=(value) ⇒ Object

Sets the devicesWithoutAutopilotProfileAssigned property value. The count of intune devices not autopilot profile assigned. Read-only.

Parameters:

  • value

    Value to set for the devicesWithoutAutopilotProfileAssigned property.

Returns:

  • a void



84
85
86
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 84

def devices_without_autopilot_profile_assigned=(value)
    @devices_without_autopilot_profile_assigned = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



91
92
93
94
95
96
97
98
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 91

def get_field_deserializers()
    return {
        "devicesNotAutopilotRegistered" => lambda {|n| @devices_not_autopilot_registered = n.get_number_value() },
        "devicesWithoutAutopilotProfileAssigned" => lambda {|n| @devices_without_autopilot_profile_assigned = n.get_number_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "totalWindows10DevicesWithoutTenantAttached" => lambda {|n| @total_windows10_devices_without_tenant_attached = n.get_number_value() },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



103
104
105
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 103

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



111
112
113
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 111

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


119
120
121
122
123
124
125
126
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 119

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_number_value("devicesNotAutopilotRegistered", @devices_not_autopilot_registered)
    writer.write_number_value("devicesWithoutAutopilotProfileAssigned", @devices_without_autopilot_profile_assigned)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_number_value("totalWindows10DevicesWithoutTenantAttached", @total_windows10_devices_without_tenant_attached)
    writer.write_additional_data(@additional_data)
end

#total_windows10_devices_without_tenant_attachedObject

Gets the totalWindows10DevicesWithoutTenantAttached property value. The count of windows 10 devices that are Intune and co-managed. Read-only.

Returns:

  • a integer



131
132
133
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 131

def total_windows10_devices_without_tenant_attached
    return @total_windows10_devices_without_tenant_attached
end

#total_windows10_devices_without_tenant_attached=(value) ⇒ Object

Sets the totalWindows10DevicesWithoutTenantAttached property value. The count of windows 10 devices that are Intune and co-managed. Read-only.

Parameters:

  • value

    Value to set for the totalWindows10DevicesWithoutTenantAttached property.

Returns:

  • a void



139
140
141
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 139

def total_windows10_devices_without_tenant_attached=(value)
    @total_windows10_devices_without_tenant_attached = value
end