Class: MicrosoftGraph::Models::UserExperienceAnalyticsWorkFromAnywhereDevice

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/user_experience_analytics_work_from_anywhere_device.rb

Overview

The user experience analytics device for work from anywhere report.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new userExperienceAnalyticsWorkFromAnywhereDevice and sets the default values.



252
253
254
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 252

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a user_experience_analytics_work_from_anywhere_device

Raises:

  • (StandardError)


260
261
262
263
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 260

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UserExperienceAnalyticsWorkFromAnywhereDevice.new
end

Instance Method Details

#auto_pilot_profile_assignedObject

Gets the autoPilotProfileAssigned property value. When TRUE, indicates the intune device’s autopilot profile is assigned. When FALSE, indicates it’s not Assigned. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



117
118
119
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 117

def auto_pilot_profile_assigned
    return @auto_pilot_profile_assigned
end

#auto_pilot_profile_assigned=(value) ⇒ Object

Sets the autoPilotProfileAssigned property value. When TRUE, indicates the intune device’s autopilot profile is assigned. When FALSE, indicates it’s not Assigned. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the autoPilotProfileAssigned property.

Returns:

  • a void



125
126
127
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 125

def auto_pilot_profile_assigned=(value)
    @auto_pilot_profile_assigned = value
end

#auto_pilot_registeredObject

Gets the autoPilotRegistered property value. When TRUE, indicates the intune device’s autopilot is registered. When FALSE, indicates it’s not registered. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



132
133
134
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 132

def auto_pilot_registered
    return @auto_pilot_registered
end

#auto_pilot_registered=(value) ⇒ Object

Sets the autoPilotRegistered property value. When TRUE, indicates the intune device’s autopilot is registered. When FALSE, indicates it’s not registered. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the autoPilotRegistered property.

Returns:

  • a void



140
141
142
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 140

def auto_pilot_registered=(value)
    @auto_pilot_registered = value
end

#azure_ad_device_idObject

Gets the azureAdDeviceId property value. The Azure Active Directory (Azure AD) device Id. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



147
148
149
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 147

def azure_ad_device_id
    return @azure_ad_device_id
end

#azure_ad_device_id=(value) ⇒ Object

Sets the azureAdDeviceId property value. The Azure Active Directory (Azure AD) device Id. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the azureAdDeviceId property.

Returns:

  • a void



155
156
157
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 155

def azure_ad_device_id=(value)
    @azure_ad_device_id = value
end

#azure_ad_join_typeObject

Gets the azureAdJoinType property value. The work from anywhere device’s Azure Active Directory (Azure AD) join type. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



162
163
164
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 162

def azure_ad_join_type
    return @azure_ad_join_type
end

#azure_ad_join_type=(value) ⇒ Object

Sets the azureAdJoinType property value. The work from anywhere device’s Azure Active Directory (Azure AD) join type. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the azureAdJoinType property.

Returns:

  • a void



170
171
172
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 170

def azure_ad_join_type=(value)
    @azure_ad_join_type = value
end

#azure_ad_registeredObject

Gets the azureAdRegistered property value. When TRUE, indicates the device’s Azure Active Directory (Azure AD) is registered. When False, indicates it’s not registered. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



177
178
179
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 177

def azure_ad_registered
    return @azure_ad_registered
end

#azure_ad_registered=(value) ⇒ Object

Sets the azureAdRegistered property value. When TRUE, indicates the device’s Azure Active Directory (Azure AD) is registered. When False, indicates it’s not registered. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the azureAdRegistered property.

Returns:

  • a void



185
186
187
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 185

def azure_ad_registered=(value)
    @azure_ad_registered = value
end

#cloud_identity_scoreObject

Gets the cloudIdentityScore property value. Indicates per device cloud identity score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



192
193
194
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 192

def cloud_identity_score
    return @cloud_identity_score
end

#cloud_identity_score=(value) ⇒ Object

Sets the cloudIdentityScore property value. Indicates per device cloud identity score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the cloudIdentityScore property.

Returns:

  • a void



200
201
202
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 200

def cloud_identity_score=(value)
    @cloud_identity_score = value
end

#cloud_management_scoreObject

Gets the cloudManagementScore property value. Indicates per device cloud management score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



207
208
209
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 207

def cloud_management_score
    return @cloud_management_score
end

#cloud_management_score=(value) ⇒ Object

Sets the cloudManagementScore property value. Indicates per device cloud management score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the cloudManagementScore property.

Returns:

  • a void



215
216
217
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 215

def cloud_management_score=(value)
    @cloud_management_score = value
end

#cloud_provisioning_scoreObject

Gets the cloudProvisioningScore property value. Indicates per device cloud provisioning score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



222
223
224
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 222

def cloud_provisioning_score
    return @cloud_provisioning_score
end

#cloud_provisioning_score=(value) ⇒ Object

Sets the cloudProvisioningScore property value. Indicates per device cloud provisioning score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the cloudProvisioningScore property.

Returns:

  • a void



230
231
232
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 230

def cloud_provisioning_score=(value)
    @cloud_provisioning_score = value
end

#compliance_policy_set_to_intuneObject

Gets the compliancePolicySetToIntune property value. When TRUE, indicates the device’s compliance policy is set to intune. When FALSE, indicates it’s not set to intune. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



237
238
239
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 237

def compliance_policy_set_to_intune
    return @compliance_policy_set_to_intune
end

#compliance_policy_set_to_intune=(value) ⇒ Object

Sets the compliancePolicySetToIntune property value. When TRUE, indicates the device’s compliance policy is set to intune. When FALSE, indicates it’s not set to intune. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the compliancePolicySetToIntune property.

Returns:

  • a void



245
246
247
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 245

def compliance_policy_set_to_intune=(value)
    @compliance_policy_set_to_intune = value
end

#device_idObject

Gets the deviceId property value. The Intune device id of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



268
269
270
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 268

def device_id
    return @device_id
end

#device_id=(value) ⇒ Object

Sets the deviceId property value. The Intune device id of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the deviceId property.

Returns:

  • a void



276
277
278
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 276

def device_id=(value)
    @device_id = value
end

#device_nameObject

Gets the deviceName property value. The name of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



283
284
285
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 283

def device_name
    return @device_name
end

#device_name=(value) ⇒ Object

Sets the deviceName property value. The name of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the deviceName property.

Returns:

  • a void



291
292
293
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 291

def device_name=(value)
    @device_name = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 298

def get_field_deserializers()
    return super.merge({
        "autoPilotProfileAssigned" => lambda {|n| @auto_pilot_profile_assigned = n.get_boolean_value() },
        "autoPilotRegistered" => lambda {|n| @auto_pilot_registered = n.get_boolean_value() },
        "azureAdDeviceId" => lambda {|n| @azure_ad_device_id = n.get_string_value() },
        "azureAdJoinType" => lambda {|n| @azure_ad_join_type = n.get_string_value() },
        "azureAdRegistered" => lambda {|n| @azure_ad_registered = n.get_boolean_value() },
        "cloudIdentityScore" => lambda {|n| @cloud_identity_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "cloudManagementScore" => lambda {|n| @cloud_management_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "cloudProvisioningScore" => lambda {|n| @cloud_provisioning_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "compliancePolicySetToIntune" => lambda {|n| @compliance_policy_set_to_intune = n.get_boolean_value() },
        "deviceId" => lambda {|n| @device_id = n.get_string_value() },
        "deviceName" => lambda {|n| @device_name = n.get_string_value() },
        "healthStatus" => lambda {|n| @health_status = n.get_enum_value(MicrosoftGraph::Models::UserExperienceAnalyticsHealthState) },
        "isCloudManagedGatewayEnabled" => lambda {|n| @is_cloud_managed_gateway_enabled = n.get_boolean_value() },
        "managedBy" => lambda {|n| @managed_by = n.get_string_value() },
        "manufacturer" => lambda {|n| @manufacturer = n.get_string_value() },
        "model" => lambda {|n| @model = n.get_string_value() },
        "osCheckFailed" => lambda {|n| @os_check_failed = n.get_boolean_value() },
        "osDescription" => lambda {|n| @os_description = n.get_string_value() },
        "osVersion" => lambda {|n| @os_version = n.get_string_value() },
        "otherWorkloadsSetToIntune" => lambda {|n| @other_workloads_set_to_intune = n.get_boolean_value() },
        "ownership" => lambda {|n| @ownership = n.get_string_value() },
        "processorCoreCountCheckFailed" => lambda {|n| @processor_core_count_check_failed = n.get_boolean_value() },
        "processorFamilyCheckFailed" => lambda {|n| @processor_family_check_failed = n.get_boolean_value() },
        "processorSpeedCheckFailed" => lambda {|n| @processor_speed_check_failed = n.get_boolean_value() },
        "processor64BitCheckFailed" => lambda {|n| @processor64_bit_check_failed = n.get_boolean_value() },
        "ramCheckFailed" => lambda {|n| @ram_check_failed = n.get_boolean_value() },
        "secureBootCheckFailed" => lambda {|n| @secure_boot_check_failed = n.get_boolean_value() },
        "serialNumber" => lambda {|n| @serial_number = n.get_string_value() },
        "storageCheckFailed" => lambda {|n| @storage_check_failed = n.get_boolean_value() },
        "tenantAttached" => lambda {|n| @tenant_attached = n.get_boolean_value() },
        "tpmCheckFailed" => lambda {|n| @tpm_check_failed = n.get_boolean_value() },
        "upgradeEligibility" => lambda {|n| @upgrade_eligibility = n.get_enum_value(MicrosoftGraph::Models::OperatingSystemUpgradeEligibility) },
        "windowsScore" => lambda {|n| @windows_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "workFromAnywhereScore" => lambda {|n| @work_from_anywhere_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
    })
end

#health_statusObject

Gets the healthStatus property value. The healthStatus property

Returns:

  • a user_experience_analytics_health_state



340
341
342
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 340

def health_status
    return @health_status
end

#health_status=(value) ⇒ Object

Sets the healthStatus property value. The healthStatus property

Parameters:

  • value

    Value to set for the healthStatus property.

Returns:

  • a void



348
349
350
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 348

def health_status=(value)
    @health_status = value
end

#is_cloud_managed_gateway_enabledObject

Gets the isCloudManagedGatewayEnabled property value. When TRUE, indicates the device’s Cloud Management Gateway for Configuration Manager is enabled. When FALSE, indicates it’s not enabled. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



355
356
357
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 355

def is_cloud_managed_gateway_enabled
    return @is_cloud_managed_gateway_enabled
end

#is_cloud_managed_gateway_enabled=(value) ⇒ Object

Sets the isCloudManagedGatewayEnabled property value. When TRUE, indicates the device’s Cloud Management Gateway for Configuration Manager is enabled. When FALSE, indicates it’s not enabled. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the isCloudManagedGatewayEnabled property.

Returns:

  • a void



363
364
365
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 363

def is_cloud_managed_gateway_enabled=(value)
    @is_cloud_managed_gateway_enabled = value
end

#managed_byObject

Gets the managedBy property value. The management agent of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



370
371
372
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 370

def managed_by
    return @managed_by
end

#managed_by=(value) ⇒ Object

Sets the managedBy property value. The management agent of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the managedBy property.

Returns:

  • a void



378
379
380
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 378

def managed_by=(value)
    @managed_by = value
end

#manufacturerObject

Gets the manufacturer property value. The manufacturer name of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



385
386
387
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 385

def manufacturer
    return @manufacturer
end

#manufacturer=(value) ⇒ Object

Sets the manufacturer property value. The manufacturer name of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the manufacturer property.

Returns:

  • a void



393
394
395
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 393

def manufacturer=(value)
    @manufacturer = value
end

#modelObject

Gets the model property value. The model name of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



400
401
402
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 400

def model
    return @model
end

#model=(value) ⇒ Object

Sets the model property value. The model name of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the model property.

Returns:

  • a void



408
409
410
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 408

def model=(value)
    @model = value
end

#os_check_failedObject

Gets the osCheckFailed property value. When TRUE, indicates OS check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



415
416
417
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 415

def os_check_failed
    return @os_check_failed
end

#os_check_failed=(value) ⇒ Object

Sets the osCheckFailed property value. When TRUE, indicates OS check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the osCheckFailed property.

Returns:

  • a void



423
424
425
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 423

def os_check_failed=(value)
    @os_check_failed = value
end

#os_descriptionObject

Gets the osDescription property value. The OS description of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



430
431
432
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 430

def os_description
    return @os_description
end

#os_description=(value) ⇒ Object

Sets the osDescription property value. The OS description of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the osDescription property.

Returns:

  • a void



438
439
440
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 438

def os_description=(value)
    @os_description = value
end

#os_versionObject

Gets the osVersion property value. The OS version of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



445
446
447
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 445

def os_version
    return @os_version
end

#os_version=(value) ⇒ Object

Sets the osVersion property value. The OS version of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the osVersion property.

Returns:

  • a void



453
454
455
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 453

def os_version=(value)
    @os_version = value
end

#other_workloads_set_to_intuneObject

Gets the otherWorkloadsSetToIntune property value. When TRUE, indicates the device’s other workloads is set to intune. When FALSE, indicates it’s not set to intune. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



460
461
462
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 460

def other_workloads_set_to_intune
    return @other_workloads_set_to_intune
end

#other_workloads_set_to_intune=(value) ⇒ Object

Sets the otherWorkloadsSetToIntune property value. When TRUE, indicates the device’s other workloads is set to intune. When FALSE, indicates it’s not set to intune. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the otherWorkloadsSetToIntune property.

Returns:

  • a void



468
469
470
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 468

def other_workloads_set_to_intune=(value)
    @other_workloads_set_to_intune = value
end

#ownershipObject

Gets the ownership property value. Ownership of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



475
476
477
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 475

def ownership
    return @ownership
end

#ownership=(value) ⇒ Object

Sets the ownership property value. Ownership of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the ownership property.

Returns:

  • a void



483
484
485
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 483

def ownership=(value)
    @ownership = value
end

#processor64_bit_check_failedObject

Gets the processor64BitCheckFailed property value. When TRUE, indicates processor hardware 64-bit architecture check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



535
536
537
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 535

def processor64_bit_check_failed
    return @processor64_bit_check_failed
end

#processor64_bit_check_failed=(value) ⇒ Object

Sets the processor64BitCheckFailed property value. When TRUE, indicates processor hardware 64-bit architecture check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the processor64BitCheckFailed property.

Returns:

  • a void



543
544
545
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 543

def processor64_bit_check_failed=(value)
    @processor64_bit_check_failed = value
end

#processor_core_count_check_failedObject

Gets the processorCoreCountCheckFailed property value. When TRUE, indicates processor hardware core count check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



490
491
492
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 490

def processor_core_count_check_failed
    return @processor_core_count_check_failed
end

#processor_core_count_check_failed=(value) ⇒ Object

Sets the processorCoreCountCheckFailed property value. When TRUE, indicates processor hardware core count check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the processorCoreCountCheckFailed property.

Returns:

  • a void



498
499
500
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 498

def processor_core_count_check_failed=(value)
    @processor_core_count_check_failed = value
end

#processor_family_check_failedObject

Gets the processorFamilyCheckFailed property value. When TRUE, indicates processor hardware family check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



505
506
507
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 505

def processor_family_check_failed
    return @processor_family_check_failed
end

#processor_family_check_failed=(value) ⇒ Object

Sets the processorFamilyCheckFailed property value. When TRUE, indicates processor hardware family check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the processorFamilyCheckFailed property.

Returns:

  • a void



513
514
515
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 513

def processor_family_check_failed=(value)
    @processor_family_check_failed = value
end

#processor_speed_check_failedObject

Gets the processorSpeedCheckFailed property value. When TRUE, indicates processor hardware speed check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



520
521
522
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 520

def processor_speed_check_failed
    return @processor_speed_check_failed
end

#processor_speed_check_failed=(value) ⇒ Object

Sets the processorSpeedCheckFailed property value. When TRUE, indicates processor hardware speed check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the processorSpeedCheckFailed property.

Returns:

  • a void



528
529
530
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 528

def processor_speed_check_failed=(value)
    @processor_speed_check_failed = value
end

#ram_check_failedObject

Gets the ramCheckFailed property value. When TRUE, indicates RAM hardware check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



550
551
552
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 550

def ram_check_failed
    return @ram_check_failed
end

#ram_check_failed=(value) ⇒ Object

Sets the ramCheckFailed property value. When TRUE, indicates RAM hardware check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the ramCheckFailed property.

Returns:

  • a void



558
559
560
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 558

def ram_check_failed=(value)
    @ram_check_failed = value
end

#secure_boot_check_failedObject

Gets the secureBootCheckFailed property value. When TRUE, indicates secure boot hardware check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



565
566
567
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 565

def secure_boot_check_failed
    return @secure_boot_check_failed
end

#secure_boot_check_failed=(value) ⇒ Object

Sets the secureBootCheckFailed property value. When TRUE, indicates secure boot hardware check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the secureBootCheckFailed property.

Returns:

  • a void



573
574
575
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 573

def secure_boot_check_failed=(value)
    @secure_boot_check_failed = value
end

#serial_numberObject

Gets the serialNumber property value. The serial number of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



580
581
582
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 580

def serial_number
    return @serial_number
end

#serial_number=(value) ⇒ Object

Sets the serialNumber property value. The serial number of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the serialNumber property.

Returns:

  • a void



588
589
590
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 588

def serial_number=(value)
    @serial_number = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 596

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_boolean_value("autoPilotProfileAssigned", @auto_pilot_profile_assigned)
    writer.write_boolean_value("autoPilotRegistered", @auto_pilot_registered)
    writer.write_string_value("azureAdDeviceId", @azure_ad_device_id)
    writer.write_string_value("azureAdJoinType", @azure_ad_join_type)
    writer.write_boolean_value("azureAdRegistered", @azure_ad_registered)
    writer.write_object_value("cloudIdentityScore", @cloud_identity_score)
    writer.write_object_value("cloudManagementScore", @cloud_management_score)
    writer.write_object_value("cloudProvisioningScore", @cloud_provisioning_score)
    writer.write_boolean_value("compliancePolicySetToIntune", @compliance_policy_set_to_intune)
    writer.write_string_value("deviceId", @device_id)
    writer.write_string_value("deviceName", @device_name)
    writer.write_enum_value("healthStatus", @health_status)
    writer.write_boolean_value("isCloudManagedGatewayEnabled", @is_cloud_managed_gateway_enabled)
    writer.write_string_value("managedBy", @managed_by)
    writer.write_string_value("manufacturer", @manufacturer)
    writer.write_string_value("model", @model)
    writer.write_boolean_value("osCheckFailed", @os_check_failed)
    writer.write_string_value("osDescription", @os_description)
    writer.write_string_value("osVersion", @os_version)
    writer.write_boolean_value("otherWorkloadsSetToIntune", @other_workloads_set_to_intune)
    writer.write_string_value("ownership", @ownership)
    writer.write_boolean_value("processorCoreCountCheckFailed", @processor_core_count_check_failed)
    writer.write_boolean_value("processorFamilyCheckFailed", @processor_family_check_failed)
    writer.write_boolean_value("processorSpeedCheckFailed", @processor_speed_check_failed)
    writer.write_boolean_value("processor64BitCheckFailed", @processor64_bit_check_failed)
    writer.write_boolean_value("ramCheckFailed", @ram_check_failed)
    writer.write_boolean_value("secureBootCheckFailed", @secure_boot_check_failed)
    writer.write_string_value("serialNumber", @serial_number)
    writer.write_boolean_value("storageCheckFailed", @storage_check_failed)
    writer.write_boolean_value("tenantAttached", @tenant_attached)
    writer.write_boolean_value("tpmCheckFailed", @tpm_check_failed)
    writer.write_enum_value("upgradeEligibility", @upgrade_eligibility)
    writer.write_object_value("windowsScore", @windows_score)
    writer.write_object_value("workFromAnywhereScore", @work_from_anywhere_score)
end

#storage_check_failedObject

Gets the storageCheckFailed property value. When TRUE, indicates storage hardware check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



638
639
640
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 638

def storage_check_failed
    return @storage_check_failed
end

#storage_check_failed=(value) ⇒ Object

Sets the storageCheckFailed property value. When TRUE, indicates storage hardware check failed for device to upgrade to the latest version of windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the storageCheckFailed property.

Returns:

  • a void



646
647
648
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 646

def storage_check_failed=(value)
    @storage_check_failed = value
end

#tenant_attachedObject

Gets the tenantAttached property value. When TRUE, indicates the device is Tenant Attached. When FALSE, indicates it’s not Tenant Attached. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



653
654
655
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 653

def tenant_attached
    return @tenant_attached
end

#tenant_attached=(value) ⇒ Object

Sets the tenantAttached property value. When TRUE, indicates the device is Tenant Attached. When FALSE, indicates it’s not Tenant Attached. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the tenantAttached property.

Returns:

  • a void



661
662
663
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 661

def tenant_attached=(value)
    @tenant_attached = value
end

#tpm_check_failedObject

Gets the tpmCheckFailed property value. When TRUE, indicates Trusted Platform Module (TPM) hardware check failed for device to the latest version of upgrade to windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Returns:

  • a boolean



668
669
670
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 668

def tpm_check_failed
    return @tpm_check_failed
end

#tpm_check_failed=(value) ⇒ Object

Sets the tpmCheckFailed property value. When TRUE, indicates Trusted Platform Module (TPM) hardware check failed for device to the latest version of upgrade to windows. When FALSE, indicates the check succeeded. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the tpmCheckFailed property.

Returns:

  • a void



676
677
678
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 676

def tpm_check_failed=(value)
    @tpm_check_failed = value
end

#upgrade_eligibilityObject

Gets the upgradeEligibility property value. Work From Anywhere windows device upgrade eligibility status.

Returns:

  • a operating_system_upgrade_eligibility



683
684
685
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 683

def upgrade_eligibility
    return @upgrade_eligibility
end

#upgrade_eligibility=(value) ⇒ Object

Sets the upgradeEligibility property value. Work From Anywhere windows device upgrade eligibility status.

Parameters:

  • value

    Value to set for the upgradeEligibility property.

Returns:

  • a void



691
692
693
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 691

def upgrade_eligibility=(value)
    @upgrade_eligibility = value
end

#windows_scoreObject

Gets the windowsScore property value. Indicates per device windows score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



698
699
700
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 698

def windows_score
    return @windows_score
end

#windows_score=(value) ⇒ Object

Sets the windowsScore property value. Indicates per device windows score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the windowsScore property.

Returns:

  • a void



706
707
708
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 706

def windows_score=(value)
    @windows_score = value
end

#work_from_anywhere_scoreObject

Gets the workFromAnywhereScore property value. Indicates work from anywhere per device overall score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



713
714
715
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 713

def work_from_anywhere_score
    return @work_from_anywhere_score
end

#work_from_anywhere_score=(value) ⇒ Object

Sets the workFromAnywhereScore property value. Indicates work from anywhere per device overall score. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the workFromAnywhereScore property.

Returns:

  • a void



721
722
723
# File 'lib/models/user_experience_analytics_work_from_anywhere_device.rb', line 721

def work_from_anywhere_score=(value)
    @work_from_anywhere_score = value
end