Class: MicrosoftGraph::Models::UserExperienceAnalyticsWorkFromAnywhereModelPerformance

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb

Overview

The user experience analytics work from anywhere model performance.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new userExperienceAnalyticsWorkFromAnywhereModelPerformance and sets the default values.



87
88
89
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 87

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a user_experience_analytics_work_from_anywhere_model_performance

Raises:

  • (StandardError)


95
96
97
98
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 95

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UserExperienceAnalyticsWorkFromAnywhereModelPerformance.new
end

Instance Method Details

#cloud_identity_scoreObject

Gets the cloudIdentityScore property value. The cloud identity score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



42
43
44
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 42

def cloud_identity_score
    return @cloud_identity_score
end

#cloud_identity_score=(value) ⇒ Object

Sets the cloudIdentityScore property value. The cloud identity score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the cloudIdentityScore property.

Returns:

  • a void



50
51
52
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 50

def cloud_identity_score=(value)
    @cloud_identity_score = value
end

#cloud_management_scoreObject

Gets the cloudManagementScore property value. The cloud management score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



57
58
59
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 57

def cloud_management_score
    return @cloud_management_score
end

#cloud_management_score=(value) ⇒ Object

Sets the cloudManagementScore property value. The cloud management score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the cloudManagementScore property.

Returns:

  • a void



65
66
67
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 65

def cloud_management_score=(value)
    @cloud_management_score = value
end

#cloud_provisioning_scoreObject

Gets the cloudProvisioningScore property value. The cloud provisioning score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



72
73
74
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 72

def cloud_provisioning_score
    return @cloud_provisioning_score
end

#cloud_provisioning_score=(value) ⇒ Object

Sets the cloudProvisioningScore property value. The cloud provisioning score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the cloudProvisioningScore property.

Returns:

  • a void



80
81
82
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 80

def cloud_provisioning_score=(value)
    @cloud_provisioning_score = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 103

def get_field_deserializers()
    return super.merge({
        "cloudIdentityScore" => lambda {|n| @cloud_identity_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "cloudManagementScore" => lambda {|n| @cloud_management_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "cloudProvisioningScore" => lambda {|n| @cloud_provisioning_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "healthStatus" => lambda {|n| @health_status = n.get_enum_value(MicrosoftGraph::Models::UserExperienceAnalyticsHealthState) },
        "manufacturer" => lambda {|n| @manufacturer = n.get_string_value() },
        "model" => lambda {|n| @model = n.get_string_value() },
        "modelDeviceCount" => lambda {|n| @model_device_count = n.get_number_value() },
        "windowsScore" => lambda {|n| @windows_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "workFromAnywhereScore" => lambda {|n| @work_from_anywhere_score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
    })
end

#health_statusObject

Gets the healthStatus property value. The healthStatus property

Returns:

  • a user_experience_analytics_health_state



120
121
122
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 120

def health_status
    return @health_status
end

#health_status=(value) ⇒ Object

Sets the healthStatus property value. The healthStatus property

Parameters:

  • value

    Value to set for the healthStatus property.

Returns:

  • a void



128
129
130
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 128

def health_status=(value)
    @health_status = value
end

#manufacturerObject

Gets the manufacturer property value. The manufacturer name of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



135
136
137
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 135

def manufacturer
    return @manufacturer
end

#manufacturer=(value) ⇒ Object

Sets the manufacturer property value. The manufacturer name of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the manufacturer property.

Returns:

  • a void



143
144
145
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 143

def manufacturer=(value)
    @manufacturer = value
end

#modelObject

Gets the model property value. The model name of the device. Supports: $select, $OrderBy. Read-only.

Returns:

  • a string



150
151
152
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 150

def model
    return @model
end

#model=(value) ⇒ Object

Sets the model property value. The model name of the device. Supports: $select, $OrderBy. Read-only.

Parameters:

  • value

    Value to set for the model property.

Returns:

  • a void



158
159
160
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 158

def model=(value)
    @model = value
end

#model_device_countObject

Gets the modelDeviceCount property value. The devices count for the model. Supports: $select, $OrderBy. Read-only. Valid values -2147483648 to 2147483647

Returns:

  • a integer



165
166
167
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 165

def model_device_count
    return @model_device_count
end

#model_device_count=(value) ⇒ Object

Sets the modelDeviceCount property value. The devices count for the model. Supports: $select, $OrderBy. Read-only. Valid values -2147483648 to 2147483647

Parameters:

  • value

    Value to set for the modelDeviceCount property.

Returns:

  • a void



173
174
175
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 173

def model_device_count=(value)
    @model_device_count = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 181

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("cloudIdentityScore", @cloud_identity_score)
    writer.write_object_value("cloudManagementScore", @cloud_management_score)
    writer.write_object_value("cloudProvisioningScore", @cloud_provisioning_score)
    writer.write_enum_value("healthStatus", @health_status)
    writer.write_string_value("manufacturer", @manufacturer)
    writer.write_string_value("model", @model)
    writer.write_number_value("modelDeviceCount", @model_device_count)
    writer.write_object_value("windowsScore", @windows_score)
    writer.write_object_value("workFromAnywhereScore", @work_from_anywhere_score)
end

#windows_scoreObject

Gets the windowsScore property value. The window score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



198
199
200
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 198

def windows_score
    return @windows_score
end

#windows_score=(value) ⇒ Object

Sets the windowsScore property value. The window score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the windowsScore property.

Returns:

  • a void



206
207
208
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 206

def windows_score=(value)
    @windows_score = value
end

#work_from_anywhere_scoreObject

Gets the workFromAnywhereScore property value. The work from anywhere score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Returns:

  • a double



213
214
215
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 213

def work_from_anywhere_score
    return @work_from_anywhere_score
end

#work_from_anywhere_score=(value) ⇒ Object

Sets the workFromAnywhereScore property value. The work from anywhere score of the device model. Valid values 0 to 100. Value -1 means associated score is unavailable. Supports: $select, $OrderBy. Read-only. Valid values -1.79769313486232E+308 to 1.79769313486232E+308

Parameters:

  • value

    Value to set for the workFromAnywhereScore property.

Returns:

  • a void



221
222
223
# File 'lib/models/user_experience_analytics_work_from_anywhere_model_performance.rb', line 221

def work_from_anywhere_score=(value)
    @work_from_anywhere_score = value
end