Class: MicrosoftGraph::Models::UserRegistrationMethodCount

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/user_registration_method_count.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new userRegistrationMethodCount and sets the default values.



55
56
57
# File 'lib/models/user_registration_method_count.rb', line 55

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a user_registration_method_count

Raises:

  • (StandardError)


63
64
65
66
# File 'lib/models/user_registration_method_count.rb', line 63

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UserRegistrationMethodCount.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



25
26
27
# File 'lib/models/user_registration_method_count.rb', line 25

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



33
34
35
# File 'lib/models/user_registration_method_count.rb', line 33

def additional_data=(value)
    @additional_data = value
end

#authentication_methodObject

Gets the authenticationMethod property value. Name of the authentication method.

Returns:

  • a string



40
41
42
# File 'lib/models/user_registration_method_count.rb', line 40

def authentication_method
    return @authentication_method
end

#authentication_method=(value) ⇒ Object

Sets the authenticationMethod property value. Name of the authentication method.

Parameters:

  • value

    Value to set for the authenticationMethod property.

Returns:

  • a void



48
49
50
# File 'lib/models/user_registration_method_count.rb', line 48

def authentication_method=(value)
    @authentication_method = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



71
72
73
74
75
76
77
# File 'lib/models/user_registration_method_count.rb', line 71

def get_field_deserializers()
    return {
        "authenticationMethod" => lambda {|n| @authentication_method = n.get_string_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "userCount" => lambda {|n| @user_count = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



82
83
84
# File 'lib/models/user_registration_method_count.rb', line 82

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



90
91
92
# File 'lib/models/user_registration_method_count.rb', line 90

def odata_type=(value)
    @odata_type = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


98
99
100
101
102
103
104
# File 'lib/models/user_registration_method_count.rb', line 98

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("authenticationMethod", @authentication_method)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_object_value("userCount", @user_count)
    writer.write_additional_data(@additional_data)
end

#user_countObject

Gets the userCount property value. Number of users registered.

Returns:

  • a int64



109
110
111
# File 'lib/models/user_registration_method_count.rb', line 109

def user_count
    return @user_count
end

#user_count=(value) ⇒ Object

Sets the userCount property value. Number of users registered.

Parameters:

  • value

    Value to set for the userCount property.

Returns:

  • a void



117
118
119
# File 'lib/models/user_registration_method_count.rb', line 117

def user_count=(value)
    @user_count = value
end