Class: MicrosoftGraph::Models::VppLicensingType
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::VppLicensingType
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/vpp_licensing_type.rb
Overview
Contains properties for iOS Volume-Purchased Program (Vpp) Licensing Type.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new vppLicensingType and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#supports_device_licensing ⇒ Object
Gets the supportsDeviceLicensing property value.
-
#supports_device_licensing=(value) ⇒ Object
Sets the supportsDeviceLicensing property value.
-
#supports_user_licensing ⇒ Object
Gets the supportsUserLicensing property value.
-
#supports_user_licensing=(value) ⇒ Object
Sets the supportsUserLicensing property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new vppLicensingType and sets the default values.
42 43 44 |
# File 'lib/models/vpp_licensing_type.rb', line 42 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
50 51 52 53 |
# File 'lib/models/vpp_licensing_type.rb', line 50 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return VppLicensingType.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
27 28 29 |
# File 'lib/models/vpp_licensing_type.rb', line 27 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
35 36 37 |
# File 'lib/models/vpp_licensing_type.rb', line 35 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
58 59 60 61 62 63 64 |
# File 'lib/models/vpp_licensing_type.rb', line 58 def get_field_deserializers() return { "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "supportsDeviceLicensing" => lambda {|n| @supports_device_licensing = n.get_boolean_value() }, "supportsUserLicensing" => lambda {|n| @supports_user_licensing = n.get_boolean_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
69 70 71 |
# File 'lib/models/vpp_licensing_type.rb', line 69 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
77 78 79 |
# File 'lib/models/vpp_licensing_type.rb', line 77 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
85 86 87 88 89 90 91 |
# File 'lib/models/vpp_licensing_type.rb', line 85 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("@odata.type", @odata_type) writer.write_boolean_value("supportsDeviceLicensing", @supports_device_licensing) writer.write_boolean_value("supportsUserLicensing", @supports_user_licensing) writer.write_additional_data(@additional_data) end |
#supports_device_licensing ⇒ Object
Gets the supportsDeviceLicensing property value. Whether the program supports the device licensing type.
96 97 98 |
# File 'lib/models/vpp_licensing_type.rb', line 96 def supports_device_licensing return @supports_device_licensing end |
#supports_device_licensing=(value) ⇒ Object
Sets the supportsDeviceLicensing property value. Whether the program supports the device licensing type.
104 105 106 |
# File 'lib/models/vpp_licensing_type.rb', line 104 def supports_device_licensing=(value) @supports_device_licensing = value end |
#supports_user_licensing ⇒ Object
Gets the supportsUserLicensing property value. Whether the program supports the user licensing type.
111 112 113 |
# File 'lib/models/vpp_licensing_type.rb', line 111 def supports_user_licensing return @supports_user_licensing end |
#supports_user_licensing=(value) ⇒ Object
Sets the supportsUserLicensing property value. Whether the program supports the user licensing type.
119 120 121 |
# File 'lib/models/vpp_licensing_type.rb', line 119 def supports_user_licensing=(value) @supports_user_licensing = value end |