Class: MicrosoftGraph::Models::WebApplication

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/web_application.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new webApplication and sets the default values.



49
50
51
# File 'lib/models/web_application.rb', line 49

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a web_application

Raises:

  • (StandardError)


57
58
59
60
# File 'lib/models/web_application.rb', line 57

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return WebApplication.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



34
35
36
# File 'lib/models/web_application.rb', line 34

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



42
43
44
# File 'lib/models/web_application.rb', line 42

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



65
66
67
68
69
70
71
72
73
74
# File 'lib/models/web_application.rb', line 65

def get_field_deserializers()
    return {
        "homePageUrl" => lambda {|n| @home_page_url = n.get_string_value() },
        "implicitGrantSettings" => lambda {|n| @implicit_grant_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ImplicitGrantSettings.create_from_discriminator_value(pn) }) },
        "logoutUrl" => lambda {|n| @logout_url = n.get_string_value() },
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "redirectUriSettings" => lambda {|n| @redirect_uri_settings = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RedirectUriSettings.create_from_discriminator_value(pn) }) },
        "redirectUris" => lambda {|n| @redirect_uris = n.get_collection_of_primitive_values(String) },
    }
end

#home_page_urlObject

Gets the homePageUrl property value. Home page or landing page of the application.

Returns:

  • a string



79
80
81
# File 'lib/models/web_application.rb', line 79

def home_page_url
    return @home_page_url
end

#home_page_url=(value) ⇒ Object

Sets the homePageUrl property value. Home page or landing page of the application.

Parameters:

  • value

    Value to set for the homePageUrl property.

Returns:

  • a void



87
88
89
# File 'lib/models/web_application.rb', line 87

def home_page_url=(value)
    @home_page_url = value
end

#implicit_grant_settingsObject

Gets the implicitGrantSettings property value. Specifies whether this web application can request tokens using the OAuth 2.0 implicit flow.

Returns:

  • a implicit_grant_settings



94
95
96
# File 'lib/models/web_application.rb', line 94

def implicit_grant_settings
    return @implicit_grant_settings
end

#implicit_grant_settings=(value) ⇒ Object

Sets the implicitGrantSettings property value. Specifies whether this web application can request tokens using the OAuth 2.0 implicit flow.

Parameters:

  • value

    Value to set for the implicitGrantSettings property.

Returns:

  • a void



102
103
104
# File 'lib/models/web_application.rb', line 102

def implicit_grant_settings=(value)
    @implicit_grant_settings = value
end

#logout_urlObject

Gets the logoutUrl property value. Specifies the URL that will be used by Microsoft’s authorization service to logout an user using front-channel, back-channel or SAML logout protocols.

Returns:

  • a string



109
110
111
# File 'lib/models/web_application.rb', line 109

def logout_url
    return @logout_url
end

#logout_url=(value) ⇒ Object

Sets the logoutUrl property value. Specifies the URL that will be used by Microsoft’s authorization service to logout an user using front-channel, back-channel or SAML logout protocols.

Parameters:

  • value

    Value to set for the logoutUrl property.

Returns:

  • a void



117
118
119
# File 'lib/models/web_application.rb', line 117

def logout_url=(value)
    @logout_url = value
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



124
125
126
# File 'lib/models/web_application.rb', line 124

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



132
133
134
# File 'lib/models/web_application.rb', line 132

def odata_type=(value)
    @odata_type = value
end

#redirect_uri_settingsObject

Gets the redirectUriSettings property value. The redirectUriSettings property

Returns:

  • a redirect_uri_settings



139
140
141
# File 'lib/models/web_application.rb', line 139

def redirect_uri_settings
    return @redirect_uri_settings
end

#redirect_uri_settings=(value) ⇒ Object

Sets the redirectUriSettings property value. The redirectUriSettings property

Parameters:

  • value

    Value to set for the redirectUriSettings property.

Returns:

  • a void



147
148
149
# File 'lib/models/web_application.rb', line 147

def redirect_uri_settings=(value)
    @redirect_uri_settings = value
end

#redirect_urisObject

Gets the redirectUris property value. Specifies the URLs where user tokens are sent for sign-in, or the redirect URIs where OAuth 2.0 authorization codes and access tokens are sent.

Returns:

  • a string



154
155
156
# File 'lib/models/web_application.rb', line 154

def redirect_uris
    return @redirect_uris
end

#redirect_uris=(value) ⇒ Object

Sets the redirectUris property value. Specifies the URLs where user tokens are sent for sign-in, or the redirect URIs where OAuth 2.0 authorization codes and access tokens are sent.

Parameters:

  • value

    Value to set for the redirectUris property.

Returns:

  • a void



162
163
164
# File 'lib/models/web_application.rb', line 162

def redirect_uris=(value)
    @redirect_uris = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


170
171
172
173
174
175
176
177
178
179
# File 'lib/models/web_application.rb', line 170

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("homePageUrl", @home_page_url)
    writer.write_object_value("implicitGrantSettings", @implicit_grant_settings)
    writer.write_string_value("logoutUrl", @logout_url)
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_collection_of_object_values("redirectUriSettings", @redirect_uri_settings)
    writer.write_collection_of_primitive_values("redirectUris", @redirect_uris)
    writer.write_additional_data(@additional_data)
end