Class: MicrosoftGraph::Models::Win32LobAppMsiInformation

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/win32_lob_app_msi_information.rb

Overview

Contains MSI app properties for a Win32 App.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new win32LobAppMsiInformation and sets the default values.



57
58
59
# File 'lib/models/win32_lob_app_msi_information.rb', line 57

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a win32_lob_app_msi_information

Raises:

  • (StandardError)


65
66
67
68
# File 'lib/models/win32_lob_app_msi_information.rb', line 65

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return Win32LobAppMsiInformation.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



42
43
44
# File 'lib/models/win32_lob_app_msi_information.rb', line 42

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



50
51
52
# File 'lib/models/win32_lob_app_msi_information.rb', line 50

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/models/win32_lob_app_msi_information.rb', line 73

def get_field_deserializers()
    return {
        "@odata.type" => lambda {|n| @odata_type = n.get_string_value() },
        "packageType" => lambda {|n| @package_type = n.get_enum_value(MicrosoftGraph::Models::Win32LobAppMsiPackageType) },
        "productCode" => lambda {|n| @product_code = n.get_string_value() },
        "productName" => lambda {|n| @product_name = n.get_string_value() },
        "productVersion" => lambda {|n| @product_version = n.get_string_value() },
        "publisher" => lambda {|n| @publisher = n.get_string_value() },
        "requiresReboot" => lambda {|n| @requires_reboot = n.get_boolean_value() },
        "upgradeCode" => lambda {|n| @upgrade_code = n.get_string_value() },
    }
end

#odata_typeObject

Gets the @odata.type property value. The OdataType property

Returns:

  • a string



89
90
91
# File 'lib/models/win32_lob_app_msi_information.rb', line 89

def odata_type
    return @odata_type
end

#odata_type=(value) ⇒ Object

Sets the @odata.type property value. The OdataType property

Parameters:

  • value

    Value to set for the @odata.type property.

Returns:

  • a void



97
98
99
# File 'lib/models/win32_lob_app_msi_information.rb', line 97

def odata_type=(value)
    @odata_type = value
end

#package_typeObject

Gets the packageType property value. Indicates the package type of an MSI Win32LobApp.

Returns:

  • a win32_lob_app_msi_package_type



104
105
106
# File 'lib/models/win32_lob_app_msi_information.rb', line 104

def package_type
    return @package_type
end

#package_type=(value) ⇒ Object

Sets the packageType property value. Indicates the package type of an MSI Win32LobApp.

Parameters:

  • value

    Value to set for the packageType property.

Returns:

  • a void



112
113
114
# File 'lib/models/win32_lob_app_msi_information.rb', line 112

def package_type=(value)
    @package_type = value
end

#product_codeObject

Gets the productCode property value. The MSI product code.

Returns:

  • a string



119
120
121
# File 'lib/models/win32_lob_app_msi_information.rb', line 119

def product_code
    return @product_code
end

#product_code=(value) ⇒ Object

Sets the productCode property value. The MSI product code.

Parameters:

  • value

    Value to set for the productCode property.

Returns:

  • a void



127
128
129
# File 'lib/models/win32_lob_app_msi_information.rb', line 127

def product_code=(value)
    @product_code = value
end

#product_nameObject

Gets the productName property value. The MSI product name.

Returns:

  • a string



134
135
136
# File 'lib/models/win32_lob_app_msi_information.rb', line 134

def product_name
    return @product_name
end

#product_name=(value) ⇒ Object

Sets the productName property value. The MSI product name.

Parameters:

  • value

    Value to set for the productName property.

Returns:

  • a void



142
143
144
# File 'lib/models/win32_lob_app_msi_information.rb', line 142

def product_name=(value)
    @product_name = value
end

#product_versionObject

Gets the productVersion property value. The MSI product version.

Returns:

  • a string



149
150
151
# File 'lib/models/win32_lob_app_msi_information.rb', line 149

def product_version
    return @product_version
end

#product_version=(value) ⇒ Object

Sets the productVersion property value. The MSI product version.

Parameters:

  • value

    Value to set for the productVersion property.

Returns:

  • a void



157
158
159
# File 'lib/models/win32_lob_app_msi_information.rb', line 157

def product_version=(value)
    @product_version = value
end

#publisherObject

Gets the publisher property value. The MSI publisher.

Returns:

  • a string



164
165
166
# File 'lib/models/win32_lob_app_msi_information.rb', line 164

def publisher
    return @publisher
end

#publisher=(value) ⇒ Object

Sets the publisher property value. The MSI publisher.

Parameters:

  • value

    Value to set for the publisher property.

Returns:

  • a void



172
173
174
# File 'lib/models/win32_lob_app_msi_information.rb', line 172

def publisher=(value)
    @publisher = value
end

#requires_rebootObject

Gets the requiresReboot property value. Whether the MSI app requires the machine to reboot to complete installation.

Returns:

  • a boolean



179
180
181
# File 'lib/models/win32_lob_app_msi_information.rb', line 179

def requires_reboot
    return @requires_reboot
end

#requires_reboot=(value) ⇒ Object

Sets the requiresReboot property value. Whether the MSI app requires the machine to reboot to complete installation.

Parameters:

  • value

    Value to set for the requiresReboot property.

Returns:

  • a void



187
188
189
# File 'lib/models/win32_lob_app_msi_information.rb', line 187

def requires_reboot=(value)
    @requires_reboot = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/models/win32_lob_app_msi_information.rb', line 195

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("@odata.type", @odata_type)
    writer.write_enum_value("packageType", @package_type)
    writer.write_string_value("productCode", @product_code)
    writer.write_string_value("productName", @product_name)
    writer.write_string_value("productVersion", @product_version)
    writer.write_string_value("publisher", @publisher)
    writer.write_boolean_value("requiresReboot", @requires_reboot)
    writer.write_string_value("upgradeCode", @upgrade_code)
    writer.write_additional_data(@additional_data)
end

#upgrade_codeObject

Gets the upgradeCode property value. The MSI upgrade code.

Returns:

  • a string



211
212
213
# File 'lib/models/win32_lob_app_msi_information.rb', line 211

def upgrade_code
    return @upgrade_code
end

#upgrade_code=(value) ⇒ Object

Sets the upgradeCode property value. The MSI upgrade code.

Parameters:

  • value

    Value to set for the upgradeCode property.

Returns:

  • a void



219
220
221
# File 'lib/models/win32_lob_app_msi_information.rb', line 219

def upgrade_code=(value)
    @upgrade_code = value
end