Class: MicrosoftGraph::Models::WindowsMalwareInformation

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/windows_malware_information.rb

Overview

Malware information entity.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new windowsMalwareInformation and sets the default values.



64
65
66
# File 'lib/models/windows_malware_information.rb', line 64

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a windows_malware_information

Raises:

  • (StandardError)


72
73
74
75
# File 'lib/models/windows_malware_information.rb', line 72

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return WindowsMalwareInformation.new
end

Instance Method Details

#additional_information_urlObject

Gets the additionalInformationUrl property value. Indicates an informational URL to learn more about the malware

Returns:

  • a string



34
35
36
# File 'lib/models/windows_malware_information.rb', line 34

def additional_information_url
    return @additional_information_url
end

#additional_information_url=(value) ⇒ Object

Sets the additionalInformationUrl property value. Indicates an informational URL to learn more about the malware

Parameters:

  • value

    Value to set for the additionalInformationUrl property.

Returns:

  • a void



42
43
44
# File 'lib/models/windows_malware_information.rb', line 42

def additional_information_url=(value)
    @additional_information_url = value
end

#categoryObject

Gets the category property value. Category of the malware. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule. default value is invalid. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule.

Returns:

  • a windows_malware_category



49
50
51
# File 'lib/models/windows_malware_information.rb', line 49

def category
    return @category
end

#category=(value) ⇒ Object

Sets the category property value. Category of the malware. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule. default value is invalid. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule.

Parameters:

  • value

    Value to set for the category property.

Returns:

  • a void



57
58
59
# File 'lib/models/windows_malware_information.rb', line 57

def category=(value)
    @category = value
end

#device_malware_statesObject

Gets the deviceMalwareStates property value. List of devices affected by current malware with the malware state on each device

Returns:

  • a malware_state_for_windows_device



80
81
82
# File 'lib/models/windows_malware_information.rb', line 80

def device_malware_states
    return @device_malware_states
end

#device_malware_states=(value) ⇒ Object

Sets the deviceMalwareStates property value. List of devices affected by current malware with the malware state on each device

Parameters:

  • value

    Value to set for the deviceMalwareStates property.

Returns:

  • a void



88
89
90
# File 'lib/models/windows_malware_information.rb', line 88

def device_malware_states=(value)
    @device_malware_states = value
end

#display_nameObject

Gets the displayName property value. Indicates the name of the malware

Returns:

  • a string



95
96
97
# File 'lib/models/windows_malware_information.rb', line 95

def display_name
    return @display_name
end

#display_name=(value) ⇒ Object

Sets the displayName property value. Indicates the name of the malware

Parameters:

  • value

    Value to set for the displayName property.

Returns:

  • a void



103
104
105
# File 'lib/models/windows_malware_information.rb', line 103

def display_name=(value)
    @display_name = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



110
111
112
113
114
115
116
117
118
119
# File 'lib/models/windows_malware_information.rb', line 110

def get_field_deserializers()
    return super.merge({
        "additionalInformationUrl" => lambda {|n| @additional_information_url = n.get_string_value() },
        "category" => lambda {|n| @category = n.get_enum_value(MicrosoftGraph::Models::WindowsMalwareCategory) },
        "deviceMalwareStates" => lambda {|n| @device_malware_states = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::MalwareStateForWindowsDevice.create_from_discriminator_value(pn) }) },
        "displayName" => lambda {|n| @display_name = n.get_string_value() },
        "lastDetectionDateTime" => lambda {|n| @last_detection_date_time = n.get_date_time_value() },
        "severity" => lambda {|n| @severity = n.get_enum_value(MicrosoftGraph::Models::WindowsMalwareSeverity) },
    })
end

#last_detection_date_timeObject

Gets the lastDetectionDateTime property value. Indicates the last time the malware was detected in UTC

Returns:

  • a date_time



124
125
126
# File 'lib/models/windows_malware_information.rb', line 124

def last_detection_date_time
    return @last_detection_date_time
end

#last_detection_date_time=(value) ⇒ Object

Sets the lastDetectionDateTime property value. Indicates the last time the malware was detected in UTC

Parameters:

  • value

    Value to set for the lastDetectionDateTime property.

Returns:

  • a void



132
133
134
# File 'lib/models/windows_malware_information.rb', line 132

def last_detection_date_time=(value)
    @last_detection_date_time = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


140
141
142
143
144
145
146
147
148
149
# File 'lib/models/windows_malware_information.rb', line 140

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("additionalInformationUrl", @additional_information_url)
    writer.write_enum_value("category", @category)
    writer.write_collection_of_object_values("deviceMalwareStates", @device_malware_states)
    writer.write_string_value("displayName", @display_name)
    writer.write_date_time_value("lastDetectionDateTime", @last_detection_date_time)
    writer.write_enum_value("severity", @severity)
end

#severityObject

Gets the severity property value. Severity of the malware. Possible values are: unknown, low, moderate, high, severe. default is unknown. Possible values are: unknown, low, moderate, high, severe.

Returns:

  • a windows_malware_severity



154
155
156
# File 'lib/models/windows_malware_information.rb', line 154

def severity
    return @severity
end

#severity=(value) ⇒ Object

Sets the severity property value. Severity of the malware. Possible values are: unknown, low, moderate, high, severe. default is unknown. Possible values are: unknown, low, moderate, high, severe.

Parameters:

  • value

    Value to set for the severity property.

Returns:

  • a void



162
163
164
# File 'lib/models/windows_malware_information.rb', line 162

def severity=(value)
    @severity = value
end