Class: MicrosoftGraph::Models::WindowsMobileMSI

Inherits:
MobileLobApp show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/windows_mobile_m_s_i.rb

Overview

Contains properties and inherited properties for Windows Mobile MSI Line Of Business apps.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MobileLobApp

#committed_content_version, #committed_content_version=, #content_versions, #content_versions=, #file_name, #file_name=, #size, #size=

Methods inherited from MobileApp

#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new windowsMobileMSI and sets the default values.



42
43
44
45
# File 'lib/models/windows_mobile_m_s_i.rb', line 42

def initialize()
    super
    @odata_type = "#microsoft.graph.windowsMobileMSI"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a windows_mobile_m_s_i

Raises:

  • (StandardError)


51
52
53
54
# File 'lib/models/windows_mobile_m_s_i.rb', line 51

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return WindowsMobileMSI.new
end

Instance Method Details

#command_lineObject

Gets the commandLine property value. The command line.

Returns:

  • a string



27
28
29
# File 'lib/models/windows_mobile_m_s_i.rb', line 27

def command_line
    return @command_line
end

#command_line=(value) ⇒ Object

Sets the commandLine property value. The command line.

Parameters:

  • value

    Value to set for the commandLine property.

Returns:

  • a void



35
36
37
# File 'lib/models/windows_mobile_m_s_i.rb', line 35

def command_line=(value)
    @command_line = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



59
60
61
62
63
64
65
66
# File 'lib/models/windows_mobile_m_s_i.rb', line 59

def get_field_deserializers()
    return super.merge({
        "commandLine" => lambda {|n| @command_line = n.get_string_value() },
        "ignoreVersionDetection" => lambda {|n| @ignore_version_detection = n.get_boolean_value() },
        "productCode" => lambda {|n| @product_code = n.get_string_value() },
        "productVersion" => lambda {|n| @product_version = n.get_string_value() },
    })
end

#ignore_version_detectionObject

Gets the ignoreVersionDetection property value. A boolean to control whether the app’s version will be used to detect the app after it is installed on a device. Set this to true for Windows Mobile MSI Line of Business (LoB) apps that use a self update feature.

Returns:

  • a boolean



71
72
73
# File 'lib/models/windows_mobile_m_s_i.rb', line 71

def ignore_version_detection
    return @ignore_version_detection
end

#ignore_version_detection=(value) ⇒ Object

Sets the ignoreVersionDetection property value. A boolean to control whether the app’s version will be used to detect the app after it is installed on a device. Set this to true for Windows Mobile MSI Line of Business (LoB) apps that use a self update feature.

Parameters:

  • value

    Value to set for the ignoreVersionDetection property.

Returns:

  • a void



79
80
81
# File 'lib/models/windows_mobile_m_s_i.rb', line 79

def ignore_version_detection=(value)
    @ignore_version_detection = value
end

#product_codeObject

Gets the productCode property value. The product code.

Returns:

  • a string



86
87
88
# File 'lib/models/windows_mobile_m_s_i.rb', line 86

def product_code
    return @product_code
end

#product_code=(value) ⇒ Object

Sets the productCode property value. The product code.

Parameters:

  • value

    Value to set for the productCode property.

Returns:

  • a void



94
95
96
# File 'lib/models/windows_mobile_m_s_i.rb', line 94

def product_code=(value)
    @product_code = value
end

#product_versionObject

Gets the productVersion property value. The product version of Windows Mobile MSI Line of Business (LoB) app.

Returns:

  • a string



101
102
103
# File 'lib/models/windows_mobile_m_s_i.rb', line 101

def product_version
    return @product_version
end

#product_version=(value) ⇒ Object

Sets the productVersion property value. The product version of Windows Mobile MSI Line of Business (LoB) app.

Parameters:

  • value

    Value to set for the productVersion property.

Returns:

  • a void



109
110
111
# File 'lib/models/windows_mobile_m_s_i.rb', line 109

def product_version=(value)
    @product_version = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


117
118
119
120
121
122
123
124
# File 'lib/models/windows_mobile_m_s_i.rb', line 117

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("commandLine", @command_line)
    writer.write_boolean_value("ignoreVersionDetection", @ignore_version_detection)
    writer.write_string_value("productCode", @product_code)
    writer.write_string_value("productVersion", @product_version)
end