Class: MicrosoftGraph::Models::WindowsUniversalAppX

Inherits:
MobileLobApp show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/windows_universal_app_x.rb

Overview

Contains properties and inherited properties for Windows Universal AppX Line Of Business apps.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MobileLobApp

#committed_content_version, #committed_content_version=, #content_versions, #content_versions=, #file_name, #file_name=, #size, #size=

Methods inherited from MobileApp

#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new windowsUniversalAppX and sets the default values.



87
88
89
90
# File 'lib/models/windows_universal_app_x.rb', line 87

def initialize()
    super
    @odata_type = "#microsoft.graph.windowsUniversalAppX"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a windows_universal_app_x

Raises:

  • (StandardError)


96
97
98
99
# File 'lib/models/windows_universal_app_x.rb', line 96

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return WindowsUniversalAppX.new
end

Instance Method Details

#applicable_architecturesObject

Gets the applicableArchitectures property value. Contains properties for Windows architecture.

Returns:

  • a windows_architecture



42
43
44
# File 'lib/models/windows_universal_app_x.rb', line 42

def applicable_architectures
    return @applicable_architectures
end

#applicable_architectures=(value) ⇒ Object

Sets the applicableArchitectures property value. Contains properties for Windows architecture.

Parameters:

  • value

    Value to set for the applicableArchitectures property.

Returns:

  • a void



50
51
52
# File 'lib/models/windows_universal_app_x.rb', line 50

def applicable_architectures=(value)
    @applicable_architectures = value
end

#applicable_device_typesObject

Gets the applicableDeviceTypes property value. Contains properties for Windows device type.

Returns:

  • a windows_device_type



57
58
59
# File 'lib/models/windows_universal_app_x.rb', line 57

def applicable_device_types
    return @applicable_device_types
end

#applicable_device_types=(value) ⇒ Object

Sets the applicableDeviceTypes property value. Contains properties for Windows device type.

Parameters:

  • value

    Value to set for the applicableDeviceTypes property.

Returns:

  • a void



65
66
67
# File 'lib/models/windows_universal_app_x.rb', line 65

def applicable_device_types=(value)
    @applicable_device_types = value
end

#committed_contained_appsObject

Gets the committedContainedApps property value. The collection of contained apps in the committed mobileAppContent of a windowsUniversalAppX app.

Returns:

  • a mobile_contained_app



72
73
74
# File 'lib/models/windows_universal_app_x.rb', line 72

def committed_contained_apps
    return @committed_contained_apps
end

#committed_contained_apps=(value) ⇒ Object

Sets the committedContainedApps property value. The collection of contained apps in the committed mobileAppContent of a windowsUniversalAppX app.

Parameters:

  • value

    Value to set for the committedContainedApps property.

Returns:

  • a void



80
81
82
# File 'lib/models/windows_universal_app_x.rb', line 80

def committed_contained_apps=(value)
    @committed_contained_apps = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/models/windows_universal_app_x.rb', line 104

def get_field_deserializers()
    return super.merge({
        "applicableArchitectures" => lambda {|n| @applicable_architectures = n.get_enum_value(MicrosoftGraph::Models::WindowsArchitecture) },
        "applicableDeviceTypes" => lambda {|n| @applicable_device_types = n.get_enum_value(MicrosoftGraph::Models::WindowsDeviceType) },
        "committedContainedApps" => lambda {|n| @committed_contained_apps = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::MobileContainedApp.create_from_discriminator_value(pn) }) },
        "identityName" => lambda {|n| @identity_name = n.get_string_value() },
        "identityPublisherHash" => lambda {|n| @identity_publisher_hash = n.get_string_value() },
        "identityResourceIdentifier" => lambda {|n| @identity_resource_identifier = n.get_string_value() },
        "identityVersion" => lambda {|n| @identity_version = n.get_string_value() },
        "isBundle" => lambda {|n| @is_bundle = n.get_boolean_value() },
        "minimumSupportedOperatingSystem" => lambda {|n| @minimum_supported_operating_system = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::WindowsMinimumOperatingSystem.create_from_discriminator_value(pn) }) },
    })
end

#identity_nameObject

Gets the identityName property value. The Identity Name.

Returns:

  • a string



121
122
123
# File 'lib/models/windows_universal_app_x.rb', line 121

def identity_name
    return @identity_name
end

#identity_name=(value) ⇒ Object

Sets the identityName property value. The Identity Name.

Parameters:

  • value

    Value to set for the identityName property.

Returns:

  • a void



129
130
131
# File 'lib/models/windows_universal_app_x.rb', line 129

def identity_name=(value)
    @identity_name = value
end

#identity_publisher_hashObject

Gets the identityPublisherHash property value. The Identity Publisher Hash.

Returns:

  • a string



136
137
138
# File 'lib/models/windows_universal_app_x.rb', line 136

def identity_publisher_hash
    return @identity_publisher_hash
end

#identity_publisher_hash=(value) ⇒ Object

Sets the identityPublisherHash property value. The Identity Publisher Hash.

Parameters:

  • value

    Value to set for the identityPublisherHash property.

Returns:

  • a void



144
145
146
# File 'lib/models/windows_universal_app_x.rb', line 144

def identity_publisher_hash=(value)
    @identity_publisher_hash = value
end

#identity_resource_identifierObject

Gets the identityResourceIdentifier property value. The Identity Resource Identifier.

Returns:

  • a string



151
152
153
# File 'lib/models/windows_universal_app_x.rb', line 151

def identity_resource_identifier
    return @identity_resource_identifier
end

#identity_resource_identifier=(value) ⇒ Object

Sets the identityResourceIdentifier property value. The Identity Resource Identifier.

Parameters:

  • value

    Value to set for the identityResourceIdentifier property.

Returns:

  • a void



159
160
161
# File 'lib/models/windows_universal_app_x.rb', line 159

def identity_resource_identifier=(value)
    @identity_resource_identifier = value
end

#identity_versionObject

Gets the identityVersion property value. The identity version.

Returns:

  • a string



166
167
168
# File 'lib/models/windows_universal_app_x.rb', line 166

def identity_version
    return @identity_version
end

#identity_version=(value) ⇒ Object

Sets the identityVersion property value. The identity version.

Parameters:

  • value

    Value to set for the identityVersion property.

Returns:

  • a void



174
175
176
# File 'lib/models/windows_universal_app_x.rb', line 174

def identity_version=(value)
    @identity_version = value
end

#is_bundleObject

Gets the isBundle property value. Whether or not the app is a bundle.

Returns:

  • a boolean



181
182
183
# File 'lib/models/windows_universal_app_x.rb', line 181

def is_bundle
    return @is_bundle
end

#is_bundle=(value) ⇒ Object

Sets the isBundle property value. Whether or not the app is a bundle.

Parameters:

  • value

    Value to set for the isBundle property.

Returns:

  • a void



189
190
191
# File 'lib/models/windows_universal_app_x.rb', line 189

def is_bundle=(value)
    @is_bundle = value
end

#minimum_supported_operating_systemObject

Gets the minimumSupportedOperatingSystem property value. The minimum operating system required for a Windows mobile app.

Returns:

  • a windows_minimum_operating_system



196
197
198
# File 'lib/models/windows_universal_app_x.rb', line 196

def minimum_supported_operating_system
    return @minimum_supported_operating_system
end

#minimum_supported_operating_system=(value) ⇒ Object

Sets the minimumSupportedOperatingSystem property value. The minimum operating system required for a Windows mobile app.

Parameters:

  • value

    Value to set for the minimumSupportedOperatingSystem property.

Returns:

  • a void



204
205
206
# File 'lib/models/windows_universal_app_x.rb', line 204

def minimum_supported_operating_system=(value)
    @minimum_supported_operating_system = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/models/windows_universal_app_x.rb', line 212

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_enum_value("applicableArchitectures", @applicable_architectures)
    writer.write_enum_value("applicableDeviceTypes", @applicable_device_types)
    writer.write_collection_of_object_values("committedContainedApps", @committed_contained_apps)
    writer.write_string_value("identityName", @identity_name)
    writer.write_string_value("identityPublisherHash", @identity_publisher_hash)
    writer.write_string_value("identityResourceIdentifier", @identity_resource_identifier)
    writer.write_string_value("identityVersion", @identity_version)
    writer.write_boolean_value("isBundle", @is_bundle)
    writer.write_object_value("minimumSupportedOperatingSystem", @minimum_supported_operating_system)
end