Class: MicrosoftGraph::Models::WindowsWebApp

Inherits:
MobileApp show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/windows_web_app.rb

Overview

Contains properties and inherited properties for Windows web apps.

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MobileApp

#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new windowsWebApp and sets the default values.



33
34
35
36
# File 'lib/models/windows_web_app.rb', line 33

def initialize()
    super
    @odata_type = "#microsoft.graph.windowsWebApp"
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a windows_web_app

Raises:

  • (StandardError)


42
43
44
45
# File 'lib/models/windows_web_app.rb', line 42

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return WindowsWebApp.new
end

Instance Method Details

#app_urlObject

Gets the appUrl property value. Indicates the Windows web app URL. Example: ‘www.contoso.com

Returns:

  • a string



18
19
20
# File 'lib/models/windows_web_app.rb', line 18

def app_url
    return @app_url
end

#app_url=(value) ⇒ Object

Sets the appUrl property value. Indicates the Windows web app URL. Example: ‘www.contoso.com

Parameters:

  • value

    Value to set for the appUrl property.

Returns:

  • a void



26
27
28
# File 'lib/models/windows_web_app.rb', line 26

def app_url=(value)
    @app_url = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



50
51
52
53
54
# File 'lib/models/windows_web_app.rb', line 50

def get_field_deserializers()
    return super.merge({
        "appUrl" => lambda {|n| @app_url = n.get_string_value() },
    })
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


60
61
62
63
64
# File 'lib/models/windows_web_app.rb', line 60

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_string_value("appUrl", @app_url)
end