Class: MicrosoftGraph::Models::WorkbookChartTitle

Inherits:
Entity
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/models/workbook_chart_title.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Entity

#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=

Constructor Details

#initializeObject

Instantiates a new workbookChartTitle and sets the default values.



25
26
27
# File 'lib/models/workbook_chart_title.rb', line 25

def initialize()
    super
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a workbook_chart_title

Raises:

  • (StandardError)


33
34
35
36
# File 'lib/models/workbook_chart_title.rb', line 33

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return WorkbookChartTitle.new
end

Instance Method Details

#formatObject

Gets the format property value. Represents the formatting of a chart title, which includes fill and font formatting. Read-only.

Returns:

  • a workbook_chart_title_format



41
42
43
# File 'lib/models/workbook_chart_title.rb', line 41

def format
    return @format
end

#format=(value) ⇒ Object

Sets the format property value. Represents the formatting of a chart title, which includes fill and font formatting. Read-only.

Parameters:

  • value

    Value to set for the format property.

Returns:

  • a void



49
50
51
# File 'lib/models/workbook_chart_title.rb', line 49

def format=(value)
    @format = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



56
57
58
59
60
61
62
63
# File 'lib/models/workbook_chart_title.rb', line 56

def get_field_deserializers()
    return super.merge({
        "format" => lambda {|n| @format = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::WorkbookChartTitleFormat.create_from_discriminator_value(pn) }) },
        "overlay" => lambda {|n| @overlay = n.get_boolean_value() },
        "text" => lambda {|n| @text = n.get_string_value() },
        "visible" => lambda {|n| @visible = n.get_boolean_value() },
    })
end

#overlayObject

Gets the overlay property value. Boolean value representing if the chart title will overlay the chart or not.

Returns:

  • a boolean



68
69
70
# File 'lib/models/workbook_chart_title.rb', line 68

def overlay
    return @overlay
end

#overlay=(value) ⇒ Object

Sets the overlay property value. Boolean value representing if the chart title will overlay the chart or not.

Parameters:

  • value

    Value to set for the overlay property.

Returns:

  • a void



76
77
78
# File 'lib/models/workbook_chart_title.rb', line 76

def overlay=(value)
    @overlay = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


84
85
86
87
88
89
90
91
# File 'lib/models/workbook_chart_title.rb', line 84

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    super
    writer.write_object_value("format", @format)
    writer.write_boolean_value("overlay", @overlay)
    writer.write_string_value("text", @text)
    writer.write_boolean_value("visible", @visible)
end

#textObject

Gets the text property value. Represents the title text of a chart.

Returns:

  • a string



96
97
98
# File 'lib/models/workbook_chart_title.rb', line 96

def text
    return @text
end

#text=(value) ⇒ Object

Sets the text property value. Represents the title text of a chart.

Parameters:

  • value

    Value to set for the text property.

Returns:

  • a void



104
105
106
# File 'lib/models/workbook_chart_title.rb', line 104

def text=(value)
    @text = value
end

#visibleObject

Gets the visible property value. A boolean value the represents the visibility of a chart title object.

Returns:

  • a boolean



111
112
113
# File 'lib/models/workbook_chart_title.rb', line 111

def visible
    return @visible
end

#visible=(value) ⇒ Object

Sets the visible property value. A boolean value the represents the visibility of a chart title object.

Parameters:

  • value

    Value to set for the visible property.

Returns:

  • a void



119
120
121
# File 'lib/models/workbook_chart_title.rb', line 119

def visible=(value)
    @visible = value
end