Class: MicrosoftGraph::Models::WorkbookRangeFill
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/workbook_range_fill.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#color ⇒ Object
Gets the color property value.
-
#color=(value) ⇒ Object
Sets the color property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new workbookRangeFill and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new workbookRangeFill and sets the default values.
31 32 33 |
# File 'lib/models/workbook_range_fill.rb', line 31 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
39 40 41 42 |
# File 'lib/models/workbook_range_fill.rb', line 39 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WorkbookRangeFill.new end |
Instance Method Details
#color ⇒ Object
Gets the color property value. HTML color code representing the color of the border line, of the form #RRGGBB (e.g. ‘FFA500’) or as a named HTML color (e.g. ‘orange’)
16 17 18 |
# File 'lib/models/workbook_range_fill.rb', line 16 def color return @color end |
#color=(value) ⇒ Object
Sets the color property value. HTML color code representing the color of the border line, of the form #RRGGBB (e.g. ‘FFA500’) or as a named HTML color (e.g. ‘orange’)
24 25 26 |
# File 'lib/models/workbook_range_fill.rb', line 24 def color=(value) @color = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
47 48 49 50 51 |
# File 'lib/models/workbook_range_fill.rb', line 47 def get_field_deserializers() return super.merge({ "color" => lambda {|n| @color = n.get_string_value() }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
57 58 59 60 61 |
# File 'lib/models/workbook_range_fill.rb', line 57 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("color", @color) end |