Class: MicrosoftGraph::Models::X509CertificateRule
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::X509CertificateRule
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/x509_certificate_rule.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#identifier ⇒ Object
Gets the identifier property value.
-
#identifier=(value) ⇒ Object
Sets the identifier property value.
-
#initialize ⇒ Object
constructor
Instantiates a new x509CertificateRule and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#x509_certificate_authentication_mode ⇒ Object
Gets the x509CertificateAuthenticationMode property value.
-
#x509_certificate_authentication_mode=(value) ⇒ Object
Sets the x509CertificateAuthenticationMode property value.
-
#x509_certificate_rule_type ⇒ Object
Gets the x509CertificateRuleType property value.
-
#x509_certificate_rule_type=(value) ⇒ Object
Sets the x509CertificateRuleType property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new x509CertificateRule and sets the default values.
43 44 45 |
# File 'lib/models/x509_certificate_rule.rb', line 43 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
51 52 53 54 |
# File 'lib/models/x509_certificate_rule.rb', line 51 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return X509CertificateRule.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
28 29 30 |
# File 'lib/models/x509_certificate_rule.rb', line 28 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
36 37 38 |
# File 'lib/models/x509_certificate_rule.rb', line 36 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
59 60 61 62 63 64 65 66 |
# File 'lib/models/x509_certificate_rule.rb', line 59 def get_field_deserializers() return { "identifier" => lambda {|n| @identifier = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "x509CertificateAuthenticationMode" => lambda {|n| @x509_certificate_authentication_mode = n.get_enum_value(MicrosoftGraph::Models::X509CertificateAuthenticationMode) }, "x509CertificateRuleType" => lambda {|n| @x509_certificate_rule_type = n.get_enum_value(MicrosoftGraph::Models::X509CertificateRuleType) }, } end |
#identifier ⇒ Object
Gets the identifier property value. The identifier of the X.509 certificate. Required.
71 72 73 |
# File 'lib/models/x509_certificate_rule.rb', line 71 def identifier return @identifier end |
#identifier=(value) ⇒ Object
Sets the identifier property value. The identifier of the X.509 certificate. Required.
79 80 81 |
# File 'lib/models/x509_certificate_rule.rb', line 79 def identifier=(value) @identifier = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
86 87 88 |
# File 'lib/models/x509_certificate_rule.rb', line 86 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
94 95 96 |
# File 'lib/models/x509_certificate_rule.rb', line 94 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
102 103 104 105 106 107 108 109 |
# File 'lib/models/x509_certificate_rule.rb', line 102 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("identifier", @identifier) writer.write_string_value("@odata.type", @odata_type) writer.write_enum_value("x509CertificateAuthenticationMode", @x509_certificate_authentication_mode) writer.write_enum_value("x509CertificateRuleType", @x509_certificate_rule_type) writer.write_additional_data(@additional_data) end |
#x509_certificate_authentication_mode ⇒ Object
Gets the x509CertificateAuthenticationMode property value. The type of strong authentication mode. The possible values are: x509CertificateSingleFactor, x509CertificateMultiFactor, unknownFutureValue. Required.
114 115 116 |
# File 'lib/models/x509_certificate_rule.rb', line 114 def x509_certificate_authentication_mode return @x509_certificate_authentication_mode end |
#x509_certificate_authentication_mode=(value) ⇒ Object
Sets the x509CertificateAuthenticationMode property value. The type of strong authentication mode. The possible values are: x509CertificateSingleFactor, x509CertificateMultiFactor, unknownFutureValue. Required.
122 123 124 |
# File 'lib/models/x509_certificate_rule.rb', line 122 def x509_certificate_authentication_mode=(value) @x509_certificate_authentication_mode = value end |
#x509_certificate_rule_type ⇒ Object
Gets the x509CertificateRuleType property value. The type of the X.509 certificate mode configuration rule. The possible values are: issuerSubject, policyOID, unknownFutureValue. Required.
129 130 131 |
# File 'lib/models/x509_certificate_rule.rb', line 129 def x509_certificate_rule_type return @x509_certificate_rule_type end |
#x509_certificate_rule_type=(value) ⇒ Object
Sets the x509CertificateRuleType property value. The type of the X.509 certificate mode configuration rule. The possible values are: issuerSubject, policyOID, unknownFutureValue. Required.
137 138 139 |
# File 'lib/models/x509_certificate_rule.rb', line 137 def x509_certificate_rule_type=(value) @x509_certificate_rule_type = value end |