Class: MicrosoftGraph::Oauth2PermissionGrants::Item::OAuth2PermissionGrantItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Oauth2PermissionGrants::Item::OAuth2PermissionGrantItemRequestBuilder
- Defined in:
- lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb
Overview
Provides operations to manage the collection of oAuth2PermissionGrant entities.
Defined Under Namespace
Classes: OAuth2PermissionGrantItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete a delegated permission grant, represented by an oAuth2PermissionGrant object.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties of a single delegated permission grant represented by an oAuth2PermissionGrant object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new OAuth2PermissionGrantItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of oAuth2PermissionGrant object, representing a delegated permission grant.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a delegated permission grant, represented by an oAuth2PermissionGrant object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties of a single delegated permission grant represented by an oAuth2PermissionGrant object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of oAuth2PermissionGrant object, representing a delegated permission grant.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new OAuth2PermissionGrantItemRequestBuilder and sets the default values.
21 22 23 |
# File 'lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb', line 21 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/oauth2PermissionGrants/{oAuth2PermissionGrant%2Did}{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete a delegated permission grant, represented by an oAuth2PermissionGrant object. When a delegated permission grant is deleted, the access it granted is revoked. Existing access tokens will continue to be valid for their lifetime, but new access tokens will not be granted for the delegated permissions identified in the deleted oAuth2PermissionGrant.
29 30 31 32 33 34 35 36 37 |
# File 'lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb', line 29 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties of a single delegated permission grant represented by an oAuth2PermissionGrant object. An oAuth2PermissionGrant represents delegated permissions which have been granted for a client application to access an API on behalf of a signed-in user.
43 44 45 46 47 48 49 50 51 |
# File 'lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb', line 43 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OAuth2PermissionGrant.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of oAuth2PermissionGrant object, representing a delegated permission grant. An oAuth2PermissionGrant can be updated to change which delegated permissions are granted, by adding or removing items from the list in scopes.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb', line 58 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OAuth2PermissionGrant.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a delegated permission grant, represented by an oAuth2PermissionGrant object. When a delegated permission grant is deleted, the access it granted is revoked. Existing access tokens will continue to be valid for their lifetime, but new access tokens will not be granted for the delegated permissions identified in the deleted oAuth2PermissionGrant.
73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb', line 73 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties of a single delegated permission grant represented by an oAuth2PermissionGrant object. An oAuth2PermissionGrant represents delegated permissions which have been granted for a client application to access an API on behalf of a signed-in user.
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb', line 89 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of oAuth2PermissionGrant object, representing a delegated permission grant. An oAuth2PermissionGrant can be updated to change which delegated permissions are granted, by adding or removing items from the list in scopes.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oauth2_permission_grants/item/o_auth2_permission_grant_item_request_builder.rb', line 108 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |