Class: MicrosoftGraph::Organization::Item::Branding::Localizations::LocalizationsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Organization::Item::Branding::Localizations::LocalizationsRequestBuilder
- Defined in:
- lib/organization/item/branding/localizations/localizations_request_builder.rb
Overview
Provides operations to manage the localizations property of the microsoft.graph.organizationalBranding entity.
Defined Under Namespace
Classes: LocalizationsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_organizational_branding_localization_id(organizational_branding_localization_id) ⇒ Object
Provides operations to manage the localizations property of the microsoft.graph.organizationalBranding entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve all localization branding objects, including the default branding.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new LocalizationsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a new organizationalBrandingLocalization object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve all localization branding objects, including the default branding.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new organizationalBrandingLocalization object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new LocalizationsRequestBuilder and sets the default values.
44 45 46 |
# File 'lib/organization/item/branding/localizations/localizations_request_builder.rb', line 44 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/organization/{organization%2Did}/branding/localizations{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_organizational_branding_localization_id(organizational_branding_localization_id) ⇒ Object
Provides operations to manage the localizations property of the microsoft.graph.organizationalBranding entity.
32 33 34 35 36 37 |
# File 'lib/organization/item/branding/localizations/localizations_request_builder.rb', line 32 def by_organizational_branding_localization_id(organizational_branding_localization_id) raise StandardError, 'organizational_branding_localization_id cannot be null' if organizational_branding_localization_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["organizationalBrandingLocalization%2Did"] = organizational_branding_localization_id return MicrosoftGraph::Organization::Item::Branding::Localizations::Item::OrganizationalBrandingLocalizationItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
24 25 26 |
# File 'lib/organization/item/branding/localizations/localizations_request_builder.rb', line 24 def count() return MicrosoftGraph::Organization::Item::Branding::Localizations::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve all localization branding objects, including the default branding.
52 53 54 55 56 57 58 59 60 |
# File 'lib/organization/item/branding/localizations/localizations_request_builder.rb', line 52 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OrganizationalBrandingLocalizationCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create a new organizationalBrandingLocalization object. This creates a localized branding and at the same time, the default branding if it doesn’t exist. The default branding is created only once. It’s loaded when a localized branding isn’t configured for the user’s browser language. To retrieve the default branding, see Get branding.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/organization/item/branding/localizations/localizations_request_builder.rb', line 67 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OrganizationalBrandingLocalization.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve all localization branding objects, including the default branding.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/organization/item/branding/localizations/localizations_request_builder.rb', line 82 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new organizationalBrandingLocalization object. This creates a localized branding and at the same time, the default branding if it doesn’t exist. The default branding is created only once. It’s loaded when a localized branding isn’t configured for the user’s browser language. To retrieve the default branding, see Get branding.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/organization/item/branding/localizations/localizations_request_builder.rb', line 101 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |