Class: MicrosoftGraph::Policies::AuthenticationStrengthPolicies::Item::AuthenticationStrengthPolicyItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Policies::AuthenticationStrengthPolicies::Item::AuthenticationStrengthPolicyItemRequestBuilder
- Defined in:
- lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb
Overview
Provides operations to manage the authenticationStrengthPolicies property of the microsoft.graph.policyRoot entity.
Defined Under Namespace
Classes: AuthenticationStrengthPolicyItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#combination_configurations ⇒ Object
Provides operations to manage the combinationConfigurations property of the microsoft.graph.authenticationStrengthPolicy entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete a custom authenticationStrengthPolicy object.
-
#get(request_configuration = nil) ⇒ Object
Read the properties and relationships of an authenticationStrengthPolicy object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new AuthenticationStrengthPolicyItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of an authenticationStrengthPolicy object.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a custom authenticationStrengthPolicy object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Read the properties and relationships of an authenticationStrengthPolicy object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of an authenticationStrengthPolicy object.
-
#update_allowed_combinations ⇒ Object
Provides operations to call the updateAllowedCombinations method.
-
#usage ⇒ Object
Provides operations to call the usage method.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new AuthenticationStrengthPolicyItemRequestBuilder and sets the default values.
41 42 43 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 41 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/policies/authenticationStrengthPolicies/{authenticationStrengthPolicy%2Did}{?%24select,%24expand}") end |
Instance Method Details
#combination_configurations ⇒ Object
Provides operations to manage the combinationConfigurations property of the microsoft.graph.authenticationStrengthPolicy entity.
22 23 24 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 22 def combination_configurations() return MicrosoftGraph::Policies::AuthenticationStrengthPolicies::Item::CombinationConfigurations::CombinationConfigurationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete a custom authenticationStrengthPolicy object.
49 50 51 52 53 54 55 56 57 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 49 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Read the properties and relationships of an authenticationStrengthPolicy object.
63 64 65 66 67 68 69 70 71 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 63 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AuthenticationStrengthPolicy.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of an authenticationStrengthPolicy object. You cannot update the allowed auth method combinations using this request. To do so, use the Update allowed combinations action.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 78 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AuthenticationStrengthPolicy.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a custom authenticationStrengthPolicy object.
93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 93 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Read the properties and relationships of an authenticationStrengthPolicy object.
109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 109 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of an authenticationStrengthPolicy object. You cannot update the allowed auth method combinations using this request. To do so, use the Update allowed combinations action.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 128 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |
#update_allowed_combinations ⇒ Object
Provides operations to call the updateAllowedCombinations method.
27 28 29 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 27 def update_allowed_combinations() return MicrosoftGraph::Policies::AuthenticationStrengthPolicies::Item::UpdateAllowedCombinations::UpdateAllowedCombinationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#usage ⇒ Object
Provides operations to call the usage method.
32 33 34 |
# File 'lib/policies/authentication_strength_policies/item/authentication_strength_policy_item_request_builder.rb', line 32 def usage() return MicrosoftGraph::Policies::AuthenticationStrengthPolicies::Item::Usage::UsageRequestBuilder.new(@path_parameters, @request_adapter) end |