Class: MicrosoftGraph::Policies::AuthenticationStrengthPolicies::Item::UpdateAllowedCombinations::UpdateAllowedCombinationsPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new updateAllowedCombinationsPostRequestBody and sets the default values.



56
57
58
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 56

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a update_allowed_combinations_post_request_body

Raises:

  • (StandardError)


64
65
66
67
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 64

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UpdateAllowedCombinationsPostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



26
27
28
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 26

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



34
35
36
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 34

def additional_data=(value)
    @additional_data = value
end

#allowed_combinationsObject

Gets the allowedCombinations property value. The allowedCombinations property

Returns:

  • a authentication_method_modes



41
42
43
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 41

def allowed_combinations
    return @allowed_combinations
end

#allowed_combinations=(value) ⇒ Object

Sets the allowedCombinations property value. The allowedCombinations property

Parameters:

  • value

    Value to set for the allowedCombinations property.

Returns:

  • a void



49
50
51
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 49

def allowed_combinations=(value)
    @allowed_combinations = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



72
73
74
75
76
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 72

def get_field_deserializers()
    return {
        "allowedCombinations" => lambda {|n| @allowed_combinations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AuthenticationMethodModes.create_from_discriminator_value(pn) }) },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


82
83
84
85
86
# File 'lib/policies/authentication_strength_policies/item/update_allowed_combinations/update_allowed_combinations_post_request_body.rb', line 82

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_object_values("allowedCombinations", @allowed_combinations)
    writer.write_additional_data(@additional_data)
end