Class: MicrosoftGraph::Policies::FeatureRolloutPolicies::Item::AppliesTo::AppliesToRequestBuilder::AppliesToRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Policies::FeatureRolloutPolicies::Item::AppliesTo::AppliesToRequestBuilder::AppliesToRequestBuilderGetQueryParameters
- Defined in:
- lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb
Overview
Nullable. Specifies a list of directoryObjects that feature is enabled for.
Instance Attribute Summary collapse
-
#count ⇒ Object
Include count of items.
-
#expand ⇒ Object
Expand related entities.
-
#filter ⇒ Object
Filter items by property values.
-
#orderby ⇒ Object
Order items by property values.
-
#search ⇒ Object
Search items by search phrases.
-
#select ⇒ Object
Select properties to be returned.
-
#skip ⇒ Object
Skip the first n items.
-
#top ⇒ Object
Show only the first n items.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#count ⇒ Object
Include count of items
152 153 154 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 152 def count @count end |
#expand ⇒ Object
Expand related entities
155 156 157 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 155 def @expand end |
#filter ⇒ Object
Filter items by property values
158 159 160 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 158 def filter @filter end |
#orderby ⇒ Object
Order items by property values
161 162 163 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 161 def orderby @orderby end |
#search ⇒ Object
Search items by search phrases
164 165 166 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 164 def search @search end |
#select ⇒ Object
Select properties to be returned
167 168 169 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 167 def select @select end |
#skip ⇒ Object
Skip the first n items
170 171 172 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 170 def skip @skip end |
#top ⇒ Object
Show only the first n items
173 174 175 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 173 def top @top end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/policies/feature_rollout_policies/item/applies_to/applies_to_request_builder.rb', line 179 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "count" return "%24count" when "expand" return "%24expand" when "filter" return "%24filter" when "orderby" return "%24orderby" when "search" return "%24search" when "select" return "%24select" when "skip" return "%24skip" when "top" return "%24top" else return original_name end end |