Class: MicrosoftGraph::Policies::RoleManagementPolicyAssignments::RoleManagementPolicyAssignmentsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Policies::RoleManagementPolicyAssignments::RoleManagementPolicyAssignmentsRequestBuilder
- Defined in:
- lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb
Overview
Provides operations to manage the roleManagementPolicyAssignments property of the microsoft.graph.policyRoot entity.
Defined Under Namespace
Classes: RoleManagementPolicyAssignmentsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_unified_role_management_policy_assignment_id(unified_role_management_policy_assignment_id) ⇒ Object
Provides operations to manage the roleManagementPolicyAssignments property of the microsoft.graph.policyRoot entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get the details of all role management policy assignments including the policies and rules associated with the Azure AD roles.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RoleManagementPolicyAssignmentsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to roleManagementPolicyAssignments for policies.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the details of all role management policy assignments including the policies and rules associated with the Azure AD roles.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to roleManagementPolicyAssignments for policies.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RoleManagementPolicyAssignmentsRequestBuilder and sets the default values.
40 41 42 |
# File 'lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb', line 40 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/policies/roleManagementPolicyAssignments{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_unified_role_management_policy_assignment_id(unified_role_management_policy_assignment_id) ⇒ Object
Provides operations to manage the roleManagementPolicyAssignments property of the microsoft.graph.policyRoot entity.
28 29 30 31 32 33 |
# File 'lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb', line 28 def by_unified_role_management_policy_assignment_id(unified_role_management_policy_assignment_id) raise StandardError, 'unified_role_management_policy_assignment_id cannot be null' if unified_role_management_policy_assignment_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["unifiedRoleManagementPolicyAssignment%2Did"] = unified_role_management_policy_assignment_id return MicrosoftGraph::Policies::RoleManagementPolicyAssignments::Item::UnifiedRoleManagementPolicyAssignmentItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
20 21 22 |
# File 'lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb', line 20 def count() return MicrosoftGraph::Policies::RoleManagementPolicyAssignments::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get the details of all role management policy assignments including the policies and rules associated with the Azure AD roles.
48 49 50 51 52 53 54 55 56 |
# File 'lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb', line 48 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::UnifiedRoleManagementPolicyAssignmentCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to roleManagementPolicyAssignments for policies
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb', line 63 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::UnifiedRoleManagementPolicyAssignment.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the details of all role management policy assignments including the policies and rules associated with the Azure AD roles.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb', line 78 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to roleManagementPolicyAssignments for policies
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/policies/role_management_policy_assignments/role_management_policy_assignments_request_builder.rb', line 97 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |