Class: MicrosoftGraph::Print::TaskDefinitions::TaskDefinitionsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Print::TaskDefinitions::TaskDefinitionsRequestBuilder
- Defined in:
- lib/print/task_definitions/task_definitions_request_builder.rb
Overview
Provides operations to manage the taskDefinitions property of the microsoft.graph.print entity.
Defined Under Namespace
Classes: TaskDefinitionsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_print_task_definition_id(print_task_definition_id) ⇒ Object
Provides operations to manage the taskDefinitions property of the microsoft.graph.print entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a list of task definitions that the requesting app defined in the tenant.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new TaskDefinitionsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a new task definition.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of task definitions that the requesting app defined in the tenant.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new task definition.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new TaskDefinitionsRequestBuilder and sets the default values.
40 41 42 |
# File 'lib/print/task_definitions/task_definitions_request_builder.rb', line 40 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/print/taskDefinitions{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_print_task_definition_id(print_task_definition_id) ⇒ Object
Provides operations to manage the taskDefinitions property of the microsoft.graph.print entity.
28 29 30 31 32 33 |
# File 'lib/print/task_definitions/task_definitions_request_builder.rb', line 28 def by_print_task_definition_id(print_task_definition_id) raise StandardError, 'print_task_definition_id cannot be null' if print_task_definition_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["printTaskDefinition%2Did"] = print_task_definition_id return MicrosoftGraph::Print::TaskDefinitions::Item::PrintTaskDefinitionItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
20 21 22 |
# File 'lib/print/task_definitions/task_definitions_request_builder.rb', line 20 def count() return MicrosoftGraph::Print::TaskDefinitions::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a list of task definitions that the requesting app defined in the tenant. For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
48 49 50 51 52 53 54 55 56 |
# File 'lib/print/task_definitions/task_definitions_request_builder.rb', line 48 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PrintTaskDefinitionCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create a new task definition. For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/print/task_definitions/task_definitions_request_builder.rb', line 63 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PrintTaskDefinition.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of task definitions that the requesting app defined in the tenant. For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/print/task_definitions/task_definitions_request_builder.rb', line 78 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new task definition. For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/print/task_definitions/task_definitions_request_builder.rb', line 97 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |