Class: MicrosoftGraph::Privacy::SubjectRightsRequests::Item::SubjectRightsRequestItemRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb

Overview

Provides operations to manage the subjectRightsRequests property of the microsoft.graph.privacy entity.

Defined Under Namespace

Classes: SubjectRightsRequestItemRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new SubjectRightsRequestItemRequestBuilder and sets the default values.



47
48
49
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 47

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/privacy/subjectRightsRequests/{subjectRightsRequest%2Did}{?%24select,%24expand}")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

Delete navigation property subjectRightsRequests for privacy



55
56
57
58
59
60
61
62
63
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 55

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Read the properties and relationships of a subjectRightsRequest object.



69
70
71
72
73
74
75
76
77
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 69

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SubjectRightsRequest.create_from_discriminator_value(pn) }, error_mapping)
end

#get_final_attachmentObject

Provides operations to call the getFinalAttachment method.



23
24
25
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 23

def get_final_attachment()
    return MicrosoftGraph::Privacy::SubjectRightsRequests::Item::GetFinalAttachment::GetFinalAttachmentRequestBuilder.new(@path_parameters, @request_adapter)
end

#get_final_reportObject

Provides operations to call the getFinalReport method.



28
29
30
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 28

def get_final_report()
    return MicrosoftGraph::Privacy::SubjectRightsRequests::Item::GetFinalReport::GetFinalReportRequestBuilder.new(@path_parameters, @request_adapter)
end

#notesObject

Provides operations to manage the notes property of the microsoft.graph.subjectRightsRequest entity.



33
34
35
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 33

def notes()
    return MicrosoftGraph::Privacy::SubjectRightsRequests::Item::Notes::NotesRequestBuilder.new(@path_parameters, @request_adapter)
end

#patch(body, request_configuration = nil) ⇒ Object

Update the properties of a subjectRightsRequest object.

Raises:

  • (StandardError)


84
85
86
87
88
89
90
91
92
93
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 84

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SubjectRightsRequest.create_from_discriminator_value(pn) }, error_mapping)
end

#teamObject

Provides operations to manage the team property of the microsoft.graph.subjectRightsRequest entity.



38
39
40
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 38

def team()
    return MicrosoftGraph::Privacy::SubjectRightsRequests::Item::Team::TeamRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Delete navigation property subjectRightsRequests for privacy



99
100
101
102
103
104
105
106
107
108
109
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 99

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Read the properties and relationships of a subjectRightsRequest object.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 115

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update the properties of a subjectRightsRequest object.

Raises:

  • (StandardError)


134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/privacy/subject_rights_requests/item/subject_rights_request_item_request_builder.rb', line 134

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end