Class: MicrosoftGraph::Reports::DailyPrintUsageByPrinter::DailyPrintUsageByPrinterRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb

Overview

Provides operations to manage the dailyPrintUsageByPrinter property of the microsoft.graph.reportRoot entity.

Defined Under Namespace

Classes: DailyPrintUsageByPrinterRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new DailyPrintUsageByPrinterRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



40
41
42
# File 'lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb', line 40

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/reports/dailyPrintUsageByPrinter{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_print_usage_by_printer_id(print_usage_by_printer_id) ⇒ Object

Provides operations to manage the dailyPrintUsageByPrinter property of the microsoft.graph.reportRoot entity.

Raises:

Parameters:

  • The unique identifier of printUsageByPrinter

Returns:

  • a print_usage_by_printer_item_request_builder



28
29
30
31
32
33
# File 'lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb', line 28

def by_print_usage_by_printer_id(print_usage_by_printer_id)
    raise StandardError, 'print_usage_by_printer_id cannot be null' if print_usage_by_printer_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["printUsageByPrinter%2Did"] = print_usage_by_printer_id
    return MicrosoftGraph::Reports::DailyPrintUsageByPrinter::Item::PrintUsageByPrinterItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



20
21
22
# File 'lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb', line 20

def count()
    return MicrosoftGraph::Reports::DailyPrintUsageByPrinter::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve a list of daily print usage summaries, grouped by printer.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of print_usage_by_printer_collection_response



48
49
50
51
52
53
54
55
56
# File 'lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb', line 48

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PrintUsageByPrinterCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Create new navigation property to dailyPrintUsageByPrinter for reports

Raises:

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of print_usage_by_printer



63
64
65
66
67
68
69
70
71
72
# File 'lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb', line 63

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PrintUsageByPrinter.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve a list of daily print usage summaries, grouped by printer.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb', line 78

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create new navigation property to dailyPrintUsageByPrinter for reports

Raises:

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/reports/daily_print_usage_by_printer/daily_print_usage_by_printer_request_builder.rb', line 97

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end