Class: MicrosoftGraph::Reports::ReportsRequestBuilder::ReportsRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Reports::ReportsRequestBuilder::ReportsRequestBuilderGetQueryParameters
- Defined in:
- lib/reports/reports_request_builder.rb
Overview
Read properties and relationships of the reportRoot object.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
1134 1135 1136 |
# File 'lib/reports/reports_request_builder.rb', line 1134 def end |
#select ⇒ Object
Select properties to be returned
1137 1138 1139 |
# File 'lib/reports/reports_request_builder.rb', line 1137 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 |
# File 'lib/reports/reports_request_builder.rb', line 1143 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |