Class: MicrosoftGraph::Security::Alerts_v2::Item::AlertItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Security::Alerts_v2::Item::AlertItemRequestBuilder
- Defined in:
- lib/security/alerts_v2/item/alert_item_request_builder.rb
Overview
Provides operations to manage the alerts_v2 property of the microsoft.graph.security entity.
Defined Under Namespace
Classes: AlertItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property alerts_v2 for security.
-
#get(request_configuration = nil) ⇒ Object
Get the properties and relationships of an alert in an organization based on the specified alert id property.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new AlertItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of an alert object in an organization based on the specified alert id property.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property alerts_v2 for security.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the properties and relationships of an alert in an organization based on the specified alert id property.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of an alert object in an organization based on the specified alert id property.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new AlertItemRequestBuilder and sets the default values.
23 24 25 |
# File 'lib/security/alerts_v2/item/alert_item_request_builder.rb', line 23 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/security/alerts_v2/{alert%2Did}{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete navigation property alerts_v2 for security
31 32 33 34 35 36 37 38 39 |
# File 'lib/security/alerts_v2/item/alert_item_request_builder.rb', line 31 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Get the properties and relationships of an alert in an organization based on the specified alert id property.
45 46 47 48 49 50 51 52 53 |
# File 'lib/security/alerts_v2/item/alert_item_request_builder.rb', line 45 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SecurityAlert.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of an alert object in an organization based on the specified alert id property.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/security/alerts_v2/item/alert_item_request_builder.rb', line 60 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SecurityAlert.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property alerts_v2 for security
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/security/alerts_v2/item/alert_item_request_builder.rb', line 75 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the properties and relationships of an alert in an organization based on the specified alert id property.
91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/security/alerts_v2/item/alert_item_request_builder.rb', line 91 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of an alert object in an organization based on the specified alert id property.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/security/alerts_v2/item/alert_item_request_builder.rb', line 110 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |