Class: MicrosoftGraph::Security::Incidents::Item::IncidentItemRequestBuilder::IncidentItemRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Security::Incidents::Item::IncidentItemRequestBuilder::IncidentItemRequestBuilderGetQueryParameters
- Defined in:
- lib/security/incidents/item/incident_item_request_builder.rb
Overview
Retrieve the properties and relationships of an incident object. Attacks are typically inflicted on different types of entities, such as devices, users, and mailboxes, resulting in multiple alert objects. Microsoft 365 Defender correlates alerts with the same attack techniques or the same attacker into an incident.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
137 138 139 |
# File 'lib/security/incidents/item/incident_item_request_builder.rb', line 137 def end |
#select ⇒ Object
Select properties to be returned
140 141 142 |
# File 'lib/security/incidents/item/incident_item_request_builder.rb', line 140 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/security/incidents/item/incident_item_request_builder.rb', line 146 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |