Class: MicrosoftGraph::Security::ThreatIntelligence::Articles::Item::Indicators::IndicatorsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Security::ThreatIntelligence::Articles::Item::Indicators::IndicatorsRequestBuilder
- Defined in:
- lib/security/threat_intelligence/articles/item/indicators/indicators_request_builder.rb
Overview
Provides operations to manage the indicators property of the microsoft.graph.security.article entity.
Defined Under Namespace
Classes: IndicatorsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_article_indicator_id(article_indicator_id) ⇒ Object
Provides operations to manage the indicators property of the microsoft.graph.security.article entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get a list of articleIndicator objects that represent indicators of threat or compromise related to the contents of an article.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new IndicatorsRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of articleIndicator objects that represent indicators of threat or compromise related to the contents of an article.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new IndicatorsRequestBuilder and sets the default values.
45 46 47 |
# File 'lib/security/threat_intelligence/articles/item/indicators/indicators_request_builder.rb', line 45 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/security/threatIntelligence/articles/{article%2Did}/indicators{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_article_indicator_id(article_indicator_id) ⇒ Object
Provides operations to manage the indicators property of the microsoft.graph.security.article entity.
33 34 35 36 37 38 |
# File 'lib/security/threat_intelligence/articles/item/indicators/indicators_request_builder.rb', line 33 def by_article_indicator_id(article_indicator_id) raise StandardError, 'article_indicator_id cannot be null' if article_indicator_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["articleIndicator%2Did"] = article_indicator_id return MicrosoftGraph::Security::ThreatIntelligence::Articles::Item::Indicators::Item::ArticleIndicatorItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
25 26 27 |
# File 'lib/security/threat_intelligence/articles/item/indicators/indicators_request_builder.rb', line 25 def count() return MicrosoftGraph::Security::ThreatIntelligence::Articles::Item::Indicators::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get a list of articleIndicator objects that represent indicators of threat or compromise related to the contents of an article.
53 54 55 56 57 58 59 60 61 |
# File 'lib/security/threat_intelligence/articles/item/indicators/indicators_request_builder.rb', line 53 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SecurityArticleIndicatorCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of articleIndicator objects that represent indicators of threat or compromise related to the contents of an article.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/security/threat_intelligence/articles/item/indicators/indicators_request_builder.rb', line 67 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |