Class: MicrosoftGraph::Security::ThreatIntelligence::Hosts::Item::HostItemRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb

Overview

Provides operations to manage the hosts property of the microsoft.graph.security.threatIntelligence entity.

Defined Under Namespace

Classes: HostItemRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new HostItemRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



61
62
63
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 61

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/security/threatIntelligence/hosts/{host%2Did}{?%24select,%24expand}")
end

Instance Method Details

#componentsObject

Provides operations to manage the components property of the microsoft.graph.security.host entity.



27
28
29
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 27

def components()
    return MicrosoftGraph::Security::ThreatIntelligence::Hosts::Item::Components::ComponentsRequestBuilder.new(@path_parameters, @request_adapter)
end

#cookiesObject

Provides operations to manage the cookies property of the microsoft.graph.security.host entity.



32
33
34
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 32

def cookies()
    return MicrosoftGraph::Security::ThreatIntelligence::Hosts::Item::Cookies::CookiesRequestBuilder.new(@path_parameters, @request_adapter)
end

#delete(request_configuration = nil) ⇒ Object

Delete navigation property hosts for security

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



69
70
71
72
73
74
75
76
77
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 69

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Read the properties and relationships of a host object. The host resource is the abstract base type that returns an implementation. A host can be of one of the following types:

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of security_host



83
84
85
86
87
88
89
90
91
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 83

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SecurityHost.create_from_discriminator_value(pn) }, error_mapping)
end

#passive_dnsObject

Provides operations to manage the passiveDns property of the microsoft.graph.security.host entity.



37
38
39
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 37

def passive_dns()
    return MicrosoftGraph::Security::ThreatIntelligence::Hosts::Item::PassiveDns::PassiveDnsRequestBuilder.new(@path_parameters, @request_adapter)
end

#passive_dns_reverseObject

Provides operations to manage the passiveDnsReverse property of the microsoft.graph.security.host entity.



42
43
44
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 42

def passive_dns_reverse()
    return MicrosoftGraph::Security::ThreatIntelligence::Hosts::Item::PassiveDnsReverse::PassiveDnsReverseRequestBuilder.new(@path_parameters, @request_adapter)
end

#patch(body, request_configuration = nil) ⇒ Object

Update the navigation property hosts in security

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of security_host

Raises:

  • (StandardError)


98
99
100
101
102
103
104
105
106
107
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 98

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SecurityHost.create_from_discriminator_value(pn) }, error_mapping)
end

#reputationObject

Provides operations to manage the reputation property of the microsoft.graph.security.host entity.



47
48
49
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 47

def reputation()
    return MicrosoftGraph::Security::ThreatIntelligence::Hosts::Item::Reputation::ReputationRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Delete navigation property hosts for security

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



113
114
115
116
117
118
119
120
121
122
123
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 113

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Read the properties and relationships of a host object. The host resource is the abstract base type that returns an implementation. A host can be of one of the following types:

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 129

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update the navigation property hosts in security

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 148

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end

#trackersObject

Provides operations to manage the trackers property of the microsoft.graph.security.host entity.



52
53
54
# File 'lib/security/threat_intelligence/hosts/item/host_item_request_builder.rb', line 52

def trackers()
    return MicrosoftGraph::Security::ThreatIntelligence::Hosts::Item::Trackers::TrackersRequestBuilder.new(@path_parameters, @request_adapter)
end