Class: MicrosoftGraph::ServicePrincipals::Item::ServicePrincipalItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::ServicePrincipals::Item::ServicePrincipalItemRequestBuilder
- Defined in:
- lib/service_principals/item/service_principal_item_request_builder.rb
Overview
Provides operations to manage the collection of servicePrincipal entities.
Defined Under Namespace
Classes: ServicePrincipalItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#add_key ⇒ Object
Provides operations to call the addKey method.
-
#add_password ⇒ Object
Provides operations to call the addPassword method.
-
#add_token_signing_certificate ⇒ Object
Provides operations to call the addTokenSigningCertificate method.
-
#app_management_policies ⇒ Object
Provides operations to manage the appManagementPolicies property of the microsoft.graph.servicePrincipal entity.
-
#app_role_assigned_to ⇒ Object
Provides operations to manage the appRoleAssignedTo property of the microsoft.graph.servicePrincipal entity.
-
#app_role_assignments ⇒ Object
Provides operations to manage the appRoleAssignments property of the microsoft.graph.servicePrincipal entity.
-
#check_member_groups ⇒ Object
Provides operations to call the checkMemberGroups method.
-
#check_member_objects ⇒ Object
Provides operations to call the checkMemberObjects method.
-
#claims_mapping_policies ⇒ Object
Provides operations to manage the claimsMappingPolicies property of the microsoft.graph.servicePrincipal entity.
-
#created_objects ⇒ Object
Provides operations to manage the createdObjects property of the microsoft.graph.servicePrincipal entity.
-
#delegated_permission_classifications ⇒ Object
Provides operations to manage the delegatedPermissionClassifications property of the microsoft.graph.servicePrincipal entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete a servicePrincipal object.
-
#endpoints ⇒ Object
Provides operations to manage the endpoints property of the microsoft.graph.servicePrincipal entity.
-
#federated_identity_credentials ⇒ Object
Provides operations to manage the federatedIdentityCredentials property of the microsoft.graph.servicePrincipal entity.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a servicePrincipal object.
-
#get_member_groups ⇒ Object
Provides operations to call the getMemberGroups method.
-
#get_member_objects ⇒ Object
Provides operations to call the getMemberObjects method.
-
#home_realm_discovery_policies ⇒ Object
Provides operations to manage the homeRealmDiscoveryPolicies property of the microsoft.graph.servicePrincipal entity.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ServicePrincipalItemRequestBuilder and sets the default values.
-
#member_of ⇒ Object
Provides operations to manage the memberOf property of the microsoft.graph.servicePrincipal entity.
-
#oauth2_permission_grants ⇒ Object
Provides operations to manage the oauth2PermissionGrants property of the microsoft.graph.servicePrincipal entity.
-
#owned_objects ⇒ Object
Provides operations to manage the ownedObjects property of the microsoft.graph.servicePrincipal entity.
-
#owners ⇒ Object
Provides operations to manage the owners property of the microsoft.graph.servicePrincipal entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update entity in servicePrincipals.
-
#remove_key ⇒ Object
Provides operations to call the removeKey method.
-
#remove_password ⇒ Object
Provides operations to call the removePassword method.
-
#restore ⇒ Object
Provides operations to call the restore method.
-
#synchronization ⇒ Object
Provides operations to manage the synchronization property of the microsoft.graph.servicePrincipal entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a servicePrincipal object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a servicePrincipal object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update entity in servicePrincipals.
-
#token_issuance_policies ⇒ Object
Provides operations to manage the tokenIssuancePolicies property of the microsoft.graph.servicePrincipal entity.
-
#token_lifetime_policies ⇒ Object
Provides operations to manage the tokenLifetimePolicies property of the microsoft.graph.servicePrincipal entity.
-
#transitive_member_of ⇒ Object
Provides operations to manage the transitiveMemberOf property of the microsoft.graph.servicePrincipal entity.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ServicePrincipalItemRequestBuilder and sets the default values.
183 184 185 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 183 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/servicePrincipals/{servicePrincipal%2Did}{?%24select,%24expand}") end |
Instance Method Details
#add_key ⇒ Object
Provides operations to call the addKey method.
44 45 46 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 44 def add_key() return MicrosoftGraph::ServicePrincipals::Item::AddKey::AddKeyRequestBuilder.new(@path_parameters, @request_adapter) end |
#add_password ⇒ Object
Provides operations to call the addPassword method.
49 50 51 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 49 def add_password() return MicrosoftGraph::ServicePrincipals::Item::AddPassword::AddPasswordRequestBuilder.new(@path_parameters, @request_adapter) end |
#add_token_signing_certificate ⇒ Object
Provides operations to call the addTokenSigningCertificate method.
54 55 56 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 54 def add_token_signing_certificate() return MicrosoftGraph::ServicePrincipals::Item::AddTokenSigningCertificate::AddTokenSigningCertificateRequestBuilder.new(@path_parameters, @request_adapter) end |
#app_management_policies ⇒ Object
Provides operations to manage the appManagementPolicies property of the microsoft.graph.servicePrincipal entity.
59 60 61 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 59 def app_management_policies() return MicrosoftGraph::ServicePrincipals::Item::AppManagementPolicies::AppManagementPoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#app_role_assigned_to ⇒ Object
Provides operations to manage the appRoleAssignedTo property of the microsoft.graph.servicePrincipal entity.
64 65 66 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 64 def app_role_assigned_to() return MicrosoftGraph::ServicePrincipals::Item::AppRoleAssignedTo::AppRoleAssignedToRequestBuilder.new(@path_parameters, @request_adapter) end |
#app_role_assignments ⇒ Object
Provides operations to manage the appRoleAssignments property of the microsoft.graph.servicePrincipal entity.
69 70 71 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 69 def app_role_assignments() return MicrosoftGraph::ServicePrincipals::Item::AppRoleAssignments::AppRoleAssignmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#check_member_groups ⇒ Object
Provides operations to call the checkMemberGroups method.
74 75 76 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 74 def check_member_groups() return MicrosoftGraph::ServicePrincipals::Item::CheckMemberGroups::CheckMemberGroupsRequestBuilder.new(@path_parameters, @request_adapter) end |
#check_member_objects ⇒ Object
Provides operations to call the checkMemberObjects method.
79 80 81 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 79 def check_member_objects() return MicrosoftGraph::ServicePrincipals::Item::CheckMemberObjects::CheckMemberObjectsRequestBuilder.new(@path_parameters, @request_adapter) end |
#claims_mapping_policies ⇒ Object
Provides operations to manage the claimsMappingPolicies property of the microsoft.graph.servicePrincipal entity.
84 85 86 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 84 def claims_mapping_policies() return MicrosoftGraph::ServicePrincipals::Item::ClaimsMappingPolicies::ClaimsMappingPoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#created_objects ⇒ Object
Provides operations to manage the createdObjects property of the microsoft.graph.servicePrincipal entity.
89 90 91 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 89 def created_objects() return MicrosoftGraph::ServicePrincipals::Item::CreatedObjects::CreatedObjectsRequestBuilder.new(@path_parameters, @request_adapter) end |
#delegated_permission_classifications ⇒ Object
Provides operations to manage the delegatedPermissionClassifications property of the microsoft.graph.servicePrincipal entity.
94 95 96 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 94 def () return MicrosoftGraph::ServicePrincipals::Item::DelegatedPermissionClassifications::DelegatedPermissionClassificationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete a servicePrincipal object.
191 192 193 194 195 196 197 198 199 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 191 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#endpoints ⇒ Object
Provides operations to manage the endpoints property of the microsoft.graph.servicePrincipal entity.
99 100 101 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 99 def endpoints() return MicrosoftGraph::ServicePrincipals::Item::Endpoints::EndpointsRequestBuilder.new(@path_parameters, @request_adapter) end |
#federated_identity_credentials ⇒ Object
Provides operations to manage the federatedIdentityCredentials property of the microsoft.graph.servicePrincipal entity.
104 105 106 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 104 def federated_identity_credentials() return MicrosoftGraph::ServicePrincipals::Item::FederatedIdentityCredentials::FederatedIdentityCredentialsRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a servicePrincipal object.
205 206 207 208 209 210 211 212 213 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 205 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ServicePrincipal.create_from_discriminator_value(pn) }, error_mapping) end |
#get_member_groups ⇒ Object
Provides operations to call the getMemberGroups method.
109 110 111 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 109 def get_member_groups() return MicrosoftGraph::ServicePrincipals::Item::GetMemberGroups::GetMemberGroupsRequestBuilder.new(@path_parameters, @request_adapter) end |
#get_member_objects ⇒ Object
Provides operations to call the getMemberObjects method.
114 115 116 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 114 def get_member_objects() return MicrosoftGraph::ServicePrincipals::Item::GetMemberObjects::GetMemberObjectsRequestBuilder.new(@path_parameters, @request_adapter) end |
#home_realm_discovery_policies ⇒ Object
Provides operations to manage the homeRealmDiscoveryPolicies property of the microsoft.graph.servicePrincipal entity.
119 120 121 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 119 def home_realm_discovery_policies() return MicrosoftGraph::ServicePrincipals::Item::HomeRealmDiscoveryPolicies::HomeRealmDiscoveryPoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#member_of ⇒ Object
Provides operations to manage the memberOf property of the microsoft.graph.servicePrincipal entity.
124 125 126 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 124 def member_of() return MicrosoftGraph::ServicePrincipals::Item::MemberOf::MemberOfRequestBuilder.new(@path_parameters, @request_adapter) end |
#oauth2_permission_grants ⇒ Object
Provides operations to manage the oauth2PermissionGrants property of the microsoft.graph.servicePrincipal entity.
129 130 131 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 129 def () return MicrosoftGraph::ServicePrincipals::Item::Oauth2PermissionGrants::Oauth2PermissionGrantsRequestBuilder.new(@path_parameters, @request_adapter) end |
#owned_objects ⇒ Object
Provides operations to manage the ownedObjects property of the microsoft.graph.servicePrincipal entity.
134 135 136 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 134 def owned_objects() return MicrosoftGraph::ServicePrincipals::Item::OwnedObjects::OwnedObjectsRequestBuilder.new(@path_parameters, @request_adapter) end |
#owners ⇒ Object
Provides operations to manage the owners property of the microsoft.graph.servicePrincipal entity.
139 140 141 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 139 def owners() return MicrosoftGraph::ServicePrincipals::Item::Owners::OwnersRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update entity in servicePrincipals
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 220 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ServicePrincipal.create_from_discriminator_value(pn) }, error_mapping) end |
#remove_key ⇒ Object
Provides operations to call the removeKey method.
144 145 146 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 144 def remove_key() return MicrosoftGraph::ServicePrincipals::Item::RemoveKey::RemoveKeyRequestBuilder.new(@path_parameters, @request_adapter) end |
#remove_password ⇒ Object
Provides operations to call the removePassword method.
149 150 151 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 149 def remove_password() return MicrosoftGraph::ServicePrincipals::Item::RemovePassword::RemovePasswordRequestBuilder.new(@path_parameters, @request_adapter) end |
#restore ⇒ Object
Provides operations to call the restore method.
154 155 156 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 154 def restore() return MicrosoftGraph::ServicePrincipals::Item::Restore::RestoreRequestBuilder.new(@path_parameters, @request_adapter) end |
#synchronization ⇒ Object
Provides operations to manage the synchronization property of the microsoft.graph.servicePrincipal entity.
159 160 161 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 159 def synchronization() return MicrosoftGraph::ServicePrincipals::Item::Synchronization::SynchronizationRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a servicePrincipal object.
235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 235 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a servicePrincipal object.
251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 251 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update entity in servicePrincipals
270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 270 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |
#token_issuance_policies ⇒ Object
Provides operations to manage the tokenIssuancePolicies property of the microsoft.graph.servicePrincipal entity.
164 165 166 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 164 def token_issuance_policies() return MicrosoftGraph::ServicePrincipals::Item::TokenIssuancePolicies::TokenIssuancePoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#token_lifetime_policies ⇒ Object
Provides operations to manage the tokenLifetimePolicies property of the microsoft.graph.servicePrincipal entity.
169 170 171 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 169 def token_lifetime_policies() return MicrosoftGraph::ServicePrincipals::Item::TokenLifetimePolicies::TokenLifetimePoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#transitive_member_of ⇒ Object
Provides operations to manage the transitiveMemberOf property of the microsoft.graph.servicePrincipal entity.
174 175 176 |
# File 'lib/service_principals/item/service_principal_item_request_builder.rb', line 174 def transitive_member_of() return MicrosoftGraph::ServicePrincipals::Item::TransitiveMemberOf::TransitiveMemberOfRequestBuilder.new(@path_parameters, @request_adapter) end |