Class: MicrosoftGraph::Shares::Item::Root::RootRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/shares/item/root/root_request_builder.rb

Overview

Provides operations to manage the root property of the microsoft.graph.sharedDriveItem entity.

Defined Under Namespace

Classes: RootRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new RootRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



29
30
31
# File 'lib/shares/item/root/root_request_builder.rb', line 29

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/shares/{sharedDriveItem%2Did}/root{?%24select,%24expand}")
end

Instance Method Details

#contentObject

Provides operations to manage the media for the sharedDriveItem entity.



20
21
22
# File 'lib/shares/item/root/root_request_builder.rb', line 20

def content()
    return MicrosoftGraph::Shares::Item::Root::Content::ContentRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Used to access the underlying driveItem. Deprecated – use driveItem instead.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of drive_item



37
38
39
40
41
42
43
44
45
# File 'lib/shares/item/root/root_request_builder.rb', line 37

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DriveItem.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Used to access the underlying driveItem. Deprecated – use driveItem instead.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/shares/item/root/root_request_builder.rb', line 51

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end