Class: MicrosoftGraph::Sites::Item::Onenote::Operations::OperationsRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/sites/item/onenote/operations/operations_request_builder.rb

Overview

Provides operations to manage the operations property of the microsoft.graph.onenote entity.

Defined Under Namespace

Classes: OperationsRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new OperationsRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



44
45
46
# File 'lib/sites/item/onenote/operations/operations_request_builder.rb', line 44

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/sites/{site%2Did}/onenote/operations{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_onenote_operation_id(onenote_operation_id) ⇒ Object

Provides operations to manage the operations property of the microsoft.graph.onenote entity.

Parameters:

  • onenote_operation_id

    The unique identifier of onenoteOperation

Returns:

  • a onenote_operation_item_request_builder

Raises:

  • (StandardError)


32
33
34
35
36
37
# File 'lib/sites/item/onenote/operations/operations_request_builder.rb', line 32

def by_onenote_operation_id(onenote_operation_id)
    raise StandardError, 'onenote_operation_id cannot be null' if onenote_operation_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["onenoteOperation%2Did"] = onenote_operation_id
    return MicrosoftGraph::Sites::Item::Onenote::Operations::Item::OnenoteOperationItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



24
25
26
# File 'lib/sites/item/onenote/operations/operations_request_builder.rb', line 24

def count()
    return MicrosoftGraph::Sites::Item::Onenote::Operations::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Get the status of a long-running OneNote operation. This applies to operations that return the Operation-Location header in the response, such as CopyNotebook, CopyToNotebook, CopyToSectionGroup, and CopyToSection. You can poll the Operation-Location endpoint until the status property returns completed or failed. If the status is completed, the resourceLocation property contains the resource endpoint URI. If the status is failed, the error and @api.diagnostics properties provide error information.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of onenote_operation_collection_response



52
53
54
55
56
57
58
59
60
# File 'lib/sites/item/onenote/operations/operations_request_builder.rb', line 52

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OnenoteOperationCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Create new navigation property to operations for sites

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of onenote_operation

Raises:

  • (StandardError)


67
68
69
70
71
72
73
74
75
76
# File 'lib/sites/item/onenote/operations/operations_request_builder.rb', line 67

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::OnenoteOperation.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get the status of a long-running OneNote operation. This applies to operations that return the Operation-Location header in the response, such as CopyNotebook, CopyToNotebook, CopyToSectionGroup, and CopyToSection. You can poll the Operation-Location endpoint until the status property returns completed or failed. If the status is completed, the resourceLocation property contains the resource endpoint URI. If the status is failed, the error and @api.diagnostics properties provide error information.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/sites/item/onenote/operations/operations_request_builder.rb', line 82

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create new navigation property to operations for sites

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/sites/item/onenote/operations/operations_request_builder.rb', line 101

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end