Class: MicrosoftGraph::Sites::Item::TermStore::TermStoreRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/sites/item/term_store/term_store_request_builder.rb

Overview

Provides operations to manage the termStore property of the microsoft.graph.site entity.

Defined Under Namespace

Classes: TermStoreRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new TermStoreRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



35
36
37
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 35

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/sites/{site%2Did}/termStore{?%24select,%24expand}")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

Delete navigation property termStore for sites

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



43
44
45
46
47
48
49
50
51
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 43

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#get(request_configuration = nil) ⇒ Object

Read the properties and relationships of a store object.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of term_store_store



57
58
59
60
61
62
63
64
65
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 57

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::TermStoreStore.create_from_discriminator_value(pn) }, error_mapping)
end

#groupsObject

Provides operations to manage the groups property of the microsoft.graph.termStore.store entity.



21
22
23
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 21

def groups()
    return MicrosoftGraph::Sites::Item::TermStore::Groups::GroupsRequestBuilder.new(@path_parameters, @request_adapter)
end

#patch(body, request_configuration = nil) ⇒ Object

Update the properties of a store object.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of term_store_store

Raises:

  • (StandardError)


72
73
74
75
76
77
78
79
80
81
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 72

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::TermStoreStore.create_from_discriminator_value(pn) }, error_mapping)
end

#setsObject

Provides operations to manage the sets property of the microsoft.graph.termStore.store entity.



26
27
28
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 26

def sets()
    return MicrosoftGraph::Sites::Item::TermStore::Sets::SetsRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Delete navigation property termStore for sites

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



87
88
89
90
91
92
93
94
95
96
97
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 87

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Read the properties and relationships of a store object.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 103

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update the properties of a store object.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/sites/item/term_store/term_store_request_builder.rb', line 122

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end