Class: MicrosoftGraph::Sites::SitesRequestBuilder::SitesRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/sites/sites_request_builder.rb

Overview

Search across a SharePoint tenant for [sites][] that match keywords provided. The only property that works for sorting is createdDateTime. The search filter is a free text search that uses multiple properties when retrieving the search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



97
98
99
# File 'lib/sites/sites_request_builder.rb', line 97

def count
  @count
end

#expandObject

Expand related entities



100
101
102
# File 'lib/sites/sites_request_builder.rb', line 100

def expand
  @expand
end

#filterObject

Filter items by property values



103
104
105
# File 'lib/sites/sites_request_builder.rb', line 103

def filter
  @filter
end

#orderbyObject

Order items by property values



106
107
108
# File 'lib/sites/sites_request_builder.rb', line 106

def orderby
  @orderby
end

#searchObject

Search items by search phrases



109
110
111
# File 'lib/sites/sites_request_builder.rb', line 109

def search
  @search
end

#selectObject

Select properties to be returned



112
113
114
# File 'lib/sites/sites_request_builder.rb', line 112

def select
  @select
end

#skipObject

Skip the first n items



115
116
117
# File 'lib/sites/sites_request_builder.rb', line 115

def skip
  @skip
end

#topObject

Show only the first n items



118
119
120
# File 'lib/sites/sites_request_builder.rb', line 118

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Raises:

  • (StandardError)


124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/sites/sites_request_builder.rb', line 124

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "expand"
            return "%24expand"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "search"
            return "%24search"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "top"
            return "%24top"
        else
            return original_name
    end
end