Class: MicrosoftGraph::Solutions::BookingBusinesses::Item::CalendarView::CalendarViewRequestBuilder::CalendarViewRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb

Overview

The set of appointments of this business in a specified date range. Read-only. Nullable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



122
123
124
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 122

def count
  @count
end

#end_escapedObject

The end date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T20:00:00-08:00



125
126
127
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 125

def end_escaped
  @end_escaped
end

#expandObject

Expand related entities



128
129
130
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 128

def expand
  @expand
end

#filterObject

Filter items by property values



131
132
133
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 131

def filter
  @filter
end

#orderbyObject

Order items by property values



134
135
136
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 134

def orderby
  @orderby
end

#searchObject

Search items by search phrases



137
138
139
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 137

def search
  @search
end

#selectObject

Select properties to be returned



140
141
142
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 140

def select
  @select
end

#skipObject

Skip the first n items



143
144
145
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 143

def skip
  @skip
end

#startObject

The start date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T19:00:00-08:00



146
147
148
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 146

def start
  @start
end

#topObject

Show only the first n items



149
150
151
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 149

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/solutions/booking_businesses/item/calendar_view/calendar_view_request_builder.rb', line 155

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "end_escaped"
            return "end"
        when "expand"
            return "%24expand"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "search"
            return "%24search"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "start"
            return "start"
        when "top"
            return "%24top"
        else
            return original_name
    end
end