Class: MicrosoftGraph::Teams::Item::PrimaryChannel::ProvisionEmail::ProvisionEmailRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/teams/item/primary_channel/provision_email/provision_email_request_builder.rb

Overview

Provides operations to call the provisionEmail method.

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ProvisionEmailRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



25
26
27
# File 'lib/teams/item/primary_channel/provision_email/provision_email_request_builder.rb', line 25

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/teams/{team%2Did}/primaryChannel/provisionEmail")
end

Instance Method Details

#post(request_configuration = nil) ⇒ Object

Provision an email address for a channel. Microsoft Teams doesn’t automatically provision an email address for a channel by default. To have Teams provision an email address, you can call provisionEmail, or through the Teams user interface, select Get email address, which triggers Teams to generate an email address if it has not already provisioned one. To remove the email address of a channel, use the removeEmail method.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of provision_channel_email_result



33
34
35
36
37
38
39
40
41
# File 'lib/teams/item/primary_channel/provision_email/provision_email_request_builder.rb', line 33

def post(request_configuration=nil)
    request_info = self.to_post_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ProvisionChannelEmailResult.create_from_discriminator_value(pn) }, error_mapping)
end

#to_post_request_information(request_configuration = nil) ⇒ Object

Provision an email address for a channel. Microsoft Teams doesn’t automatically provision an email address for a channel by default. To have Teams provision an email address, you can call provisionEmail, or through the Teams user interface, select Get email address, which triggers Teams to generate an email address if it has not already provisioned one. To remove the email address of a channel, use the removeEmail method.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/teams/item/primary_channel/provision_email/provision_email_request_builder.rb', line 47

def to_post_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end