Class: MicrosoftGraph::Teams::Item::PrimaryChannel::RemoveEmail::RemoveEmailRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/teams/item/primary_channel/remove_email/remove_email_request_builder.rb

Overview

Provides operations to call the removeEmail method.

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new RemoveEmailRequestBuilder and sets the default values.



24
25
26
# File 'lib/teams/item/primary_channel/remove_email/remove_email_request_builder.rb', line 24

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/teams/{team%2Did}/primaryChannel/removeEmail")
end

Instance Method Details

#post(request_configuration = nil) ⇒ Object

Remove the email address of a channel. You can remove an email address only if it was provisioned using the provisionEmail method or through the Microsoft Teams client.



32
33
34
35
36
37
38
39
40
# File 'lib/teams/item/primary_channel/remove_email/remove_email_request_builder.rb', line 32

def post(request_configuration=nil)
    request_info = self.to_post_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#to_post_request_information(request_configuration = nil) ⇒ Object

Remove the email address of a channel. You can remove an email address only if it was provisioned using the provisionEmail method or through the Microsoft Teams client.



46
47
48
49
50
51
52
53
54
55
56
# File 'lib/teams/item/primary_channel/remove_email/remove_email_request_builder.rb', line 46

def to_post_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end