Class: MicrosoftGraph::TenantRelationships::DelegatedAdminRelationships::Item::DelegatedAdminRelationshipItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::TenantRelationships::DelegatedAdminRelationships::Item::DelegatedAdminRelationshipItemRequestBuilder
- Defined in:
- lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb
Overview
Provides operations to manage the delegatedAdminRelationships property of the microsoft.graph.tenantRelationship entity.
Defined Under Namespace
Classes: DelegatedAdminRelationshipItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#access_assignments ⇒ Object
Provides operations to manage the accessAssignments property of the microsoft.graph.delegatedAdminRelationship entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete a delegatedAdminRelationship object.
-
#get(request_configuration = nil) ⇒ Object
Read the properties of a delegatedAdminRelationship object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DelegatedAdminRelationshipItemRequestBuilder and sets the default values.
-
#operations ⇒ Object
Provides operations to manage the operations property of the microsoft.graph.delegatedAdminRelationship entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of a delegatedAdminRelationship object.
-
#requests ⇒ Object
Provides operations to manage the requests property of the microsoft.graph.delegatedAdminRelationship entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a delegatedAdminRelationship object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Read the properties of a delegatedAdminRelationship object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of a delegatedAdminRelationship object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DelegatedAdminRelationshipItemRequestBuilder and sets the default values.
41 42 43 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 41 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/tenantRelationships/delegatedAdminRelationships/{delegatedAdminRelationship%2Did}{?%24select,%24expand}") end |
Instance Method Details
#access_assignments ⇒ Object
Provides operations to manage the accessAssignments property of the microsoft.graph.delegatedAdminRelationship entity.
22 23 24 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 22 def access_assignments() return MicrosoftGraph::TenantRelationships::DelegatedAdminRelationships::Item::AccessAssignments::AccessAssignmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete a delegatedAdminRelationship object. A relationship can only be deleted if it's in the 'created' status.
49 50 51 52 53 54 55 56 57 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 49 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Read the properties of a delegatedAdminRelationship object.
63 64 65 66 67 68 69 70 71 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 63 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DelegatedAdminRelationship.create_from_discriminator_value(pn) }, error_mapping) end |
#operations ⇒ Object
Provides operations to manage the operations property of the microsoft.graph.delegatedAdminRelationship entity.
27 28 29 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 27 def operations() return MicrosoftGraph::TenantRelationships::DelegatedAdminRelationships::Item::Operations::OperationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of a delegatedAdminRelationship object. A relationship can only be updated if it's in the created status.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 78 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DelegatedAdminRelationship.create_from_discriminator_value(pn) }, error_mapping) end |
#requests ⇒ Object
Provides operations to manage the requests property of the microsoft.graph.delegatedAdminRelationship entity.
32 33 34 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 32 def requests() return MicrosoftGraph::TenantRelationships::DelegatedAdminRelationships::Item::Requests::RequestsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete a delegatedAdminRelationship object. A relationship can only be deleted if it's in the 'created' status.
93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 93 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Read the properties of a delegatedAdminRelationship object.
109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 109 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of a delegatedAdminRelationship object. A relationship can only be updated if it's in the created status.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/tenant_relationships/delegated_admin_relationships/item/delegated_admin_relationship_item_request_builder.rb', line 128 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |