Class: MicrosoftGraph::Users::Item::Authentication::AuthenticationRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/users/item/authentication/authentication_request_builder.rb

Overview

Provides operations to manage the authentication property of the microsoft.graph.user entity.

Defined Under Namespace

Classes: AuthenticationRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new AuthenticationRequestBuilder and sets the default values.

Parameters:

  • Path parameters for the request

  • The request adapter to use to execute the requests.



83
84
85
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 83

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/authentication{?%24select,%24expand}")
end

Instance Method Details

#delete(request_configuration = nil) ⇒ Object

Delete navigation property authentication for users

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void



91
92
93
94
95
96
97
98
99
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 91

def delete(request_configuration=nil)
    request_info = self.to_delete_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#email_methodsObject

Provides operations to manage the emailMethods property of the microsoft.graph.authentication entity.



29
30
31
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 29

def email_methods()
    return MicrosoftGraph::Users::Item::Authentication::EmailMethods::EmailMethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#fido2_methodsObject

Provides operations to manage the fido2Methods property of the microsoft.graph.authentication entity.



34
35
36
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 34

def fido2_methods()
    return MicrosoftGraph::Users::Item::Authentication::Fido2Methods::Fido2MethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

The authentication methods that are supported for the user.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of authentication



105
106
107
108
109
110
111
112
113
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 105

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Authentication.create_from_discriminator_value(pn) }, error_mapping)
end

#methodsObject

Provides operations to manage the methods property of the microsoft.graph.authentication entity.



39
40
41
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 39

def methods()
    return MicrosoftGraph::Users::Item::Authentication::Methods::MethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#microsoft_authenticator_methodsObject

Provides operations to manage the microsoftAuthenticatorMethods property of the microsoft.graph.authentication entity.



44
45
46
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 44

def microsoft_authenticator_methods()
    return MicrosoftGraph::Users::Item::Authentication::MicrosoftAuthenticatorMethods::MicrosoftAuthenticatorMethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#operationsObject

Provides operations to manage the operations property of the microsoft.graph.authentication entity.



49
50
51
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 49

def operations()
    return MicrosoftGraph::Users::Item::Authentication::Operations::OperationsRequestBuilder.new(@path_parameters, @request_adapter)
end

#password_methodsObject

Provides operations to manage the passwordMethods property of the microsoft.graph.authentication entity.



54
55
56
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 54

def password_methods()
    return MicrosoftGraph::Users::Item::Authentication::PasswordMethods::PasswordMethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#patch(body, request_configuration = nil) ⇒ Object

Update the navigation property authentication in users

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of authentication

Raises:



120
121
122
123
124
125
126
127
128
129
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 120

def patch(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_patch_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Authentication.create_from_discriminator_value(pn) }, error_mapping)
end

#phone_methodsObject

Provides operations to manage the phoneMethods property of the microsoft.graph.authentication entity.



59
60
61
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 59

def phone_methods()
    return MicrosoftGraph::Users::Item::Authentication::PhoneMethods::PhoneMethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#software_oath_methodsObject

Provides operations to manage the softwareOathMethods property of the microsoft.graph.authentication entity.



64
65
66
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 64

def software_oath_methods()
    return MicrosoftGraph::Users::Item::Authentication::SoftwareOathMethods::SoftwareOathMethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#temporary_access_pass_methodsObject

Provides operations to manage the temporaryAccessPassMethods property of the microsoft.graph.authentication entity.



69
70
71
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 69

def temporary_access_pass_methods()
    return MicrosoftGraph::Users::Item::Authentication::TemporaryAccessPassMethods::TemporaryAccessPassMethodsRequestBuilder.new(@path_parameters, @request_adapter)
end

#to_delete_request_information(request_configuration = nil) ⇒ Object

Delete navigation property authentication for users

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



135
136
137
138
139
140
141
142
143
144
145
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 135

def to_delete_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :DELETE
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_get_request_information(request_configuration = nil) ⇒ Object

The authentication methods that are supported for the user.

Parameters:

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 151

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_patch_request_information(body, request_configuration = nil) ⇒ Object

Update the navigation property authentication in users

Parameters:

  • The request body

  • (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:



170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 170

def to_patch_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :PATCH
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end

#windows_hello_for_business_methodsObject

Provides operations to manage the windowsHelloForBusinessMethods property of the microsoft.graph.authentication entity.



74
75
76
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 74

def windows_hello_for_business_methods()
    return MicrosoftGraph::Users::Item::Authentication::WindowsHelloForBusinessMethods::WindowsHelloForBusinessMethodsRequestBuilder.new(@path_parameters, @request_adapter)
end