Class: MicrosoftGraph::Users::Item::Authentication::AuthenticationRequestBuilder::AuthenticationRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Users::Item::Authentication::AuthenticationRequestBuilder::AuthenticationRequestBuilderGetQueryParameters
- Defined in:
- lib/users/item/authentication/authentication_request_builder.rb
Overview
The authentication methods that are supported for the user.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
191 192 193 |
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 191 def end |
#select ⇒ Object
Select properties to be returned
194 195 196 |
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 194 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/users/item/authentication/authentication_request_builder.rb', line 200 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |