Class: MicrosoftGraph::Users::Item::Authentication::Methods::MethodsRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/users/item/authentication/methods/methods_request_builder.rb

Overview

Provides operations to manage the methods property of the microsoft.graph.authentication entity.

Defined Under Namespace

Classes: MethodsRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new MethodsRequestBuilder and sets the default values.



44
45
46
# File 'lib/users/item/authentication/methods/methods_request_builder.rb', line 44

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/authentication/methods{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_authentication_method_id(authentication_method_id) ⇒ Object

Provides operations to manage the methods property of the microsoft.graph.authentication entity.

Raises:



32
33
34
35
36
37
# File 'lib/users/item/authentication/methods/methods_request_builder.rb', line 32

def by_authentication_method_id(authentication_method_id)
    raise StandardError, 'authentication_method_id cannot be null' if authentication_method_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["authenticationMethod%2Did"] = authentication_method_id
    return MicrosoftGraph::Users::Item::Authentication::Methods::Item::AuthenticationMethodItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



24
25
26
# File 'lib/users/item/authentication/methods/methods_request_builder.rb', line 24

def count()
    return MicrosoftGraph::Users::Item::Authentication::Methods::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve a list of authentication methods registered to a user. The authentication methods are defined by the types derived from the authenticationMethod resource type, and only the methods supported on this API version. See Azure AD authentication methods API overview for a list of currently supported methods.



52
53
54
55
56
57
58
59
60
# File 'lib/users/item/authentication/methods/methods_request_builder.rb', line 52

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AuthenticationMethodCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Create new navigation property to methods for users

Raises:



67
68
69
70
71
72
73
74
75
76
# File 'lib/users/item/authentication/methods/methods_request_builder.rb', line 67

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::AuthenticationMethod.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve a list of authentication methods registered to a user. The authentication methods are defined by the types derived from the authenticationMethod resource type, and only the methods supported on this API version. See Azure AD authentication methods API overview for a list of currently supported methods.



82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/users/item/authentication/methods/methods_request_builder.rb', line 82

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create new navigation property to methods for users

Raises:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/users/item/authentication/methods/methods_request_builder.rb', line 101

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end