Class: MicrosoftGraph::Users::Item::Calendar::CalendarRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Users::Item::Calendar::CalendarRequestBuilder
- Defined in:
- lib/users/item/calendar/calendar_request_builder.rb
Overview
Provides operations to manage the calendar property of the microsoft.graph.user entity.
Defined Under Namespace
Classes: CalendarRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#allowed_calendar_sharing_roles_with_user(user) ⇒ Object
Provides operations to call the allowedCalendarSharingRoles method.
-
#calendar_permissions ⇒ Object
Provides operations to manage the calendarPermissions property of the microsoft.graph.calendar entity.
-
#calendar_view ⇒ Object
Provides operations to manage the calendarView property of the microsoft.graph.calendar entity.
-
#events ⇒ Object
Provides operations to manage the events property of the microsoft.graph.calendar entity.
-
#get(request_configuration = nil) ⇒ Object
Get the properties and relationships of a calendar object.
-
#get_schedule ⇒ Object
Provides operations to call the getSchedule method.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new CalendarRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of a calendar object.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the properties and relationships of a calendar object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of a calendar object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new CalendarRequestBuilder and sets the default values.
57 58 59 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 57 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/calendar{?%24select}") end |
Instance Method Details
#allowed_calendar_sharing_roles_with_user(user) ⇒ Object
Provides operations to call the allowedCalendarSharingRoles method.
47 48 49 50 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 47 def allowed_calendar_sharing_roles_with_user(user) raise StandardError, 'user cannot be null' if user.nil? return AllowedCalendarSharingRolesWithUserRequestBuilder.new(@path_parameters, @request_adapter, User) end |
#calendar_permissions ⇒ Object
Provides operations to manage the calendarPermissions property of the microsoft.graph.calendar entity.
24 25 26 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 24 def () return MicrosoftGraph::Users::Item::Calendar::CalendarPermissions::CalendarPermissionsRequestBuilder.new(@path_parameters, @request_adapter) end |
#calendar_view ⇒ Object
Provides operations to manage the calendarView property of the microsoft.graph.calendar entity.
29 30 31 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 29 def calendar_view() return MicrosoftGraph::Users::Item::Calendar::CalendarView::CalendarViewRequestBuilder.new(@path_parameters, @request_adapter) end |
#events ⇒ Object
Provides operations to manage the events property of the microsoft.graph.calendar entity.
34 35 36 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 34 def events() return MicrosoftGraph::Users::Item::Calendar::Events::EventsRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get the properties and relationships of a calendar object. The calendar can be one for a user, or the default calendar of a Microsoft 365 group. There are two scenarios where an app can get another user’s calendar:
65 66 67 68 69 70 71 72 73 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 65 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Calendar.create_from_discriminator_value(pn) }, error_mapping) end |
#get_schedule ⇒ Object
Provides operations to call the getSchedule method.
39 40 41 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 39 def get_schedule() return MicrosoftGraph::Users::Item::Calendar::GetSchedule::GetScheduleRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of a calendar object. The calendar can be one for a user, or the default calendar of a Microsoft 365 group.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 80 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Calendar.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the properties and relationships of a calendar object. The calendar can be one for a user, or the default calendar of a Microsoft 365 group. There are two scenarios where an app can get another user’s calendar:
95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 95 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of a calendar object. The calendar can be one for a user, or the default calendar of a Microsoft 365 group.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/users/item/calendar/calendar_request_builder.rb', line 114 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |