Class: MicrosoftGraph::Users::Item::Calendar::GetSchedule::GetSchedulePostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Users::Item::Calendar::GetSchedule::GetSchedulePostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#availability_view_interval ⇒ Object
Gets the AvailabilityViewInterval property value.
-
#availability_view_interval=(value) ⇒ Object
Sets the AvailabilityViewInterval property value.
-
#end_time ⇒ Object
Gets the EndTime property value.
-
#end_time=(value) ⇒ Object
Sets the EndTime property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new getSchedulePostRequestBody and sets the default values.
-
#schedules ⇒ Object
Gets the Schedules property value.
-
#schedules=(value) ⇒ Object
Sets the Schedules property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#start_time ⇒ Object
Gets the StartTime property value.
-
#start_time=(value) ⇒ Object
Sets the StartTime property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new getSchedulePostRequestBody and sets the default values.
65 66 67 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 65 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
73 74 75 76 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 73 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GetSchedulePostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
35 36 37 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 35 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
43 44 45 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 43 def additional_data=(value) @additional_data = value end |
#availability_view_interval ⇒ Object
Gets the AvailabilityViewInterval property value. The AvailabilityViewInterval property
50 51 52 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 50 def availability_view_interval return @availability_view_interval end |
#availability_view_interval=(value) ⇒ Object
Sets the AvailabilityViewInterval property value. The AvailabilityViewInterval property
58 59 60 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 58 def availability_view_interval=(value) @availability_view_interval = value end |
#end_time ⇒ Object
Gets the EndTime property value. The EndTime property
81 82 83 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 81 def end_time return @end_time end |
#end_time=(value) ⇒ Object
Sets the EndTime property value. The EndTime property
89 90 91 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 89 def end_time=(value) @end_time = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
96 97 98 99 100 101 102 103 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 96 def get_field_deserializers() return { "AvailabilityViewInterval" => lambda {|n| @availability_view_interval = n.get_number_value() }, "EndTime" => lambda {|n| @end_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DateTimeTimeZone.create_from_discriminator_value(pn) }) }, "Schedules" => lambda {|n| @schedules = n.get_collection_of_primitive_values(String) }, "StartTime" => lambda {|n| @start_time = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DateTimeTimeZone.create_from_discriminator_value(pn) }) }, } end |
#schedules ⇒ Object
Gets the Schedules property value. The Schedules property
108 109 110 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 108 def schedules return @schedules end |
#schedules=(value) ⇒ Object
Sets the Schedules property value. The Schedules property
116 117 118 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 116 def schedules=(value) @schedules = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
124 125 126 127 128 129 130 131 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 124 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("AvailabilityViewInterval", @availability_view_interval) writer.write_object_value("EndTime", @end_time) writer.write_collection_of_primitive_values("Schedules", @schedules) writer.write_object_value("StartTime", @start_time) writer.write_additional_data(@additional_data) end |
#start_time ⇒ Object
Gets the StartTime property value. The StartTime property
136 137 138 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 136 def start_time return @start_time end |
#start_time=(value) ⇒ Object
Sets the StartTime property value. The StartTime property
144 145 146 |
# File 'lib/users/item/calendar/get_schedule/get_schedule_post_request_body.rb', line 144 def start_time=(value) @start_time = value end |