Class: MicrosoftGraph::Users::Item::CalendarView::CalendarViewRequestBuilder::CalendarViewRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/users/item/calendar_view/calendar_view_request_builder.rb

Overview

The calendar view for the calendar. Read-only. Nullable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#countObject

Include count of items



89
90
91
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 89

def count
  @count
end

#end_date_timeObject

The end date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T20:00:00-08:00



92
93
94
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 92

def end_date_time
  @end_date_time
end

#expandObject

Expand related entities



95
96
97
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 95

def expand
  @expand
end

#filterObject

Filter items by property values



98
99
100
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 98

def filter
  @filter
end

#orderbyObject

Order items by property values



101
102
103
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 101

def orderby
  @orderby
end

#selectObject

Select properties to be returned



104
105
106
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 104

def select
  @select
end

#skipObject

Skip the first n items



107
108
109
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 107

def skip
  @skip
end

#start_date_timeObject

The start date and time of the time range, represented in ISO 8601 format. For example, 2019-11-08T19:00:00-08:00



110
111
112
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 110

def start_date_time
  @start_date_time
end

#topObject

Show only the first n items



113
114
115
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 113

def top
  @top
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • The original query parameter name in the class.

Returns:

  • a string

Raises:



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/users/item/calendar_view/calendar_view_request_builder.rb', line 119

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "count"
            return "%24count"
        when "end_date_time"
            return "endDateTime"
        when "expand"
            return "%24expand"
        when "filter"
            return "%24filter"
        when "orderby"
            return "%24orderby"
        when "select"
            return "%24select"
        when "skip"
            return "%24skip"
        when "start_date_time"
            return "startDateTime"
        when "top"
            return "%24top"
        else
            return original_name
    end
end