Class: MicrosoftGraph::Users::Item::ChangePassword::ChangePasswordPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Users::Item::ChangePassword::ChangePasswordPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/users/item/change_password/change_password_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#current_password ⇒ Object
Gets the currentPassword property value.
-
#current_password=(value) ⇒ Object
Sets the currentPassword property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new changePasswordPostRequestBody and sets the default values.
-
#new_password ⇒ Object
Gets the newPassword property value.
-
#new_password=(value) ⇒ Object
Sets the newPassword property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new changePasswordPostRequestBody and sets the default values.
41 42 43 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 41 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
49 50 51 52 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 49 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ChangePasswordPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
26 27 28 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 26 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
34 35 36 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 34 def additional_data=(value) @additional_data = value end |
#current_password ⇒ Object
Gets the currentPassword property value. The currentPassword property
57 58 59 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 57 def current_password return @current_password end |
#current_password=(value) ⇒ Object
Sets the currentPassword property value. The currentPassword property
65 66 67 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 65 def current_password=(value) @current_password = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
72 73 74 75 76 77 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 72 def get_field_deserializers() return { "currentPassword" => lambda {|n| @current_password = n.get_string_value() }, "newPassword" => lambda {|n| @new_password = n.get_string_value() }, } end |
#new_password ⇒ Object
Gets the newPassword property value. The newPassword property
82 83 84 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 82 def new_password return @new_password end |
#new_password=(value) ⇒ Object
Sets the newPassword property value. The newPassword property
90 91 92 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 90 def new_password=(value) @new_password = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
98 99 100 101 102 103 |
# File 'lib/users/item/change_password/change_password_post_request_body.rb', line 98 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("currentPassword", @current_password) writer.write_string_value("newPassword", @new_password) writer.write_additional_data(@additional_data) end |