Class: MicrosoftGraph::Users::Item::ChangePassword::ChangePasswordRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Users::Item::ChangePassword::ChangePasswordRequestBuilder
- Defined in:
- lib/users/item/change_password/change_password_request_builder.rb
Overview
Provides operations to call the changePassword method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ChangePasswordRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Enable the user to update their password.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Enable the user to update their password.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ChangePasswordRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/users/item/change_password/change_password_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/changePassword") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Enable the user to update their password. Any user can update their password without belonging to any administrator role.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/users/item/change_password/change_password_request_builder.rb', line 31 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Enable the user to update their password. Any user can update their password without belonging to any administrator role.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/users/item/change_password/change_password_request_builder.rb', line 47 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |