Class: MicrosoftGraph::Users::Item::Chats::ChatsRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/users/item/chats/chats_request_builder.rb

Overview

Provides operations to manage the chats property of the microsoft.graph.user entity.

Defined Under Namespace

Classes: ChatsRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ChatsRequestBuilder and sets the default values.



48
49
50
# File 'lib/users/item/chats/chats_request_builder.rb', line 48

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/chats{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_chat_id(chat_id) ⇒ Object

Provides operations to manage the chats property of the microsoft.graph.user entity.

Raises:

  • (StandardError)


36
37
38
39
40
41
# File 'lib/users/item/chats/chats_request_builder.rb', line 36

def by_chat_id(chat_id)
    raise StandardError, 'chat_id cannot be null' if chat_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["chat%2Did"] = chat_id
    return MicrosoftGraph::Users::Item::Chats::Item::ChatItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#count ⇒ Object

Provides operations to count the resources in the collection.



23
24
25
# File 'lib/users/item/chats/chats_request_builder.rb', line 23

def count()
    return MicrosoftGraph::Users::Item::Chats::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.



56
57
58
59
60
61
62
63
64
# File 'lib/users/item/chats/chats_request_builder.rb', line 56

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ChatCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#get_all_messages ⇒ Object

Provides operations to call the getAllMessages method.



28
29
30
# File 'lib/users/item/chats/chats_request_builder.rb', line 28

def get_all_messages()
    return MicrosoftGraph::Users::Item::Chats::GetAllMessages::GetAllMessagesRequestBuilder.new(@path_parameters, @request_adapter)
end

#post(body, request_configuration = nil) ⇒ Object

Create new navigation property to chats for users

Raises:

  • (StandardError)


71
72
73
74
75
76
77
78
79
80
# File 'lib/users/item/chats/chats_request_builder.rb', line 71

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Chat.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve the list of chats that the user is part of. This method supports federation. When a user ID is provided, the calling application must belong to the same tenant that the user belongs to.



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/users/item/chats/chats_request_builder.rb', line 86

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create new navigation property to chats for users

Raises:

  • (StandardError)


105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/users/item/chats/chats_request_builder.rb', line 105

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end