Class: MicrosoftGraph::Users::Item::Events::Item::EventItemRequestBuilder::EventItemRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/users/item/events/item/event_item_request_builder.rb

Overview

Get the properties and relationships of the specified event object. Currently, this operation returns event bodies in only HTML format. There are two scenarios where an app can get an event in another user’s calendar: Since the event resource supports extensions, you can also use the GET operation to get custom properties and extension data in an event instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#expandObject

Expand related entities



199
200
201
# File 'lib/users/item/events/item/event_item_request_builder.rb', line 199

def expand
  @expand
end

#selectObject

Select properties to be returned



202
203
204
# File 'lib/users/item/events/item/event_item_request_builder.rb', line 202

def select
  @select
end

Instance Method Details

#get_query_parameter(original_name) ⇒ Object

Maps the query parameters names to their encoded names for the URI template parsing.

Parameters:

  • original_name

    The original query parameter name in the class.

Returns:

  • a string

Raises:

  • (StandardError)


208
209
210
211
212
213
214
215
216
217
218
# File 'lib/users/item/events/item/event_item_request_builder.rb', line 208

def get_query_parameter(original_name)
    raise StandardError, 'original_name cannot be null' if original_name.nil?
    case original_name
        when "expand"
            return "%24expand"
        when "select"
            return "%24select"
        else
            return original_name
    end
end