Class: MicrosoftGraph::Users::Item::MailFolders::Delta::DeltaRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/users/item/mail_folders/delta/delta_request_builder.rb

Overview

Provides operations to call the delta method.

Defined Under Namespace

Classes: DeltaRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new DeltaRequestBuilder and sets the default values.



24
25
26
# File 'lib/users/item/mail_folders/delta/delta_request_builder.rb', line 24

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/mailFolders/delta(){?%24top,%24skip,%24search,%24filter,%24count,%24select,%24orderby}")
end

Instance Method Details

#get(request_configuration = nil) ⇒ Object

Get a set of mail folders that have been added, deleted, or removed from the user’s mailbox. A delta function call for mail folders in a mailbox is similar to a GET request, except that by appropriately applying state tokens in one or more of these calls, you can query for incremental changes in the mail folders. This allows you to maintain and synchronize a local store of a user’s mail folders without having to fetch all the mail folders of that mailbox from the server every time.



32
33
34
35
36
37
38
39
40
# File 'lib/users/item/mail_folders/delta/delta_request_builder.rb', line 32

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Users::Item::MailFolders::Delta::DeltaResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Get a set of mail folders that have been added, deleted, or removed from the user’s mailbox. A delta function call for mail folders in a mailbox is similar to a GET request, except that by appropriately applying state tokens in one or more of these calls, you can query for incremental changes in the mail folders. This allows you to maintain and synchronize a local store of a user’s mail folders without having to fetch all the mail folders of that mailbox from the server every time.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/users/item/mail_folders/delta/delta_request_builder.rb', line 46

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end