Class: MicrosoftGraph::Users::Item::MailFolders::Item::Copy::CopyPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Users::Item::MailFolders::Item::Copy::CopyPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/users/item/mail_folders/item/copy/copy_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#destination_id ⇒ Object
Gets the DestinationId property value.
-
#destination_id=(value) ⇒ Object
Sets the DestinationId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new copyPostRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new copyPostRequestBody and sets the default values.
42 43 44 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 42 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
50 51 52 53 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 50 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CopyPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
27 28 29 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 27 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
35 36 37 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 35 def additional_data=(value) @additional_data = value end |
#destination_id ⇒ Object
Gets the DestinationId property value. The DestinationId property
58 59 60 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 58 def destination_id return @destination_id end |
#destination_id=(value) ⇒ Object
Sets the DestinationId property value. The DestinationId property
66 67 68 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 66 def destination_id=(value) @destination_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
73 74 75 76 77 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 73 def get_field_deserializers() return { "DestinationId" => lambda {|n| @destination_id = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
83 84 85 86 87 |
# File 'lib/users/item/mail_folders/item/copy/copy_post_request_body.rb', line 83 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("DestinationId", @destination_id) writer.write_additional_data(@additional_data) end |