Class: MicrosoftGraph::Users::Item::Onenote::Notebooks::NotebooksRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/users/item/onenote/notebooks/notebooks_request_builder.rb

Overview

Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.

Defined Under Namespace

Classes: NotebooksRequestBuilderGetQueryParameters

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new NotebooksRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



51
52
53
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 51

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/onenote/notebooks{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}")
end

Instance Method Details

#by_notebook_id(notebook_id) ⇒ Object

Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.

Parameters:

  • notebook_id

    The unique identifier of notebook

Returns:

  • a notebook_item_request_builder

Raises:

  • (StandardError)


39
40
41
42
43
44
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 39

def by_notebook_id(notebook_id)
    raise StandardError, 'notebook_id cannot be null' if notebook_id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["notebook%2Did"] = notebook_id
    return MicrosoftGraph::Users::Item::Onenote::Notebooks::Item::NotebookItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#countObject

Provides operations to count the resources in the collection.



26
27
28
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 26

def count()
    return MicrosoftGraph::Users::Item::Onenote::Notebooks::Count::CountRequestBuilder.new(@path_parameters, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Retrieve a list of notebook objects.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of notebook_collection_response



59
60
61
62
63
64
65
66
67
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 59

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::NotebookCollectionResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#get_notebook_from_web_urlObject

Provides operations to call the getNotebookFromWebUrl method.



31
32
33
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 31

def get_notebook_from_web_url()
    return MicrosoftGraph::Users::Item::Onenote::Notebooks::GetNotebookFromWebUrl::GetNotebookFromWebUrlRequestBuilder.new(@path_parameters, @request_adapter)
end

#get_recent_notebooks_with_include_personal_notebooks(include_personal_notebooks) ⇒ Object

Provides operations to call the getRecentNotebooks method.

Parameters:

  • include_personal_notebooks

    Usage: includePersonalNotebooks=includePersonalNotebooks

Returns:

  • a get_recent_notebooks_with_include_personal_notebooks_request_builder

Raises:

  • (StandardError)


73
74
75
76
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 73

def get_recent_notebooks_with_include_personal_notebooks(include_personal_notebooks)
    raise StandardError, 'include_personal_notebooks cannot be null' if include_personal_notebooks.nil?
    return GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilder.new(@path_parameters, @request_adapter, includePersonalNotebooks)
end

#post(body, request_configuration = nil) ⇒ Object

Create a new OneNote notebook.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of notebook

Raises:

  • (StandardError)


83
84
85
86
87
88
89
90
91
92
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 83

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Notebook.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Retrieve a list of notebook objects.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 98

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters)
        request_info.add_request_options(request_configuration.options)
    end
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Create a new OneNote notebook.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/users/item/onenote/notebooks/notebooks_request_builder.rb', line 117

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.add('Accept', 'application/json')
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end