Class: MicrosoftGraph::Users::Item::Onenote::Pages::Item::CopyToSection::CopyToSectionPostRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new copyToSectionPostRequestBody and sets the default values.



53
54
55
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 53

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a copy_to_section_post_request_body

Raises:

  • (StandardError)


61
62
63
64
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 61

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return CopyToSectionPostRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



38
39
40
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 38

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the additionalData property.

Returns:

  • a void



46
47
48
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 46

def additional_data=(value)
    @additional_data = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



69
70
71
72
73
74
75
76
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 69

def get_field_deserializers()
    return {
        "groupId" => lambda {|n| @group_id = n.get_string_value() },
        "id" => lambda {|n| @id = n.get_string_value() },
        "siteCollectionId" => lambda {|n| @site_collection_id = n.get_string_value() },
        "siteId" => lambda {|n| @site_id = n.get_string_value() },
    }
end

#group_idObject

Gets the groupId property value. The groupId property

Returns:

  • a string



81
82
83
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 81

def group_id
    return @group_id
end

#group_id=(value) ⇒ Object

Sets the groupId property value. The groupId property

Parameters:

  • value

    Value to set for the groupId property.

Returns:

  • a void



89
90
91
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 89

def group_id=(value)
    @group_id = value
end

#idObject

Gets the id property value. The id property

Returns:

  • a string



96
97
98
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 96

def id
    return @id
end

#id=(value) ⇒ Object

Sets the id property value. The id property

Parameters:

  • value

    Value to set for the id property.

Returns:

  • a void



104
105
106
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 104

def id=(value)
    @id = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


112
113
114
115
116
117
118
119
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 112

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("groupId", @group_id)
    writer.write_string_value("id", @id)
    writer.write_string_value("siteCollectionId", @site_collection_id)
    writer.write_string_value("siteId", @site_id)
    writer.write_additional_data(@additional_data)
end

#site_collection_idObject

Gets the siteCollectionId property value. The siteCollectionId property

Returns:

  • a string



124
125
126
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 124

def site_collection_id
    return @site_collection_id
end

#site_collection_id=(value) ⇒ Object

Sets the siteCollectionId property value. The siteCollectionId property

Parameters:

  • value

    Value to set for the siteCollectionId property.

Returns:

  • a void



132
133
134
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 132

def site_collection_id=(value)
    @site_collection_id = value
end

#site_idObject

Gets the siteId property value. The siteId property

Returns:

  • a string



139
140
141
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 139

def site_id
    return @site_id
end

#site_id=(value) ⇒ Object

Sets the siteId property value. The siteId property

Parameters:

  • value

    Value to set for the siteId property.

Returns:

  • a void



147
148
149
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 147

def site_id=(value)
    @site_id = value
end