Class: MicrosoftGraph::Users::Item::OwnedDevices::OwnedDevicesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Users::Item::OwnedDevices::OwnedDevicesRequestBuilder
- Defined in:
- lib/users/item/owned_devices/owned_devices_request_builder.rb
Overview
Provides operations to manage the ownedDevices property of the microsoft.graph.user entity.
Defined Under Namespace
Classes: OwnedDevicesRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_directory_object_id(directory_object_id) ⇒ Object
Provides operations to manage the ownedDevices property of the microsoft.graph.user entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Devices that are owned by the user.
-
#graph_app_role_assignment ⇒ Object
Casts the previous resource to appRoleAssignment.
-
#graph_device ⇒ Object
Casts the previous resource to device.
-
#graph_endpoint ⇒ Object
Casts the previous resource to endpoint.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new OwnedDevicesRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Devices that are owned by the user.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new OwnedDevicesRequestBuilder and sets the default values.
59 60 61 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 59 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/ownedDevices{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_directory_object_id(directory_object_id) ⇒ Object
Provides operations to manage the ownedDevices property of the microsoft.graph.user entity.
47 48 49 50 51 52 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 47 def by_directory_object_id(directory_object_id) raise StandardError, 'directory_object_id cannot be null' if directory_object_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["directoryObject%2Did"] = directory_object_id return MicrosoftGraph::Users::Item::OwnedDevices::Item::DirectoryObjectItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
24 25 26 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 24 def count() return MicrosoftGraph::Users::Item::OwnedDevices::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Devices that are owned by the user. Read-only. Nullable. Supports $expand and $filter (/$count eq 0, /$count ne 0, /$count eq 1, /$count ne 1).
67 68 69 70 71 72 73 74 75 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 67 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DirectoryObjectCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#graph_app_role_assignment ⇒ Object
Casts the previous resource to appRoleAssignment.
29 30 31 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 29 def graph_app_role_assignment() return MicrosoftGraph::Users::Item::OwnedDevices::GraphAppRoleAssignment::GraphAppRoleAssignmentRequestBuilder.new(@path_parameters, @request_adapter) end |
#graph_device ⇒ Object
Casts the previous resource to device.
34 35 36 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 34 def graph_device() return MicrosoftGraph::Users::Item::OwnedDevices::GraphDevice::GraphDeviceRequestBuilder.new(@path_parameters, @request_adapter) end |
#graph_endpoint ⇒ Object
Casts the previous resource to endpoint.
39 40 41 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 39 def graph_endpoint() return MicrosoftGraph::Users::Item::OwnedDevices::GraphEndpoint::GraphEndpointRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Devices that are owned by the user. Read-only. Nullable. Supports $expand and $filter (/$count eq 0, /$count ne 0, /$count eq 1, /$count ne 1).
81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/users/item/owned_devices/owned_devices_request_builder.rb', line 81 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |