Class: MicrosoftGraph::Users::Item::Presence::SetUserPreferredPresence::SetUserPreferredPresenceRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/users/item/presence/set_user_preferred_presence/set_user_preferred_presence_request_builder.rb

Overview

Provides operations to call the setUserPreferredPresence method.

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new SetUserPreferredPresenceRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



24
25
26
# File 'lib/users/item/presence/set_user_preferred_presence/set_user_preferred_presence_request_builder.rb', line 24

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/presence/setUserPreferredPresence")
end

Instance Method Details

#post(body, request_configuration = nil) ⇒ Object

Set the preferred availability and activity status for a user. If the preferred presence of a user is set, the user’s presence shows as the preferred status. Preferred presence takes effect only when at least one presence session exists for the user. Otherwise, the user’s presence shows as Offline. A presence session is created as a result of a successful setPresence operation, or if the user is signed in on a Microsoft Teams client. For more details, see presence sessions and time-out and expiration.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of void

Raises:

  • (StandardError)


33
34
35
36
37
38
39
40
41
42
# File 'lib/users/item/presence/set_user_preferred_presence/set_user_preferred_presence_request_builder.rb', line 33

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, nil, error_mapping)
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Set the preferred availability and activity status for a user. If the preferred presence of a user is set, the user’s presence shows as the preferred status. Preferred presence takes effect only when at least one presence session exists for the user. Otherwise, the user’s presence shows as Offline. A presence session is created as a result of a successful setPresence operation, or if the user is signed in on a Microsoft Teams client. For more details, see presence sessions and time-out and expiration.

Parameters:

  • body

    The request body

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/users/item/presence/set_user_preferred_presence/set_user_preferred_presence_request_builder.rb', line 49

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, "application/json", body)
    return request_info
end