Class: MicrosoftGraph::Users::Item::TranslateExchangeIds::TranslateExchangeIdsPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Users::Item::TranslateExchangeIds::TranslateExchangeIdsPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new translateExchangeIdsPostRequestBody and sets the default values.
-
#input_ids ⇒ Object
Gets the InputIds property value.
-
#input_ids=(value) ⇒ Object
Sets the InputIds property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#source_id_type ⇒ Object
Gets the SourceIdType property value.
-
#source_id_type=(value) ⇒ Object
Sets the SourceIdType property value.
-
#target_id_type ⇒ Object
Gets the TargetIdType property value.
-
#target_id_type=(value) ⇒ Object
Sets the TargetIdType property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new translateExchangeIdsPostRequestBody and sets the default values.
45 46 47 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 45 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
53 54 55 56 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 53 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return TranslateExchangeIdsPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 30 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 38 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
61 62 63 64 65 66 67 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 61 def get_field_deserializers() return { "InputIds" => lambda {|n| @input_ids = n.get_collection_of_primitive_values(String) }, "SourceIdType" => lambda {|n| @source_id_type = n.get_enum_value(MicrosoftGraph::Models::ExchangeIdFormat) }, "TargetIdType" => lambda {|n| @target_id_type = n.get_enum_value(MicrosoftGraph::Models::ExchangeIdFormat) }, } end |
#input_ids ⇒ Object
Gets the InputIds property value. The InputIds property
72 73 74 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 72 def input_ids return @input_ids end |
#input_ids=(value) ⇒ Object
Sets the InputIds property value. The InputIds property
80 81 82 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 80 def input_ids=(value) @input_ids = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
88 89 90 91 92 93 94 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 88 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_primitive_values("InputIds", @input_ids) writer.write_enum_value("SourceIdType", @source_id_type) writer.write_enum_value("TargetIdType", @target_id_type) writer.write_additional_data(@additional_data) end |
#source_id_type ⇒ Object
Gets the SourceIdType property value. The SourceIdType property
99 100 101 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 99 def source_id_type return @source_id_type end |
#source_id_type=(value) ⇒ Object
Sets the SourceIdType property value. The SourceIdType property
107 108 109 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 107 def source_id_type=(value) @source_id_type = value end |
#target_id_type ⇒ Object
Gets the TargetIdType property value. The TargetIdType property
114 115 116 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 114 def target_id_type return @target_id_type end |
#target_id_type=(value) ⇒ Object
Sets the TargetIdType property value. The TargetIdType property
122 123 124 |
# File 'lib/users/item/translate_exchange_ids/translate_exchange_ids_post_request_body.rb', line 122 def target_id_type=(value) @target_id_type = value end |