Class: MicrosoftGraph::Applications::Item::RemoveKey::RemoveKeyRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Applications::Item::RemoveKey::RemoveKeyRequestBuilder
- Defined in:
- lib/applications/item/remove_key/remove_key_request_builder.rb
Overview
Provides operations to call the removeKey method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RemoveKeyRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Remove a key credential from an application.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Remove a key credential from an application.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RemoveKeyRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/applications/item/remove_key/remove_key_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/applications/{application%2Did}/removeKey") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Remove a key credential from an application. This method along with addKey can be used by an application to automate rolling its expiring keys. As part of the request validation for this method, a proof of possession of an existing key is verified before the action can be performed.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/applications/item/remove_key/remove_key_request_builder.rb', line 31 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Remove a key credential from an application. This method along with addKey can be used by an application to automate rolling its expiring keys. As part of the request validation for this method, a proof of possession of an existing key is verified before the action can be performed.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/applications/item/remove_key/remove_key_request_builder.rb', line 47 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |