Class: MicrosoftGraph::Communications::CallRecords::Item::CallRecordItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Communications::CallRecords::Item::CallRecordItemRequestBuilder
- Defined in:
- lib/communications/call_records/item/call_record_item_request_builder.rb
Overview
Provides operations to manage the callRecords property of the microsoft.graph.cloudCommunications entity.
Defined Under Namespace
Classes: CallRecordItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property callRecords for communications.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a callRecord object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new CallRecordItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property callRecords in communications.
-
#sessions ⇒ Object
Provides operations to manage the sessions property of the microsoft.graph.callRecords.callRecord entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property callRecords for communications.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a callRecord object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property callRecords in communications.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new CallRecordItemRequestBuilder and sets the default values.
29 30 31 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 29 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/communications/callRecords/{callRecord%2Did}{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete navigation property callRecords for communications
37 38 39 40 41 42 43 44 45 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 37 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a callRecord object. There are two ways to get the id of a callRecord: You can use the $expand query parameter to optionally include session and segment details, as shown in the Get full details example. When you expand session details, the maximum page size is 60 sessions.
51 52 53 54 55 56 57 58 59 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 51 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::CallRecordsCallRecord.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property callRecords in communications
66 67 68 69 70 71 72 73 74 75 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 66 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::CallRecordsCallRecord.create_from_discriminator_value(pn) }, error_mapping) end |
#sessions ⇒ Object
Provides operations to manage the sessions property of the microsoft.graph.callRecords.callRecord entity.
20 21 22 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 20 def sessions() return MicrosoftGraph::Communications::CallRecords::Item::Sessions::SessionsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property callRecords for communications
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 81 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a callRecord object. There are two ways to get the id of a callRecord: You can use the $expand query parameter to optionally include session and segment details, as shown in the Get full details example. When you expand session details, the maximum page size is 60 sessions.
97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 97 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property callRecords in communications
116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/communications/call_records/item/call_record_item_request_builder.rb', line 116 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |