Class: MicrosoftGraph::Communications::Calls::Item::KeepAlive::KeepAliveRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Communications::Calls::Item::KeepAlive::KeepAliveRequestBuilder
- Defined in:
- lib/communications/calls/item/keep_alive/keep_alive_request_builder.rb
Overview
Provides operations to call the keepAlive method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new KeepAliveRequestBuilder and sets the default values.
-
#post(request_configuration = nil) ⇒ Object
Make a request to this API every 15 to 45 minutes to ensure that an ongoing call remains active.
-
#to_post_request_information(request_configuration = nil) ⇒ Object
Make a request to this API every 15 to 45 minutes to ensure that an ongoing call remains active.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new KeepAliveRequestBuilder and sets the default values.
24 25 26 |
# File 'lib/communications/calls/item/keep_alive/keep_alive_request_builder.rb', line 24 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/communications/calls/{call%2Did}/keepAlive") end |
Instance Method Details
#post(request_configuration = nil) ⇒ Object
Make a request to this API every 15 to 45 minutes to ensure that an ongoing call remains active. A call that does not receive this request within 45 minutes is considered inactive and will subsequently end. At least one successful request must be made within 45 minutes of the previous request, or the start of the call. We recommend that you send a request in shorter time intervals (every 15 minutes). Make sure that these requests are successful to prevent the call from timing out and ending. Attempting to send a request to a call that has already ended will result in a 404 Not-Found error. The resources related to the call should be cleaned up on the application side.
32 33 34 35 36 37 38 39 40 |
# File 'lib/communications/calls/item/keep_alive/keep_alive_request_builder.rb', line 32 def post(request_configuration=nil) request_info = self.to_post_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(request_configuration = nil) ⇒ Object
Make a request to this API every 15 to 45 minutes to ensure that an ongoing call remains active. A call that does not receive this request within 45 minutes is considered inactive and will subsequently end. At least one successful request must be made within 45 minutes of the previous request, or the start of the call. We recommend that you send a request in shorter time intervals (every 15 minutes). Make sure that these requests are successful to prevent the call from timing out and ending. Attempting to send a request to a call that has already ended will result in a 404 Not-Found error. The resources related to the call should be cleaned up on the application side.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/communications/calls/item/keep_alive/keep_alive_request_builder.rb', line 46 def to_post_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |