Class: MicrosoftGraph::Communications::Calls::Item::Mute::MuteRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Communications::Calls::Item::Mute::MuteRequestBuilder
- Defined in:
- lib/communications/calls/item/mute/mute_request_builder.rb
Overview
Provides operations to call the mute method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MuteRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Allows the application to mute itself.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Allows the application to mute itself.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MuteRequestBuilder and sets the default values.
25 26 27 |
# File 'lib/communications/calls/item/mute/mute_request_builder.rb', line 25 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/communications/calls/{call%2Did}/mute") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Allows the application to mute itself. This is a server mute, meaning that the server will drop all audio packets for this participant, even if the participant continues to stream audio. For more details about how to handle mute operations, see muteParticipantOperation
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/communications/calls/item/mute/mute_request_builder.rb', line 34 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::MuteParticipantOperation.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Allows the application to mute itself. This is a server mute, meaning that the server will drop all audio packets for this participant, even if the participant continues to stream audio. For more details about how to handle mute operations, see muteParticipantOperation
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/communications/calls/item/mute/mute_request_builder.rb', line 50 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |