Class: MicrosoftGraph::Communications::Calls::Item::Reject::RejectRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Communications::Calls::Item::Reject::RejectRequestBuilder
- Defined in:
- lib/communications/calls/item/reject/reject_request_builder.rb
Overview
Provides operations to call the reject method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RejectRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Enable a bot to reject an incoming call.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Enable a bot to reject an incoming call.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RejectRequestBuilder and sets the default values.
24 25 26 |
# File 'lib/communications/calls/item/reject/reject_request_builder.rb', line 24 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/communications/calls/{call%2Did}/reject") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Enable a bot to reject an incoming call. The incoming call request can be an invite from a participant in a group call or a peer-to-peer call. If an invite to a group call is received, the notification will contain the chatInfo and meetingInfo parameters. The bot is expected to answer or reject the call before the call times out. The current timeout value is 15 seconds. This API does not end existing calls that have already been answered. Use delete call to end a call.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/communications/calls/item/reject/reject_request_builder.rb', line 33 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Enable a bot to reject an incoming call. The incoming call request can be an invite from a participant in a group call or a peer-to-peer call. If an invite to a group call is received, the notification will contain the chatInfo and meetingInfo parameters. The bot is expected to answer or reject the call before the call times out. The current timeout value is 15 seconds. This API does not end existing calls that have already been answered. Use delete call to end a call.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/communications/calls/item/reject/reject_request_builder.rb', line 49 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |