Class: MicrosoftGraph::DeviceManagement::ExchangeConnectors::Item::Sync::SyncPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::DeviceManagement::ExchangeConnectors::Item::Sync::SyncPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new syncPostRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#sync_type ⇒ Object
Gets the syncType property value.
-
#sync_type=(value) ⇒ Object
Sets the syncType property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new syncPostRequestBody and sets the default values.
41 42 43 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 41 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
49 50 51 52 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 49 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SyncPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
26 27 28 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 26 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
34 35 36 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 34 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
57 58 59 60 61 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 57 def get_field_deserializers() return { "syncType" => lambda {|n| @sync_type = n.get_enum_value(MicrosoftGraph::Models::DeviceManagementExchangeConnectorSyncType) }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
67 68 69 70 71 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 67 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_enum_value("syncType", @sync_type) writer.write_additional_data(@additional_data) end |
#sync_type ⇒ Object
Gets the syncType property value. The type of Exchange Connector sync requested.
76 77 78 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 76 def sync_type return @sync_type end |
#sync_type=(value) ⇒ Object
Sets the syncType property value. The type of Exchange Connector sync requested.
84 85 86 |
# File 'lib/device_management/exchange_connectors/item/sync/sync_post_request_body.rb', line 84 def sync_type=(value) @sync_type = value end |