Class: MicrosoftGraph::DirectoryRoles::Item::DirectoryRoleItemRequestBuilder::DirectoryRoleItemRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::DirectoryRoles::Item::DirectoryRoleItemRequestBuilder::DirectoryRoleItemRequestBuilderGetQueryParameters
- Defined in:
- lib/directory_roles/item/directory_role_item_request_builder.rb
Overview
Retrieve the properties of a directoryRole object. The role must be activated in tenant for a successful response. You can use both the object ID and template ID of the directoryRole with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see Role template IDs.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
171 172 173 |
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 171 def end |
#select ⇒ Object
Select properties to be returned
174 175 176 |
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 174 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/directory_roles/item/directory_role_item_request_builder.rb', line 180 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |