Class: MicrosoftGraph::Drives::Item::Following::FollowingRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Drives::Item::Following::FollowingRequestBuilder
- Defined in:
- lib/drives/item/following/following_request_builder.rb
Overview
Provides operations to manage the following property of the microsoft.graph.drive entity.
Defined Under Namespace
Classes: FollowingRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_drive_item_id(drive_item_id) ⇒ Object
Provides operations to manage the following property of the microsoft.graph.drive entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
List the items that have been followed by the signed in user.This collection includes items that are in the user’s drive as well as items they have access to from other drives.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new FollowingRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
List the items that have been followed by the signed in user.This collection includes items that are in the user’s drive as well as items they have access to from other drives.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new FollowingRequestBuilder and sets the default values.
41 42 43 |
# File 'lib/drives/item/following/following_request_builder.rb', line 41 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/drives/{drive%2Did}/following{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_drive_item_id(drive_item_id) ⇒ Object
Provides operations to manage the following property of the microsoft.graph.drive entity.
29 30 31 32 33 34 |
# File 'lib/drives/item/following/following_request_builder.rb', line 29 def by_drive_item_id(drive_item_id) raise StandardError, 'drive_item_id cannot be null' if drive_item_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["driveItem%2Did"] = drive_item_id return MicrosoftGraph::Drives::Item::Following::Item::DriveItemItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
21 22 23 |
# File 'lib/drives/item/following/following_request_builder.rb', line 21 def count() return MicrosoftGraph::Drives::Item::Following::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
List the items that have been followed by the signed in user.This collection includes items that are in the user’s drive as well as items they have access to from other drives.
49 50 51 52 53 54 55 56 57 |
# File 'lib/drives/item/following/following_request_builder.rb', line 49 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DriveItemCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
List the items that have been followed by the signed in user.This collection includes items that are in the user’s drive as well as items they have access to from other drives.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/drives/item/following/following_request_builder.rb', line 63 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |