Class: MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Match::MatchPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Drives::Item::Items::Item::Workbook::Functions::Match::MatchPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new matchPostRequestBody and sets the default values.
-
#lookup_array ⇒ Object
Gets the lookupArray property value.
-
#lookup_array=(value) ⇒ Object
Sets the lookupArray property value.
-
#lookup_value ⇒ Object
Gets the lookupValue property value.
-
#lookup_value=(value) ⇒ Object
Sets the lookupValue property value.
-
#match_type ⇒ Object
Gets the matchType property value.
-
#match_type=(value) ⇒ Object
Sets the matchType property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new matchPostRequestBody and sets the default values.
53 54 55 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 53 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
61 62 63 64 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 61 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MatchPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 38 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
46 47 48 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 46 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
69 70 71 72 73 74 75 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 69 def get_field_deserializers() return { "lookupArray" => lambda {|n| @lookup_array = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "lookupValue" => lambda {|n| @lookup_value = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, "matchType" => lambda {|n| @match_type = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Json.create_from_discriminator_value(pn) }) }, } end |
#lookup_array ⇒ Object
Gets the lookupArray property value. The lookupArray property
80 81 82 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 80 def lookup_array return @lookup_array end |
#lookup_array=(value) ⇒ Object
Sets the lookupArray property value. The lookupArray property
88 89 90 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 88 def lookup_array=(value) @lookup_array = value end |
#lookup_value ⇒ Object
Gets the lookupValue property value. The lookupValue property
95 96 97 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 95 def lookup_value return @lookup_value end |
#lookup_value=(value) ⇒ Object
Sets the lookupValue property value. The lookupValue property
103 104 105 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 103 def lookup_value=(value) @lookup_value = value end |
#match_type ⇒ Object
Gets the matchType property value. The matchType property
110 111 112 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 110 def match_type return @match_type end |
#match_type=(value) ⇒ Object
Sets the matchType property value. The matchType property
118 119 120 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 118 def match_type=(value) @match_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
126 127 128 129 130 131 132 |
# File 'lib/drives/item/items/item/workbook/functions/match/match_post_request_body.rb', line 126 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("lookupArray", @lookup_array) writer.write_object_value("lookupValue", @lookup_value) writer.write_object_value("matchType", @match_type) writer.write_additional_data(@additional_data) end |