Class: MicrosoftGraph::Education::Me::Assignments::Item::Publish::PublishRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Education::Me::Assignments::Item::Publish::PublishRequestBuilder
- Defined in:
- lib/education/me/assignments/item/publish/publish_request_builder.rb
Overview
Provides operations to call the publish method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new PublishRequestBuilder and sets the default values.
-
#post(request_configuration = nil) ⇒ Object
Publish an education assignment.
-
#to_post_request_information(request_configuration = nil) ⇒ Object
Publish an education assignment.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new PublishRequestBuilder and sets the default values.
27 28 29 |
# File 'lib/education/me/assignments/item/publish/publish_request_builder.rb', line 27 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/education/me/assignments/{educationAssignment%2Did}/publish") end |
Instance Method Details
#post(request_configuration = nil) ⇒ Object
Publish an education assignment. Change the state of an educationAssignment from its original draft status to the published status. You can change the state from draft to scheduled if the assignment is scheduled for a future date. Only a teacher in the class can make this call. When an assignment is in draft status, students will not see the assignment, nor will there be any submission objects. Calling this API creates educationSubmission objects and displays the assignment in each student's list. The state of the assignment goes back to draft if there is any backend failure during publish process. To update the properties of a published assignment, see update an assignment.
35 36 37 38 39 40 41 42 43 |
# File 'lib/education/me/assignments/item/publish/publish_request_builder.rb', line 35 def post(request_configuration=nil) request_info = self.to_post_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EducationAssignment.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(request_configuration = nil) ⇒ Object
Publish an education assignment. Change the state of an educationAssignment from its original draft status to the published status. You can change the state from draft to scheduled if the assignment is scheduled for a future date. Only a teacher in the class can make this call. When an assignment is in draft status, students will not see the assignment, nor will there be any submission objects. Calling this API creates educationSubmission objects and displays the assignment in each student's list. The state of the assignment goes back to draft if there is any backend failure during publish process. To update the properties of a published assignment, see update an assignment.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/education/me/assignments/item/publish/publish_request_builder.rb', line 49 def to_post_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |