Class: MicrosoftGraph::Groups::Item::Events::EventsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::Events::EventsRequestBuilder
- Defined in:
- lib/groups/item/events/events_request_builder.rb
Overview
Provides operations to manage the events property of the microsoft.graph.group entity.
Defined Under Namespace
Classes: EventsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_event_id(event_id) ⇒ Object
Provides operations to manage the events property of the microsoft.graph.group entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#delta ⇒ Object
Provides operations to call the delta method.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a list of event objects.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new EventsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Use this API to create a new event.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of event objects.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Use this API to create a new event.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new EventsRequestBuilder and sets the default values.
48 49 50 |
# File 'lib/groups/item/events/events_request_builder.rb', line 48 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/events{?%24top,%24skip,%24filter,%24count,%24orderby,%24select}") end |
Instance Method Details
#by_event_id(event_id) ⇒ Object
Provides operations to manage the events property of the microsoft.graph.group entity.
36 37 38 39 40 41 |
# File 'lib/groups/item/events/events_request_builder.rb', line 36 def by_event_id(event_id) raise StandardError, 'event_id cannot be null' if event_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["event%2Did"] = event_id return MicrosoftGraph::Groups::Item::Events::Item::EventItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
23 24 25 |
# File 'lib/groups/item/events/events_request_builder.rb', line 23 def count() return MicrosoftGraph::Groups::Item::Events::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#delta ⇒ Object
Provides operations to call the delta method.
28 29 30 |
# File 'lib/groups/item/events/events_request_builder.rb', line 28 def delta() return MicrosoftGraph::Groups::Item::Events::Delta::DeltaRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a list of event objects.
56 57 58 59 60 61 62 63 64 |
# File 'lib/groups/item/events/events_request_builder.rb', line 56 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EventCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Use this API to create a new event.
71 72 73 74 75 76 77 78 79 80 |
# File 'lib/groups/item/events/events_request_builder.rb', line 71 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Event.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of event objects.
86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/groups/item/events/events_request_builder.rb', line 86 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Use this API to create a new event.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/groups/item/events/events_request_builder.rb', line 105 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |