Class: MicrosoftGraph::Groups::Item::Onenote::Sections::Item::CopyToSectionGroup::CopyToSectionGroupPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Groups::Item::Onenote::Sections::Item::CopyToSectionGroup::CopyToSectionGroupPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#group_id ⇒ Object
Gets the groupId property value.
-
#group_id=(value) ⇒ Object
Sets the groupId property value.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new copyToSectionGroupPostRequestBody and sets the default values.
-
#rename_as ⇒ Object
Gets the renameAs property value.
-
#rename_as=(value) ⇒ Object
Sets the renameAs property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#site_collection_id ⇒ Object
Gets the siteCollectionId property value.
-
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value.
-
#site_id ⇒ Object
Gets the siteId property value.
-
#site_id=(value) ⇒ Object
Sets the siteId property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new copyToSectionGroupPostRequestBody and sets the default values.
56 57 58 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 56 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
64 65 66 67 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 64 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CopyToSectionGroupPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
41 42 43 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 41 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
49 50 51 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 49 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
72 73 74 75 76 77 78 79 80 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 72 def get_field_deserializers() return { "groupId" => lambda {|n| @group_id = n.get_string_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "renameAs" => lambda {|n| @rename_as = n.get_string_value() }, "siteCollectionId" => lambda {|n| @site_collection_id = n.get_string_value() }, "siteId" => lambda {|n| @site_id = n.get_string_value() }, } end |
#group_id ⇒ Object
Gets the groupId property value. The groupId property
85 86 87 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 85 def group_id return @group_id end |
#group_id=(value) ⇒ Object
Sets the groupId property value. The groupId property
93 94 95 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 93 def group_id=(value) @group_id = value end |
#id ⇒ Object
Gets the id property value. The id property
100 101 102 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 100 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
108 109 110 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 108 def id=(value) @id = value end |
#rename_as ⇒ Object
Gets the renameAs property value. The renameAs property
115 116 117 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 115 def rename_as return @rename_as end |
#rename_as=(value) ⇒ Object
Sets the renameAs property value. The renameAs property
123 124 125 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 123 def rename_as=(value) @rename_as = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
131 132 133 134 135 136 137 138 139 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 131 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("groupId", @group_id) writer.write_string_value("id", @id) writer.write_string_value("renameAs", @rename_as) writer.write_string_value("siteCollectionId", @site_collection_id) writer.write_string_value("siteId", @site_id) writer.write_additional_data(@additional_data) end |
#site_collection_id ⇒ Object
Gets the siteCollectionId property value. The siteCollectionId property
144 145 146 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 144 def site_collection_id return @site_collection_id end |
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value. The siteCollectionId property
152 153 154 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 152 def site_collection_id=(value) @site_collection_id = value end |
#site_id ⇒ Object
Gets the siteId property value. The siteId property
159 160 161 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 159 def site_id return @site_id end |
#site_id=(value) ⇒ Object
Sets the siteId property value. The siteId property
167 168 169 |
# File 'lib/groups/item/onenote/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 167 def site_id=(value) @site_id = value end |