Class: MicrosoftGraph::Groups::Item::RejectedSenders::RejectedSendersRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Groups::Item::RejectedSenders::RejectedSendersRequestBuilder
- Defined in:
- lib/groups/item/rejected_senders/rejected_senders_request_builder.rb
Overview
Provides operations to manage the rejectedSenders property of the microsoft.graph.group entity.
Defined Under Namespace
Classes: RejectedSendersRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_directory_object_id(directory_object_id) ⇒ Object
Gets an item from the MicrosoftGraph.groups.item.rejectedSenders.item collection.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Users in the rejected senders list cannot post to conversations of the group (identified in the GET request URL).
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RejectedSendersRequestBuilder and sets the default values.
-
#ref ⇒ Object
Provides operations to manage the collection of group entities.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Users in the rejected senders list cannot post to conversations of the group (identified in the GET request URL).
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RejectedSendersRequestBuilder and sets the default values.
47 48 49 |
# File 'lib/groups/item/rejected_senders/rejected_senders_request_builder.rb', line 47 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/groups/{group%2Did}/rejectedSenders{?%24top,%24skip,%24filter,%24count,%24orderby,%24select}") end |
Instance Method Details
#by_directory_object_id(directory_object_id) ⇒ Object
Gets an item from the MicrosoftGraph.groups.item.rejectedSenders.item collection
35 36 37 38 39 40 |
# File 'lib/groups/item/rejected_senders/rejected_senders_request_builder.rb', line 35 def by_directory_object_id(directory_object_id) raise StandardError, 'directory_object_id cannot be null' if directory_object_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["directoryObject%2Did"] = directory_object_id return MicrosoftGraph::Groups::Item::RejectedSenders::Item::DirectoryObjectItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
22 23 24 |
# File 'lib/groups/item/rejected_senders/rejected_senders_request_builder.rb', line 22 def count() return MicrosoftGraph::Groups::Item::RejectedSenders::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Users in the rejected senders list cannot post to conversations of the group (identified in the GET request URL). Make sure you do not specify the same user or group in the rejected senders and accepted senders lists, otherwise you will get an error.
55 56 57 58 59 60 61 62 63 |
# File 'lib/groups/item/rejected_senders/rejected_senders_request_builder.rb', line 55 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::DirectoryObjectCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#ref ⇒ Object
Provides operations to manage the collection of group entities.
27 28 29 |
# File 'lib/groups/item/rejected_senders/rejected_senders_request_builder.rb', line 27 def ref() return MicrosoftGraph::Groups::Item::RejectedSenders::Ref::RefRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Users in the rejected senders list cannot post to conversations of the group (identified in the GET request URL). Make sure you do not specify the same user or group in the rejected senders and accepted senders lists, otherwise you will get an error.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/groups/item/rejected_senders/rejected_senders_request_builder.rb', line 69 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |