Class: MicrosoftGraph::Identity::IdentityProviders::IdentityProvidersRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Identity::IdentityProviders::IdentityProvidersRequestBuilder
- Defined in:
- lib/identity/identity_providers/identity_providers_request_builder.rb
Overview
Provides operations to manage the identityProviders property of the microsoft.graph.identityContainer entity.
Defined Under Namespace
Classes: IdentityProvidersRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#available_provider_types ⇒ Object
Provides operations to call the availableProviderTypes method.
-
#by_identity_provider_base_id(identity_provider_base_id) ⇒ Object
Provides operations to manage the identityProviders property of the microsoft.graph.identityContainer entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get a collection of identity provider resources that are configured for a tenant, and that are derived from identityProviderBase.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new IdentityProvidersRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create an identity provider object that is of the type specified in the request body.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a collection of identity provider resources that are configured for a tenant, and that are derived from identityProviderBase.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create an identity provider object that is of the type specified in the request body.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new IdentityProvidersRequestBuilder and sets the default values.
46 47 48 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 46 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identity/identityProviders{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#available_provider_types ⇒ Object
Provides operations to call the availableProviderTypes method.
21 22 23 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 21 def available_provider_types() return MicrosoftGraph::Identity::IdentityProviders::AvailableProviderTypes::AvailableProviderTypesRequestBuilder.new(@path_parameters, @request_adapter) end |
#by_identity_provider_base_id(identity_provider_base_id) ⇒ Object
Provides operations to manage the identityProviders property of the microsoft.graph.identityContainer entity.
34 35 36 37 38 39 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 34 def by_identity_provider_base_id(identity_provider_base_id) raise StandardError, 'identity_provider_base_id cannot be null' if identity_provider_base_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["identityProviderBase%2Did"] = identity_provider_base_id return MicrosoftGraph::Identity::IdentityProviders::Item::IdentityProviderBaseItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
26 27 28 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 26 def count() return MicrosoftGraph::Identity::IdentityProviders::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get a collection of identity provider resources that are configured for a tenant, and that are derived from identityProviderBase. For an Azure AD tenant, the providers can be socialIdentityProviders or builtinIdentityProviders objects. For an Azure AD B2C, the providers can be socialIdentityProvider, or appleManagedIdentityProvider objects.
54 55 56 57 58 59 60 61 62 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 54 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityProviderBaseCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create an identity provider object that is of the type specified in the request body. Among the types of providers derived from identityProviderBase, you can currently create a socialIdentityProvider resource in Azure AD. In Azure AD B2C, this operation can currently create a socialIdentityProvider, or an appleManagedIdentityProvider resource.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 69 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityProviderBase.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a collection of identity provider resources that are configured for a tenant, and that are derived from identityProviderBase. For an Azure AD tenant, the providers can be socialIdentityProviders or builtinIdentityProviders objects. For an Azure AD B2C, the providers can be socialIdentityProvider, or appleManagedIdentityProvider objects.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 84 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create an identity provider object that is of the type specified in the request body. Among the types of providers derived from identityProviderBase, you can currently create a socialIdentityProvider resource in Azure AD. In Azure AD B2C, this operation can currently create a socialIdentityProvider, or an appleManagedIdentityProvider resource.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/identity/identity_providers/identity_providers_request_builder.rb', line 103 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |