Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::IncompatibleGroupsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::IncompatibleGroupsRequestBuilder
- Defined in:
- lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/incompatible_groups_request_builder.rb
Overview
Provides operations to manage the incompatibleGroups property of the microsoft.graph.accessPackage entity.
Defined Under Namespace
Classes: IncompatibleGroupsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_group_id(group_id) ⇒ Object
Gets an item from the MicrosoftGraph.identityGovernance.entitlementManagement.accessPackages.item.incompatibleGroups.item collection.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a list of the group objects that have been marked as incompatible on an accessPackage.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new IncompatibleGroupsRequestBuilder and sets the default values.
-
#ref ⇒ Object
Provides operations to manage the collection of identityGovernance entities.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of the group objects that have been marked as incompatible on an accessPackage.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new IncompatibleGroupsRequestBuilder and sets the default values.
51 52 53 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/incompatible_groups_request_builder.rb', line 51 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/entitlementManagement/accessPackages/{accessPackage%2Did}/incompatibleGroups{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_group_id(group_id) ⇒ Object
Gets an item from the MicrosoftGraph.identityGovernance.entitlementManagement.accessPackages.item.incompatibleGroups.item collection
39 40 41 42 43 44 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/incompatible_groups_request_builder.rb', line 39 def by_group_id(group_id) raise StandardError, 'group_id cannot be null' if group_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["group%2Did"] = group_id return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::Item::GroupItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
26 27 28 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/incompatible_groups_request_builder.rb', line 26 def count() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a list of the group objects that have been marked as incompatible on an accessPackage.
59 60 61 62 63 64 65 66 67 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/incompatible_groups_request_builder.rb', line 59 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::GroupCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#ref ⇒ Object
Provides operations to manage the collection of identityGovernance entities.
31 32 33 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/incompatible_groups_request_builder.rb', line 31 def ref() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::Ref::RefRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of the group objects that have been marked as incompatible on an accessPackage.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/incompatible_groups_request_builder.rb', line 73 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |