Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::Item::Ref::RefRequestBuilder::RefRequestBuilderDeleteQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::Item::IncompatibleGroups::Item::Ref::RefRequestBuilder::RefRequestBuilderDeleteQueryParameters
- Defined in:
- lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/item/ref/ref_request_builder.rb
Overview
Remove a group from the list of groups that have been marked as incompatible on an accessPackage.
Instance Attribute Summary collapse
-
#id ⇒ Object
Delete Uri.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#id ⇒ Object
Delete Uri
71 72 73 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/item/ref/ref_request_builder.rb', line 71 def id @id end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
77 78 79 80 81 82 83 84 85 |
# File 'lib/identity_governance/entitlement_management/access_packages/item/incompatible_groups/item/ref/ref_request_builder.rb', line 77 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "id" return "%40id" else return original_name end end |