Class: MicrosoftGraph::IdentityGovernance::EntitlementManagement::EntitlementManagementRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::EntitlementManagement::EntitlementManagementRequestBuilder
- Defined in:
- lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb
Overview
Provides operations to manage the entitlementManagement property of the microsoft.graph.identityGovernance entity.
Defined Under Namespace
Classes: EntitlementManagementRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#access_package_assignment_approvals ⇒ Object
Provides operations to manage the accessPackageAssignmentApprovals property of the microsoft.graph.entitlementManagement entity.
-
#access_packages ⇒ Object
Provides operations to manage the accessPackages property of the microsoft.graph.entitlementManagement entity.
-
#assignment_policies ⇒ Object
Provides operations to manage the assignmentPolicies property of the microsoft.graph.entitlementManagement entity.
-
#assignment_requests ⇒ Object
Provides operations to manage the assignmentRequests property of the microsoft.graph.entitlementManagement entity.
-
#assignments ⇒ Object
Provides operations to manage the assignments property of the microsoft.graph.entitlementManagement entity.
-
#catalogs ⇒ Object
Provides operations to manage the catalogs property of the microsoft.graph.entitlementManagement entity.
-
#connected_organizations ⇒ Object
Provides operations to manage the connectedOrganizations property of the microsoft.graph.entitlementManagement entity.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property entitlementManagement for identityGovernance.
-
#get(request_configuration = nil) ⇒ Object
Get entitlementManagement from identityGovernance.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new EntitlementManagementRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property entitlementManagement in identityGovernance.
-
#resource_environments ⇒ Object
Provides operations to manage the resourceEnvironments property of the microsoft.graph.entitlementManagement entity.
-
#resource_requests ⇒ Object
Provides operations to manage the resourceRequests property of the microsoft.graph.entitlementManagement entity.
-
#resource_role_scopes ⇒ Object
Provides operations to manage the resourceRoleScopes property of the microsoft.graph.entitlementManagement entity.
-
#resources ⇒ Object
Provides operations to manage the resources property of the microsoft.graph.entitlementManagement entity.
-
#settings ⇒ Object
Provides operations to manage the settings property of the microsoft.graph.entitlementManagement entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property entitlementManagement for identityGovernance.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get entitlementManagement from identityGovernance.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property entitlementManagement in identityGovernance.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new EntitlementManagementRequestBuilder and sets the default values.
93 94 95 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 93 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/entitlementManagement{?%24select,%24expand}") end |
Instance Method Details
#access_package_assignment_approvals ⇒ Object
Provides operations to manage the accessPackageAssignmentApprovals property of the microsoft.graph.entitlementManagement entity.
29 30 31 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 29 def access_package_assignment_approvals() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackageAssignmentApprovals::AccessPackageAssignmentApprovalsRequestBuilder.new(@path_parameters, @request_adapter) end |
#access_packages ⇒ Object
Provides operations to manage the accessPackages property of the microsoft.graph.entitlementManagement entity.
34 35 36 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 34 def access_packages() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AccessPackages::AccessPackagesRequestBuilder.new(@path_parameters, @request_adapter) end |
#assignment_policies ⇒ Object
Provides operations to manage the assignmentPolicies property of the microsoft.graph.entitlementManagement entity.
39 40 41 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 39 def assignment_policies() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AssignmentPolicies::AssignmentPoliciesRequestBuilder.new(@path_parameters, @request_adapter) end |
#assignment_requests ⇒ Object
Provides operations to manage the assignmentRequests property of the microsoft.graph.entitlementManagement entity.
44 45 46 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 44 def assignment_requests() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::AssignmentRequests::AssignmentRequestsRequestBuilder.new(@path_parameters, @request_adapter) end |
#assignments ⇒ Object
Provides operations to manage the assignments property of the microsoft.graph.entitlementManagement entity.
49 50 51 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 49 def assignments() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::Assignments::AssignmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#catalogs ⇒ Object
Provides operations to manage the catalogs property of the microsoft.graph.entitlementManagement entity.
54 55 56 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 54 def catalogs() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::Catalogs::CatalogsRequestBuilder.new(@path_parameters, @request_adapter) end |
#connected_organizations ⇒ Object
Provides operations to manage the connectedOrganizations property of the microsoft.graph.entitlementManagement entity.
59 60 61 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 59 def connected_organizations() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ConnectedOrganizations::ConnectedOrganizationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property entitlementManagement for identityGovernance
101 102 103 104 105 106 107 108 109 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 101 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Get entitlementManagement from identityGovernance
115 116 117 118 119 120 121 122 123 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 115 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EntitlementManagement.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property entitlementManagement in identityGovernance
130 131 132 133 134 135 136 137 138 139 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 130 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::EntitlementManagement.create_from_discriminator_value(pn) }, error_mapping) end |
#resource_environments ⇒ Object
Provides operations to manage the resourceEnvironments property of the microsoft.graph.entitlementManagement entity.
64 65 66 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 64 def resource_environments() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceEnvironments::ResourceEnvironmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#resource_requests ⇒ Object
Provides operations to manage the resourceRequests property of the microsoft.graph.entitlementManagement entity.
69 70 71 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 69 def resource_requests() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRequests::ResourceRequestsRequestBuilder.new(@path_parameters, @request_adapter) end |
#resource_role_scopes ⇒ Object
Provides operations to manage the resourceRoleScopes property of the microsoft.graph.entitlementManagement entity.
74 75 76 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 74 def resource_role_scopes() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::ResourceRoleScopes::ResourceRoleScopesRequestBuilder.new(@path_parameters, @request_adapter) end |
#resources ⇒ Object
Provides operations to manage the resources property of the microsoft.graph.entitlementManagement entity.
79 80 81 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 79 def resources() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::Resources::ResourcesRequestBuilder.new(@path_parameters, @request_adapter) end |
#settings ⇒ Object
Provides operations to manage the settings property of the microsoft.graph.entitlementManagement entity.
84 85 86 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 84 def settings() return MicrosoftGraph::IdentityGovernance::EntitlementManagement::Settings::SettingsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property entitlementManagement for identityGovernance
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 145 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get entitlementManagement from identityGovernance
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 161 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property entitlementManagement in identityGovernance
180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/identity_governance/entitlement_management/entitlement_management_request_builder.rb', line 180 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |