Class: MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::Workflows::Item::MicrosoftGraphIdentityGovernanceRestore::MicrosoftGraphIdentityGovernanceRestoreRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::IdentityGovernance::LifecycleWorkflows::Workflows::Item::MicrosoftGraphIdentityGovernanceRestore::MicrosoftGraphIdentityGovernanceRestoreRequestBuilder
- Defined in:
- lib/identity_governance/lifecycle_workflows/workflows/item/microsoft_graph_identity_governance_restore/microsoft_graph_identity_governance_restore_request_builder.rb
Overview
Provides operations to call the restore method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MicrosoftGraphIdentityGovernanceRestoreRequestBuilder and sets the default values.
-
#post(request_configuration = nil) ⇒ Object
Restore a workflow that has been deleted.
-
#to_post_request_information(request_configuration = nil) ⇒ Object
Restore a workflow that has been deleted.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MicrosoftGraphIdentityGovernanceRestoreRequestBuilder and sets the default values.
27 28 29 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/microsoft_graph_identity_governance_restore/microsoft_graph_identity_governance_restore_request_builder.rb', line 27 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/identityGovernance/lifecycleWorkflows/workflows/{workflow%2Did}/microsoft.graph.identityGovernance.restore") end |
Instance Method Details
#post(request_configuration = nil) ⇒ Object
Restore a workflow that has been deleted. You can only restore a workflow that was deleted within the last 30 days before Azure AD automatically permanently deletes it.
35 36 37 38 39 40 41 42 43 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/microsoft_graph_identity_governance_restore/microsoft_graph_identity_governance_restore_request_builder.rb', line 35 def post(request_configuration=nil) request_info = self.to_post_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::IdentityGovernanceWorkflow.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(request_configuration = nil) ⇒ Object
Restore a workflow that has been deleted. You can only restore a workflow that was deleted within the last 30 days before Azure AD automatically permanently deletes it.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/identity_governance/lifecycle_workflows/workflows/item/microsoft_graph_identity_governance_restore/microsoft_graph_identity_governance_restore_request_builder.rb', line 49 def to_post_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |