Class: MicrosoftGraph::Me::Activities::Recent::RecentRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Activities::Recent::RecentRequestBuilder
- Defined in:
- lib/me/activities/recent/recent_request_builder.rb
Overview
Provides operations to call the recent method.
Defined Under Namespace
Classes: RecentRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Get recent activities for a given user.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RecentRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get recent activities for a given user.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RecentRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/me/activities/recent/recent_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/activities/recent(){?%24top,%24skip,%24search,%24filter,%24count,%24select,%24orderby}") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Get recent activities for a given user. This OData function has some default behaviors included to make it operate like a ‘most recently used’ API. The service will query for the most recent historyItems, and then pull those related activities. Activities will be sorted according to the most recent lastModified on the historyItem. This means that activities without historyItems will not be included in the response. The UserActivity.ReadWrite.CreatedByApp permission will also apply extra filtering to the response, so that only activities created by your application are returned. This server-side filtering might result in empty pages if the user is particularly active and other applications have created more recent activities. To get your application’s activities, use the nextLink property to paginate.
30 31 32 33 34 35 36 37 38 |
# File 'lib/me/activities/recent/recent_request_builder.rb', line 30 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Me::Activities::Recent::RecentResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get recent activities for a given user. This OData function has some default behaviors included to make it operate like a ‘most recently used’ API. The service will query for the most recent historyItems, and then pull those related activities. Activities will be sorted according to the most recent lastModified on the historyItem. This means that activities without historyItems will not be included in the response. The UserActivity.ReadWrite.CreatedByApp permission will also apply extra filtering to the response, so that only activities created by your application are returned. This server-side filtering might result in empty pages if the user is particularly active and other applications have created more recent activities. To get your application’s activities, use the nextLink property to paginate.
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/me/activities/recent/recent_request_builder.rb', line 44 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |