Class: MicrosoftGraph::Me::Authentication::AuthenticationRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Authentication::AuthenticationRequestBuilder
- Defined in:
- lib/me/authentication/authentication_request_builder.rb
Overview
Provides operations to manage the authentication property of the microsoft.graph.user entity.
Defined Under Namespace
Classes: AuthenticationRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property authentication for me.
-
#email_methods ⇒ Object
Provides operations to manage the emailMethods property of the microsoft.graph.authentication entity.
-
#fido2_methods ⇒ Object
Provides operations to manage the fido2Methods property of the microsoft.graph.authentication entity.
-
#get(request_configuration = nil) ⇒ Object
The authentication methods that are supported for the user.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new AuthenticationRequestBuilder and sets the default values.
-
#methods ⇒ Object
Provides operations to manage the methods property of the microsoft.graph.authentication entity.
-
#microsoft_authenticator_methods ⇒ Object
Provides operations to manage the microsoftAuthenticatorMethods property of the microsoft.graph.authentication entity.
-
#operations ⇒ Object
Provides operations to manage the operations property of the microsoft.graph.authentication entity.
-
#password_methods ⇒ Object
Provides operations to manage the passwordMethods property of the microsoft.graph.authentication entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property authentication in me.
-
#phone_methods ⇒ Object
Provides operations to manage the phoneMethods property of the microsoft.graph.authentication entity.
-
#software_oath_methods ⇒ Object
Provides operations to manage the softwareOathMethods property of the microsoft.graph.authentication entity.
-
#temporary_access_pass_methods ⇒ Object
Provides operations to manage the temporaryAccessPassMethods property of the microsoft.graph.authentication entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property authentication for me.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
The authentication methods that are supported for the user.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property authentication in me.
-
#windows_hello_for_business_methods ⇒ Object
Provides operations to manage the windowsHelloForBusinessMethods property of the microsoft.graph.authentication entity.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new AuthenticationRequestBuilder and sets the default values.
81 82 83 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 81 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/authentication{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete navigation property authentication for me
89 90 91 92 93 94 95 96 97 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 89 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#email_methods ⇒ Object
Provides operations to manage the emailMethods property of the microsoft.graph.authentication entity.
27 28 29 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 27 def email_methods() return MicrosoftGraph::Me::Authentication::EmailMethods::EmailMethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#fido2_methods ⇒ Object
Provides operations to manage the fido2Methods property of the microsoft.graph.authentication entity.
32 33 34 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 32 def fido2_methods() return MicrosoftGraph::Me::Authentication::Fido2Methods::Fido2MethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
The authentication methods that are supported for the user.
103 104 105 106 107 108 109 110 111 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 103 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Authentication.create_from_discriminator_value(pn) }, error_mapping) end |
#methods ⇒ Object
Provides operations to manage the methods property of the microsoft.graph.authentication entity.
37 38 39 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 37 def methods() return MicrosoftGraph::Me::Authentication::Methods::MethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#microsoft_authenticator_methods ⇒ Object
Provides operations to manage the microsoftAuthenticatorMethods property of the microsoft.graph.authentication entity.
42 43 44 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 42 def microsoft_authenticator_methods() return MicrosoftGraph::Me::Authentication::MicrosoftAuthenticatorMethods::MicrosoftAuthenticatorMethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#operations ⇒ Object
Provides operations to manage the operations property of the microsoft.graph.authentication entity.
47 48 49 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 47 def operations() return MicrosoftGraph::Me::Authentication::Operations::OperationsRequestBuilder.new(@path_parameters, @request_adapter) end |
#password_methods ⇒ Object
Provides operations to manage the passwordMethods property of the microsoft.graph.authentication entity.
52 53 54 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 52 def password_methods() return MicrosoftGraph::Me::Authentication::PasswordMethods::PasswordMethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property authentication in me
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 118 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Authentication.create_from_discriminator_value(pn) }, error_mapping) end |
#phone_methods ⇒ Object
Provides operations to manage the phoneMethods property of the microsoft.graph.authentication entity.
57 58 59 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 57 def phone_methods() return MicrosoftGraph::Me::Authentication::PhoneMethods::PhoneMethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#software_oath_methods ⇒ Object
Provides operations to manage the softwareOathMethods property of the microsoft.graph.authentication entity.
62 63 64 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 62 def software_oath_methods() return MicrosoftGraph::Me::Authentication::SoftwareOathMethods::SoftwareOathMethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#temporary_access_pass_methods ⇒ Object
Provides operations to manage the temporaryAccessPassMethods property of the microsoft.graph.authentication entity.
67 68 69 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 67 def temporary_access_pass_methods() return MicrosoftGraph::Me::Authentication::TemporaryAccessPassMethods::TemporaryAccessPassMethodsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property authentication for me
133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 133 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
The authentication methods that are supported for the user.
149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 149 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property authentication in me
168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 168 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |
#windows_hello_for_business_methods ⇒ Object
Provides operations to manage the windowsHelloForBusinessMethods property of the microsoft.graph.authentication entity.
72 73 74 |
# File 'lib/me/authentication/authentication_request_builder.rb', line 72 def windows_hello_for_business_methods() return MicrosoftGraph::Me::Authentication::WindowsHelloForBusinessMethods::WindowsHelloForBusinessMethodsRequestBuilder.new(@path_parameters, @request_adapter) end |