Class: MicrosoftGraph::Me::Calendar::CalendarView::Item::Accept::AcceptPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Calendar::CalendarView::Item::Accept::AcceptPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#comment ⇒ Object
Gets the Comment property value.
-
#comment=(value) ⇒ Object
Sets the Comment property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new acceptPostRequestBody and sets the default values.
-
#send_response ⇒ Object
Gets the SendResponse property value.
-
#send_response=(value) ⇒ Object
Sets the SendResponse property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new acceptPostRequestBody and sets the default values.
60 61 62 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 60 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
68 69 70 71 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 68 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AcceptPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 30 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 38 def additional_data=(value) @additional_data = value end |
#comment ⇒ Object
Gets the Comment property value. The Comment property
45 46 47 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 45 def comment return @comment end |
#comment=(value) ⇒ Object
Sets the Comment property value. The Comment property
53 54 55 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 53 def comment=(value) @comment = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
76 77 78 79 80 81 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 76 def get_field_deserializers() return { "Comment" => lambda {|n| @comment = n.get_string_value() }, "SendResponse" => lambda {|n| @send_response = n.get_boolean_value() }, } end |
#send_response ⇒ Object
Gets the SendResponse property value. The SendResponse property
86 87 88 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 86 def send_response return @send_response end |
#send_response=(value) ⇒ Object
Sets the SendResponse property value. The SendResponse property
94 95 96 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 94 def send_response=(value) @send_response = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
102 103 104 105 106 107 |
# File 'lib/me/calendar/calendar_view/item/accept/accept_post_request_body.rb', line 102 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("Comment", @comment) writer.write_boolean_value("SendResponse", @send_response) writer.write_additional_data(@additional_data) end |