Class: MicrosoftGraph::Me::Calendar::Events::Item::Forward::ForwardRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Calendar::Events::Item::Forward::ForwardRequestBuilder
- Defined in:
- lib/me/calendar/events/item/forward/forward_request_builder.rb
Overview
Provides operations to call the forward method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ForwardRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
This action allows the organizer or attendee of a meeting event to forward the meeting request to a new recipient.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
This action allows the organizer or attendee of a meeting event to forward the meeting request to a new recipient.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ForwardRequestBuilder and sets the default values.
26 27 28 |
# File 'lib/me/calendar/events/item/forward/forward_request_builder.rb', line 26 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/calendar/events/{event%2Did}/forward") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
This action allows the organizer or attendee of a meeting event to forward the meeting request to a new recipient. If the meeting event is forwarded from an attendee’s Microsoft 365 mailbox to another recipient, this action also sends a message to notify the organizer of the forwarding, and adds the recipient to the organizer’s copy of the meeting event. This convenience is not available when forwarding from an Outlook.com account.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/me/calendar/events/item/forward/forward_request_builder.rb', line 35 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
This action allows the organizer or attendee of a meeting event to forward the meeting request to a new recipient. If the meeting event is forwarded from an attendee’s Microsoft 365 mailbox to another recipient, this action also sends a message to notify the organizer of the forwarding, and adds the recipient to the organizer’s copy of the meeting event. This convenience is not available when forwarding from an Outlook.com account.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/me/calendar/events/item/forward/forward_request_builder.rb', line 51 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |