Class: MicrosoftGraph::Me::CalendarView::Item::Decline::DeclineRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::CalendarView::Item::Decline::DeclineRequestBuilder
- Defined in:
- lib/me/calendar_view/item/decline/decline_request_builder.rb
Overview
Provides operations to call the decline method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DeclineRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Decline invitation to the specified event in a user calendar.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Decline invitation to the specified event in a user calendar.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DeclineRequestBuilder and sets the default values.
24 25 26 |
# File 'lib/me/calendar_view/item/decline/decline_request_builder.rb', line 24 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/calendarView/{event%2Did}/decline") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Decline invitation to the specified event in a user calendar. If the event allows proposals for new times, on declining the event, an invitee can choose to suggest an alternative time by including the proposedNewTime parameter. For more information on how to propose a time, and how to receive and accept a new time proposal, see Propose new meeting times.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/me/calendar_view/item/decline/decline_request_builder.rb', line 33 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Decline invitation to the specified event in a user calendar. If the event allows proposals for new times, on declining the event, an invitee can choose to suggest an alternative time by including the proposedNewTime parameter. For more information on how to propose a time, and how to receive and accept a new time proposal, see Propose new meeting times.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/me/calendar_view/item/decline/decline_request_builder.rb', line 49 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |