Class: MicrosoftGraph::Me::Chats::Item::ChatItemRequestBuilder::ChatItemRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Chats::Item::ChatItemRequestBuilder::ChatItemRequestBuilderGetQueryParameters
- Defined in:
- lib/me/chats/item/chat_item_request_builder.rb
Overview
Retrieve a single chat (without its messages). This method supports federation. To access a chat, at least one chat member must belong to the tenant the request initiated from.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
203 204 205 |
# File 'lib/me/chats/item/chat_item_request_builder.rb', line 203 def @expand end |
#select ⇒ Object
Select properties to be returned
206 207 208 |
# File 'lib/me/chats/item/chat_item_request_builder.rb', line 206 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/me/chats/item/chat_item_request_builder.rb', line 212 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |