Class: MicrosoftGraph::Me::Chats::Item::Messages::MessagesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Chats::Item::Messages::MessagesRequestBuilder
- Defined in:
- lib/me/chats/item/messages/messages_request_builder.rb
Overview
Provides operations to manage the messages property of the microsoft.graph.chat entity.
Defined Under Namespace
Classes: MessagesRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_chat_message_id(chat_message_id) ⇒ Object
Provides operations to manage the messages property of the microsoft.graph.chat entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#delta ⇒ Object
Provides operations to call the delta method.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the list of messages in a chat.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MessagesRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Send a new chatMessage in the specified channel or a chat.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the list of messages in a chat.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Send a new chatMessage in the specified channel or a chat.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MessagesRequestBuilder and sets the default values.
50 51 52 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 50 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/chats/{chat%2Did}/messages{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_chat_message_id(chat_message_id) ⇒ Object
Provides operations to manage the messages property of the microsoft.graph.chat entity.
38 39 40 41 42 43 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 38 def () raise StandardError, 'chat_message_id cannot be null' if .nil? url_tpl_params = @path_parameters.clone url_tpl_params["chatMessage%2Did"] = return MicrosoftGraph::Me::Chats::Item::Messages::Item::ChatMessageItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
25 26 27 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 25 def count() return MicrosoftGraph::Me::Chats::Item::Messages::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#delta ⇒ Object
Provides operations to call the delta method.
30 31 32 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 30 def delta() return MicrosoftGraph::Me::Chats::Item::Messages::Delta::DeltaRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the list of messages in a chat. This method supports federation. To list chat messages in application context, the request must be made from the tenant that the channel owner belongs to (represented by the tenantId property on the channel).
58 59 60 61 62 63 64 65 66 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 58 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ChatMessageCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Send a new chatMessage in the specified channel or a chat.
73 74 75 76 77 78 79 80 81 82 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 73 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::ChatMessage.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the list of messages in a chat. This method supports federation. To list chat messages in application context, the request must be made from the tenant that the channel owner belongs to (represented by the tenantId property on the channel).
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 88 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Send a new chatMessage in the specified channel or a chat.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/me/chats/item/messages/messages_request_builder.rb', line 107 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |