Class: MicrosoftGraph::Me::Events::Item::EventItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Events::Item::EventItemRequestBuilder
- Defined in:
- lib/me/events/item/event_item_request_builder.rb
Overview
Provides operations to manage the events property of the microsoft.graph.user entity.
Defined Under Namespace
Classes: EventItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#accept ⇒ Object
Provides operations to call the accept method.
-
#attachments ⇒ Object
Provides operations to manage the attachments property of the microsoft.graph.event entity.
-
#calendar ⇒ Object
Provides operations to manage the calendar property of the microsoft.graph.event entity.
-
#cancel ⇒ Object
Provides operations to call the cancel method.
-
#decline ⇒ Object
Provides operations to call the decline method.
-
#delete(request_configuration = nil) ⇒ Object
Removes the specified event from the containing calendar.
-
#dismiss_reminder ⇒ Object
Provides operations to call the dismissReminder method.
-
#extensions ⇒ Object
Provides operations to manage the extensions property of the microsoft.graph.event entity.
-
#forward ⇒ Object
Provides operations to call the forward method.
-
#get(request_configuration = nil) ⇒ Object
Get the properties and relationships of the specified event object.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new EventItemRequestBuilder and sets the default values.
-
#instances ⇒ Object
Provides operations to manage the instances property of the microsoft.graph.event entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of the event object.
-
#snooze_reminder ⇒ Object
Provides operations to call the snoozeReminder method.
-
#tentatively_accept ⇒ Object
Provides operations to call the tentativelyAccept method.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Removes the specified event from the containing calendar.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the properties and relationships of the specified event object.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of the event object.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new EventItemRequestBuilder and sets the default values.
89 90 91 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 89 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/events/{event%2Did}{?%24select,%24expand}") end |
Instance Method Details
#accept ⇒ Object
Provides operations to call the accept method.
30 31 32 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 30 def accept() return MicrosoftGraph::Me::Events::Item::Accept::AcceptRequestBuilder.new(@path_parameters, @request_adapter) end |
#attachments ⇒ Object
Provides operations to manage the attachments property of the microsoft.graph.event entity.
35 36 37 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 35 def () return MicrosoftGraph::Me::Events::Item::Attachments::AttachmentsRequestBuilder.new(@path_parameters, @request_adapter) end |
#calendar ⇒ Object
Provides operations to manage the calendar property of the microsoft.graph.event entity.
40 41 42 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 40 def calendar() return MicrosoftGraph::Me::Events::Item::Calendar::CalendarRequestBuilder.new(@path_parameters, @request_adapter) end |
#cancel ⇒ Object
Provides operations to call the cancel method.
45 46 47 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 45 def cancel() return MicrosoftGraph::Me::Events::Item::Cancel::CancelRequestBuilder.new(@path_parameters, @request_adapter) end |
#decline ⇒ Object
Provides operations to call the decline method.
50 51 52 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 50 def decline() return MicrosoftGraph::Me::Events::Item::Decline::DeclineRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Removes the specified event from the containing calendar. If the event is a meeting, deleting the event on the organizer’s calendar sends a cancellation message to the meeting attendees.
97 98 99 100 101 102 103 104 105 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 97 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#dismiss_reminder ⇒ Object
Provides operations to call the dismissReminder method.
55 56 57 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 55 def dismiss_reminder() return MicrosoftGraph::Me::Events::Item::DismissReminder::DismissReminderRequestBuilder.new(@path_parameters, @request_adapter) end |
#extensions ⇒ Object
Provides operations to manage the extensions property of the microsoft.graph.event entity.
60 61 62 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 60 def extensions() return MicrosoftGraph::Me::Events::Item::Extensions::ExtensionsRequestBuilder.new(@path_parameters, @request_adapter) end |
#forward ⇒ Object
Provides operations to call the forward method.
65 66 67 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 65 def forward() return MicrosoftGraph::Me::Events::Item::Forward::ForwardRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get the properties and relationships of the specified event object. Currently, this operation returns event bodies in only HTML format. There are two scenarios where an app can get an event in another user’s calendar: Since the event resource supports extensions, you can also use the GET operation to get custom properties and extension data in an event instance.
111 112 113 114 115 116 117 118 119 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 111 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Event.create_from_discriminator_value(pn) }, error_mapping) end |
#instances ⇒ Object
Provides operations to manage the instances property of the microsoft.graph.event entity.
70 71 72 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 70 def instances() return MicrosoftGraph::Me::Events::Item::Instances::InstancesRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of the event object.
126 127 128 129 130 131 132 133 134 135 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 126 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Event.create_from_discriminator_value(pn) }, error_mapping) end |
#snooze_reminder ⇒ Object
Provides operations to call the snoozeReminder method.
75 76 77 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 75 def snooze_reminder() return MicrosoftGraph::Me::Events::Item::SnoozeReminder::SnoozeReminderRequestBuilder.new(@path_parameters, @request_adapter) end |
#tentatively_accept ⇒ Object
Provides operations to call the tentativelyAccept method.
80 81 82 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 80 def tentatively_accept() return MicrosoftGraph::Me::Events::Item::TentativelyAccept::TentativelyAcceptRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Removes the specified event from the containing calendar. If the event is a meeting, deleting the event on the organizer’s calendar sends a cancellation message to the meeting attendees.
141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 141 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the properties and relationships of the specified event object. Currently, this operation returns event bodies in only HTML format. There are two scenarios where an app can get an event in another user’s calendar: Since the event resource supports extensions, you can also use the GET operation to get custom properties and extension data in an event instance.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 157 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of the event object.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/me/events/item/event_item_request_builder.rb', line 176 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |