Class: MicrosoftGraph::Me::Insights::Shared::Item::SharedInsightItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Insights::Shared::Item::SharedInsightItemRequestBuilder
- Defined in:
- lib/me/insights/shared/item/shared_insight_item_request_builder.rb
Overview
Provides operations to manage the shared property of the microsoft.graph.officeGraphInsights entity.
Defined Under Namespace
Classes: SharedInsightItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property shared for me.
-
#get(request_configuration = nil) ⇒ Object
Calculated relationship identifying documents shared with or by the user.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new SharedInsightItemRequestBuilder and sets the default values.
-
#last_shared_method ⇒ Object
Provides operations to manage the lastSharedMethod property of the microsoft.graph.sharedInsight entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property shared in me.
-
#resource ⇒ Object
Provides operations to manage the resource property of the microsoft.graph.sharedInsight entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property shared for me.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Calculated relationship identifying documents shared with or by the user.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property shared in me.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new SharedInsightItemRequestBuilder and sets the default values.
37 38 39 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 37 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/insights/shared/{sharedInsight%2Did}{?%24select,%24expand}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete navigation property shared for me
45 46 47 48 49 50 51 52 53 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 45 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Calculated relationship identifying documents shared with or by the user. This includes URLs, file attachments, and reference attachments to OneDrive for Business and SharePoint files found in Outlook messages and meetings. This also includes URLs and reference attachments to Teams conversations. Ordered by recency of share.
59 60 61 62 63 64 65 66 67 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 59 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SharedInsight.create_from_discriminator_value(pn) }, error_mapping) end |
#last_shared_method ⇒ Object
Provides operations to manage the lastSharedMethod property of the microsoft.graph.sharedInsight entity.
23 24 25 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 23 def last_shared_method() return MicrosoftGraph::Me::Insights::Shared::Item::LastSharedMethod::LastSharedMethodRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property shared in me
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 74 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SharedInsight.create_from_discriminator_value(pn) }, error_mapping) end |
#resource ⇒ Object
Provides operations to manage the resource property of the microsoft.graph.sharedInsight entity.
28 29 30 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 28 def resource() return MicrosoftGraph::Me::Insights::Shared::Item::Resource::ResourceRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property shared for me
89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 89 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Calculated relationship identifying documents shared with or by the user. This includes URLs, file attachments, and reference attachments to OneDrive for Business and SharePoint files found in Outlook messages and meetings. This also includes URLs and reference attachments to Teams conversations. Ordered by recency of share.
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 105 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property shared in me
124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/me/insights/shared/item/shared_insight_item_request_builder.rb', line 124 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |