Class: MicrosoftGraph::Me::Insights::Trending::Item::TrendingItemRequestBuilder::TrendingItemRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Insights::Trending::Item::TrendingItemRequestBuilder::TrendingItemRequestBuilderGetQueryParameters
- Defined in:
- lib/me/insights/trending/item/trending_item_request_builder.rb
Overview
Calculated relationship identifying documents trending around a user. Trending documents are calculated based on activity of the user's closest network of people and include files stored in OneDrive for Business and SharePoint. Trending insights help the user to discover potentially useful content that the user has access to, but has never viewed before.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
139 140 141 |
# File 'lib/me/insights/trending/item/trending_item_request_builder.rb', line 139 def @expand end |
#select ⇒ Object
Select properties to be returned
142 143 144 |
# File 'lib/me/insights/trending/item/trending_item_request_builder.rb', line 142 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/me/insights/trending/item/trending_item_request_builder.rb', line 148 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |