Class: MicrosoftGraph::Me::JoinedTeams::Item::Clone::CloneRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::JoinedTeams::Item::Clone::CloneRequestBuilder
- Defined in:
- lib/me/joined_teams/item/clone/clone_request_builder.rb
Overview
Provides operations to call the clone method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new CloneRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a copy of a team.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a copy of a team.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new CloneRequestBuilder and sets the default values.
24 25 26 |
# File 'lib/me/joined_teams/item/clone/clone_request_builder.rb', line 24 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/joinedTeams/{team%2Did}/clone") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Create a copy of a team. This operation also creates a copy of the corresponding group.You can specify which parts of the team to clone: When tabs are cloned, they are put into an unconfigured state -- they are displayed on the tab bar in Microsoft Teams, and the first time you open them, you'll go through the configuration screen. (If the person opening the tab does not have permission to configure apps, they will see a message explaining that the tab hasn't been configured.) Cloning is a long-running operation.After the POST clone returns, you need to GET the operation to see if it's 'running' or 'succeeded' or 'failed'. You should continue to GET until the status is not 'running'. The recommended delay between GETs is 5 seconds.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/me/joined_teams/item/clone/clone_request_builder.rb', line 33 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a copy of a team. This operation also creates a copy of the corresponding group.You can specify which parts of the team to clone: When tabs are cloned, they are put into an unconfigured state -- they are displayed on the tab bar in Microsoft Teams, and the first time you open them, you'll go through the configuration screen. (If the person opening the tab does not have permission to configure apps, they will see a message explaining that the tab hasn't been configured.) Cloning is a long-running operation.After the POST clone returns, you need to GET the operation to see if it's 'running' or 'succeeded' or 'failed'. You should continue to GET until the status is not 'running'. The recommended delay between GETs is 5 seconds.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/me/joined_teams/item/clone/clone_request_builder.rb', line 49 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |