Class: MicrosoftGraph::Me::JoinedTeams::Item::Schedule::TimeOffReasons::Item::TimeOffReasonItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::JoinedTeams::Item::Schedule::TimeOffReasons::Item::TimeOffReasonItemRequestBuilder
- Defined in:
- lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb
Overview
Provides operations to manage the timeOffReasons property of the microsoft.graph.schedule entity.
Defined Under Namespace
Classes: TimeOffReasonItemRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Mark a timeOffReason as inactive by setting the isActive property.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a timeOffReason object by ID.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new TimeOffReasonItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Replace an existing timeOffReason.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Mark a timeOffReason as inactive by setting the isActive property.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a timeOffReason object by ID.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Replace an existing timeOffReason.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new TimeOffReasonItemRequestBuilder and sets the default values.
29 30 31 |
# File 'lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb', line 29 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/joinedTeams/{team%2Did}/schedule/timeOffReasons/{timeOffReason%2Did}{?%24select}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Mark a timeOffReason as inactive by setting the isActive property. Every team must include at least one timeoff reason. This method does not remove the specified timeOffReason instance. timeOffItem instances that have been assigned this reason remain assigned to this reason.
37 38 39 40 41 42 43 44 45 |
# File 'lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb', line 37 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a timeOffReason object by ID.
51 52 53 54 55 56 57 58 59 |
# File 'lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb', line 51 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::TimeOffReason.create_from_discriminator_value(pn) }, error_mapping) end |
#patch(body, request_configuration = nil) ⇒ Object
Replace an existing timeOffReason. If the specified timeOffReason doesn't exist, this method returns 404 Not found.
66 67 68 69 70 71 72 73 74 75 |
# File 'lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb', line 66 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::TimeOffReason.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Mark a timeOffReason as inactive by setting the isActive property. Every team must include at least one timeoff reason. This method does not remove the specified timeOffReason instance. timeOffItem instances that have been assigned this reason remain assigned to this reason.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb', line 81 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of a timeOffReason object by ID.
97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb', line 97 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Replace an existing timeOffReason. If the specified timeOffReason doesn't exist, this method returns 404 Not found.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/me/joined_teams/item/schedule/time_off_reasons/item/time_off_reason_item_request_builder.rb', line 116 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |