Class: MicrosoftGraph::Me::Messages::Item::Forward::ForwardRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Me::Messages::Item::Forward::ForwardRequestBuilder
- Defined in:
- lib/me/messages/item/forward/forward_request_builder.rb
Overview
Provides operations to call the forward method.
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ForwardRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Forward a message using either JSON or MIME format.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Forward a message using either JSON or MIME format.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ForwardRequestBuilder and sets the default values.
24 25 26 |
# File 'lib/me/messages/item/forward/forward_request_builder.rb', line 24 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/me/messages/{message%2Did}/forward") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Forward a message using either JSON or MIME format. When using JSON format, you can:- Specify either a comment or the body property of the message parameter. Specifying both will return an HTTP 400 Bad Request error.- Specify either the toRecipients parameter or the toRecipients property of the message parameter. Specifying both or specifying neither will return an HTTP 400 Bad Request error. When using MIME format:- Provide the applicable Internet message headers and the MIME content, all encoded in base64 format in the request body.- Add any attachments and S/MIME properties to the MIME content. This method saves the message in the Sent Items folder. Alternatively, create a draft to forward a message, and send it later.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/me/messages/item/forward/forward_request_builder.rb', line 33 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Forward a message using either JSON or MIME format. When using JSON format, you can:- Specify either a comment or the body property of the message parameter. Specifying both will return an HTTP 400 Bad Request error.- Specify either the toRecipients parameter or the toRecipients property of the message parameter. Specifying both or specifying neither will return an HTTP 400 Bad Request error. When using MIME format:- Provide the applicable Internet message headers and the MIME content, all encoded in base64 format in the request body.- Add any attachments and S/MIME properties to the MIME content. This method saves the message in the Sent Items folder. Alternatively, create a draft to forward a message, and send it later.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/me/messages/item/forward/forward_request_builder.rb', line 49 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |