Class: MicrosoftGraph::Me::Onenote::Notebooks::Item::CopyNotebook::CopyNotebookPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Onenote::Notebooks::Item::CopyNotebook::CopyNotebookPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#group_id ⇒ Object
Gets the groupId property value.
-
#group_id=(value) ⇒ Object
Sets the groupId property value.
-
#initialize ⇒ Object
constructor
Instantiates a new copyNotebookPostRequestBody and sets the default values.
-
#notebook_folder ⇒ Object
Gets the notebookFolder property value.
-
#notebook_folder=(value) ⇒ Object
Sets the notebookFolder property value.
-
#rename_as ⇒ Object
Gets the renameAs property value.
-
#rename_as=(value) ⇒ Object
Sets the renameAs property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#site_collection_id ⇒ Object
Gets the siteCollectionId property value.
-
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value.
-
#site_id ⇒ Object
Gets the siteId property value.
-
#site_id=(value) ⇒ Object
Sets the siteId property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new copyNotebookPostRequestBody and sets the default values.
54 55 56 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 54 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
62 63 64 65 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 62 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CopyNotebookPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 39 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
47 48 49 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 47 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
70 71 72 73 74 75 76 77 78 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 70 def get_field_deserializers() return { "groupId" => lambda {|n| @group_id = n.get_string_value() }, "notebookFolder" => lambda {|n| @notebook_folder = n.get_string_value() }, "renameAs" => lambda {|n| @rename_as = n.get_string_value() }, "siteCollectionId" => lambda {|n| @site_collection_id = n.get_string_value() }, "siteId" => lambda {|n| @site_id = n.get_string_value() }, } end |
#group_id ⇒ Object
Gets the groupId property value. The groupId property
83 84 85 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 83 def group_id return @group_id end |
#group_id=(value) ⇒ Object
Sets the groupId property value. The groupId property
91 92 93 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 91 def group_id=(value) @group_id = value end |
#notebook_folder ⇒ Object
Gets the notebookFolder property value. The notebookFolder property
98 99 100 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 98 def notebook_folder return @notebook_folder end |
#notebook_folder=(value) ⇒ Object
Sets the notebookFolder property value. The notebookFolder property
106 107 108 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 106 def notebook_folder=(value) @notebook_folder = value end |
#rename_as ⇒ Object
Gets the renameAs property value. The renameAs property
113 114 115 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 113 def rename_as return @rename_as end |
#rename_as=(value) ⇒ Object
Sets the renameAs property value. The renameAs property
121 122 123 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 121 def rename_as=(value) @rename_as = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
129 130 131 132 133 134 135 136 137 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 129 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("groupId", @group_id) writer.write_string_value("notebookFolder", @notebook_folder) writer.write_string_value("renameAs", @rename_as) writer.write_string_value("siteCollectionId", @site_collection_id) writer.write_string_value("siteId", @site_id) writer.write_additional_data(@additional_data) end |
#site_collection_id ⇒ Object
Gets the siteCollectionId property value. The siteCollectionId property
142 143 144 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 142 def site_collection_id return @site_collection_id end |
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value. The siteCollectionId property
150 151 152 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 150 def site_collection_id=(value) @site_collection_id = value end |
#site_id ⇒ Object
Gets the siteId property value. The siteId property
157 158 159 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 157 def site_id return @site_id end |
#site_id=(value) ⇒ Object
Sets the siteId property value. The siteId property
165 166 167 |
# File 'lib/me/onenote/notebooks/item/copy_notebook/copy_notebook_post_request_body.rb', line 165 def site_id=(value) @site_id = value end |