Class: MicrosoftGraph::Me::Onenote::Notebooks::Item::Sections::Item::CopyToSectionGroup::CopyToSectionGroupPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Me::Onenote::Notebooks::Item::Sections::Item::CopyToSectionGroup::CopyToSectionGroupPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#group_id ⇒ Object
Gets the groupId property value.
-
#group_id=(value) ⇒ Object
Sets the groupId property value.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new copyToSectionGroupPostRequestBody and sets the default values.
-
#rename_as ⇒ Object
Gets the renameAs property value.
-
#rename_as=(value) ⇒ Object
Sets the renameAs property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#site_collection_id ⇒ Object
Gets the siteCollectionId property value.
-
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value.
-
#site_id ⇒ Object
Gets the siteId property value.
-
#site_id=(value) ⇒ Object
Sets the siteId property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new copyToSectionGroupPostRequestBody and sets the default values.
58 59 60 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 58 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
66 67 68 69 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 66 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CopyToSectionGroupPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
43 44 45 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 43 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
51 52 53 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 51 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
74 75 76 77 78 79 80 81 82 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 74 def get_field_deserializers() return { "groupId" => lambda {|n| @group_id = n.get_string_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "renameAs" => lambda {|n| @rename_as = n.get_string_value() }, "siteCollectionId" => lambda {|n| @site_collection_id = n.get_string_value() }, "siteId" => lambda {|n| @site_id = n.get_string_value() }, } end |
#group_id ⇒ Object
Gets the groupId property value. The groupId property
87 88 89 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 87 def group_id return @group_id end |
#group_id=(value) ⇒ Object
Sets the groupId property value. The groupId property
95 96 97 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 95 def group_id=(value) @group_id = value end |
#id ⇒ Object
Gets the id property value. The id property
102 103 104 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 102 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
110 111 112 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 110 def id=(value) @id = value end |
#rename_as ⇒ Object
Gets the renameAs property value. The renameAs property
117 118 119 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 117 def rename_as return @rename_as end |
#rename_as=(value) ⇒ Object
Sets the renameAs property value. The renameAs property
125 126 127 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 125 def rename_as=(value) @rename_as = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
133 134 135 136 137 138 139 140 141 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 133 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("groupId", @group_id) writer.write_string_value("id", @id) writer.write_string_value("renameAs", @rename_as) writer.write_string_value("siteCollectionId", @site_collection_id) writer.write_string_value("siteId", @site_id) writer.write_additional_data(@additional_data) end |
#site_collection_id ⇒ Object
Gets the siteCollectionId property value. The siteCollectionId property
146 147 148 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 146 def site_collection_id return @site_collection_id end |
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value. The siteCollectionId property
154 155 156 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 154 def site_collection_id=(value) @site_collection_id = value end |
#site_id ⇒ Object
Gets the siteId property value. The siteId property
161 162 163 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 161 def site_id return @site_id end |
#site_id=(value) ⇒ Object
Sets the siteId property value. The siteId property
169 170 171 |
# File 'lib/me/onenote/notebooks/item/sections/item/copy_to_section_group/copy_to_section_group_post_request_body.rb', line 169 def site_id=(value) @site_id = value end |