Class: MicrosoftGraph::Models::AttributeSet
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/attribute_set.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new attributeSet and sets the default values.
-
#max_attributes_per_set ⇒ Object
Gets the maxAttributesPerSet property value.
-
#max_attributes_per_set=(value) ⇒ Object
Sets the maxAttributesPerSet property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new attributeSet and sets the default values.
19 20 21 |
# File 'lib/models/attribute_set.rb', line 19 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
27 28 29 30 |
# File 'lib/models/attribute_set.rb', line 27 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AttributeSet.new end |
Instance Method Details
#description ⇒ Object
Gets the description property value. Description of the attribute set. Can be up to 128 characters long and include Unicode characters. Can be changed later.
35 36 37 |
# File 'lib/models/attribute_set.rb', line 35 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. Description of the attribute set. Can be up to 128 characters long and include Unicode characters. Can be changed later.
43 44 45 |
# File 'lib/models/attribute_set.rb', line 43 def description=(value) @description = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
50 51 52 53 54 55 |
# File 'lib/models/attribute_set.rb', line 50 def get_field_deserializers() return super.merge({ "description" => lambda {|n| @description = n.get_string_value() }, "maxAttributesPerSet" => lambda {|n| @max_attributes_per_set = n.get_number_value() }, }) end |
#max_attributes_per_set ⇒ Object
Gets the maxAttributesPerSet property value. Maximum number of custom security attributes that can be defined in this attribute set. Default value is null. If not specified, the administrator can add up to the maximum of 500 active attributes per tenant. Can be changed later.
60 61 62 |
# File 'lib/models/attribute_set.rb', line 60 def max_attributes_per_set return @max_attributes_per_set end |
#max_attributes_per_set=(value) ⇒ Object
Sets the maxAttributesPerSet property value. Maximum number of custom security attributes that can be defined in this attribute set. Default value is null. If not specified, the administrator can add up to the maximum of 500 active attributes per tenant. Can be changed later.
68 69 70 |
# File 'lib/models/attribute_set.rb', line 68 def max_attributes_per_set=(value) @max_attributes_per_set = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
76 77 78 79 80 81 |
# File 'lib/models/attribute_set.rb', line 76 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("description", @description) writer.write_number_value("maxAttributesPerSet", @max_attributes_per_set) end |