Class: MicrosoftGraph::Models::AuditResource
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::AuditResource
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/audit_resource.rb
Overview
A class containing the properties for Audit Resource.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#audit_resource_type ⇒ Object
Gets the auditResourceType property value.
-
#audit_resource_type=(value) ⇒ Object
Sets the auditResourceType property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new auditResource and sets the default values.
-
#modified_properties ⇒ Object
Gets the modifiedProperties property value.
-
#modified_properties=(value) ⇒ Object
Sets the modifiedProperties property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#resource_id ⇒ Object
Gets the resourceId property value.
-
#resource_id=(value) ⇒ Object
Sets the resourceId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new auditResource and sets the default values.
63 64 65 |
# File 'lib/models/audit_resource.rb', line 63 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
71 72 73 74 |
# File 'lib/models/audit_resource.rb', line 71 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AuditResource.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/models/audit_resource.rb', line 33 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
41 42 43 |
# File 'lib/models/audit_resource.rb', line 41 def additional_data=(value) @additional_data = value end |
#audit_resource_type ⇒ Object
Gets the auditResourceType property value. Audit resource’s type.
48 49 50 |
# File 'lib/models/audit_resource.rb', line 48 def audit_resource_type return @audit_resource_type end |
#audit_resource_type=(value) ⇒ Object
Sets the auditResourceType property value. Audit resource’s type.
56 57 58 |
# File 'lib/models/audit_resource.rb', line 56 def audit_resource_type=(value) @audit_resource_type = value end |
#display_name ⇒ Object
Gets the displayName property value. Display name.
79 80 81 |
# File 'lib/models/audit_resource.rb', line 79 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. Display name.
87 88 89 |
# File 'lib/models/audit_resource.rb', line 87 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
94 95 96 97 98 99 100 101 102 |
# File 'lib/models/audit_resource.rb', line 94 def get_field_deserializers() return { "auditResourceType" => lambda {|n| @audit_resource_type = n.get_string_value() }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, "modifiedProperties" => lambda {|n| @modified_properties = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AuditProperty.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "resourceId" => lambda {|n| @resource_id = n.get_string_value() }, } end |
#modified_properties ⇒ Object
Gets the modifiedProperties property value. List of modified properties.
107 108 109 |
# File 'lib/models/audit_resource.rb', line 107 def modified_properties return @modified_properties end |
#modified_properties=(value) ⇒ Object
Sets the modifiedProperties property value. List of modified properties.
115 116 117 |
# File 'lib/models/audit_resource.rb', line 115 def modified_properties=(value) @modified_properties = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
122 123 124 |
# File 'lib/models/audit_resource.rb', line 122 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
130 131 132 |
# File 'lib/models/audit_resource.rb', line 130 def odata_type=(value) @odata_type = value end |
#resource_id ⇒ Object
Gets the resourceId property value. Audit resource’s Id.
137 138 139 |
# File 'lib/models/audit_resource.rb', line 137 def resource_id return @resource_id end |
#resource_id=(value) ⇒ Object
Sets the resourceId property value. Audit resource’s Id.
145 146 147 |
# File 'lib/models/audit_resource.rb', line 145 def resource_id=(value) @resource_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
153 154 155 156 157 158 159 160 161 |
# File 'lib/models/audit_resource.rb', line 153 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("auditResourceType", @audit_resource_type) writer.write_string_value("displayName", @display_name) writer.write_collection_of_object_values("modifiedProperties", @modified_properties) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("resourceId", @resource_id) writer.write_additional_data(@additional_data) end |