Class: MicrosoftGraph::Models::AuthenticationStrengthRoot
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/authentication_strength_root.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#authentication_method_modes ⇒ Object
Gets the authenticationMethodModes property value.
-
#authentication_method_modes=(value) ⇒ Object
Sets the authenticationMethodModes property value.
-
#combinations ⇒ Object
Gets the combinations property value.
-
#combinations=(value) ⇒ Object
Sets the combinations property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new authenticationStrengthRoot and sets the default values.
-
#policies ⇒ Object
Gets the policies property value.
-
#policies=(value) ⇒ Object
Sets the policies property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new authenticationStrengthRoot and sets the default values.
52 53 54 |
# File 'lib/models/authentication_strength_root.rb', line 52 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
60 61 62 63 |
# File 'lib/models/authentication_strength_root.rb', line 60 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AuthenticationStrengthRoot.new end |
Instance Method Details
#authentication_method_modes ⇒ Object
Gets the authenticationMethodModes property value. Names and descriptions of all valid authentication method modes in the system.
22 23 24 |
# File 'lib/models/authentication_strength_root.rb', line 22 def authentication_method_modes return @authentication_method_modes end |
#authentication_method_modes=(value) ⇒ Object
Sets the authenticationMethodModes property value. Names and descriptions of all valid authentication method modes in the system.
30 31 32 |
# File 'lib/models/authentication_strength_root.rb', line 30 def authentication_method_modes=(value) @authentication_method_modes = value end |
#combinations ⇒ Object
Gets the combinations property value. The combinations property
37 38 39 |
# File 'lib/models/authentication_strength_root.rb', line 37 def combinations return @combinations end |
#combinations=(value) ⇒ Object
Sets the combinations property value. The combinations property
45 46 47 |
# File 'lib/models/authentication_strength_root.rb', line 45 def combinations=(value) @combinations = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
68 69 70 71 72 73 74 |
# File 'lib/models/authentication_strength_root.rb', line 68 def get_field_deserializers() return super.merge({ "authenticationMethodModes" => lambda {|n| @authentication_method_modes = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AuthenticationMethodModeDetail.create_from_discriminator_value(pn) }) }, "combinations" => lambda {|n| @combinations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AuthenticationMethodModes.create_from_discriminator_value(pn) }) }, "policies" => lambda {|n| @policies = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AuthenticationStrengthPolicy.create_from_discriminator_value(pn) }) }, }) end |
#policies ⇒ Object
Gets the policies property value. A collection of authentication strength policies that exist for this tenant, including both built-in and custom policies.
79 80 81 |
# File 'lib/models/authentication_strength_root.rb', line 79 def policies return @policies end |
#policies=(value) ⇒ Object
Sets the policies property value. A collection of authentication strength policies that exist for this tenant, including both built-in and custom policies.
87 88 89 |
# File 'lib/models/authentication_strength_root.rb', line 87 def policies=(value) @policies = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
95 96 97 98 99 100 101 |
# File 'lib/models/authentication_strength_root.rb', line 95 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_collection_of_object_values("authenticationMethodModes", @authentication_method_modes) writer.write_collection_of_object_values("combinations", @combinations) writer.write_collection_of_object_values("policies", @policies) end |