Class: MicrosoftGraph::Models::BookingStaffMember
- Inherits:
-
BookingStaffMemberBase
- Object
- Entity
- BookingStaffMemberBase
- MicrosoftGraph::Models::BookingStaffMember
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/booking_staff_member.rb
Overview
Represents a staff member who provides services in a business.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#availability_is_affected_by_personal_calendar ⇒ Object
Gets the availabilityIsAffectedByPersonalCalendar property value.
-
#availability_is_affected_by_personal_calendar=(value) ⇒ Object
Sets the availabilityIsAffectedByPersonalCalendar property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#email_address ⇒ Object
Gets the emailAddress property value.
-
#email_address=(value) ⇒ Object
Sets the emailAddress property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new bookingStaffMember and sets the default values.
-
#is_email_notification_enabled ⇒ Object
Gets the isEmailNotificationEnabled property value.
-
#is_email_notification_enabled=(value) ⇒ Object
Sets the isEmailNotificationEnabled property value.
-
#role ⇒ Object
Gets the role property value.
-
#role=(value) ⇒ Object
Sets the role property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#time_zone ⇒ Object
Gets the timeZone property value.
-
#time_zone=(value) ⇒ Object
Sets the timeZone property value.
-
#use_business_hours ⇒ Object
Gets the useBusinessHours property value.
-
#use_business_hours=(value) ⇒ Object
Sets the useBusinessHours property value.
-
#working_hours ⇒ Object
Gets the workingHours property value.
-
#working_hours=(value) ⇒ Object
Sets the workingHours property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new bookingStaffMember and sets the default values.
54 55 56 57 |
# File 'lib/models/booking_staff_member.rb', line 54 def initialize() super @odata_type = "#microsoft.graph.bookingStaffMember" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
63 64 65 66 |
# File 'lib/models/booking_staff_member.rb', line 63 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return BookingStaffMember.new end |
Instance Method Details
#availability_is_affected_by_personal_calendar ⇒ Object
Gets the availabilityIsAffectedByPersonalCalendar property value. True means that if the staff member is a Microsoft 365 user, the Bookings API would verify the staff member’s availability in their personal calendar in Microsoft 365, before making a booking.
39 40 41 |
# File 'lib/models/booking_staff_member.rb', line 39 def availability_is_affected_by_personal_calendar return @availability_is_affected_by_personal_calendar end |
#availability_is_affected_by_personal_calendar=(value) ⇒ Object
Sets the availabilityIsAffectedByPersonalCalendar property value. True means that if the staff member is a Microsoft 365 user, the Bookings API would verify the staff member’s availability in their personal calendar in Microsoft 365, before making a booking.
47 48 49 |
# File 'lib/models/booking_staff_member.rb', line 47 def availability_is_affected_by_personal_calendar=(value) @availability_is_affected_by_personal_calendar = value end |
#display_name ⇒ Object
Gets the displayName property value. The name of the staff member, as displayed to customers. Required.
71 72 73 |
# File 'lib/models/booking_staff_member.rb', line 71 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. The name of the staff member, as displayed to customers. Required.
79 80 81 |
# File 'lib/models/booking_staff_member.rb', line 79 def display_name=(value) @display_name = value end |
#email_address ⇒ Object
Gets the emailAddress property value. The email address of the staff member. This can be in the same Microsoft 365 tenant as the business, or in a different email domain. This email address can be used if the sendConfirmationsToOwner property is set to true in the scheduling policy of the business. Required.
86 87 88 |
# File 'lib/models/booking_staff_member.rb', line 86 def email_address return @email_address end |
#email_address=(value) ⇒ Object
Sets the emailAddress property value. The email address of the staff member. This can be in the same Microsoft 365 tenant as the business, or in a different email domain. This email address can be used if the sendConfirmationsToOwner property is set to true in the scheduling policy of the business. Required.
94 95 96 |
# File 'lib/models/booking_staff_member.rb', line 94 def email_address=(value) @email_address = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/models/booking_staff_member.rb', line 101 def get_field_deserializers() return super.merge({ "availabilityIsAffectedByPersonalCalendar" => lambda {|n| @availability_is_affected_by_personal_calendar = n.get_boolean_value() }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, "emailAddress" => lambda {|n| @email_address = n.get_string_value() }, "isEmailNotificationEnabled" => lambda {|n| @is_email_notification_enabled = n.get_boolean_value() }, "role" => lambda {|n| @role = n.get_enum_value(MicrosoftGraph::Models::BookingStaffRole) }, "timeZone" => lambda {|n| @time_zone = n.get_string_value() }, "useBusinessHours" => lambda {|n| @use_business_hours = n.get_boolean_value() }, "workingHours" => lambda {|n| @working_hours = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::BookingWorkHours.create_from_discriminator_value(pn) }) }, }) end |
#is_email_notification_enabled ⇒ Object
Gets the isEmailNotificationEnabled property value. True indicates that a staff member will be notified via email when a booking assigned to them is created or changed.
117 118 119 |
# File 'lib/models/booking_staff_member.rb', line 117 def is_email_notification_enabled return @is_email_notification_enabled end |
#is_email_notification_enabled=(value) ⇒ Object
Sets the isEmailNotificationEnabled property value. True indicates that a staff member will be notified via email when a booking assigned to them is created or changed.
125 126 127 |
# File 'lib/models/booking_staff_member.rb', line 125 def is_email_notification_enabled=(value) @is_email_notification_enabled = value end |
#role ⇒ Object
Gets the role property value. The role property
132 133 134 |
# File 'lib/models/booking_staff_member.rb', line 132 def role return @role end |
#role=(value) ⇒ Object
Sets the role property value. The role property
140 141 142 |
# File 'lib/models/booking_staff_member.rb', line 140 def role=(value) @role = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/models/booking_staff_member.rb', line 148 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_boolean_value("availabilityIsAffectedByPersonalCalendar", @availability_is_affected_by_personal_calendar) writer.write_string_value("displayName", @display_name) writer.write_string_value("emailAddress", @email_address) writer.write_boolean_value("isEmailNotificationEnabled", @is_email_notification_enabled) writer.write_enum_value("role", @role) writer.write_string_value("timeZone", @time_zone) writer.write_boolean_value("useBusinessHours", @use_business_hours) writer.write_collection_of_object_values("workingHours", @working_hours) end |
#time_zone ⇒ Object
Gets the timeZone property value. The time zone of the staff member. For a list of possible values, see dateTimeTimeZone.
164 165 166 |
# File 'lib/models/booking_staff_member.rb', line 164 def time_zone return @time_zone end |
#time_zone=(value) ⇒ Object
Sets the timeZone property value. The time zone of the staff member. For a list of possible values, see dateTimeTimeZone.
172 173 174 |
# File 'lib/models/booking_staff_member.rb', line 172 def time_zone=(value) @time_zone = value end |
#use_business_hours ⇒ Object
Gets the useBusinessHours property value. True means the staff member’s availability is as specified in the businessHours property of the business. False means the availability is determined by the staff member’s workingHours property setting.
179 180 181 |
# File 'lib/models/booking_staff_member.rb', line 179 def use_business_hours return @use_business_hours end |
#use_business_hours=(value) ⇒ Object
Sets the useBusinessHours property value. True means the staff member’s availability is as specified in the businessHours property of the business. False means the availability is determined by the staff member’s workingHours property setting.
187 188 189 |
# File 'lib/models/booking_staff_member.rb', line 187 def use_business_hours=(value) @use_business_hours = value end |
#working_hours ⇒ Object
Gets the workingHours property value. The range of hours each day of the week that the staff member is available for booking. By default, they are initialized to be the same as the businessHours property of the business.
194 195 196 |
# File 'lib/models/booking_staff_member.rb', line 194 def working_hours return @working_hours end |
#working_hours=(value) ⇒ Object
Sets the workingHours property value. The range of hours each day of the week that the staff member is available for booking. By default, they are initialized to be the same as the businessHours property of the business.
202 203 204 |
# File 'lib/models/booking_staff_member.rb', line 202 def working_hours=(value) @working_hours = value end |