Class: MicrosoftGraph::Models::BrowserSharedCookieHistory
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::BrowserSharedCookieHistory
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/browser_shared_cookie_history.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#comment ⇒ Object
Gets the comment property value.
-
#comment=(value) ⇒ Object
Sets the comment property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#host_only ⇒ Object
Gets the hostOnly property value.
-
#host_only=(value) ⇒ Object
Sets the hostOnly property value.
-
#host_or_domain ⇒ Object
Gets the hostOrDomain property value.
-
#host_or_domain=(value) ⇒ Object
Sets the hostOrDomain property value.
-
#initialize ⇒ Object
constructor
Instantiates a new browserSharedCookieHistory and sets the default values.
-
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value.
-
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#path ⇒ Object
Gets the path property value.
-
#path=(value) ⇒ Object
Sets the path property value.
-
#published_date_time ⇒ Object
Gets the publishedDateTime property value.
-
#published_date_time=(value) ⇒ Object
Sets the publishedDateTime property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#source_environment ⇒ Object
Gets the sourceEnvironment property value.
-
#source_environment=(value) ⇒ Object
Sets the sourceEnvironment property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new browserSharedCookieHistory and sets the default values.
74 75 76 |
# File 'lib/models/browser_shared_cookie_history.rb', line 74 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
82 83 84 85 |
# File 'lib/models/browser_shared_cookie_history.rb', line 82 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return BrowserSharedCookieHistory.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
44 45 46 |
# File 'lib/models/browser_shared_cookie_history.rb', line 44 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
52 53 54 |
# File 'lib/models/browser_shared_cookie_history.rb', line 52 def additional_data=(value) @additional_data = value end |
#comment ⇒ Object
Gets the comment property value. The comment for the shared cookie.
59 60 61 |
# File 'lib/models/browser_shared_cookie_history.rb', line 59 def comment return @comment end |
#comment=(value) ⇒ Object
Sets the comment property value. The comment for the shared cookie.
67 68 69 |
# File 'lib/models/browser_shared_cookie_history.rb', line 67 def comment=(value) @comment = value end |
#display_name ⇒ Object
Gets the displayName property value. The name of the cookie.
90 91 92 |
# File 'lib/models/browser_shared_cookie_history.rb', line 90 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. The name of the cookie.
98 99 100 |
# File 'lib/models/browser_shared_cookie_history.rb', line 98 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/models/browser_shared_cookie_history.rb', line 105 def get_field_deserializers() return { "comment" => lambda {|n| @comment = n.get_string_value() }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, "hostOnly" => lambda {|n| @host_only = n.get_boolean_value() }, "hostOrDomain" => lambda {|n| @host_or_domain = n.get_string_value() }, "lastModifiedBy" => lambda {|n| @last_modified_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "path" => lambda {|n| @path = n.get_string_value() }, "publishedDateTime" => lambda {|n| @published_date_time = n.get_date_time_value() }, "sourceEnvironment" => lambda {|n| @source_environment = n.get_enum_value(MicrosoftGraph::Models::BrowserSharedCookieSourceEnvironment) }, } end |
#host_only ⇒ Object
Gets the hostOnly property value. Controls whether a cookie is a host-only or domain cookie.
122 123 124 |
# File 'lib/models/browser_shared_cookie_history.rb', line 122 def host_only return @host_only end |
#host_only=(value) ⇒ Object
Sets the hostOnly property value. Controls whether a cookie is a host-only or domain cookie.
130 131 132 |
# File 'lib/models/browser_shared_cookie_history.rb', line 130 def host_only=(value) @host_only = value end |
#host_or_domain ⇒ Object
Gets the hostOrDomain property value. The URL of the cookie.
137 138 139 |
# File 'lib/models/browser_shared_cookie_history.rb', line 137 def host_or_domain return @host_or_domain end |
#host_or_domain=(value) ⇒ Object
Sets the hostOrDomain property value. The URL of the cookie.
145 146 147 |
# File 'lib/models/browser_shared_cookie_history.rb', line 145 def host_or_domain=(value) @host_or_domain = value end |
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value. The lastModifiedBy property
152 153 154 |
# File 'lib/models/browser_shared_cookie_history.rb', line 152 def last_modified_by return @last_modified_by end |
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value. The lastModifiedBy property
160 161 162 |
# File 'lib/models/browser_shared_cookie_history.rb', line 160 def last_modified_by=(value) @last_modified_by = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
167 168 169 |
# File 'lib/models/browser_shared_cookie_history.rb', line 167 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
175 176 177 |
# File 'lib/models/browser_shared_cookie_history.rb', line 175 def odata_type=(value) @odata_type = value end |
#path ⇒ Object
Gets the path property value. The path of the cookie.
182 183 184 |
# File 'lib/models/browser_shared_cookie_history.rb', line 182 def path return @path end |
#path=(value) ⇒ Object
Sets the path property value. The path of the cookie.
190 191 192 |
# File 'lib/models/browser_shared_cookie_history.rb', line 190 def path=(value) @path = value end |
#published_date_time ⇒ Object
Gets the publishedDateTime property value. The date and time when the cookie was last published.
197 198 199 |
# File 'lib/models/browser_shared_cookie_history.rb', line 197 def published_date_time return @published_date_time end |
#published_date_time=(value) ⇒ Object
Sets the publishedDateTime property value. The date and time when the cookie was last published.
205 206 207 |
# File 'lib/models/browser_shared_cookie_history.rb', line 205 def published_date_time=(value) @published_date_time = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/models/browser_shared_cookie_history.rb', line 213 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("comment", @comment) writer.write_string_value("displayName", @display_name) writer.write_boolean_value("hostOnly", @host_only) writer.write_string_value("hostOrDomain", @host_or_domain) writer.write_object_value("lastModifiedBy", @last_modified_by) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("path", @path) writer.write_date_time_value("publishedDateTime", @published_date_time) writer.write_enum_value("sourceEnvironment", @source_environment) writer.write_additional_data(@additional_data) end |
#source_environment ⇒ Object
Gets the sourceEnvironment property value. Specifies how the cookies are shared between Microsoft Edge and Internet Explorer. The possible values are: microsoftEdge, internetExplorer11, both, unknownFutureValue.
230 231 232 |
# File 'lib/models/browser_shared_cookie_history.rb', line 230 def source_environment return @source_environment end |
#source_environment=(value) ⇒ Object
Sets the sourceEnvironment property value. Specifies how the cookies are shared between Microsoft Edge and Internet Explorer. The possible values are: microsoftEdge, internetExplorer11, both, unknownFutureValue.
238 239 240 |
# File 'lib/models/browser_shared_cookie_history.rb', line 238 def source_environment=(value) @source_environment = value end |