Class: MicrosoftGraph::Models::BrowserSiteHistory
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::BrowserSiteHistory
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/browser_site_history.rb
Overview
The history for the site modifications
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#allow_redirect ⇒ Object
Gets the allowRedirect property value.
-
#allow_redirect=(value) ⇒ Object
Sets the allowRedirect property value.
-
#comment ⇒ Object
Gets the comment property value.
-
#comment=(value) ⇒ Object
Sets the comment property value.
-
#compatibility_mode ⇒ Object
Gets the compatibilityMode property value.
-
#compatibility_mode=(value) ⇒ Object
Sets the compatibilityMode property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new browserSiteHistory and sets the default values.
-
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value.
-
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value.
-
#merge_type ⇒ Object
Gets the mergeType property value.
-
#merge_type=(value) ⇒ Object
Sets the mergeType property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#published_date_time ⇒ Object
Gets the publishedDateTime property value.
-
#published_date_time=(value) ⇒ Object
Sets the publishedDateTime property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#target_environment ⇒ Object
Gets the targetEnvironment property value.
-
#target_environment=(value) ⇒ Object
Sets the targetEnvironment property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new browserSiteHistory and sets the default values.
103 104 105 |
# File 'lib/models/browser_site_history.rb', line 103 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
111 112 113 114 |
# File 'lib/models/browser_site_history.rb', line 111 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return BrowserSiteHistory.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
43 44 45 |
# File 'lib/models/browser_site_history.rb', line 43 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
51 52 53 |
# File 'lib/models/browser_site_history.rb', line 51 def additional_data=(value) @additional_data = value end |
#allow_redirect ⇒ Object
Gets the allowRedirect property value. Controls the behavior of redirected sites. If true, indicates that the site will open in Internet Explorer 11 or Microsoft Edge even if the site is navigated to as part of a HTTP or meta refresh redirection chain.
58 59 60 |
# File 'lib/models/browser_site_history.rb', line 58 def allow_redirect return @allow_redirect end |
#allow_redirect=(value) ⇒ Object
Sets the allowRedirect property value. Controls the behavior of redirected sites. If true, indicates that the site will open in Internet Explorer 11 or Microsoft Edge even if the site is navigated to as part of a HTTP or meta refresh redirection chain.
66 67 68 |
# File 'lib/models/browser_site_history.rb', line 66 def allow_redirect=(value) @allow_redirect = value end |
#comment ⇒ Object
Gets the comment property value. The comment for the site.
73 74 75 |
# File 'lib/models/browser_site_history.rb', line 73 def comment return @comment end |
#comment=(value) ⇒ Object
Sets the comment property value. The comment for the site.
81 82 83 |
# File 'lib/models/browser_site_history.rb', line 81 def comment=(value) @comment = value end |
#compatibility_mode ⇒ Object
Gets the compatibilityMode property value. Controls what compatibility setting is used for specific sites or domains. The possible values are: default, internetExplorer8Enterprise, internetExplorer7Enterprise, internetExplorer11, internetExplorer10, internetExplorer9, internetExplorer8, internetExplorer7, internetExplorer5, unknownFutureValue.
88 89 90 |
# File 'lib/models/browser_site_history.rb', line 88 def compatibility_mode return @compatibility_mode end |
#compatibility_mode=(value) ⇒ Object
Sets the compatibilityMode property value. Controls what compatibility setting is used for specific sites or domains. The possible values are: default, internetExplorer8Enterprise, internetExplorer7Enterprise, internetExplorer11, internetExplorer10, internetExplorer9, internetExplorer8, internetExplorer7, internetExplorer5, unknownFutureValue.
96 97 98 |
# File 'lib/models/browser_site_history.rb', line 96 def compatibility_mode=(value) @compatibility_mode = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/models/browser_site_history.rb', line 119 def get_field_deserializers() return { "allowRedirect" => lambda {|n| @allow_redirect = n.get_boolean_value() }, "comment" => lambda {|n| @comment = n.get_string_value() }, "compatibilityMode" => lambda {|n| @compatibility_mode = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteCompatibilityMode) }, "lastModifiedBy" => lambda {|n| @last_modified_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) }, "mergeType" => lambda {|n| @merge_type = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteMergeType) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "publishedDateTime" => lambda {|n| @published_date_time = n.get_date_time_value() }, "targetEnvironment" => lambda {|n| @target_environment = n.get_enum_value(MicrosoftGraph::Models::BrowserSiteTargetEnvironment) }, } end |
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value. The user who last modified the site.
135 136 137 |
# File 'lib/models/browser_site_history.rb', line 135 def last_modified_by return @last_modified_by end |
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value. The user who last modified the site.
143 144 145 |
# File 'lib/models/browser_site_history.rb', line 143 def last_modified_by=(value) @last_modified_by = value end |
#merge_type ⇒ Object
Gets the mergeType property value. The merge type of the site. The possible values are: noMerge, default, unknownFutureValue.
150 151 152 |
# File 'lib/models/browser_site_history.rb', line 150 def merge_type return @merge_type end |
#merge_type=(value) ⇒ Object
Sets the mergeType property value. The merge type of the site. The possible values are: noMerge, default, unknownFutureValue.
158 159 160 |
# File 'lib/models/browser_site_history.rb', line 158 def merge_type=(value) @merge_type = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
165 166 167 |
# File 'lib/models/browser_site_history.rb', line 165 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
173 174 175 |
# File 'lib/models/browser_site_history.rb', line 173 def odata_type=(value) @odata_type = value end |
#published_date_time ⇒ Object
Gets the publishedDateTime property value. The date and time when the site was last published.
180 181 182 |
# File 'lib/models/browser_site_history.rb', line 180 def published_date_time return @published_date_time end |
#published_date_time=(value) ⇒ Object
Sets the publishedDateTime property value. The date and time when the site was last published.
188 189 190 |
# File 'lib/models/browser_site_history.rb', line 188 def published_date_time=(value) @published_date_time = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/models/browser_site_history.rb', line 196 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("allowRedirect", @allow_redirect) writer.write_string_value("comment", @comment) writer.write_enum_value("compatibilityMode", @compatibility_mode) writer.write_object_value("lastModifiedBy", @last_modified_by) writer.write_enum_value("mergeType", @merge_type) writer.write_string_value("@odata.type", @odata_type) writer.write_date_time_value("publishedDateTime", @published_date_time) writer.write_enum_value("targetEnvironment", @target_environment) writer.write_additional_data(@additional_data) end |
#target_environment ⇒ Object
Gets the targetEnvironment property value. The target environment that the site should open in. The possible values are: internetExplorerMode, internetExplorer11, microsoftEdge, configurable, none, unknownFutureValue.Prior to June 15, 2022, the internetExplorer11 option would allow opening a site in the Internet Explorer 11 (IE11) desktop application. Following the retirement of IE11 on June 15, 2022, the internetExplorer11 option will no longer open an IE11 window and will instead behave the same as the internetExplorerMode option.
212 213 214 |
# File 'lib/models/browser_site_history.rb', line 212 def target_environment return @target_environment end |
#target_environment=(value) ⇒ Object
Sets the targetEnvironment property value. The target environment that the site should open in. The possible values are: internetExplorerMode, internetExplorer11, microsoftEdge, configurable, none, unknownFutureValue.Prior to June 15, 2022, the internetExplorer11 option would allow opening a site in the Internet Explorer 11 (IE11) desktop application. Following the retirement of IE11 on June 15, 2022, the internetExplorer11 option will no longer open an IE11 window and will instead behave the same as the internetExplorerMode option.
220 221 222 |
# File 'lib/models/browser_site_history.rb', line 220 def target_environment=(value) @target_environment = value end |