Class: MicrosoftGraph::Models::CallEndedEventMessageDetail
- Inherits:
-
EventMessageDetail
- Object
- EventMessageDetail
- MicrosoftGraph::Models::CallEndedEventMessageDetail
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/call_ended_event_message_detail.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#call_duration ⇒ Object
Gets the callDuration property value.
-
#call_duration=(value) ⇒ Object
Sets the callDuration property value.
-
#call_event_type ⇒ Object
Gets the callEventType property value.
-
#call_event_type=(value) ⇒ Object
Sets the callEventType property value.
-
#call_id ⇒ Object
Gets the callId property value.
-
#call_id=(value) ⇒ Object
Sets the callId property value.
-
#call_participants ⇒ Object
Gets the callParticipants property value.
-
#call_participants=(value) ⇒ Object
Sets the callParticipants property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new callEndedEventMessageDetail and sets the default values.
-
#initiator ⇒ Object
Gets the initiator property value.
-
#initiator=(value) ⇒ Object
Sets the initiator property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from EventMessageDetail
#additional_data, #additional_data=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new callEndedEventMessageDetail and sets the default values.
88 89 90 91 |
# File 'lib/models/call_ended_event_message_detail.rb', line 88 def initialize() super @odata_type = "#microsoft.graph.callEndedEventMessageDetail" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
97 98 99 100 |
# File 'lib/models/call_ended_event_message_detail.rb', line 97 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CallEndedEventMessageDetail.new end |
Instance Method Details
#call_duration ⇒ Object
Gets the callDuration property value. Duration of the call.
28 29 30 |
# File 'lib/models/call_ended_event_message_detail.rb', line 28 def call_duration return @call_duration end |
#call_duration=(value) ⇒ Object
Sets the callDuration property value. Duration of the call.
36 37 38 |
# File 'lib/models/call_ended_event_message_detail.rb', line 36 def call_duration=(value) @call_duration = value end |
#call_event_type ⇒ Object
Gets the callEventType property value. Represents the call event type. Possible values are: call, meeting, screenShare, unknownFutureValue.
43 44 45 |
# File 'lib/models/call_ended_event_message_detail.rb', line 43 def call_event_type return @call_event_type end |
#call_event_type=(value) ⇒ Object
Sets the callEventType property value. Represents the call event type. Possible values are: call, meeting, screenShare, unknownFutureValue.
51 52 53 |
# File 'lib/models/call_ended_event_message_detail.rb', line 51 def call_event_type=(value) @call_event_type = value end |
#call_id ⇒ Object
Gets the callId property value. Unique identifier of the call.
58 59 60 |
# File 'lib/models/call_ended_event_message_detail.rb', line 58 def call_id return @call_id end |
#call_id=(value) ⇒ Object
Sets the callId property value. Unique identifier of the call.
66 67 68 |
# File 'lib/models/call_ended_event_message_detail.rb', line 66 def call_id=(value) @call_id = value end |
#call_participants ⇒ Object
Gets the callParticipants property value. List of call participants.
73 74 75 |
# File 'lib/models/call_ended_event_message_detail.rb', line 73 def call_participants return @call_participants end |
#call_participants=(value) ⇒ Object
Sets the callParticipants property value. List of call participants.
81 82 83 |
# File 'lib/models/call_ended_event_message_detail.rb', line 81 def call_participants=(value) @call_participants = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
105 106 107 108 109 110 111 112 113 |
# File 'lib/models/call_ended_event_message_detail.rb', line 105 def get_field_deserializers() return super.merge({ "callDuration" => lambda {|n| @call_duration = n.get_duration_value() }, "callEventType" => lambda {|n| @call_event_type = n.get_enum_value(MicrosoftGraph::Models::TeamworkCallEventType) }, "callId" => lambda {|n| @call_id = n.get_string_value() }, "callParticipants" => lambda {|n| @call_participants = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::CallParticipantInfo.create_from_discriminator_value(pn) }) }, "initiator" => lambda {|n| @initiator = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) }, }) end |
#initiator ⇒ Object
Gets the initiator property value. Initiator of the event.
118 119 120 |
# File 'lib/models/call_ended_event_message_detail.rb', line 118 def initiator return @initiator end |
#initiator=(value) ⇒ Object
Sets the initiator property value. Initiator of the event.
126 127 128 |
# File 'lib/models/call_ended_event_message_detail.rb', line 126 def initiator=(value) @initiator = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
134 135 136 137 138 139 140 141 142 |
# File 'lib/models/call_ended_event_message_detail.rb', line 134 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_duration_value("callDuration", @call_duration) writer.write_enum_value("callEventType", @call_event_type) writer.write_string_value("callId", @call_id) writer.write_collection_of_object_values("callParticipants", @call_participants) writer.write_object_value("initiator", @initiator) end |