Class: MicrosoftGraph::Models::ChoiceColumn
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::ChoiceColumn
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/choice_column.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#allow_text_entry ⇒ Object
Gets the allowTextEntry property value.
-
#allow_text_entry=(value) ⇒ Object
Sets the allowTextEntry property value.
-
#choices ⇒ Object
Gets the choices property value.
-
#choices=(value) ⇒ Object
Sets the choices property value.
-
#display_as ⇒ Object
Gets the displayAs property value.
-
#display_as=(value) ⇒ Object
Sets the displayAs property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new choiceColumn and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new choiceColumn and sets the default values.
73 74 75 |
# File 'lib/models/choice_column.rb', line 73 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
81 82 83 84 |
# File 'lib/models/choice_column.rb', line 81 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ChoiceColumn.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
28 29 30 |
# File 'lib/models/choice_column.rb', line 28 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
36 37 38 |
# File 'lib/models/choice_column.rb', line 36 def additional_data=(value) @additional_data = value end |
#allow_text_entry ⇒ Object
Gets the allowTextEntry property value. If true, allows custom values that aren’t in the configured choices.
43 44 45 |
# File 'lib/models/choice_column.rb', line 43 def allow_text_entry return @allow_text_entry end |
#allow_text_entry=(value) ⇒ Object
Sets the allowTextEntry property value. If true, allows custom values that aren’t in the configured choices.
51 52 53 |
# File 'lib/models/choice_column.rb', line 51 def allow_text_entry=(value) @allow_text_entry = value end |
#choices ⇒ Object
Gets the choices property value. The list of values available for this column.
58 59 60 |
# File 'lib/models/choice_column.rb', line 58 def choices return @choices end |
#choices=(value) ⇒ Object
Sets the choices property value. The list of values available for this column.
66 67 68 |
# File 'lib/models/choice_column.rb', line 66 def choices=(value) @choices = value end |
#display_as ⇒ Object
Gets the displayAs property value. How the choices are to be presented in the UX. Must be one of checkBoxes, dropDownMenu, or radioButtons
89 90 91 |
# File 'lib/models/choice_column.rb', line 89 def display_as return @display_as end |
#display_as=(value) ⇒ Object
Sets the displayAs property value. How the choices are to be presented in the UX. Must be one of checkBoxes, dropDownMenu, or radioButtons
97 98 99 |
# File 'lib/models/choice_column.rb', line 97 def display_as=(value) @display_as = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
104 105 106 107 108 109 110 111 |
# File 'lib/models/choice_column.rb', line 104 def get_field_deserializers() return { "allowTextEntry" => lambda {|n| @allow_text_entry = n.get_boolean_value() }, "choices" => lambda {|n| @choices = n.get_collection_of_primitive_values(String) }, "displayAs" => lambda {|n| @display_as = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
116 117 118 |
# File 'lib/models/choice_column.rb', line 116 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
124 125 126 |
# File 'lib/models/choice_column.rb', line 124 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
132 133 134 135 136 137 138 139 |
# File 'lib/models/choice_column.rb', line 132 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("allowTextEntry", @allow_text_entry) writer.write_collection_of_primitive_values("choices", @choices) writer.write_string_value("displayAs", @display_as) writer.write_string_value("@odata.type", @odata_type) writer.write_additional_data(@additional_data) end |