Class: MicrosoftGraph::Models::Contract
- Inherits:
-
DirectoryObject
- Object
- Entity
- DirectoryObject
- MicrosoftGraph::Models::Contract
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/contract.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#contract_type ⇒ Object
Gets the contractType property value.
-
#contract_type=(value) ⇒ Object
Sets the contractType property value.
-
#customer_id ⇒ Object
Gets the customerId property value.
-
#customer_id=(value) ⇒ Object
Sets the customerId property value.
-
#default_domain_name ⇒ Object
Gets the defaultDomainName property value.
-
#default_domain_name=(value) ⇒ Object
Sets the defaultDomainName property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new contract and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from DirectoryObject
#deleted_date_time, #deleted_date_time=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new contract and sets the default values.
25 26 27 28 |
# File 'lib/models/contract.rb', line 25 def initialize() super @odata_type = "#microsoft.graph.contract" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
49 50 51 52 |
# File 'lib/models/contract.rb', line 49 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Contract.new end |
Instance Method Details
#contract_type ⇒ Object
Gets the contractType property value. Type of contract. Possible values are: SyndicationPartner, BreadthPartner, ResellerPartner. See more in the table below.
33 34 35 |
# File 'lib/models/contract.rb', line 33 def contract_type return @contract_type end |
#contract_type=(value) ⇒ Object
Sets the contractType property value. Type of contract. Possible values are: SyndicationPartner, BreadthPartner, ResellerPartner. See more in the table below.
41 42 43 |
# File 'lib/models/contract.rb', line 41 def contract_type=(value) @contract_type = value end |
#customer_id ⇒ Object
Gets the customerId property value. The unique identifier for the customer tenant referenced by this partnership. Corresponds to the id property of the customer tenant’s organization resource.
57 58 59 |
# File 'lib/models/contract.rb', line 57 def customer_id return @customer_id end |
#customer_id=(value) ⇒ Object
Sets the customerId property value. The unique identifier for the customer tenant referenced by this partnership. Corresponds to the id property of the customer tenant’s organization resource.
65 66 67 |
# File 'lib/models/contract.rb', line 65 def customer_id=(value) @customer_id = value end |
#default_domain_name ⇒ Object
Gets the defaultDomainName property value. A copy of the customer tenant’s default domain name. The copy is made when the partnership with the customer is established. It is not automatically updated if the customer tenant’s default domain name changes.
72 73 74 |
# File 'lib/models/contract.rb', line 72 def default_domain_name return @default_domain_name end |
#default_domain_name=(value) ⇒ Object
Sets the defaultDomainName property value. A copy of the customer tenant’s default domain name. The copy is made when the partnership with the customer is established. It is not automatically updated if the customer tenant’s default domain name changes.
80 81 82 |
# File 'lib/models/contract.rb', line 80 def default_domain_name=(value) @default_domain_name = value end |
#display_name ⇒ Object
Gets the displayName property value. A copy of the customer tenant’s display name. The copy is made when the partnership with the customer is established. It is not automatically updated if the customer tenant’s display name changes.
87 88 89 |
# File 'lib/models/contract.rb', line 87 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. A copy of the customer tenant’s display name. The copy is made when the partnership with the customer is established. It is not automatically updated if the customer tenant’s display name changes.
95 96 97 |
# File 'lib/models/contract.rb', line 95 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
102 103 104 105 106 107 108 109 |
# File 'lib/models/contract.rb', line 102 def get_field_deserializers() return super.merge({ "contractType" => lambda {|n| @contract_type = n.get_string_value() }, "customerId" => lambda {|n| @customer_id = n.get_guid_value() }, "defaultDomainName" => lambda {|n| @default_domain_name = n.get_string_value() }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
115 116 117 118 119 120 121 122 |
# File 'lib/models/contract.rb', line 115 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("contractType", @contract_type) writer.write_guid_value("customerId", @customer_id) writer.write_string_value("defaultDomainName", @default_domain_name) writer.write_string_value("displayName", @display_name) end |