Class: MicrosoftGraph::Models::EBookInstallSummary
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/e_book_install_summary.rb
Overview
Contains properties for the installation summary of a book for a device.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#failed_device_count ⇒ Object
Gets the failedDeviceCount property value.
-
#failed_device_count=(value) ⇒ Object
Sets the failedDeviceCount property value.
-
#failed_user_count ⇒ Object
Gets the failedUserCount property value.
-
#failed_user_count=(value) ⇒ Object
Sets the failedUserCount property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new eBookInstallSummary and sets the default values.
-
#installed_device_count ⇒ Object
Gets the installedDeviceCount property value.
-
#installed_device_count=(value) ⇒ Object
Sets the installedDeviceCount property value.
-
#installed_user_count ⇒ Object
Gets the installedUserCount property value.
-
#installed_user_count=(value) ⇒ Object
Sets the installedUserCount property value.
-
#not_installed_device_count ⇒ Object
Gets the notInstalledDeviceCount property value.
-
#not_installed_device_count=(value) ⇒ Object
Sets the notInstalledDeviceCount property value.
-
#not_installed_user_count ⇒ Object
Gets the notInstalledUserCount property value.
-
#not_installed_user_count=(value) ⇒ Object
Sets the notInstalledUserCount property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new eBookInstallSummary and sets the default values.
33 34 35 |
# File 'lib/models/e_book_install_summary.rb', line 33 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
41 42 43 44 |
# File 'lib/models/e_book_install_summary.rb', line 41 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return EBookInstallSummary.new end |
Instance Method Details
#failed_device_count ⇒ Object
Gets the failedDeviceCount property value. Number of Devices that have failed to install this book.
49 50 51 |
# File 'lib/models/e_book_install_summary.rb', line 49 def failed_device_count return @failed_device_count end |
#failed_device_count=(value) ⇒ Object
Sets the failedDeviceCount property value. Number of Devices that have failed to install this book.
57 58 59 |
# File 'lib/models/e_book_install_summary.rb', line 57 def failed_device_count=(value) @failed_device_count = value end |
#failed_user_count ⇒ Object
Gets the failedUserCount property value. Number of Users that have 1 or more device that failed to install this book.
64 65 66 |
# File 'lib/models/e_book_install_summary.rb', line 64 def failed_user_count return @failed_user_count end |
#failed_user_count=(value) ⇒ Object
Sets the failedUserCount property value. Number of Users that have 1 or more device that failed to install this book.
72 73 74 |
# File 'lib/models/e_book_install_summary.rb', line 72 def failed_user_count=(value) @failed_user_count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/models/e_book_install_summary.rb', line 79 def get_field_deserializers() return super.merge({ "failedDeviceCount" => lambda {|n| @failed_device_count = n.get_number_value() }, "failedUserCount" => lambda {|n| @failed_user_count = n.get_number_value() }, "installedDeviceCount" => lambda {|n| @installed_device_count = n.get_number_value() }, "installedUserCount" => lambda {|n| @installed_user_count = n.get_number_value() }, "notInstalledDeviceCount" => lambda {|n| @not_installed_device_count = n.get_number_value() }, "notInstalledUserCount" => lambda {|n| @not_installed_user_count = n.get_number_value() }, }) end |
#installed_device_count ⇒ Object
Gets the installedDeviceCount property value. Number of Devices that have successfully installed this book.
93 94 95 |
# File 'lib/models/e_book_install_summary.rb', line 93 def installed_device_count return @installed_device_count end |
#installed_device_count=(value) ⇒ Object
Sets the installedDeviceCount property value. Number of Devices that have successfully installed this book.
101 102 103 |
# File 'lib/models/e_book_install_summary.rb', line 101 def installed_device_count=(value) @installed_device_count = value end |
#installed_user_count ⇒ Object
Gets the installedUserCount property value. Number of Users whose devices have all succeeded to install this book.
108 109 110 |
# File 'lib/models/e_book_install_summary.rb', line 108 def installed_user_count return @installed_user_count end |
#installed_user_count=(value) ⇒ Object
Sets the installedUserCount property value. Number of Users whose devices have all succeeded to install this book.
116 117 118 |
# File 'lib/models/e_book_install_summary.rb', line 116 def installed_user_count=(value) @installed_user_count = value end |
#not_installed_device_count ⇒ Object
Gets the notInstalledDeviceCount property value. Number of Devices that does not have this book installed.
123 124 125 |
# File 'lib/models/e_book_install_summary.rb', line 123 def not_installed_device_count return @not_installed_device_count end |
#not_installed_device_count=(value) ⇒ Object
Sets the notInstalledDeviceCount property value. Number of Devices that does not have this book installed.
131 132 133 |
# File 'lib/models/e_book_install_summary.rb', line 131 def not_installed_device_count=(value) @not_installed_device_count = value end |
#not_installed_user_count ⇒ Object
Gets the notInstalledUserCount property value. Number of Users that did not install this book.
138 139 140 |
# File 'lib/models/e_book_install_summary.rb', line 138 def not_installed_user_count return @not_installed_user_count end |
#not_installed_user_count=(value) ⇒ Object
Sets the notInstalledUserCount property value. Number of Users that did not install this book.
146 147 148 |
# File 'lib/models/e_book_install_summary.rb', line 146 def not_installed_user_count=(value) @not_installed_user_count = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/models/e_book_install_summary.rb', line 154 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_number_value("failedDeviceCount", @failed_device_count) writer.write_number_value("failedUserCount", @failed_user_count) writer.write_number_value("installedDeviceCount", @installed_device_count) writer.write_number_value("installedUserCount", @installed_user_count) writer.write_number_value("notInstalledDeviceCount", @not_installed_device_count) writer.write_number_value("notInstalledUserCount", @not_installed_user_count) end |