Class: MicrosoftGraph::Models::EducationRubricOutcome
- Inherits:
-
EducationOutcome
- Object
- Entity
- EducationOutcome
- MicrosoftGraph::Models::EducationRubricOutcome
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/education_rubric_outcome.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new educationRubricOutcome and sets the default values.
-
#published_rubric_quality_feedback ⇒ Object
Gets the publishedRubricQualityFeedback property value.
-
#published_rubric_quality_feedback=(value) ⇒ Object
Sets the publishedRubricQualityFeedback property value.
-
#published_rubric_quality_selected_levels ⇒ Object
Gets the publishedRubricQualitySelectedLevels property value.
-
#published_rubric_quality_selected_levels=(value) ⇒ Object
Sets the publishedRubricQualitySelectedLevels property value.
-
#rubric_quality_feedback ⇒ Object
Gets the rubricQualityFeedback property value.
-
#rubric_quality_feedback=(value) ⇒ Object
Sets the rubricQualityFeedback property value.
-
#rubric_quality_selected_levels ⇒ Object
Gets the rubricQualitySelectedLevels property value.
-
#rubric_quality_selected_levels=(value) ⇒ Object
Sets the rubricQualitySelectedLevels property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from EducationOutcome
#last_modified_by, #last_modified_by=, #last_modified_date_time, #last_modified_date_time=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new educationRubricOutcome and sets the default values.
25 26 27 28 |
# File 'lib/models/education_rubric_outcome.rb', line 25 def initialize() super @odata_type = "#microsoft.graph.educationRubricOutcome" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
34 35 36 37 |
# File 'lib/models/education_rubric_outcome.rb', line 34 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return EducationRubricOutcome.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
42 43 44 45 46 47 48 49 |
# File 'lib/models/education_rubric_outcome.rb', line 42 def get_field_deserializers() return super.merge({ "publishedRubricQualityFeedback" => lambda {|n| @published_rubric_quality_feedback = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualityFeedbackModel.create_from_discriminator_value(pn) }) }, "publishedRubricQualitySelectedLevels" => lambda {|n| @published_rubric_quality_selected_levels = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualitySelectedColumnModel.create_from_discriminator_value(pn) }) }, "rubricQualityFeedback" => lambda {|n| @rubric_quality_feedback = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualityFeedbackModel.create_from_discriminator_value(pn) }) }, "rubricQualitySelectedLevels" => lambda {|n| @rubric_quality_selected_levels = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RubricQualitySelectedColumnModel.create_from_discriminator_value(pn) }) }, }) end |
#published_rubric_quality_feedback ⇒ Object
Gets the publishedRubricQualityFeedback property value. A copy of the rubricQualityFeedback property that is made when the grade is released to the student.
54 55 56 |
# File 'lib/models/education_rubric_outcome.rb', line 54 def published_rubric_quality_feedback return @published_rubric_quality_feedback end |
#published_rubric_quality_feedback=(value) ⇒ Object
Sets the publishedRubricQualityFeedback property value. A copy of the rubricQualityFeedback property that is made when the grade is released to the student.
62 63 64 |
# File 'lib/models/education_rubric_outcome.rb', line 62 def published_rubric_quality_feedback=(value) @published_rubric_quality_feedback = value end |
#published_rubric_quality_selected_levels ⇒ Object
Gets the publishedRubricQualitySelectedLevels property value. A copy of the rubricQualitySelectedLevels property that is made when the grade is released to the student.
69 70 71 |
# File 'lib/models/education_rubric_outcome.rb', line 69 def published_rubric_quality_selected_levels return @published_rubric_quality_selected_levels end |
#published_rubric_quality_selected_levels=(value) ⇒ Object
Sets the publishedRubricQualitySelectedLevels property value. A copy of the rubricQualitySelectedLevels property that is made when the grade is released to the student.
77 78 79 |
# File 'lib/models/education_rubric_outcome.rb', line 77 def published_rubric_quality_selected_levels=(value) @published_rubric_quality_selected_levels = value end |
#rubric_quality_feedback ⇒ Object
Gets the rubricQualityFeedback property value. A collection of specific feedback for each quality of this rubric.
84 85 86 |
# File 'lib/models/education_rubric_outcome.rb', line 84 def rubric_quality_feedback return @rubric_quality_feedback end |
#rubric_quality_feedback=(value) ⇒ Object
Sets the rubricQualityFeedback property value. A collection of specific feedback for each quality of this rubric.
92 93 94 |
# File 'lib/models/education_rubric_outcome.rb', line 92 def rubric_quality_feedback=(value) @rubric_quality_feedback = value end |
#rubric_quality_selected_levels ⇒ Object
Gets the rubricQualitySelectedLevels property value. The level that the teacher has selected for each quality while grading this assignment.
99 100 101 |
# File 'lib/models/education_rubric_outcome.rb', line 99 def rubric_quality_selected_levels return @rubric_quality_selected_levels end |
#rubric_quality_selected_levels=(value) ⇒ Object
Sets the rubricQualitySelectedLevels property value. The level that the teacher has selected for each quality while grading this assignment.
107 108 109 |
# File 'lib/models/education_rubric_outcome.rb', line 107 def rubric_quality_selected_levels=(value) @rubric_quality_selected_levels = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
115 116 117 118 119 120 121 122 |
# File 'lib/models/education_rubric_outcome.rb', line 115 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_collection_of_object_values("publishedRubricQualityFeedback", @published_rubric_quality_feedback) writer.write_collection_of_object_values("publishedRubricQualitySelectedLevels", @published_rubric_quality_selected_levels) writer.write_collection_of_object_values("rubricQualityFeedback", @rubric_quality_feedback) writer.write_collection_of_object_values("rubricQualitySelectedLevels", @rubric_quality_selected_levels) end |