Class: MicrosoftGraph::Models::ExternalConnectorsExternalConnection
- Inherits:
-
Entity
- Object
- Entity
- MicrosoftGraph::Models::ExternalConnectorsExternalConnection
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/external_connectors_external_connection.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#activity_settings ⇒ Object
Gets the activitySettings property value.
-
#activity_settings=(value) ⇒ Object
Sets the activitySettings property value.
-
#configuration ⇒ Object
Gets the configuration property value.
-
#configuration=(value) ⇒ Object
Sets the configuration property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#groups ⇒ Object
Gets the groups property value.
-
#groups=(value) ⇒ Object
Sets the groups property value.
-
#initialize ⇒ Object
constructor
Instantiates a new externalConnectorsExternalConnection and sets the default values.
-
#items ⇒ Object
Gets the items property value.
-
#items=(value) ⇒ Object
Sets the items property value.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#operations ⇒ Object
Gets the operations property value.
-
#operations=(value) ⇒ Object
Sets the operations property value.
-
#schema ⇒ Object
Gets the schema property value.
-
#schema=(value) ⇒ Object
Sets the schema property value.
-
#search_settings ⇒ Object
Gets the searchSettings property value.
-
#search_settings=(value) ⇒ Object
Sets the searchSettings property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#state ⇒ Object
Gets the state property value.
-
#state=(value) ⇒ Object
Sets the state property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new externalConnectorsExternalConnection and sets the default values.
73 74 75 |
# File 'lib/models/external_connectors_external_connection.rb', line 73 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
81 82 83 84 |
# File 'lib/models/external_connectors_external_connection.rb', line 81 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ExternalConnectorsExternalConnection.new end |
Instance Method Details
#activity_settings ⇒ Object
Gets the activitySettings property value. Collects configurable settings related to activities involving connector content.
43 44 45 |
# File 'lib/models/external_connectors_external_connection.rb', line 43 def activity_settings return @activity_settings end |
#activity_settings=(value) ⇒ Object
Sets the activitySettings property value. Collects configurable settings related to activities involving connector content.
51 52 53 |
# File 'lib/models/external_connectors_external_connection.rb', line 51 def activity_settings=(value) @activity_settings = value end |
#configuration ⇒ Object
Gets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.
58 59 60 |
# File 'lib/models/external_connectors_external_connection.rb', line 58 def configuration return @configuration end |
#configuration=(value) ⇒ Object
Sets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.
66 67 68 |
# File 'lib/models/external_connectors_external_connection.rb', line 66 def configuration=(value) @configuration = value end |
#description ⇒ Object
Gets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.
89 90 91 |
# File 'lib/models/external_connectors_external_connection.rb', line 89 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.
97 98 99 |
# File 'lib/models/external_connectors_external_connection.rb', line 97 def description=(value) @description = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/models/external_connectors_external_connection.rb', line 104 def get_field_deserializers() return super.merge({ "activitySettings" => lambda {|n| @activity_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsActivitySettings.create_from_discriminator_value(pn) }) }, "configuration" => lambda {|n| @configuration = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsConfiguration.create_from_discriminator_value(pn) }) }, "description" => lambda {|n| @description = n.get_string_value() }, "groups" => lambda {|n| @groups = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsExternalGroup.create_from_discriminator_value(pn) }) }, "items" => lambda {|n| @items = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsExternalItem.create_from_discriminator_value(pn) }) }, "name" => lambda {|n| @name = n.get_string_value() }, "operations" => lambda {|n| @operations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsConnectionOperation.create_from_discriminator_value(pn) }) }, "schema" => lambda {|n| @schema = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsSchema.create_from_discriminator_value(pn) }) }, "searchSettings" => lambda {|n| @search_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ExternalConnectorsSearchSettings.create_from_discriminator_value(pn) }) }, "state" => lambda {|n| @state = n.get_enum_value(MicrosoftGraph::Models::ExternalConnectorsConnectionState) }, }) end |
#groups ⇒ Object
Gets the groups property value. The groups property
122 123 124 |
# File 'lib/models/external_connectors_external_connection.rb', line 122 def groups return @groups end |
#groups=(value) ⇒ Object
Sets the groups property value. The groups property
130 131 132 |
# File 'lib/models/external_connectors_external_connection.rb', line 130 def groups=(value) @groups = value end |
#items ⇒ Object
Gets the items property value. The items property
137 138 139 |
# File 'lib/models/external_connectors_external_connection.rb', line 137 def items return @items end |
#items=(value) ⇒ Object
Sets the items property value. The items property
145 146 147 |
# File 'lib/models/external_connectors_external_connection.rb', line 145 def items=(value) @items = value end |
#name ⇒ Object
Gets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.
152 153 154 |
# File 'lib/models/external_connectors_external_connection.rb', line 152 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.
160 161 162 |
# File 'lib/models/external_connectors_external_connection.rb', line 160 def name=(value) @name = value end |
#operations ⇒ Object
Gets the operations property value. The operations property
167 168 169 |
# File 'lib/models/external_connectors_external_connection.rb', line 167 def operations return @operations end |
#operations=(value) ⇒ Object
Sets the operations property value. The operations property
175 176 177 |
# File 'lib/models/external_connectors_external_connection.rb', line 175 def operations=(value) @operations = value end |
#schema ⇒ Object
Gets the schema property value. The schema property
182 183 184 |
# File 'lib/models/external_connectors_external_connection.rb', line 182 def schema return @schema end |
#schema=(value) ⇒ Object
Sets the schema property value. The schema property
190 191 192 |
# File 'lib/models/external_connectors_external_connection.rb', line 190 def schema=(value) @schema = value end |
#search_settings ⇒ Object
Gets the searchSettings property value. The settings configuring the search experience for content in this connection, such as the display templates for search results.
197 198 199 |
# File 'lib/models/external_connectors_external_connection.rb', line 197 def search_settings return @search_settings end |
#search_settings=(value) ⇒ Object
Sets the searchSettings property value. The settings configuring the search experience for content in this connection, such as the display templates for search results.
205 206 207 |
# File 'lib/models/external_connectors_external_connection.rb', line 205 def search_settings=(value) @search_settings = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/models/external_connectors_external_connection.rb', line 213 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("activitySettings", @activity_settings) writer.write_object_value("configuration", @configuration) writer.write_string_value("description", @description) writer.write_collection_of_object_values("groups", @groups) writer.write_collection_of_object_values("items", @items) writer.write_string_value("name", @name) writer.write_collection_of_object_values("operations", @operations) writer.write_object_value("schema", @schema) writer.write_object_value("searchSettings", @search_settings) end |
#state ⇒ Object
Gets the state property value. Indicates the current state of the connection. Possible values are: draft, ready, obsolete, limitExceeded, unknownFutureValue.
230 231 232 |
# File 'lib/models/external_connectors_external_connection.rb', line 230 def state return @state end |
#state=(value) ⇒ Object
Sets the state property value. Indicates the current state of the connection. Possible values are: draft, ready, obsolete, limitExceeded, unknownFutureValue.
238 239 240 |
# File 'lib/models/external_connectors_external_connection.rb', line 238 def state=(value) @state = value end |