Class: MicrosoftGraph::Models::IdentityGovernanceTriggerAndScopeBasedConditions
- Inherits:
-
IdentityGovernanceWorkflowExecutionConditions
- Object
- IdentityGovernanceWorkflowExecutionConditions
- MicrosoftGraph::Models::IdentityGovernanceTriggerAndScopeBasedConditions
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/identity_governance_trigger_and_scope_based_conditions.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new identityGovernanceTriggerAndScopeBasedConditions and sets the default values.
-
#scope ⇒ Object
Gets the scope property value.
-
#scope=(value) ⇒ Object
Sets the scope property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#trigger ⇒ Object
Gets the trigger property value.
-
#trigger=(value) ⇒ Object
Sets the trigger property value.
Methods inherited from IdentityGovernanceWorkflowExecutionConditions
#additional_data, #additional_data=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new identityGovernanceTriggerAndScopeBasedConditions and sets the default values.
19 20 21 22 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 19 def initialize() super @odata_type = "#microsoft.graph.identityGovernance.triggerAndScopeBasedConditions" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
28 29 30 31 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 28 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return IdentityGovernanceTriggerAndScopeBasedConditions.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
36 37 38 39 40 41 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 36 def get_field_deserializers() return super.merge({ "scope" => lambda {|n| @scope = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SubjectSet.create_from_discriminator_value(pn) }) }, "trigger" => lambda {|n| @trigger = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentityGovernanceWorkflowExecutionTrigger.create_from_discriminator_value(pn) }) }, }) end |
#scope ⇒ Object
Gets the scope property value. Defines who the workflow runs for.
46 47 48 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 46 def scope return @scope end |
#scope=(value) ⇒ Object
Sets the scope property value. Defines who the workflow runs for.
54 55 56 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 54 def scope=(value) @scope = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
62 63 64 65 66 67 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 62 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("scope", @scope) writer.write_object_value("trigger", @trigger) end |
#trigger ⇒ Object
Gets the trigger property value. What triggers a workflow to run.
72 73 74 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 72 def trigger return @trigger end |
#trigger=(value) ⇒ Object
Sets the trigger property value. What triggers a workflow to run.
80 81 82 |
# File 'lib/models/identity_governance_trigger_and_scope_based_conditions.rb', line 80 def trigger=(value) @trigger = value end |