Class: MicrosoftGraph::Models::IosiPadOSWebClip
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/iosi_pad_o_s_web_clip.rb
Overview
Contains properties and inherited properties for iOS web apps.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#app_url ⇒ Object
Gets the appUrl property value.
-
#app_url=(value) ⇒ Object
Sets the appUrl property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new iosiPadOSWebClip and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#use_managed_browser ⇒ Object
Gets the useManagedBrowser property value.
-
#use_managed_browser=(value) ⇒ Object
Sets the useManagedBrowser property value.
Methods inherited from MobileApp
#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new iosiPadOSWebClip and sets the default values.
36 37 38 39 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 36 def initialize() super @odata_type = "#microsoft.graph.iosiPadOSWebClip" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
45 46 47 48 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 45 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return IosiPadOSWebClip.new end |
Instance Method Details
#app_url ⇒ Object
Gets the appUrl property value. Indicates iOS/iPadOS web clip app URL. Example: ‘www.contoso.com’
21 22 23 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 21 def app_url return @app_url end |
#app_url=(value) ⇒ Object
Sets the appUrl property value. Indicates iOS/iPadOS web clip app URL. Example: ‘www.contoso.com’
29 30 31 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 29 def app_url=(value) @app_url = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
53 54 55 56 57 58 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 53 def get_field_deserializers() return super.merge({ "appUrl" => lambda {|n| @app_url = n.get_string_value() }, "useManagedBrowser" => lambda {|n| @use_managed_browser = n.get_boolean_value() }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
64 65 66 67 68 69 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 64 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("appUrl", @app_url) writer.write_boolean_value("useManagedBrowser", @use_managed_browser) end |
#use_managed_browser ⇒ Object
Gets the useManagedBrowser property value. Whether or not to use managed browser. When TRUE, the app will be required to be opened in Microsoft Edge. When FALSE, the app will not be required to be opened in Microsoft Edge. By default, this property is set to FALSE.
74 75 76 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 74 def use_managed_browser return @use_managed_browser end |
#use_managed_browser=(value) ⇒ Object
Sets the useManagedBrowser property value. Whether or not to use managed browser. When TRUE, the app will be required to be opened in Microsoft Edge. When FALSE, the app will not be required to be opened in Microsoft Edge. By default, this property is set to FALSE.
82 83 84 |
# File 'lib/models/iosi_pad_o_s_web_clip.rb', line 82 def use_managed_browser=(value) @use_managed_browser = value end |