Class: MicrosoftGraph::Models::ManagedAppDiagnosticStatus
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::ManagedAppDiagnosticStatus
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/managed_app_diagnostic_status.rb
Overview
Represents diagnostics status.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new managedAppDiagnosticStatus and sets the default values.
-
#mitigation_instruction ⇒ Object
Gets the mitigationInstruction property value.
-
#mitigation_instruction=(value) ⇒ Object
Sets the mitigationInstruction property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#state ⇒ Object
Gets the state property value.
-
#state=(value) ⇒ Object
Sets the state property value.
-
#validation_name ⇒ Object
Gets the validationName property value.
-
#validation_name=(value) ⇒ Object
Sets the validationName property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new managedAppDiagnosticStatus and sets the default values.
45 46 47 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 45 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
53 54 55 56 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 53 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ManagedAppDiagnosticStatus.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 30 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 38 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
61 62 63 64 65 66 67 68 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 61 def get_field_deserializers() return { "mitigationInstruction" => lambda {|n| @mitigation_instruction = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "state" => lambda {|n| @state = n.get_string_value() }, "validationName" => lambda {|n| @validation_name = n.get_string_value() }, } end |
#mitigation_instruction ⇒ Object
Gets the mitigationInstruction property value. Instruction on how to mitigate a failed validation
73 74 75 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 73 def mitigation_instruction return @mitigation_instruction end |
#mitigation_instruction=(value) ⇒ Object
Sets the mitigationInstruction property value. Instruction on how to mitigate a failed validation
81 82 83 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 81 def mitigation_instruction=(value) @mitigation_instruction = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
88 89 90 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 88 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
96 97 98 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 96 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
104 105 106 107 108 109 110 111 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 104 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("mitigationInstruction", @mitigation_instruction) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("state", @state) writer.write_string_value("validationName", @validation_name) writer.write_additional_data(@additional_data) end |
#state ⇒ Object
Gets the state property value. The state of the operation
116 117 118 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 116 def state return @state end |
#state=(value) ⇒ Object
Sets the state property value. The state of the operation
124 125 126 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 124 def state=(value) @state = value end |
#validation_name ⇒ Object
Gets the validationName property value. The validation friendly name
131 132 133 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 131 def validation_name return @validation_name end |
#validation_name=(value) ⇒ Object
Sets the validationName property value. The validation friendly name
139 140 141 |
# File 'lib/models/managed_app_diagnostic_status.rb', line 139 def validation_name=(value) @validation_name = value end |