Class: MicrosoftGraph::Models::MicrosoftStoreForBusinessApp
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/microsoft_store_for_business_app.rb
Overview
Microsoft Store for Business Apps. This class does not support Create, Delete, or Update.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new microsoftStoreForBusinessApp and sets the default values.
-
#license_type ⇒ Object
Gets the licenseType property value.
-
#license_type=(value) ⇒ Object
Sets the licenseType property value.
-
#package_identity_name ⇒ Object
Gets the packageIdentityName property value.
-
#package_identity_name=(value) ⇒ Object
Sets the packageIdentityName property value.
-
#product_key ⇒ Object
Gets the productKey property value.
-
#product_key=(value) ⇒ Object
Sets the productKey property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#total_license_count ⇒ Object
Gets the totalLicenseCount property value.
-
#total_license_count=(value) ⇒ Object
Sets the totalLicenseCount property value.
-
#used_license_count ⇒ Object
Gets the usedLicenseCount property value.
-
#used_license_count=(value) ⇒ Object
Sets the usedLicenseCount property value.
Methods inherited from MobileApp
#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new microsoftStoreForBusinessApp and sets the default values.
30 31 32 33 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 30 def initialize() super @odata_type = "#microsoft.graph.microsoftStoreForBusinessApp" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
39 40 41 42 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 39 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MicrosoftStoreForBusinessApp.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
47 48 49 50 51 52 53 54 55 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 47 def get_field_deserializers() return super.merge({ "licenseType" => lambda {|n| @license_type = n.get_enum_value(MicrosoftGraph::Models::MicrosoftStoreForBusinessLicenseType) }, "packageIdentityName" => lambda {|n| @package_identity_name = n.get_string_value() }, "productKey" => lambda {|n| @product_key = n.get_string_value() }, "totalLicenseCount" => lambda {|n| @total_license_count = n.get_number_value() }, "usedLicenseCount" => lambda {|n| @used_license_count = n.get_number_value() }, }) end |
#license_type ⇒ Object
Gets the licenseType property value. The licenseType property
60 61 62 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 60 def license_type return @license_type end |
#license_type=(value) ⇒ Object
Sets the licenseType property value. The licenseType property
68 69 70 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 68 def license_type=(value) @license_type = value end |
#package_identity_name ⇒ Object
Gets the packageIdentityName property value. The app package identifier
75 76 77 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 75 def package_identity_name return @package_identity_name end |
#package_identity_name=(value) ⇒ Object
Sets the packageIdentityName property value. The app package identifier
83 84 85 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 83 def package_identity_name=(value) @package_identity_name = value end |
#product_key ⇒ Object
Gets the productKey property value. The app product key
90 91 92 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 90 def product_key return @product_key end |
#product_key=(value) ⇒ Object
Sets the productKey property value. The app product key
98 99 100 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 98 def product_key=(value) @product_key = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
106 107 108 109 110 111 112 113 114 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 106 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_enum_value("licenseType", @license_type) writer.write_string_value("packageIdentityName", @package_identity_name) writer.write_string_value("productKey", @product_key) writer.write_number_value("totalLicenseCount", @total_license_count) writer.write_number_value("usedLicenseCount", @used_license_count) end |
#total_license_count ⇒ Object
Gets the totalLicenseCount property value. The total number of Microsoft Store for Business licenses.
119 120 121 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 119 def total_license_count return @total_license_count end |
#total_license_count=(value) ⇒ Object
Sets the totalLicenseCount property value. The total number of Microsoft Store for Business licenses.
127 128 129 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 127 def total_license_count=(value) @total_license_count = value end |
#used_license_count ⇒ Object
Gets the usedLicenseCount property value. The number of Microsoft Store for Business licenses in use.
134 135 136 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 134 def used_license_count return @used_license_count end |
#used_license_count=(value) ⇒ Object
Sets the usedLicenseCount property value. The number of Microsoft Store for Business licenses in use.
142 143 144 |
# File 'lib/models/microsoft_store_for_business_app.rb', line 142 def used_license_count=(value) @used_license_count = value end |