Class: MicrosoftGraph::Models::NumberColumn
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::NumberColumn
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/number_column.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#decimal_places ⇒ Object
Gets the decimalPlaces property value.
-
#decimal_places=(value) ⇒ Object
Sets the decimalPlaces property value.
-
#display_as ⇒ Object
Gets the displayAs property value.
-
#display_as=(value) ⇒ Object
Sets the displayAs property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new numberColumn and sets the default values.
-
#maximum ⇒ Object
Gets the maximum property value.
-
#maximum=(value) ⇒ Object
Sets the maximum property value.
-
#minimum ⇒ Object
Gets the minimum property value.
-
#minimum=(value) ⇒ Object
Sets the minimum property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new numberColumn and sets the default values.
46 47 48 |
# File 'lib/models/number_column.rb', line 46 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
54 55 56 57 |
# File 'lib/models/number_column.rb', line 54 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return NumberColumn.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/models/number_column.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/models/number_column.rb', line 39 def additional_data=(value) @additional_data = value end |
#decimal_places ⇒ Object
Gets the decimalPlaces property value. How many decimal places to display. See below for information about the possible values.
62 63 64 |
# File 'lib/models/number_column.rb', line 62 def decimal_places return @decimal_places end |
#decimal_places=(value) ⇒ Object
Sets the decimalPlaces property value. How many decimal places to display. See below for information about the possible values.
70 71 72 |
# File 'lib/models/number_column.rb', line 70 def decimal_places=(value) @decimal_places = value end |
#display_as ⇒ Object
Gets the displayAs property value. How the value should be presented in the UX. Must be one of number or percentage. If unspecified, treated as number.
77 78 79 |
# File 'lib/models/number_column.rb', line 77 def display_as return @display_as end |
#display_as=(value) ⇒ Object
Sets the displayAs property value. How the value should be presented in the UX. Must be one of number or percentage. If unspecified, treated as number.
85 86 87 |
# File 'lib/models/number_column.rb', line 85 def display_as=(value) @display_as = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
92 93 94 95 96 97 98 99 100 |
# File 'lib/models/number_column.rb', line 92 def get_field_deserializers() return { "decimalPlaces" => lambda {|n| @decimal_places = n.get_string_value() }, "displayAs" => lambda {|n| @display_as = n.get_string_value() }, "maximum" => lambda {|n| @maximum = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "minimum" => lambda {|n| @minimum = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, } end |
#maximum ⇒ Object
Gets the maximum property value. The maximum permitted value.
105 106 107 |
# File 'lib/models/number_column.rb', line 105 def maximum return @maximum end |
#maximum=(value) ⇒ Object
Sets the maximum property value. The maximum permitted value.
113 114 115 |
# File 'lib/models/number_column.rb', line 113 def maximum=(value) @maximum = value end |
#minimum ⇒ Object
Gets the minimum property value. The minimum permitted value.
120 121 122 |
# File 'lib/models/number_column.rb', line 120 def minimum return @minimum end |
#minimum=(value) ⇒ Object
Sets the minimum property value. The minimum permitted value.
128 129 130 |
# File 'lib/models/number_column.rb', line 128 def minimum=(value) @minimum = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
135 136 137 |
# File 'lib/models/number_column.rb', line 135 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
143 144 145 |
# File 'lib/models/number_column.rb', line 143 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
151 152 153 154 155 156 157 158 159 |
# File 'lib/models/number_column.rb', line 151 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("decimalPlaces", @decimal_places) writer.write_string_value("displayAs", @display_as) writer.write_object_value("maximum", @maximum) writer.write_object_value("minimum", @minimum) writer.write_string_value("@odata.type", @odata_type) writer.write_additional_data(@additional_data) end |