Class: MicrosoftGraph::Models::OnPremisesAccidentalDeletionPrevention
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::OnPremisesAccidentalDeletionPrevention
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/on_premises_accidental_deletion_prevention.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#alert_threshold ⇒ Object
Gets the alertThreshold property value.
-
#alert_threshold=(value) ⇒ Object
Sets the alertThreshold property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new onPremisesAccidentalDeletionPrevention and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#synchronization_prevention_type ⇒ Object
Gets the synchronizationPreventionType property value.
-
#synchronization_prevention_type=(value) ⇒ Object
Sets the synchronizationPreventionType property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new onPremisesAccidentalDeletionPrevention and sets the default values.
55 56 57 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 55 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
63 64 65 66 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 63 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return OnPremisesAccidentalDeletionPrevention.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 33 def additional_data=(value) @additional_data = value end |
#alert_threshold ⇒ Object
Gets the alertThreshold property value. Threshold value which triggers accidental deletion prevention. The threshold is either an absolute number of objects or a percentage number of objects.
40 41 42 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 40 def alert_threshold return @alert_threshold end |
#alert_threshold=(value) ⇒ Object
Sets the alertThreshold property value. Threshold value which triggers accidental deletion prevention. The threshold is either an absolute number of objects or a percentage number of objects.
48 49 50 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 48 def alert_threshold=(value) @alert_threshold = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
71 72 73 74 75 76 77 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 71 def get_field_deserializers() return { "alertThreshold" => lambda {|n| @alert_threshold = n.get_number_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "synchronizationPreventionType" => lambda {|n| @synchronization_prevention_type = n.get_enum_value(MicrosoftGraph::Models::OnPremisesDirectorySynchronizationDeletionPreventionType) }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
82 83 84 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 82 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
90 91 92 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 90 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
98 99 100 101 102 103 104 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 98 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("alertThreshold", @alert_threshold) writer.write_string_value("@odata.type", @odata_type) writer.write_enum_value("synchronizationPreventionType", @synchronization_prevention_type) writer.write_additional_data(@additional_data) end |
#synchronization_prevention_type ⇒ Object
Gets the synchronizationPreventionType property value. The status of the accidental deletion prevention feature. The possible values are: disabled, enabledForCount, enabledForPercentage, unknownFutureValue.
109 110 111 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 109 def synchronization_prevention_type return @synchronization_prevention_type end |
#synchronization_prevention_type=(value) ⇒ Object
Sets the synchronizationPreventionType property value. The status of the accidental deletion prevention feature. The possible values are: disabled, enabledForCount, enabledForPercentage, unknownFutureValue.
117 118 119 |
# File 'lib/models/on_premises_accidental_deletion_prevention.rb', line 117 def synchronization_prevention_type=(value) @synchronization_prevention_type = value end |