Class: MicrosoftGraph::Models::OnPremisesConditionalAccessSettings
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/on_premises_conditional_access_settings.rb
Overview
Singleton entity which represents the Exchange OnPremises Conditional Access Settings for a tenant.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#enabled ⇒ Object
Gets the enabled property value.
-
#enabled=(value) ⇒ Object
Sets the enabled property value.
-
#excluded_groups ⇒ Object
Gets the excludedGroups property value.
-
#excluded_groups=(value) ⇒ Object
Sets the excludedGroups property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#included_groups ⇒ Object
Gets the includedGroups property value.
-
#included_groups=(value) ⇒ Object
Sets the includedGroups property value.
-
#initialize ⇒ Object
constructor
Instantiates a new onPremisesConditionalAccessSettings and sets the default values.
-
#override_default_rule ⇒ Object
Gets the overrideDefaultRule property value.
-
#override_default_rule=(value) ⇒ Object
Sets the overrideDefaultRule property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new onPremisesConditionalAccessSettings and sets the default values.
27 28 29 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 27 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
35 36 37 38 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 35 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return OnPremisesConditionalAccessSettings.new end |
Instance Method Details
#enabled ⇒ Object
Gets the enabled property value. Indicates if on premises conditional access is enabled for this organization
43 44 45 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 43 def enabled return @enabled end |
#enabled=(value) ⇒ Object
Sets the enabled property value. Indicates if on premises conditional access is enabled for this organization
51 52 53 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 51 def enabled=(value) @enabled = value end |
#excluded_groups ⇒ Object
Gets the excludedGroups property value. User groups that will be exempt by on premises conditional access. All users in these groups will be exempt from the conditional access policy.
58 59 60 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 58 def excluded_groups return @excluded_groups end |
#excluded_groups=(value) ⇒ Object
Sets the excludedGroups property value. User groups that will be exempt by on premises conditional access. All users in these groups will be exempt from the conditional access policy.
66 67 68 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 66 def excluded_groups=(value) @excluded_groups = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
73 74 75 76 77 78 79 80 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 73 def get_field_deserializers() return super.merge({ "enabled" => lambda {|n| @enabled = n.get_boolean_value() }, "excludedGroups" => lambda {|n| @excluded_groups = n.get_collection_of_primitive_values(UUIDTools::UUID) }, "includedGroups" => lambda {|n| @included_groups = n.get_collection_of_primitive_values(UUIDTools::UUID) }, "overrideDefaultRule" => lambda {|n| @override_default_rule = n.get_boolean_value() }, }) end |
#included_groups ⇒ Object
Gets the includedGroups property value. User groups that will be targeted by on premises conditional access. All users in these groups will be required to have mobile device managed and compliant for mail access.
85 86 87 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 85 def included_groups return @included_groups end |
#included_groups=(value) ⇒ Object
Sets the includedGroups property value. User groups that will be targeted by on premises conditional access. All users in these groups will be required to have mobile device managed and compliant for mail access.
93 94 95 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 93 def included_groups=(value) @included_groups = value end |
#override_default_rule ⇒ Object
Gets the overrideDefaultRule property value. Override the default access rule when allowing a device to ensure access is granted.
100 101 102 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 100 def override_default_rule return @override_default_rule end |
#override_default_rule=(value) ⇒ Object
Sets the overrideDefaultRule property value. Override the default access rule when allowing a device to ensure access is granted.
108 109 110 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 108 def override_default_rule=(value) @override_default_rule = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
116 117 118 119 120 121 122 123 |
# File 'lib/models/on_premises_conditional_access_settings.rb', line 116 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_boolean_value("enabled", @enabled) writer.write_collection_of_primitive_values("excludedGroups", @excluded_groups) writer.write_collection_of_primitive_values("includedGroups", @included_groups) writer.write_boolean_value("overrideDefaultRule", @override_default_rule) end |