Class: MicrosoftGraph::Models::OnenotePage
- Inherits:
-
OnenoteEntitySchemaObjectModel
- Object
- Entity
- OnenoteEntityBaseModel
- OnenoteEntitySchemaObjectModel
- MicrosoftGraph::Models::OnenotePage
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/onenote_page.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#content ⇒ Object
Gets the content property value.
-
#content=(value) ⇒ Object
Sets the content property value.
-
#content_url ⇒ Object
Gets the contentUrl property value.
-
#content_url=(value) ⇒ Object
Sets the contentUrl property value.
-
#created_by_app_id ⇒ Object
Gets the createdByAppId property value.
-
#created_by_app_id=(value) ⇒ Object
Sets the createdByAppId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new onenotePage and sets the default values.
-
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value.
-
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value.
-
#level ⇒ Object
Gets the level property value.
-
#level=(value) ⇒ Object
Sets the level property value.
-
#links ⇒ Object
Gets the links property value.
-
#links=(value) ⇒ Object
Sets the links property value.
-
#order ⇒ Object
Gets the order property value.
-
#order=(value) ⇒ Object
Sets the order property value.
-
#parent_notebook ⇒ Object
Gets the parentNotebook property value.
-
#parent_notebook=(value) ⇒ Object
Sets the parentNotebook property value.
-
#parent_section ⇒ Object
Gets the parentSection property value.
-
#parent_section=(value) ⇒ Object
Sets the parentSection property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#title ⇒ Object
Gets the title property value.
-
#title=(value) ⇒ Object
Sets the title property value.
-
#user_tags ⇒ Object
Gets the userTags property value.
-
#user_tags=(value) ⇒ Object
Sets the userTags property value.
Methods inherited from OnenoteEntitySchemaObjectModel
#created_date_time, #created_date_time=
Methods inherited from OnenoteEntityBaseModel
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new onenotePage and sets the default values.
47 48 49 50 |
# File 'lib/models/onenote_page.rb', line 47 def initialize() super @odata_type = "#microsoft.graph.onenotePage" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
101 102 103 104 |
# File 'lib/models/onenote_page.rb', line 101 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return OnenotePage.new end |
Instance Method Details
#content ⇒ Object
Gets the content property value. The page’s HTML content.
55 56 57 |
# File 'lib/models/onenote_page.rb', line 55 def content return @content end |
#content=(value) ⇒ Object
Sets the content property value. The page’s HTML content.
63 64 65 |
# File 'lib/models/onenote_page.rb', line 63 def content=(value) @content = value end |
#content_url ⇒ Object
Gets the contentUrl property value. The URL for the page’s HTML content. Read-only.
70 71 72 |
# File 'lib/models/onenote_page.rb', line 70 def content_url return @content_url end |
#content_url=(value) ⇒ Object
Sets the contentUrl property value. The URL for the page’s HTML content. Read-only.
78 79 80 |
# File 'lib/models/onenote_page.rb', line 78 def content_url=(value) @content_url = value end |
#created_by_app_id ⇒ Object
Gets the createdByAppId property value. The unique identifier of the application that created the page. Read-only.
85 86 87 |
# File 'lib/models/onenote_page.rb', line 85 def created_by_app_id return @created_by_app_id end |
#created_by_app_id=(value) ⇒ Object
Sets the createdByAppId property value. The unique identifier of the application that created the page. Read-only.
93 94 95 |
# File 'lib/models/onenote_page.rb', line 93 def created_by_app_id=(value) @created_by_app_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/models/onenote_page.rb', line 109 def get_field_deserializers() return super.merge({ "content" => lambda {|n| @content = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) }, "contentUrl" => lambda {|n| @content_url = n.get_string_value() }, "createdByAppId" => lambda {|n| @created_by_app_id = n.get_string_value() }, "lastModifiedDateTime" => lambda {|n| @last_modified_date_time = n.get_date_time_value() }, "level" => lambda {|n| @level = n.get_number_value() }, "links" => lambda {|n| @links = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::PageLinks.create_from_discriminator_value(pn) }) }, "order" => lambda {|n| @order = n.get_number_value() }, "parentNotebook" => lambda {|n| @parent_notebook = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Notebook.create_from_discriminator_value(pn) }) }, "parentSection" => lambda {|n| @parent_section = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::OnenoteSection.create_from_discriminator_value(pn) }) }, "title" => lambda {|n| @title = n.get_string_value() }, "userTags" => lambda {|n| = n.get_collection_of_primitive_values(String) }, }) end |
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value. The date and time when the page was last modified. The timestamp represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
128 129 130 |
# File 'lib/models/onenote_page.rb', line 128 def last_modified_date_time return @last_modified_date_time end |
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value. The date and time when the page was last modified. The timestamp represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
136 137 138 |
# File 'lib/models/onenote_page.rb', line 136 def last_modified_date_time=(value) @last_modified_date_time = value end |
#level ⇒ Object
Gets the level property value. The indentation level of the page. Read-only.
143 144 145 |
# File 'lib/models/onenote_page.rb', line 143 def level return @level end |
#level=(value) ⇒ Object
Sets the level property value. The indentation level of the page. Read-only.
151 152 153 |
# File 'lib/models/onenote_page.rb', line 151 def level=(value) @level = value end |
#links ⇒ Object
Gets the links property value. Links for opening the page. The oneNoteClientURL link opens the page in the OneNote native client if it ‘s installed. The oneNoteWebUrl link opens the page in OneNote on the web. Read-only.
158 159 160 |
# File 'lib/models/onenote_page.rb', line 158 def links return @links end |
#links=(value) ⇒ Object
Sets the links property value. Links for opening the page. The oneNoteClientURL link opens the page in the OneNote native client if it ‘s installed. The oneNoteWebUrl link opens the page in OneNote on the web. Read-only.
166 167 168 |
# File 'lib/models/onenote_page.rb', line 166 def links=(value) @links = value end |
#order ⇒ Object
Gets the order property value. The order of the page within its parent section. Read-only.
173 174 175 |
# File 'lib/models/onenote_page.rb', line 173 def order return @order end |
#order=(value) ⇒ Object
Sets the order property value. The order of the page within its parent section. Read-only.
181 182 183 |
# File 'lib/models/onenote_page.rb', line 181 def order=(value) @order = value end |
#parent_notebook ⇒ Object
Gets the parentNotebook property value. The notebook that contains the page. Read-only.
188 189 190 |
# File 'lib/models/onenote_page.rb', line 188 def parent_notebook return @parent_notebook end |
#parent_notebook=(value) ⇒ Object
Sets the parentNotebook property value. The notebook that contains the page. Read-only.
196 197 198 |
# File 'lib/models/onenote_page.rb', line 196 def parent_notebook=(value) @parent_notebook = value end |
#parent_section ⇒ Object
Gets the parentSection property value. The section that contains the page. Read-only.
203 204 205 |
# File 'lib/models/onenote_page.rb', line 203 def parent_section return @parent_section end |
#parent_section=(value) ⇒ Object
Sets the parentSection property value. The section that contains the page. Read-only.
211 212 213 |
# File 'lib/models/onenote_page.rb', line 211 def parent_section=(value) @parent_section = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/models/onenote_page.rb', line 219 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("content", @content) writer.write_string_value("contentUrl", @content_url) writer.write_string_value("createdByAppId", @created_by_app_id) writer.write_date_time_value("lastModifiedDateTime", @last_modified_date_time) writer.write_number_value("level", @level) writer.write_object_value("links", @links) writer.write_number_value("order", @order) writer.write_object_value("parentNotebook", @parent_notebook) writer.write_object_value("parentSection", @parent_section) writer.write_string_value("title", @title) writer.write_collection_of_primitive_values("userTags", ) end |
#title ⇒ Object
Gets the title property value. The title of the page.
238 239 240 |
# File 'lib/models/onenote_page.rb', line 238 def title return @title end |
#title=(value) ⇒ Object
Sets the title property value. The title of the page.
246 247 248 |
# File 'lib/models/onenote_page.rb', line 246 def title=(value) @title = value end |
#user_tags ⇒ Object
Gets the userTags property value. The userTags property
253 254 255 |
# File 'lib/models/onenote_page.rb', line 253 def return end |
#user_tags=(value) ⇒ Object
Sets the userTags property value. The userTags property
261 262 263 |
# File 'lib/models/onenote_page.rb', line 261 def (value) = value end |