Class: MicrosoftGraph::Models::OutlookCategory
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/outlook_category.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#color ⇒ Object
Gets the color property value.
-
#color=(value) ⇒ Object
Sets the color property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new outlookCategory and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new outlookCategory and sets the default values.
34 35 36 |
# File 'lib/models/outlook_category.rb', line 34 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
42 43 44 45 |
# File 'lib/models/outlook_category.rb', line 42 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return OutlookCategory.new end |
Instance Method Details
#color ⇒ Object
Gets the color property value. A pre-set color constant that characterizes a category, and that is mapped to one of 25 predefined colors. For more details, see the following note.
19 20 21 |
# File 'lib/models/outlook_category.rb', line 19 def color return @color end |
#color=(value) ⇒ Object
Sets the color property value. A pre-set color constant that characterizes a category, and that is mapped to one of 25 predefined colors. For more details, see the following note.
27 28 29 |
# File 'lib/models/outlook_category.rb', line 27 def color=(value) @color = value end |
#display_name ⇒ Object
Gets the displayName property value. A unique name that identifies a category in the user’s mailbox. After a category is created, the name cannot be changed. Read-only.
50 51 52 |
# File 'lib/models/outlook_category.rb', line 50 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. A unique name that identifies a category in the user’s mailbox. After a category is created, the name cannot be changed. Read-only.
58 59 60 |
# File 'lib/models/outlook_category.rb', line 58 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
65 66 67 68 69 70 |
# File 'lib/models/outlook_category.rb', line 65 def get_field_deserializers() return super.merge({ "color" => lambda {|n| @color = n.get_enum_value(MicrosoftGraph::Models::CategoryColor) }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
76 77 78 79 80 81 |
# File 'lib/models/outlook_category.rb', line 76 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_enum_value("color", @color) writer.write_string_value("displayName", @display_name) end |