Class: MicrosoftGraph::Models::PermissionGrantConditionSet
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/permission_grant_condition_set.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#client_application_ids ⇒ Object
Gets the clientApplicationIds property value.
-
#client_application_ids=(value) ⇒ Object
Sets the clientApplicationIds property value.
-
#client_application_publisher_ids ⇒ Object
Gets the clientApplicationPublisherIds property value.
-
#client_application_publisher_ids=(value) ⇒ Object
Sets the clientApplicationPublisherIds property value.
-
#client_application_tenant_ids ⇒ Object
Gets the clientApplicationTenantIds property value.
-
#client_application_tenant_ids=(value) ⇒ Object
Sets the clientApplicationTenantIds property value.
-
#client_applications_from_verified_publisher_only ⇒ Object
Gets the clientApplicationsFromVerifiedPublisherOnly property value.
-
#client_applications_from_verified_publisher_only=(value) ⇒ Object
Sets the clientApplicationsFromVerifiedPublisherOnly property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new permissionGrantConditionSet and sets the default values.
-
#permission_classification ⇒ Object
Gets the permissionClassification property value.
-
#permission_classification=(value) ⇒ Object
Sets the permissionClassification property value.
-
#permission_type ⇒ Object
Gets the permissionType property value.
-
#permission_type=(value) ⇒ Object
Sets the permissionType property value.
-
#permissions ⇒ Object
Gets the permissions property value.
-
#permissions=(value) ⇒ Object
Sets the permissions property value.
-
#resource_application ⇒ Object
Gets the resourceApplication property value.
-
#resource_application=(value) ⇒ Object
Sets the resourceApplication property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new permissionGrantConditionSet and sets the default values.
97 98 99 |
# File 'lib/models/permission_grant_condition_set.rb', line 97 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
105 106 107 108 |
# File 'lib/models/permission_grant_condition_set.rb', line 105 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return PermissionGrantConditionSet.new end |
Instance Method Details
#client_application_ids ⇒ Object
Gets the clientApplicationIds property value. A list of appId values for the client applications to match with, or a list with the single value all to match any client application. Default is the single value all.
37 38 39 |
# File 'lib/models/permission_grant_condition_set.rb', line 37 def client_application_ids return @client_application_ids end |
#client_application_ids=(value) ⇒ Object
Sets the clientApplicationIds property value. A list of appId values for the client applications to match with, or a list with the single value all to match any client application. Default is the single value all.
45 46 47 |
# File 'lib/models/permission_grant_condition_set.rb', line 45 def client_application_ids=(value) @client_application_ids = value end |
#client_application_publisher_ids ⇒ Object
Gets the clientApplicationPublisherIds property value. A list of Microsoft Partner Network (MPN) IDs for verified publishers of the client application, or a list with the single value all to match with client apps from any publisher. Default is the single value all.
52 53 54 |
# File 'lib/models/permission_grant_condition_set.rb', line 52 def client_application_publisher_ids return @client_application_publisher_ids end |
#client_application_publisher_ids=(value) ⇒ Object
Sets the clientApplicationPublisherIds property value. A list of Microsoft Partner Network (MPN) IDs for verified publishers of the client application, or a list with the single value all to match with client apps from any publisher. Default is the single value all.
60 61 62 |
# File 'lib/models/permission_grant_condition_set.rb', line 60 def client_application_publisher_ids=(value) @client_application_publisher_ids = value end |
#client_application_tenant_ids ⇒ Object
Gets the clientApplicationTenantIds property value. A list of Azure Active Directory tenant IDs in which the client application is registered, or a list with the single value all to match with client apps registered in any tenant. Default is the single value all.
67 68 69 |
# File 'lib/models/permission_grant_condition_set.rb', line 67 def client_application_tenant_ids return @client_application_tenant_ids end |
#client_application_tenant_ids=(value) ⇒ Object
Sets the clientApplicationTenantIds property value. A list of Azure Active Directory tenant IDs in which the client application is registered, or a list with the single value all to match with client apps registered in any tenant. Default is the single value all.
75 76 77 |
# File 'lib/models/permission_grant_condition_set.rb', line 75 def client_application_tenant_ids=(value) @client_application_tenant_ids = value end |
#client_applications_from_verified_publisher_only ⇒ Object
Gets the clientApplicationsFromVerifiedPublisherOnly property value. Set to true to only match on client applications with a verified publisher. Set to false to match on any client app, even if it does not have a verified publisher. Default is false.
82 83 84 |
# File 'lib/models/permission_grant_condition_set.rb', line 82 def client_applications_from_verified_publisher_only return @client_applications_from_verified_publisher_only end |
#client_applications_from_verified_publisher_only=(value) ⇒ Object
Sets the clientApplicationsFromVerifiedPublisherOnly property value. Set to true to only match on client applications with a verified publisher. Set to false to match on any client app, even if it does not have a verified publisher. Default is false.
90 91 92 |
# File 'lib/models/permission_grant_condition_set.rb', line 90 def client_applications_from_verified_publisher_only=(value) @client_applications_from_verified_publisher_only = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/models/permission_grant_condition_set.rb', line 113 def get_field_deserializers() return super.merge({ "clientApplicationIds" => lambda {|n| @client_application_ids = n.get_collection_of_primitive_values(String) }, "clientApplicationPublisherIds" => lambda {|n| @client_application_publisher_ids = n.get_collection_of_primitive_values(String) }, "clientApplicationTenantIds" => lambda {|n| @client_application_tenant_ids = n.get_collection_of_primitive_values(String) }, "clientApplicationsFromVerifiedPublisherOnly" => lambda {|n| @client_applications_from_verified_publisher_only = n.get_boolean_value() }, "permissionClassification" => lambda {|n| = n.get_string_value() }, "permissionType" => lambda {|n| = n.get_enum_value(MicrosoftGraph::Models::PermissionType) }, "permissions" => lambda {|n| = n.get_collection_of_primitive_values(String) }, "resourceApplication" => lambda {|n| @resource_application = n.get_string_value() }, }) end |
#permission_classification ⇒ Object
Gets the permissionClassification property value. The permission classification for the permission being granted, or all to match with any permission classification (including permissions which are not classified). Default is all.
129 130 131 |
# File 'lib/models/permission_grant_condition_set.rb', line 129 def return end |
#permission_classification=(value) ⇒ Object
Sets the permissionClassification property value. The permission classification for the permission being granted, or all to match with any permission classification (including permissions which are not classified). Default is all.
137 138 139 |
# File 'lib/models/permission_grant_condition_set.rb', line 137 def (value) = value end |
#permission_type ⇒ Object
Gets the permissionType property value. The permission type of the permission being granted. Possible values: application for application permissions (e.g. app roles), or delegated for delegated permissions. The value delegatedUserConsentable indicates delegated permissions which have not been configured by the API publisher to require admin consent—this value may be used in built-in permission grant policies, but cannot be used in custom permission grant policies. Required.
144 145 146 |
# File 'lib/models/permission_grant_condition_set.rb', line 144 def return end |
#permission_type=(value) ⇒ Object
Sets the permissionType property value. The permission type of the permission being granted. Possible values: application for application permissions (e.g. app roles), or delegated for delegated permissions. The value delegatedUserConsentable indicates delegated permissions which have not been configured by the API publisher to require admin consent—this value may be used in built-in permission grant policies, but cannot be used in custom permission grant policies. Required.
152 153 154 |
# File 'lib/models/permission_grant_condition_set.rb', line 152 def (value) = value end |
#permissions ⇒ Object
Gets the permissions property value. The list of id values for the specific permissions to match with, or a list with the single value all to match with any permission. The id of delegated permissions can be found in the oauth2PermissionScopes property of the API’s servicePrincipal object. The id of application permissions can be found in the appRoles property of the API’s servicePrincipal object. The id of resource-specific application permissions can be found in the resourceSpecificApplicationPermissions property of the API’s servicePrincipal object. Default is the single value all.
159 160 161 |
# File 'lib/models/permission_grant_condition_set.rb', line 159 def return end |
#permissions=(value) ⇒ Object
Sets the permissions property value. The list of id values for the specific permissions to match with, or a list with the single value all to match with any permission. The id of delegated permissions can be found in the oauth2PermissionScopes property of the API’s servicePrincipal object. The id of application permissions can be found in the appRoles property of the API’s servicePrincipal object. The id of resource-specific application permissions can be found in the resourceSpecificApplicationPermissions property of the API’s servicePrincipal object. Default is the single value all.
167 168 169 |
# File 'lib/models/permission_grant_condition_set.rb', line 167 def (value) = value end |
#resource_application ⇒ Object
Gets the resourceApplication property value. The appId of the resource application (e.g. the API) for which a permission is being granted, or any to match with any resource application or API. Default is any.
174 175 176 |
# File 'lib/models/permission_grant_condition_set.rb', line 174 def resource_application return @resource_application end |
#resource_application=(value) ⇒ Object
Sets the resourceApplication property value. The appId of the resource application (e.g. the API) for which a permission is being granted, or any to match with any resource application or API. Default is any.
182 183 184 |
# File 'lib/models/permission_grant_condition_set.rb', line 182 def resource_application=(value) @resource_application = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/models/permission_grant_condition_set.rb', line 190 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_collection_of_primitive_values("clientApplicationIds", @client_application_ids) writer.write_collection_of_primitive_values("clientApplicationPublisherIds", @client_application_publisher_ids) writer.write_collection_of_primitive_values("clientApplicationTenantIds", @client_application_tenant_ids) writer.write_boolean_value("clientApplicationsFromVerifiedPublisherOnly", @client_applications_from_verified_publisher_only) writer.write_string_value("permissionClassification", ) writer.write_enum_value("permissionType", ) writer.write_collection_of_primitive_values("permissions", ) writer.write_string_value("resourceApplication", @resource_application) end |