Class: MicrosoftGraph::Models::PermissionScope
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::PermissionScope
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/permission_scope.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#admin_consent_description ⇒ Object
Gets the adminConsentDescription property value.
-
#admin_consent_description=(value) ⇒ Object
Sets the adminConsentDescription property value.
-
#admin_consent_display_name ⇒ Object
Gets the adminConsentDisplayName property value.
-
#admin_consent_display_name=(value) ⇒ Object
Sets the adminConsentDisplayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new permissionScope and sets the default values.
-
#is_enabled ⇒ Object
Gets the isEnabled property value.
-
#is_enabled=(value) ⇒ Object
Sets the isEnabled property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#origin ⇒ Object
Gets the origin property value.
-
#origin=(value) ⇒ Object
Sets the origin property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#type ⇒ Object
Gets the type property value.
-
#type=(value) ⇒ Object
Sets the type property value.
-
#user_consent_description ⇒ Object
Gets the userConsentDescription property value.
-
#user_consent_description=(value) ⇒ Object
Sets the userConsentDescription property value.
-
#user_consent_display_name ⇒ Object
Gets the userConsentDisplayName property value.
-
#user_consent_display_name=(value) ⇒ Object
Sets the userConsentDisplayName property value.
-
#value ⇒ Object
Gets the value property value.
-
#value=(value) ⇒ Object
Sets the value property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new permissionScope and sets the default values.
91 92 93 |
# File 'lib/models/permission_scope.rb', line 91 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
99 100 101 102 |
# File 'lib/models/permission_scope.rb', line 99 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return PermissionScope.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
46 47 48 |
# File 'lib/models/permission_scope.rb', line 46 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
54 55 56 |
# File 'lib/models/permission_scope.rb', line 54 def additional_data=(value) @additional_data = value end |
#admin_consent_description ⇒ Object
Gets the adminConsentDescription property value. A description of the delegated permissions, intended to be read by an administrator granting the permission on behalf of all users. This text appears in tenant-wide admin consent experiences.
61 62 63 |
# File 'lib/models/permission_scope.rb', line 61 def return end |
#admin_consent_description=(value) ⇒ Object
Sets the adminConsentDescription property value. A description of the delegated permissions, intended to be read by an administrator granting the permission on behalf of all users. This text appears in tenant-wide admin consent experiences.
69 70 71 |
# File 'lib/models/permission_scope.rb', line 69 def (value) = value end |
#admin_consent_display_name ⇒ Object
Gets the adminConsentDisplayName property value. The permission’s title, intended to be read by an administrator granting the permission on behalf of all users.
76 77 78 |
# File 'lib/models/permission_scope.rb', line 76 def return end |
#admin_consent_display_name=(value) ⇒ Object
Sets the adminConsentDisplayName property value. The permission’s title, intended to be read by an administrator granting the permission on behalf of all users.
84 85 86 |
# File 'lib/models/permission_scope.rb', line 84 def (value) = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/models/permission_scope.rb', line 107 def get_field_deserializers() return { "adminConsentDescription" => lambda {|n| = n.get_string_value() }, "adminConsentDisplayName" => lambda {|n| = n.get_string_value() }, "id" => lambda {|n| @id = n.get_guid_value() }, "isEnabled" => lambda {|n| @is_enabled = n.get_boolean_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "origin" => lambda {|n| @origin = n.get_string_value() }, "type" => lambda {|n| @type = n.get_string_value() }, "userConsentDescription" => lambda {|n| = n.get_string_value() }, "userConsentDisplayName" => lambda {|n| = n.get_string_value() }, "value" => lambda {|n| @value = n.get_string_value() }, } end |
#id ⇒ Object
Gets the id property value. Unique delegated permission identifier inside the collection of delegated permissions defined for a resource application.
125 126 127 |
# File 'lib/models/permission_scope.rb', line 125 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. Unique delegated permission identifier inside the collection of delegated permissions defined for a resource application.
133 134 135 |
# File 'lib/models/permission_scope.rb', line 133 def id=(value) @id = value end |
#is_enabled ⇒ Object
Gets the isEnabled property value. When creating or updating a permission, this property must be set to true (which is the default). To delete a permission, this property must first be set to false. At that point, in a subsequent call, the permission may be removed.
140 141 142 |
# File 'lib/models/permission_scope.rb', line 140 def is_enabled return @is_enabled end |
#is_enabled=(value) ⇒ Object
Sets the isEnabled property value. When creating or updating a permission, this property must be set to true (which is the default). To delete a permission, this property must first be set to false. At that point, in a subsequent call, the permission may be removed.
148 149 150 |
# File 'lib/models/permission_scope.rb', line 148 def is_enabled=(value) @is_enabled = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
155 156 157 |
# File 'lib/models/permission_scope.rb', line 155 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
163 164 165 |
# File 'lib/models/permission_scope.rb', line 163 def odata_type=(value) @odata_type = value end |
#origin ⇒ Object
Gets the origin property value. The origin property
170 171 172 |
# File 'lib/models/permission_scope.rb', line 170 def origin return @origin end |
#origin=(value) ⇒ Object
Sets the origin property value. The origin property
178 179 180 |
# File 'lib/models/permission_scope.rb', line 178 def origin=(value) @origin = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/models/permission_scope.rb', line 186 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("adminConsentDescription", ) writer.write_string_value("adminConsentDisplayName", ) writer.write_guid_value("id", @id) writer.write_boolean_value("isEnabled", @is_enabled) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("origin", @origin) writer.write_string_value("type", @type) writer.write_string_value("userConsentDescription", ) writer.write_string_value("userConsentDisplayName", ) writer.write_string_value("value", @value) writer.write_additional_data(@additional_data) end |
#type ⇒ Object
Gets the type property value. The possible values are: User and Admin. Specifies whether this delegated permission should be considered safe for non-admin users to consent to on behalf of themselves, or whether an administrator consent should always be required. While Microsoft Graph defines the default consent requirement for each permission, the tenant administrator may override the behavior in their organization (by allowing, restricting, or limiting user consent to this delegated permission). For more information, see Configure how users consent to applications.
204 205 206 |
# File 'lib/models/permission_scope.rb', line 204 def type return @type end |
#type=(value) ⇒ Object
Sets the type property value. The possible values are: User and Admin. Specifies whether this delegated permission should be considered safe for non-admin users to consent to on behalf of themselves, or whether an administrator consent should always be required. While Microsoft Graph defines the default consent requirement for each permission, the tenant administrator may override the behavior in their organization (by allowing, restricting, or limiting user consent to this delegated permission). For more information, see Configure how users consent to applications.
212 213 214 |
# File 'lib/models/permission_scope.rb', line 212 def type=(value) @type = value end |
#user_consent_description ⇒ Object
Gets the userConsentDescription property value. A description of the delegated permissions, intended to be read by a user granting the permission on their own behalf. This text appears in consent experiences where the user is consenting only on behalf of themselves.
219 220 221 |
# File 'lib/models/permission_scope.rb', line 219 def return end |
#user_consent_description=(value) ⇒ Object
Sets the userConsentDescription property value. A description of the delegated permissions, intended to be read by a user granting the permission on their own behalf. This text appears in consent experiences where the user is consenting only on behalf of themselves.
227 228 229 |
# File 'lib/models/permission_scope.rb', line 227 def (value) = value end |
#user_consent_display_name ⇒ Object
Gets the userConsentDisplayName property value. A title for the permission, intended to be read by a user granting the permission on their own behalf. This text appears in consent experiences where the user is consenting only on behalf of themselves.
234 235 236 |
# File 'lib/models/permission_scope.rb', line 234 def return end |
#user_consent_display_name=(value) ⇒ Object
Sets the userConsentDisplayName property value. A title for the permission, intended to be read by a user granting the permission on their own behalf. This text appears in consent experiences where the user is consenting only on behalf of themselves.
242 243 244 |
# File 'lib/models/permission_scope.rb', line 242 def (value) = value end |
#value ⇒ Object
Gets the value property value. Specifies the value to include in the scp (scope) claim in access tokens. Must not exceed 120 characters in length. Allowed characters are : ! # $ % & ‘ ( ) * + , - . / : ; = ? @ [ ] ^ + _ { } ~, as well as characters in the ranges 0-9, A-Z and a-z. Any other character, including the space character, are not allowed. May not begin with ..
249 250 251 |
# File 'lib/models/permission_scope.rb', line 249 def value return @value end |
#value=(value) ⇒ Object
Sets the value property value. Specifies the value to include in the scp (scope) claim in access tokens. Must not exceed 120 characters in length. Allowed characters are : ! # $ % & ‘ ( ) * + , - . / : ; = ? @ [ ] ^ + _ { } ~, as well as characters in the ranges 0-9, A-Z and a-z. Any other character, including the space character, are not allowed. May not begin with ..
257 258 259 |
# File 'lib/models/permission_scope.rb', line 257 def value=(value) @value = value end |