Class: MicrosoftGraph::Models::Pkcs12CertificateInformation
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::Pkcs12CertificateInformation
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/pkcs12_certificate_information.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new pkcs12CertificateInformation and sets the default values.
-
#is_active ⇒ Object
Gets the isActive property value.
-
#is_active=(value) ⇒ Object
Sets the isActive property value.
-
#not_after ⇒ Object
Gets the notAfter property value.
-
#not_after=(value) ⇒ Object
Sets the notAfter property value.
-
#not_before ⇒ Object
Gets the notBefore property value.
-
#not_before=(value) ⇒ Object
Sets the notBefore property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#thumbprint ⇒ Object
Gets the thumbprint property value.
-
#thumbprint=(value) ⇒ Object
Sets the thumbprint property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new pkcs12CertificateInformation and sets the default values.
46 47 48 |
# File 'lib/models/pkcs12_certificate_information.rb', line 46 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
54 55 56 57 |
# File 'lib/models/pkcs12_certificate_information.rb', line 54 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Pkcs12CertificateInformation.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/models/pkcs12_certificate_information.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/models/pkcs12_certificate_information.rb', line 39 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
62 63 64 65 66 67 68 69 70 |
# File 'lib/models/pkcs12_certificate_information.rb', line 62 def get_field_deserializers() return { "isActive" => lambda {|n| @is_active = n.get_boolean_value() }, "notAfter" => lambda {|n| @not_after = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) }, "notBefore" => lambda {|n| @not_before = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "thumbprint" => lambda {|n| @thumbprint = n.get_string_value() }, } end |
#is_active ⇒ Object
Gets the isActive property value. Represents whether the certificate is the active certificate to be used for calling the API connector. The active certificate is the most recently uploaded certificate which is not yet expired but whose notBefore time is in the past.
75 76 77 |
# File 'lib/models/pkcs12_certificate_information.rb', line 75 def is_active return @is_active end |
#is_active=(value) ⇒ Object
Sets the isActive property value. Represents whether the certificate is the active certificate to be used for calling the API connector. The active certificate is the most recently uploaded certificate which is not yet expired but whose notBefore time is in the past.
83 84 85 |
# File 'lib/models/pkcs12_certificate_information.rb', line 83 def is_active=(value) @is_active = value end |
#not_after ⇒ Object
Gets the notAfter property value. The certificate’s expiry. This value is a NumericDate as defined in RFC 7519 (A JSON numeric value representing the number of seconds from 1970-01-01T00:00:00Z UTC until the specified UTC date/time, ignoring leap seconds.)
90 91 92 |
# File 'lib/models/pkcs12_certificate_information.rb', line 90 def not_after return @not_after end |
#not_after=(value) ⇒ Object
Sets the notAfter property value. The certificate’s expiry. This value is a NumericDate as defined in RFC 7519 (A JSON numeric value representing the number of seconds from 1970-01-01T00:00:00Z UTC until the specified UTC date/time, ignoring leap seconds.)
98 99 100 |
# File 'lib/models/pkcs12_certificate_information.rb', line 98 def not_after=(value) @not_after = value end |
#not_before ⇒ Object
Gets the notBefore property value. The certificate’s issue time (not before). This value is a NumericDate as defined in RFC 7519 (A JSON numeric value representing the number of seconds from 1970-01-01T00:00:00Z UTC until the specified UTC date/time, ignoring leap seconds.)
105 106 107 |
# File 'lib/models/pkcs12_certificate_information.rb', line 105 def not_before return @not_before end |
#not_before=(value) ⇒ Object
Sets the notBefore property value. The certificate’s issue time (not before). This value is a NumericDate as defined in RFC 7519 (A JSON numeric value representing the number of seconds from 1970-01-01T00:00:00Z UTC until the specified UTC date/time, ignoring leap seconds.)
113 114 115 |
# File 'lib/models/pkcs12_certificate_information.rb', line 113 def not_before=(value) @not_before = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
120 121 122 |
# File 'lib/models/pkcs12_certificate_information.rb', line 120 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
128 129 130 |
# File 'lib/models/pkcs12_certificate_information.rb', line 128 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
136 137 138 139 140 141 142 143 144 |
# File 'lib/models/pkcs12_certificate_information.rb', line 136 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("isActive", @is_active) writer.write_object_value("notAfter", @not_after) writer.write_object_value("notBefore", @not_before) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("thumbprint", @thumbprint) writer.write_additional_data(@additional_data) end |
#thumbprint ⇒ Object
Gets the thumbprint property value. The certificate thumbprint.
149 150 151 |
# File 'lib/models/pkcs12_certificate_information.rb', line 149 def thumbprint return @thumbprint end |
#thumbprint=(value) ⇒ Object
Sets the thumbprint property value. The certificate thumbprint.
157 158 159 |
# File 'lib/models/pkcs12_certificate_information.rb', line 157 def thumbprint=(value) @thumbprint = value end |