Class: MicrosoftGraph::Models::RemoteItem
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::RemoteItem
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/remote_item.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#created_by ⇒ Object
Gets the createdBy property value.
-
#created_by=(value) ⇒ Object
Sets the createdBy property value.
-
#created_date_time ⇒ Object
Gets the createdDateTime property value.
-
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value.
-
#file ⇒ Object
Gets the file property value.
-
#file=(value) ⇒ Object
Sets the file property value.
-
#file_system_info ⇒ Object
Gets the fileSystemInfo property value.
-
#file_system_info=(value) ⇒ Object
Sets the fileSystemInfo property value.
-
#folder ⇒ Object
Gets the folder property value.
-
#folder=(value) ⇒ Object
Sets the folder property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#image ⇒ Object
Gets the image property value.
-
#image=(value) ⇒ Object
Sets the image property value.
-
#initialize ⇒ Object
constructor
Instantiates a new remoteItem and sets the default values.
-
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value.
-
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value.
-
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value.
-
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#package ⇒ Object
Gets the package property value.
-
#package=(value) ⇒ Object
Sets the package property value.
-
#parent_reference ⇒ Object
Gets the parentReference property value.
-
#parent_reference=(value) ⇒ Object
Sets the parentReference property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#shared ⇒ Object
Gets the shared property value.
-
#shared=(value) ⇒ Object
Sets the shared property value.
-
#sharepoint_ids ⇒ Object
Gets the sharepointIds property value.
-
#sharepoint_ids=(value) ⇒ Object
Sets the sharepointIds property value.
-
#size ⇒ Object
Gets the size property value.
-
#size=(value) ⇒ Object
Sets the size property value.
-
#special_folder ⇒ Object
Gets the specialFolder property value.
-
#special_folder=(value) ⇒ Object
Sets the specialFolder property value.
-
#video ⇒ Object
Gets the video property value.
-
#video=(value) ⇒ Object
Sets the video property value.
-
#web_dav_url ⇒ Object
Gets the webDavUrl property value.
-
#web_dav_url=(value) ⇒ Object
Sets the webDavUrl property value.
-
#web_url ⇒ Object
Gets the webUrl property value.
-
#web_url=(value) ⇒ Object
Sets the webUrl property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new remoteItem and sets the default values.
92 93 94 |
# File 'lib/models/remote_item.rb', line 92 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
130 131 132 133 |
# File 'lib/models/remote_item.rb', line 130 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return RemoteItem.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
77 78 79 |
# File 'lib/models/remote_item.rb', line 77 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
85 86 87 |
# File 'lib/models/remote_item.rb', line 85 def additional_data=(value) @additional_data = value end |
#created_by ⇒ Object
Gets the createdBy property value. Identity of the user, device, and application which created the item. Read-only.
99 100 101 |
# File 'lib/models/remote_item.rb', line 99 def created_by return @created_by end |
#created_by=(value) ⇒ Object
Sets the createdBy property value. Identity of the user, device, and application which created the item. Read-only.
107 108 109 |
# File 'lib/models/remote_item.rb', line 107 def created_by=(value) @created_by = value end |
#created_date_time ⇒ Object
Gets the createdDateTime property value. Date and time of item creation. Read-only.
114 115 116 |
# File 'lib/models/remote_item.rb', line 114 def created_date_time return @created_date_time end |
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value. Date and time of item creation. Read-only.
122 123 124 |
# File 'lib/models/remote_item.rb', line 122 def created_date_time=(value) @created_date_time = value end |
#file ⇒ Object
Gets the file property value. Indicates that the remote item is a file. Read-only.
138 139 140 |
# File 'lib/models/remote_item.rb', line 138 def file return @file end |
#file=(value) ⇒ Object
Sets the file property value. Indicates that the remote item is a file. Read-only.
146 147 148 |
# File 'lib/models/remote_item.rb', line 146 def file=(value) @file = value end |
#file_system_info ⇒ Object
Gets the fileSystemInfo property value. Information about the remote item from the local file system. Read-only.
153 154 155 |
# File 'lib/models/remote_item.rb', line 153 def file_system_info return @file_system_info end |
#file_system_info=(value) ⇒ Object
Sets the fileSystemInfo property value. Information about the remote item from the local file system. Read-only.
161 162 163 |
# File 'lib/models/remote_item.rb', line 161 def file_system_info=(value) @file_system_info = value end |
#folder ⇒ Object
Gets the folder property value. Indicates that the remote item is a folder. Read-only.
168 169 170 |
# File 'lib/models/remote_item.rb', line 168 def folder return @folder end |
#folder=(value) ⇒ Object
Sets the folder property value. Indicates that the remote item is a folder. Read-only.
176 177 178 |
# File 'lib/models/remote_item.rb', line 176 def folder=(value) @folder = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/models/remote_item.rb', line 183 def get_field_deserializers() return { "createdBy" => lambda {|n| @created_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) }, "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() }, "file" => lambda {|n| @file = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::File.create_from_discriminator_value(pn) }) }, "fileSystemInfo" => lambda {|n| @file_system_info = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::FileSystemInfo.create_from_discriminator_value(pn) }) }, "folder" => lambda {|n| @folder = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Folder.create_from_discriminator_value(pn) }) }, "id" => lambda {|n| @id = n.get_string_value() }, "image" => lambda {|n| @image = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Image.create_from_discriminator_value(pn) }) }, "lastModifiedBy" => lambda {|n| @last_modified_by = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::IdentitySet.create_from_discriminator_value(pn) }) }, "lastModifiedDateTime" => lambda {|n| @last_modified_date_time = n.get_date_time_value() }, "name" => lambda {|n| @name = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "package" => lambda {|n| @package = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Package.create_from_discriminator_value(pn) }) }, "parentReference" => lambda {|n| @parent_reference = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ItemReference.create_from_discriminator_value(pn) }) }, "shared" => lambda {|n| @shared = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Shared.create_from_discriminator_value(pn) }) }, "sharepointIds" => lambda {|n| @sharepoint_ids = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SharepointIds.create_from_discriminator_value(pn) }) }, "size" => lambda {|n| @size = n.get_object_value(lambda {|pn| Int64.create_from_discriminator_value(pn) }) }, "specialFolder" => lambda {|n| @special_folder = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SpecialFolder.create_from_discriminator_value(pn) }) }, "video" => lambda {|n| @video = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Video.create_from_discriminator_value(pn) }) }, "webDavUrl" => lambda {|n| @web_dav_url = n.get_string_value() }, "webUrl" => lambda {|n| @web_url = n.get_string_value() }, } end |
#id ⇒ Object
Gets the id property value. Unique identifier for the remote item in its drive. Read-only.
211 212 213 |
# File 'lib/models/remote_item.rb', line 211 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. Unique identifier for the remote item in its drive. Read-only.
219 220 221 |
# File 'lib/models/remote_item.rb', line 219 def id=(value) @id = value end |
#image ⇒ Object
Gets the image property value. Image metadata, if the item is an image. Read-only.
226 227 228 |
# File 'lib/models/remote_item.rb', line 226 def image return @image end |
#image=(value) ⇒ Object
Sets the image property value. Image metadata, if the item is an image. Read-only.
234 235 236 |
# File 'lib/models/remote_item.rb', line 234 def image=(value) @image = value end |
#last_modified_by ⇒ Object
Gets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
241 242 243 |
# File 'lib/models/remote_item.rb', line 241 def last_modified_by return @last_modified_by end |
#last_modified_by=(value) ⇒ Object
Sets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
249 250 251 |
# File 'lib/models/remote_item.rb', line 249 def last_modified_by=(value) @last_modified_by = value end |
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
256 257 258 |
# File 'lib/models/remote_item.rb', line 256 def last_modified_date_time return @last_modified_date_time end |
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
264 265 266 |
# File 'lib/models/remote_item.rb', line 264 def last_modified_date_time=(value) @last_modified_date_time = value end |
#name ⇒ Object
Gets the name property value. Optional. Filename of the remote item. Read-only.
271 272 273 |
# File 'lib/models/remote_item.rb', line 271 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. Optional. Filename of the remote item. Read-only.
279 280 281 |
# File 'lib/models/remote_item.rb', line 279 def name=(value) @name = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
286 287 288 |
# File 'lib/models/remote_item.rb', line 286 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
294 295 296 |
# File 'lib/models/remote_item.rb', line 294 def odata_type=(value) @odata_type = value end |
#package ⇒ Object
Gets the package property value. If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only.
301 302 303 |
# File 'lib/models/remote_item.rb', line 301 def package return @package end |
#package=(value) ⇒ Object
Sets the package property value. If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only.
309 310 311 |
# File 'lib/models/remote_item.rb', line 309 def package=(value) @package = value end |
#parent_reference ⇒ Object
Gets the parentReference property value. Properties of the parent of the remote item. Read-only.
316 317 318 |
# File 'lib/models/remote_item.rb', line 316 def parent_reference return @parent_reference end |
#parent_reference=(value) ⇒ Object
Sets the parentReference property value. Properties of the parent of the remote item. Read-only.
324 325 326 |
# File 'lib/models/remote_item.rb', line 324 def parent_reference=(value) @parent_reference = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/models/remote_item.rb', line 332 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("createdBy", @created_by) writer.write_date_time_value("createdDateTime", @created_date_time) writer.write_object_value("file", @file) writer.write_object_value("fileSystemInfo", @file_system_info) writer.write_object_value("folder", @folder) writer.write_string_value("id", @id) writer.write_object_value("image", @image) writer.write_object_value("lastModifiedBy", @last_modified_by) writer.write_date_time_value("lastModifiedDateTime", @last_modified_date_time) writer.write_string_value("name", @name) writer.write_string_value("@odata.type", @odata_type) writer.write_object_value("package", @package) writer.write_object_value("parentReference", @parent_reference) writer.write_object_value("shared", @shared) writer.write_object_value("sharepointIds", @sharepoint_ids) writer.write_object_value("size", @size) writer.write_object_value("specialFolder", @special_folder) writer.write_object_value("video", @video) writer.write_string_value("webDavUrl", @web_dav_url) writer.write_string_value("webUrl", @web_url) writer.write_additional_data(@additional_data) end |
#shared ⇒ Object
Gets the shared property value. Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only.
360 361 362 |
# File 'lib/models/remote_item.rb', line 360 def shared return @shared end |
#shared=(value) ⇒ Object
Sets the shared property value. Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only.
368 369 370 |
# File 'lib/models/remote_item.rb', line 368 def shared=(value) @shared = value end |
#sharepoint_ids ⇒ Object
Gets the sharepointIds property value. Provides interop between items in OneDrive for Business and SharePoint with the full set of item identifiers. Read-only.
375 376 377 |
# File 'lib/models/remote_item.rb', line 375 def sharepoint_ids return @sharepoint_ids end |
#sharepoint_ids=(value) ⇒ Object
Sets the sharepointIds property value. Provides interop between items in OneDrive for Business and SharePoint with the full set of item identifiers. Read-only.
383 384 385 |
# File 'lib/models/remote_item.rb', line 383 def sharepoint_ids=(value) @sharepoint_ids = value end |
#size ⇒ Object
Gets the size property value. Size of the remote item. Read-only.
390 391 392 |
# File 'lib/models/remote_item.rb', line 390 def size return @size end |
#size=(value) ⇒ Object
Sets the size property value. Size of the remote item. Read-only.
398 399 400 |
# File 'lib/models/remote_item.rb', line 398 def size=(value) @size = value end |
#special_folder ⇒ Object
Gets the specialFolder property value. If the current item is also available as a special folder, this facet is returned. Read-only.
405 406 407 |
# File 'lib/models/remote_item.rb', line 405 def special_folder return @special_folder end |
#special_folder=(value) ⇒ Object
Sets the specialFolder property value. If the current item is also available as a special folder, this facet is returned. Read-only.
413 414 415 |
# File 'lib/models/remote_item.rb', line 413 def special_folder=(value) @special_folder = value end |
#video ⇒ Object
Gets the video property value. Video metadata, if the item is a video. Read-only.
420 421 422 |
# File 'lib/models/remote_item.rb', line 420 def video return @video end |
#video=(value) ⇒ Object
Sets the video property value. Video metadata, if the item is a video. Read-only.
428 429 430 |
# File 'lib/models/remote_item.rb', line 428 def video=(value) @video = value end |
#web_dav_url ⇒ Object
Gets the webDavUrl property value. DAV compatible URL for the item.
435 436 437 |
# File 'lib/models/remote_item.rb', line 435 def web_dav_url return @web_dav_url end |
#web_dav_url=(value) ⇒ Object
Sets the webDavUrl property value. DAV compatible URL for the item.
443 444 445 |
# File 'lib/models/remote_item.rb', line 443 def web_dav_url=(value) @web_dav_url = value end |
#web_url ⇒ Object
Gets the webUrl property value. URL that displays the resource in the browser. Read-only.
450 451 452 |
# File 'lib/models/remote_item.rb', line 450 def web_url return @web_url end |
#web_url=(value) ⇒ Object
Sets the webUrl property value. URL that displays the resource in the browser. Read-only.
458 459 460 |
# File 'lib/models/remote_item.rb', line 458 def web_url=(value) @web_url = value end |