Class: MicrosoftGraph::Models::ReportRoot
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::ReportRoot
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/report_root.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#authentication_methods ⇒ Object
Gets the authenticationMethods property value.
-
#authentication_methods=(value) ⇒ Object
Sets the authenticationMethods property value.
-
#daily_print_usage_by_printer ⇒ Object
Gets the dailyPrintUsageByPrinter property value.
-
#daily_print_usage_by_printer=(value) ⇒ Object
Sets the dailyPrintUsageByPrinter property value.
-
#daily_print_usage_by_user ⇒ Object
Gets the dailyPrintUsageByUser property value.
-
#daily_print_usage_by_user=(value) ⇒ Object
Sets the dailyPrintUsageByUser property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new reportRoot and sets the default values.
-
#monthly_print_usage_by_printer ⇒ Object
Gets the monthlyPrintUsageByPrinter property value.
-
#monthly_print_usage_by_printer=(value) ⇒ Object
Sets the monthlyPrintUsageByPrinter property value.
-
#monthly_print_usage_by_user ⇒ Object
Gets the monthlyPrintUsageByUser property value.
-
#monthly_print_usage_by_user=(value) ⇒ Object
Sets the monthlyPrintUsageByUser property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#security ⇒ Object
Gets the security property value.
-
#security=(value) ⇒ Object
Sets the security property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new reportRoot and sets the default values.
67 68 69 |
# File 'lib/models/report_root.rb', line 67 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
75 76 77 78 |
# File 'lib/models/report_root.rb', line 75 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ReportRoot.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
37 38 39 |
# File 'lib/models/report_root.rb', line 37 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
45 46 47 |
# File 'lib/models/report_root.rb', line 45 def additional_data=(value) @additional_data = value end |
#authentication_methods ⇒ Object
Gets the authenticationMethods property value. Container for navigation properties for Azure AD authentication methods resources.
52 53 54 |
# File 'lib/models/report_root.rb', line 52 def authentication_methods return @authentication_methods end |
#authentication_methods=(value) ⇒ Object
Sets the authenticationMethods property value. Container for navigation properties for Azure AD authentication methods resources.
60 61 62 |
# File 'lib/models/report_root.rb', line 60 def authentication_methods=(value) @authentication_methods = value end |
#daily_print_usage_by_printer ⇒ Object
Gets the dailyPrintUsageByPrinter property value. Retrieve a list of daily print usage summaries, grouped by printer.
83 84 85 |
# File 'lib/models/report_root.rb', line 83 def daily_print_usage_by_printer return @daily_print_usage_by_printer end |
#daily_print_usage_by_printer=(value) ⇒ Object
Sets the dailyPrintUsageByPrinter property value. Retrieve a list of daily print usage summaries, grouped by printer.
91 92 93 |
# File 'lib/models/report_root.rb', line 91 def daily_print_usage_by_printer=(value) @daily_print_usage_by_printer = value end |
#daily_print_usage_by_user ⇒ Object
Gets the dailyPrintUsageByUser property value. Retrieve a list of daily print usage summaries, grouped by user.
98 99 100 |
# File 'lib/models/report_root.rb', line 98 def daily_print_usage_by_user return @daily_print_usage_by_user end |
#daily_print_usage_by_user=(value) ⇒ Object
Sets the dailyPrintUsageByUser property value. Retrieve a list of daily print usage summaries, grouped by user.
106 107 108 |
# File 'lib/models/report_root.rb', line 106 def daily_print_usage_by_user=(value) @daily_print_usage_by_user = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/models/report_root.rb', line 113 def get_field_deserializers() return { "authenticationMethods" => lambda {|n| @authentication_methods = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::AuthenticationMethodsRoot.create_from_discriminator_value(pn) }) }, "dailyPrintUsageByPrinter" => lambda {|n| @daily_print_usage_by_printer = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByPrinter.create_from_discriminator_value(pn) }) }, "dailyPrintUsageByUser" => lambda {|n| @daily_print_usage_by_user = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByUser.create_from_discriminator_value(pn) }) }, "monthlyPrintUsageByPrinter" => lambda {|n| @monthly_print_usage_by_printer = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByPrinter.create_from_discriminator_value(pn) }) }, "monthlyPrintUsageByUser" => lambda {|n| @monthly_print_usage_by_user = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::PrintUsageByUser.create_from_discriminator_value(pn) }) }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "security" => lambda {|n| @security = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SecurityReportsRoot.create_from_discriminator_value(pn) }) }, } end |
#monthly_print_usage_by_printer ⇒ Object
Gets the monthlyPrintUsageByPrinter property value. Retrieve a list of monthly print usage summaries, grouped by printer.
128 129 130 |
# File 'lib/models/report_root.rb', line 128 def monthly_print_usage_by_printer return @monthly_print_usage_by_printer end |
#monthly_print_usage_by_printer=(value) ⇒ Object
Sets the monthlyPrintUsageByPrinter property value. Retrieve a list of monthly print usage summaries, grouped by printer.
136 137 138 |
# File 'lib/models/report_root.rb', line 136 def monthly_print_usage_by_printer=(value) @monthly_print_usage_by_printer = value end |
#monthly_print_usage_by_user ⇒ Object
Gets the monthlyPrintUsageByUser property value. Retrieve a list of monthly print usage summaries, grouped by user.
143 144 145 |
# File 'lib/models/report_root.rb', line 143 def monthly_print_usage_by_user return @monthly_print_usage_by_user end |
#monthly_print_usage_by_user=(value) ⇒ Object
Sets the monthlyPrintUsageByUser property value. Retrieve a list of monthly print usage summaries, grouped by user.
151 152 153 |
# File 'lib/models/report_root.rb', line 151 def monthly_print_usage_by_user=(value) @monthly_print_usage_by_user = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
158 159 160 |
# File 'lib/models/report_root.rb', line 158 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
166 167 168 |
# File 'lib/models/report_root.rb', line 166 def odata_type=(value) @odata_type = value end |
#security ⇒ Object
Gets the security property value. Represents an abstract type that contains resources for attack simulation and training reports.
173 174 175 |
# File 'lib/models/report_root.rb', line 173 def security return @security end |
#security=(value) ⇒ Object
Sets the security property value. Represents an abstract type that contains resources for attack simulation and training reports.
181 182 183 |
# File 'lib/models/report_root.rb', line 181 def security=(value) @security = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/models/report_root.rb', line 189 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("authenticationMethods", @authentication_methods) writer.write_collection_of_object_values("dailyPrintUsageByPrinter", @daily_print_usage_by_printer) writer.write_collection_of_object_values("dailyPrintUsageByUser", @daily_print_usage_by_user) writer.write_collection_of_object_values("monthlyPrintUsageByPrinter", @monthly_print_usage_by_printer) writer.write_collection_of_object_values("monthlyPrintUsageByUser", @monthly_print_usage_by_user) writer.write_string_value("@odata.type", @odata_type) writer.write_object_value("security", @security) writer.write_additional_data(@additional_data) end |