Class: MicrosoftGraph::Models::ResourceSpecificPermissionGrant
- Inherits:
-
DirectoryObject
- Object
- Entity
- DirectoryObject
- MicrosoftGraph::Models::ResourceSpecificPermissionGrant
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/resource_specific_permission_grant.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#client_app_id ⇒ Object
Gets the clientAppId property value.
-
#client_app_id=(value) ⇒ Object
Sets the clientAppId property value.
-
#client_id ⇒ Object
Gets the clientId property value.
-
#client_id=(value) ⇒ Object
Sets the clientId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new resourceSpecificPermissionGrant and sets the default values.
-
#permission ⇒ Object
Gets the permission property value.
-
#permission=(value) ⇒ Object
Sets the permission property value.
-
#permission_type ⇒ Object
Gets the permissionType property value.
-
#permission_type=(value) ⇒ Object
Sets the permissionType property value.
-
#resource_app_id ⇒ Object
Gets the resourceAppId property value.
-
#resource_app_id=(value) ⇒ Object
Sets the resourceAppId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from DirectoryObject
#deleted_date_time, #deleted_date_time=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new resourceSpecificPermissionGrant and sets the default values.
58 59 60 61 |
# File 'lib/models/resource_specific_permission_grant.rb', line 58 def initialize() super @odata_type = "#microsoft.graph.resourceSpecificPermissionGrant" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
67 68 69 70 |
# File 'lib/models/resource_specific_permission_grant.rb', line 67 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ResourceSpecificPermissionGrant.new end |
Instance Method Details
#client_app_id ⇒ Object
Gets the clientAppId property value. ID of the service principal of the Azure AD app that has been granted access. Read-only.
28 29 30 |
# File 'lib/models/resource_specific_permission_grant.rb', line 28 def client_app_id return @client_app_id end |
#client_app_id=(value) ⇒ Object
Sets the clientAppId property value. ID of the service principal of the Azure AD app that has been granted access. Read-only.
36 37 38 |
# File 'lib/models/resource_specific_permission_grant.rb', line 36 def client_app_id=(value) @client_app_id = value end |
#client_id ⇒ Object
Gets the clientId property value. ID of the Azure AD app that has been granted access. Read-only.
43 44 45 |
# File 'lib/models/resource_specific_permission_grant.rb', line 43 def client_id return @client_id end |
#client_id=(value) ⇒ Object
Sets the clientId property value. ID of the Azure AD app that has been granted access. Read-only.
51 52 53 |
# File 'lib/models/resource_specific_permission_grant.rb', line 51 def client_id=(value) @client_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
75 76 77 78 79 80 81 82 83 |
# File 'lib/models/resource_specific_permission_grant.rb', line 75 def get_field_deserializers() return super.merge({ "clientAppId" => lambda {|n| @client_app_id = n.get_string_value() }, "clientId" => lambda {|n| @client_id = n.get_string_value() }, "permission" => lambda {|n| = n.get_string_value() }, "permissionType" => lambda {|n| = n.get_string_value() }, "resourceAppId" => lambda {|n| @resource_app_id = n.get_string_value() }, }) end |
#permission ⇒ Object
Gets the permission property value. The name of the resource-specific permission. Read-only.
88 89 90 |
# File 'lib/models/resource_specific_permission_grant.rb', line 88 def return end |
#permission=(value) ⇒ Object
Sets the permission property value. The name of the resource-specific permission. Read-only.
96 97 98 |
# File 'lib/models/resource_specific_permission_grant.rb', line 96 def (value) = value end |
#permission_type ⇒ Object
Gets the permissionType property value. The type of permission. Possible values are: Application, Delegated. Read-only.
103 104 105 |
# File 'lib/models/resource_specific_permission_grant.rb', line 103 def return end |
#permission_type=(value) ⇒ Object
Sets the permissionType property value. The type of permission. Possible values are: Application, Delegated. Read-only.
111 112 113 |
# File 'lib/models/resource_specific_permission_grant.rb', line 111 def (value) = value end |
#resource_app_id ⇒ Object
Gets the resourceAppId property value. ID of the Azure AD app that is hosting the resource. Read-only.
118 119 120 |
# File 'lib/models/resource_specific_permission_grant.rb', line 118 def resource_app_id return @resource_app_id end |
#resource_app_id=(value) ⇒ Object
Sets the resourceAppId property value. ID of the Azure AD app that is hosting the resource. Read-only.
126 127 128 |
# File 'lib/models/resource_specific_permission_grant.rb', line 126 def resource_app_id=(value) @resource_app_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
134 135 136 137 138 139 140 141 142 |
# File 'lib/models/resource_specific_permission_grant.rb', line 134 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("clientAppId", @client_app_id) writer.write_string_value("clientId", @client_id) writer.write_string_value("permission", ) writer.write_string_value("permissionType", ) writer.write_string_value("resourceAppId", @resource_app_id) end |