Class: MicrosoftGraph::Models::SectionGroup
- Inherits:
-
OnenoteEntityHierarchyModel
- Object
- Entity
- OnenoteEntityBaseModel
- OnenoteEntitySchemaObjectModel
- OnenoteEntityHierarchyModel
- MicrosoftGraph::Models::SectionGroup
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/section_group.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new sectionGroup and sets the default values.
-
#parent_notebook ⇒ Object
Gets the parentNotebook property value.
-
#parent_notebook=(value) ⇒ Object
Sets the parentNotebook property value.
-
#parent_section_group ⇒ Object
Gets the parentSectionGroup property value.
-
#parent_section_group=(value) ⇒ Object
Sets the parentSectionGroup property value.
-
#section_groups ⇒ Object
Gets the sectionGroups property value.
-
#section_groups=(value) ⇒ Object
Sets the sectionGroups property value.
-
#section_groups_url ⇒ Object
Gets the sectionGroupsUrl property value.
-
#section_groups_url=(value) ⇒ Object
Sets the sectionGroupsUrl property value.
-
#sections ⇒ Object
Gets the sections property value.
-
#sections=(value) ⇒ Object
Sets the sections property value.
-
#sections_url ⇒ Object
Gets the sectionsUrl property value.
-
#sections_url=(value) ⇒ Object
Sets the sectionsUrl property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from OnenoteEntityHierarchyModel
#created_by, #created_by=, #display_name, #display_name=, #last_modified_by, #last_modified_by=, #last_modified_date_time, #last_modified_date_time=
Methods inherited from OnenoteEntitySchemaObjectModel
#created_date_time, #created_date_time=
Methods inherited from OnenoteEntityBaseModel
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new sectionGroup and sets the default values.
31 32 33 34 |
# File 'lib/models/section_group.rb', line 31 def initialize() super @odata_type = "#microsoft.graph.sectionGroup" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
40 41 42 43 |
# File 'lib/models/section_group.rb', line 40 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SectionGroup.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/models/section_group.rb', line 48 def get_field_deserializers() return super.merge({ "parentNotebook" => lambda {|n| @parent_notebook = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Notebook.create_from_discriminator_value(pn) }) }, "parentSectionGroup" => lambda {|n| @parent_section_group = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SectionGroup.create_from_discriminator_value(pn) }) }, "sectionGroups" => lambda {|n| @section_groups = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::SectionGroup.create_from_discriminator_value(pn) }) }, "sectionGroupsUrl" => lambda {|n| @section_groups_url = n.get_string_value() }, "sections" => lambda {|n| @sections = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::OnenoteSection.create_from_discriminator_value(pn) }) }, "sectionsUrl" => lambda {|n| @sections_url = n.get_string_value() }, }) end |
#parent_notebook ⇒ Object
Gets the parentNotebook property value. The notebook that contains the section group. Read-only.
62 63 64 |
# File 'lib/models/section_group.rb', line 62 def parent_notebook return @parent_notebook end |
#parent_notebook=(value) ⇒ Object
Sets the parentNotebook property value. The notebook that contains the section group. Read-only.
70 71 72 |
# File 'lib/models/section_group.rb', line 70 def parent_notebook=(value) @parent_notebook = value end |
#parent_section_group ⇒ Object
Gets the parentSectionGroup property value. The section group that contains the section group. Read-only.
77 78 79 |
# File 'lib/models/section_group.rb', line 77 def parent_section_group return @parent_section_group end |
#parent_section_group=(value) ⇒ Object
Sets the parentSectionGroup property value. The section group that contains the section group. Read-only.
85 86 87 |
# File 'lib/models/section_group.rb', line 85 def parent_section_group=(value) @parent_section_group = value end |
#section_groups ⇒ Object
Gets the sectionGroups property value. The section groups in the section. Read-only. Nullable.
92 93 94 |
# File 'lib/models/section_group.rb', line 92 def section_groups return @section_groups end |
#section_groups=(value) ⇒ Object
Sets the sectionGroups property value. The section groups in the section. Read-only. Nullable.
100 101 102 |
# File 'lib/models/section_group.rb', line 100 def section_groups=(value) @section_groups = value end |
#section_groups_url ⇒ Object
Gets the sectionGroupsUrl property value. The URL for the sectionGroups navigation property, which returns all the section groups in the section group. Read-only.
107 108 109 |
# File 'lib/models/section_group.rb', line 107 def section_groups_url return @section_groups_url end |
#section_groups_url=(value) ⇒ Object
Sets the sectionGroupsUrl property value. The URL for the sectionGroups navigation property, which returns all the section groups in the section group. Read-only.
115 116 117 |
# File 'lib/models/section_group.rb', line 115 def section_groups_url=(value) @section_groups_url = value end |
#sections ⇒ Object
Gets the sections property value. The sections in the section group. Read-only. Nullable.
122 123 124 |
# File 'lib/models/section_group.rb', line 122 def sections return @sections end |
#sections=(value) ⇒ Object
Sets the sections property value. The sections in the section group. Read-only. Nullable.
130 131 132 |
# File 'lib/models/section_group.rb', line 130 def sections=(value) @sections = value end |
#sections_url ⇒ Object
Gets the sectionsUrl property value. The URL for the sections navigation property, which returns all the sections in the section group. Read-only.
137 138 139 |
# File 'lib/models/section_group.rb', line 137 def sections_url return @sections_url end |
#sections_url=(value) ⇒ Object
Sets the sectionsUrl property value. The URL for the sections navigation property, which returns all the sections in the section group. Read-only.
145 146 147 |
# File 'lib/models/section_group.rb', line 145 def sections_url=(value) @sections_url = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/models/section_group.rb', line 153 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("parentNotebook", @parent_notebook) writer.write_object_value("parentSectionGroup", @parent_section_group) writer.write_collection_of_object_values("sectionGroups", @section_groups) writer.write_string_value("sectionGroupsUrl", @section_groups_url) writer.write_collection_of_object_values("sections", @sections) writer.write_string_value("sectionsUrl", @sections_url) end |