Class: MicrosoftGraph::Models::SecurityBlobEvidence
- Inherits:
-
SecurityAlertEvidence
- Object
- SecurityAlertEvidence
- MicrosoftGraph::Models::SecurityBlobEvidence
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/security_blob_evidence.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#blob_container ⇒ Object
Gets the blobContainer property value.
-
#blob_container=(value) ⇒ Object
Sets the blobContainer property value.
-
#etag ⇒ Object
Gets the etag property value.
-
#etag=(value) ⇒ Object
Sets the etag property value.
-
#file_hashes ⇒ Object
Gets the fileHashes property value.
-
#file_hashes=(value) ⇒ Object
Sets the fileHashes property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new securityBlobEvidence and sets the default values.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#url ⇒ Object
Gets the url property value.
-
#url=(value) ⇒ Object
Sets the url property value.
Methods inherited from SecurityAlertEvidence
#additional_data, #additional_data=, #created_date_time, #created_date_time=, #detailed_roles, #detailed_roles=, #odata_type, #odata_type=, #remediation_status, #remediation_status=, #remediation_status_details, #remediation_status_details=, #roles, #roles=, #tags, #tags=, #verdict, #verdict=
Constructor Details
#initialize ⇒ Object
Instantiates a new securityBlobEvidence and sets the default values.
43 44 45 46 |
# File 'lib/models/security_blob_evidence.rb', line 43 def initialize() super @odata_type = "#microsoft.graph.security.blobEvidence" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
52 53 54 55 |
# File 'lib/models/security_blob_evidence.rb', line 52 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SecurityBlobEvidence.new end |
Instance Method Details
#blob_container ⇒ Object
Gets the blobContainer property value. The container which the blob belongs to.
28 29 30 |
# File 'lib/models/security_blob_evidence.rb', line 28 def blob_container return @blob_container end |
#blob_container=(value) ⇒ Object
Sets the blobContainer property value. The container which the blob belongs to.
36 37 38 |
# File 'lib/models/security_blob_evidence.rb', line 36 def blob_container=(value) @blob_container = value end |
#etag ⇒ Object
Gets the etag property value. The Etag associated with this blob.
60 61 62 |
# File 'lib/models/security_blob_evidence.rb', line 60 def etag return @etag end |
#etag=(value) ⇒ Object
Sets the etag property value. The Etag associated with this blob.
68 69 70 |
# File 'lib/models/security_blob_evidence.rb', line 68 def etag=(value) @etag = value end |
#file_hashes ⇒ Object
Gets the fileHashes property value. The file hashes associated with this blob.
75 76 77 |
# File 'lib/models/security_blob_evidence.rb', line 75 def file_hashes return @file_hashes end |
#file_hashes=(value) ⇒ Object
Sets the fileHashes property value. The file hashes associated with this blob.
83 84 85 |
# File 'lib/models/security_blob_evidence.rb', line 83 def file_hashes=(value) @file_hashes = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
90 91 92 93 94 95 96 97 98 |
# File 'lib/models/security_blob_evidence.rb', line 90 def get_field_deserializers() return super.merge({ "blobContainer" => lambda {|n| @blob_container = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SecurityBlobContainerEvidence.create_from_discriminator_value(pn) }) }, "etag" => lambda {|n| @etag = n.get_string_value() }, "fileHashes" => lambda {|n| @file_hashes = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::SecurityFileHash.create_from_discriminator_value(pn) }) }, "name" => lambda {|n| @name = n.get_string_value() }, "url" => lambda {|n| @url = n.get_string_value() }, }) end |
#name ⇒ Object
Gets the name property value. The name of the blob.
103 104 105 |
# File 'lib/models/security_blob_evidence.rb', line 103 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. The name of the blob.
111 112 113 |
# File 'lib/models/security_blob_evidence.rb', line 111 def name=(value) @name = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
119 120 121 122 123 124 125 126 127 |
# File 'lib/models/security_blob_evidence.rb', line 119 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("blobContainer", @blob_container) writer.write_string_value("etag", @etag) writer.write_collection_of_object_values("fileHashes", @file_hashes) writer.write_string_value("name", @name) writer.write_string_value("url", @url) end |
#url ⇒ Object
Gets the url property value. The full URL representation of the blob.
132 133 134 |
# File 'lib/models/security_blob_evidence.rb', line 132 def url return @url end |
#url=(value) ⇒ Object
Sets the url property value. The full URL representation of the blob.
140 141 142 |
# File 'lib/models/security_blob_evidence.rb', line 140 def url=(value) @url = value end |