Class: MicrosoftGraph::Models::SecurityCvssSummary
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::SecurityCvssSummary
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/security_cvss_summary.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new securityCvssSummary and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#score ⇒ Object
Gets the score property value.
-
#score=(value) ⇒ Object
Sets the score property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#severity ⇒ Object
Gets the severity property value.
-
#severity=(value) ⇒ Object
Sets the severity property value.
-
#vector_string ⇒ Object
Gets the vectorString property value.
-
#vector_string=(value) ⇒ Object
Sets the vectorString property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new securityCvssSummary and sets the default values.
43 44 45 |
# File 'lib/models/security_cvss_summary.rb', line 43 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
51 52 53 54 |
# File 'lib/models/security_cvss_summary.rb', line 51 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SecurityCvssSummary.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
28 29 30 |
# File 'lib/models/security_cvss_summary.rb', line 28 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
36 37 38 |
# File 'lib/models/security_cvss_summary.rb', line 36 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
59 60 61 62 63 64 65 66 |
# File 'lib/models/security_cvss_summary.rb', line 59 def get_field_deserializers() return { "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "score" => lambda {|n| @score = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "severity" => lambda {|n| @severity = n.get_enum_value(MicrosoftGraph::Models::SecurityVulnerabilitySeverity) }, "vectorString" => lambda {|n| @vector_string = n.get_string_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
71 72 73 |
# File 'lib/models/security_cvss_summary.rb', line 71 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
79 80 81 |
# File 'lib/models/security_cvss_summary.rb', line 79 def odata_type=(value) @odata_type = value end |
#score ⇒ Object
Gets the score property value. The CVSS score about this vulnerability.
86 87 88 |
# File 'lib/models/security_cvss_summary.rb', line 86 def score return @score end |
#score=(value) ⇒ Object
Sets the score property value. The CVSS score about this vulnerability.
94 95 96 |
# File 'lib/models/security_cvss_summary.rb', line 94 def score=(value) @score = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
102 103 104 105 106 107 108 109 |
# File 'lib/models/security_cvss_summary.rb', line 102 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("@odata.type", @odata_type) writer.write_object_value("score", @score) writer.write_enum_value("severity", @severity) writer.write_string_value("vectorString", @vector_string) writer.write_additional_data(@additional_data) end |
#severity ⇒ Object
Gets the severity property value. The CVSS severity rating for this vulnerability. The possible values are: none, low, medium, high, critical, unknownFutureValue.
114 115 116 |
# File 'lib/models/security_cvss_summary.rb', line 114 def severity return @severity end |
#severity=(value) ⇒ Object
Sets the severity property value. The CVSS severity rating for this vulnerability. The possible values are: none, low, medium, high, critical, unknownFutureValue.
122 123 124 |
# File 'lib/models/security_cvss_summary.rb', line 122 def severity=(value) @severity = value end |
#vector_string ⇒ Object
Gets the vectorString property value. The CVSS vector string for this vulnerability.
129 130 131 |
# File 'lib/models/security_cvss_summary.rb', line 129 def vector_string return @vector_string end |
#vector_string=(value) ⇒ Object
Sets the vectorString property value. The CVSS vector string for this vulnerability.
137 138 139 |
# File 'lib/models/security_cvss_summary.rb', line 137 def vector_string=(value) @vector_string = value end |