Class: MicrosoftGraph::Models::SecurityEdiscoveryCustodian
- Inherits:
-
SecurityDataSourceContainer
- Object
- Entity
- SecurityDataSourceContainer
- MicrosoftGraph::Models::SecurityEdiscoveryCustodian
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/security_ediscovery_custodian.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#acknowledged_date_time ⇒ Object
Gets the acknowledgedDateTime property value.
-
#acknowledged_date_time=(value) ⇒ Object
Sets the acknowledgedDateTime property value.
-
#email ⇒ Object
Gets the email property value.
-
#email=(value) ⇒ Object
Sets the email property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new securityEdiscoveryCustodian and sets the default values.
-
#last_index_operation ⇒ Object
Gets the lastIndexOperation property value.
-
#last_index_operation=(value) ⇒ Object
Sets the lastIndexOperation property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#site_sources ⇒ Object
Gets the siteSources property value.
-
#site_sources=(value) ⇒ Object
Sets the siteSources property value.
-
#unified_group_sources ⇒ Object
Gets the unifiedGroupSources property value.
-
#unified_group_sources=(value) ⇒ Object
Sets the unifiedGroupSources property value.
-
#user_sources ⇒ Object
Gets the userSources property value.
-
#user_sources=(value) ⇒ Object
Sets the userSources property value.
Methods inherited from SecurityDataSourceContainer
#created_date_time, #created_date_time=, #display_name, #display_name=, #hold_status, #hold_status=, #last_modified_date_time, #last_modified_date_time=, #released_date_time, #released_date_time=, #status, #status=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new securityEdiscoveryCustodian and sets the default values.
47 48 49 50 |
# File 'lib/models/security_ediscovery_custodian.rb', line 47 def initialize() super @odata_type = "#microsoft.graph.security.ediscoveryCustodian" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
56 57 58 59 |
# File 'lib/models/security_ediscovery_custodian.rb', line 56 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SecurityEdiscoveryCustodian.new end |
Instance Method Details
#acknowledged_date_time ⇒ Object
Gets the acknowledgedDateTime property value. Date and time the custodian acknowledged a hold notification.
32 33 34 |
# File 'lib/models/security_ediscovery_custodian.rb', line 32 def acknowledged_date_time return @acknowledged_date_time end |
#acknowledged_date_time=(value) ⇒ Object
Sets the acknowledgedDateTime property value. Date and time the custodian acknowledged a hold notification.
40 41 42 |
# File 'lib/models/security_ediscovery_custodian.rb', line 40 def acknowledged_date_time=(value) @acknowledged_date_time = value end |
#email ⇒ Object
Gets the email property value. Email address of the custodian.
64 65 66 |
# File 'lib/models/security_ediscovery_custodian.rb', line 64 def email return @email end |
#email=(value) ⇒ Object
Sets the email property value. Email address of the custodian.
72 73 74 |
# File 'lib/models/security_ediscovery_custodian.rb', line 72 def email=(value) @email = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/models/security_ediscovery_custodian.rb', line 79 def get_field_deserializers() return super.merge({ "acknowledgedDateTime" => lambda {|n| @acknowledged_date_time = n.get_date_time_value() }, "email" => lambda {|n| @email = n.get_string_value() }, "lastIndexOperation" => lambda {|n| @last_index_operation = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SecurityEdiscoveryIndexOperation.create_from_discriminator_value(pn) }) }, "siteSources" => lambda {|n| @site_sources = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::SecuritySiteSource.create_from_discriminator_value(pn) }) }, "unifiedGroupSources" => lambda {|n| @unified_group_sources = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::SecurityUnifiedGroupSource.create_from_discriminator_value(pn) }) }, "userSources" => lambda {|n| @user_sources = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::SecurityUserSource.create_from_discriminator_value(pn) }) }, }) end |
#last_index_operation ⇒ Object
Gets the lastIndexOperation property value. Operation entity that represents the latest indexing for the custodian.
93 94 95 |
# File 'lib/models/security_ediscovery_custodian.rb', line 93 def last_index_operation return @last_index_operation end |
#last_index_operation=(value) ⇒ Object
Sets the lastIndexOperation property value. Operation entity that represents the latest indexing for the custodian.
101 102 103 |
# File 'lib/models/security_ediscovery_custodian.rb', line 101 def last_index_operation=(value) @last_index_operation = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
109 110 111 112 113 114 115 116 117 118 |
# File 'lib/models/security_ediscovery_custodian.rb', line 109 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_date_time_value("acknowledgedDateTime", @acknowledged_date_time) writer.write_string_value("email", @email) writer.write_object_value("lastIndexOperation", @last_index_operation) writer.write_collection_of_object_values("siteSources", @site_sources) writer.write_collection_of_object_values("unifiedGroupSources", @unified_group_sources) writer.write_collection_of_object_values("userSources", @user_sources) end |
#site_sources ⇒ Object
Gets the siteSources property value. Data source entity for SharePoint sites associated with the custodian.
123 124 125 |
# File 'lib/models/security_ediscovery_custodian.rb', line 123 def site_sources return @site_sources end |
#site_sources=(value) ⇒ Object
Sets the siteSources property value. Data source entity for SharePoint sites associated with the custodian.
131 132 133 |
# File 'lib/models/security_ediscovery_custodian.rb', line 131 def site_sources=(value) @site_sources = value end |
#unified_group_sources ⇒ Object
Gets the unifiedGroupSources property value. Data source entity for groups associated with the custodian.
138 139 140 |
# File 'lib/models/security_ediscovery_custodian.rb', line 138 def unified_group_sources return @unified_group_sources end |
#unified_group_sources=(value) ⇒ Object
Sets the unifiedGroupSources property value. Data source entity for groups associated with the custodian.
146 147 148 |
# File 'lib/models/security_ediscovery_custodian.rb', line 146 def unified_group_sources=(value) @unified_group_sources = value end |
#user_sources ⇒ Object
Gets the userSources property value. Data source entity for a the custodian. This is the container for a custodian’s mailbox and OneDrive for Business site.
153 154 155 |
# File 'lib/models/security_ediscovery_custodian.rb', line 153 def user_sources return @user_sources end |
#user_sources=(value) ⇒ Object
Sets the userSources property value. Data source entity for a the custodian. This is the container for a custodian’s mailbox and OneDrive for Business site.
161 162 163 |
# File 'lib/models/security_ediscovery_custodian.rb', line 161 def user_sources=(value) @user_sources = value end |