Class: MicrosoftGraph::Models::SecurityOauthApplicationEvidence
- Inherits:
-
SecurityAlertEvidence
- Object
- SecurityAlertEvidence
- MicrosoftGraph::Models::SecurityOauthApplicationEvidence
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/security_oauth_application_evidence.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#app_id ⇒ Object
Gets the appId property value.
-
#app_id=(value) ⇒ Object
Sets the appId property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new securityOauthApplicationEvidence and sets the default values.
-
#object_id_escaped ⇒ Object
Gets the objectId property value.
-
#object_id_escaped=(value) ⇒ Object
Sets the objectId property value.
-
#publisher ⇒ Object
Gets the publisher property value.
-
#publisher=(value) ⇒ Object
Sets the publisher property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from SecurityAlertEvidence
#additional_data, #additional_data=, #created_date_time, #created_date_time=, #detailed_roles, #detailed_roles=, #odata_type, #odata_type=, #remediation_status, #remediation_status=, #remediation_status_details, #remediation_status_details=, #roles, #roles=, #tags, #tags=, #verdict, #verdict=
Constructor Details
#initialize ⇒ Object
Instantiates a new securityOauthApplicationEvidence and sets the default values.
40 41 42 43 |
# File 'lib/models/security_oauth_application_evidence.rb', line 40 def initialize() super @odata_type = "#microsoft.graph.security.oauthApplicationEvidence" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
49 50 51 52 |
# File 'lib/models/security_oauth_application_evidence.rb', line 49 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SecurityOauthApplicationEvidence.new end |
Instance Method Details
#app_id ⇒ Object
Gets the appId property value. Unique identifier of the application.
25 26 27 |
# File 'lib/models/security_oauth_application_evidence.rb', line 25 def app_id return @app_id end |
#app_id=(value) ⇒ Object
Sets the appId property value. Unique identifier of the application.
33 34 35 |
# File 'lib/models/security_oauth_application_evidence.rb', line 33 def app_id=(value) @app_id = value end |
#display_name ⇒ Object
Gets the displayName property value. Name of the application.
57 58 59 |
# File 'lib/models/security_oauth_application_evidence.rb', line 57 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. Name of the application.
65 66 67 |
# File 'lib/models/security_oauth_application_evidence.rb', line 65 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
72 73 74 75 76 77 78 79 |
# File 'lib/models/security_oauth_application_evidence.rb', line 72 def get_field_deserializers() return super.merge({ "appId" => lambda {|n| @app_id = n.get_string_value() }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, "objectId" => lambda {|n| @object_id_escaped = n.get_string_value() }, "publisher" => lambda {|n| @publisher = n.get_string_value() }, }) end |
#object_id_escaped ⇒ Object
Gets the objectId property value. The unique identifier of the application object in Azure AD.
84 85 86 |
# File 'lib/models/security_oauth_application_evidence.rb', line 84 def object_id_escaped return @object_id_escaped end |
#object_id_escaped=(value) ⇒ Object
Sets the objectId property value. The unique identifier of the application object in Azure AD.
92 93 94 |
# File 'lib/models/security_oauth_application_evidence.rb', line 92 def object_id_escaped=(value) @object_id_escaped = value end |
#publisher ⇒ Object
Gets the publisher property value. The name of the application publisher.
99 100 101 |
# File 'lib/models/security_oauth_application_evidence.rb', line 99 def publisher return @publisher end |
#publisher=(value) ⇒ Object
Sets the publisher property value. The name of the application publisher.
107 108 109 |
# File 'lib/models/security_oauth_application_evidence.rb', line 107 def publisher=(value) @publisher = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
115 116 117 118 119 120 121 122 |
# File 'lib/models/security_oauth_application_evidence.rb', line 115 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("appId", @app_id) writer.write_string_value("displayName", @display_name) writer.write_string_value("objectId", @object_id_escaped) writer.write_string_value("publisher", @publisher) end |