Class: MicrosoftGraph::Models::ServiceAnnouncementAttachment
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/service_announcement_attachment.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#content ⇒ Object
Gets the content property value.
-
#content=(value) ⇒ Object
Sets the content property value.
-
#content_type ⇒ Object
Gets the contentType property value.
-
#content_type=(value) ⇒ Object
Sets the contentType property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new serviceAnnouncementAttachment and sets the default values.
-
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value.
-
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#size ⇒ Object
Gets the size property value.
-
#size=(value) ⇒ Object
Sets the size property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new serviceAnnouncementAttachment and sets the default values.
29 30 31 |
# File 'lib/models/service_announcement_attachment.rb', line 29 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
67 68 69 70 |
# File 'lib/models/service_announcement_attachment.rb', line 67 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ServiceAnnouncementAttachment.new end |
Instance Method Details
#content ⇒ Object
Gets the content property value. The attachment content.
36 37 38 |
# File 'lib/models/service_announcement_attachment.rb', line 36 def content return @content end |
#content=(value) ⇒ Object
Sets the content property value. The attachment content.
44 45 46 |
# File 'lib/models/service_announcement_attachment.rb', line 44 def content=(value) @content = value end |
#content_type ⇒ Object
Gets the contentType property value. The contentType property
51 52 53 |
# File 'lib/models/service_announcement_attachment.rb', line 51 def content_type return @content_type end |
#content_type=(value) ⇒ Object
Sets the contentType property value. The contentType property
59 60 61 |
# File 'lib/models/service_announcement_attachment.rb', line 59 def content_type=(value) @content_type = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
75 76 77 78 79 80 81 82 83 |
# File 'lib/models/service_announcement_attachment.rb', line 75 def get_field_deserializers() return super.merge({ "content" => lambda {|n| @content = n.get_object_value(lambda {|pn| Base64url.create_from_discriminator_value(pn) }) }, "contentType" => lambda {|n| @content_type = n.get_string_value() }, "lastModifiedDateTime" => lambda {|n| @last_modified_date_time = n.get_date_time_value() }, "name" => lambda {|n| @name = n.get_string_value() }, "size" => lambda {|n| @size = n.get_number_value() }, }) end |
#last_modified_date_time ⇒ Object
Gets the lastModifiedDateTime property value. The lastModifiedDateTime property
88 89 90 |
# File 'lib/models/service_announcement_attachment.rb', line 88 def last_modified_date_time return @last_modified_date_time end |
#last_modified_date_time=(value) ⇒ Object
Sets the lastModifiedDateTime property value. The lastModifiedDateTime property
96 97 98 |
# File 'lib/models/service_announcement_attachment.rb', line 96 def last_modified_date_time=(value) @last_modified_date_time = value end |
#name ⇒ Object
Gets the name property value. The name property
103 104 105 |
# File 'lib/models/service_announcement_attachment.rb', line 103 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. The name property
111 112 113 |
# File 'lib/models/service_announcement_attachment.rb', line 111 def name=(value) @name = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
119 120 121 122 123 124 125 126 127 |
# File 'lib/models/service_announcement_attachment.rb', line 119 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("content", @content) writer.write_string_value("contentType", @content_type) writer.write_date_time_value("lastModifiedDateTime", @last_modified_date_time) writer.write_string_value("name", @name) writer.write_number_value("size", @size) end |
#size ⇒ Object
Gets the size property value. The size property
132 133 134 |
# File 'lib/models/service_announcement_attachment.rb', line 132 def size return @size end |
#size=(value) ⇒ Object
Sets the size property value. The size property
140 141 142 |
# File 'lib/models/service_announcement_attachment.rb', line 140 def size=(value) @size = value end |