Class: MicrosoftGraph::Models::ServicePlanInfo
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::ServicePlanInfo
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/service_plan_info.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#applies_to ⇒ Object
Gets the appliesTo property value.
-
#applies_to=(value) ⇒ Object
Sets the appliesTo property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new servicePlanInfo and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#provisioning_status ⇒ Object
Gets the provisioningStatus property value.
-
#provisioning_status=(value) ⇒ Object
Sets the provisioningStatus property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#service_plan_id ⇒ Object
Gets the servicePlanId property value.
-
#service_plan_id=(value) ⇒ Object
Sets the servicePlanId property value.
-
#service_plan_name ⇒ Object
Gets the servicePlanName property value.
-
#service_plan_name=(value) ⇒ Object
Sets the servicePlanName property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new servicePlanInfo and sets the default values.
61 62 63 |
# File 'lib/models/service_plan_info.rb', line 61 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
69 70 71 72 |
# File 'lib/models/service_plan_info.rb', line 69 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ServicePlanInfo.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/models/service_plan_info.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/models/service_plan_info.rb', line 39 def additional_data=(value) @additional_data = value end |
#applies_to ⇒ Object
Gets the appliesTo property value. The object the service plan can be assigned to. The possible values are:User - service plan can be assigned to individual users.Company - service plan can be assigned to the entire tenant.
46 47 48 |
# File 'lib/models/service_plan_info.rb', line 46 def applies_to return @applies_to end |
#applies_to=(value) ⇒ Object
Sets the appliesTo property value. The object the service plan can be assigned to. The possible values are:User - service plan can be assigned to individual users.Company - service plan can be assigned to the entire tenant.
54 55 56 |
# File 'lib/models/service_plan_info.rb', line 54 def applies_to=(value) @applies_to = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
77 78 79 80 81 82 83 84 85 |
# File 'lib/models/service_plan_info.rb', line 77 def get_field_deserializers() return { "appliesTo" => lambda {|n| @applies_to = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "provisioningStatus" => lambda {|n| @provisioning_status = n.get_string_value() }, "servicePlanId" => lambda {|n| @service_plan_id = n.get_guid_value() }, "servicePlanName" => lambda {|n| @service_plan_name = n.get_string_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
90 91 92 |
# File 'lib/models/service_plan_info.rb', line 90 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
98 99 100 |
# File 'lib/models/service_plan_info.rb', line 98 def odata_type=(value) @odata_type = value end |
#provisioning_status ⇒ Object
Gets the provisioningStatus property value. The provisioning status of the service plan. The possible values are:Success - Service is fully provisioned.Disabled - Service has been disabled.ErrorStatus - The service plan has not been provisioned and is in an error state.PendingInput - Service is not yet provisioned; awaiting service confirmation.PendingActivation - Service is provisioned but requires explicit activation by administrator (for example, Intune_O365 service plan)PendingProvisioning - Microsoft has added a new service to the product SKU and it has not been activated in the tenant, yet.
105 106 107 |
# File 'lib/models/service_plan_info.rb', line 105 def provisioning_status return @provisioning_status end |
#provisioning_status=(value) ⇒ Object
Sets the provisioningStatus property value. The provisioning status of the service plan. The possible values are:Success - Service is fully provisioned.Disabled - Service has been disabled.ErrorStatus - The service plan has not been provisioned and is in an error state.PendingInput - Service is not yet provisioned; awaiting service confirmation.PendingActivation - Service is provisioned but requires explicit activation by administrator (for example, Intune_O365 service plan)PendingProvisioning - Microsoft has added a new service to the product SKU and it has not been activated in the tenant, yet.
113 114 115 |
# File 'lib/models/service_plan_info.rb', line 113 def provisioning_status=(value) @provisioning_status = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
121 122 123 124 125 126 127 128 129 |
# File 'lib/models/service_plan_info.rb', line 121 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("appliesTo", @applies_to) writer.write_string_value("@odata.type", @odata_type) writer.write_string_value("provisioningStatus", @provisioning_status) writer.write_guid_value("servicePlanId", @service_plan_id) writer.write_string_value("servicePlanName", @service_plan_name) writer.write_additional_data(@additional_data) end |
#service_plan_id ⇒ Object
Gets the servicePlanId property value. The unique identifier of the service plan.
134 135 136 |
# File 'lib/models/service_plan_info.rb', line 134 def service_plan_id return @service_plan_id end |
#service_plan_id=(value) ⇒ Object
Sets the servicePlanId property value. The unique identifier of the service plan.
142 143 144 |
# File 'lib/models/service_plan_info.rb', line 142 def service_plan_id=(value) @service_plan_id = value end |
#service_plan_name ⇒ Object
Gets the servicePlanName property value. The name of the service plan.
149 150 151 |
# File 'lib/models/service_plan_info.rb', line 149 def service_plan_name return @service_plan_name end |
#service_plan_name=(value) ⇒ Object
Sets the servicePlanName property value. The name of the service plan.
157 158 159 |
# File 'lib/models/service_plan_info.rb', line 157 def service_plan_name=(value) @service_plan_name = value end |