Class: MicrosoftGraph::Models::SignIn
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/sign_in.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#app_display_name ⇒ Object
Gets the appDisplayName property value.
-
#app_display_name=(value) ⇒ Object
Sets the appDisplayName property value.
-
#app_id ⇒ Object
Gets the appId property value.
-
#app_id=(value) ⇒ Object
Sets the appId property value.
-
#applied_conditional_access_policies ⇒ Object
Gets the appliedConditionalAccessPolicies property value.
-
#applied_conditional_access_policies=(value) ⇒ Object
Sets the appliedConditionalAccessPolicies property value.
-
#client_app_used ⇒ Object
Gets the clientAppUsed property value.
-
#client_app_used=(value) ⇒ Object
Sets the clientAppUsed property value.
-
#conditional_access_status ⇒ Object
Gets the conditionalAccessStatus property value.
-
#conditional_access_status=(value) ⇒ Object
Sets the conditionalAccessStatus property value.
-
#correlation_id ⇒ Object
Gets the correlationId property value.
-
#correlation_id=(value) ⇒ Object
Sets the correlationId property value.
-
#created_date_time ⇒ Object
Gets the createdDateTime property value.
-
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value.
-
#device_detail ⇒ Object
Gets the deviceDetail property value.
-
#device_detail=(value) ⇒ Object
Sets the deviceDetail property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new signIn and sets the default values.
-
#ip_address ⇒ Object
Gets the ipAddress property value.
-
#ip_address=(value) ⇒ Object
Sets the ipAddress property value.
-
#is_interactive ⇒ Object
Gets the isInteractive property value.
-
#is_interactive=(value) ⇒ Object
Sets the isInteractive property value.
-
#location ⇒ Object
Gets the location property value.
-
#location=(value) ⇒ Object
Sets the location property value.
-
#resource_display_name ⇒ Object
Gets the resourceDisplayName property value.
-
#resource_display_name=(value) ⇒ Object
Sets the resourceDisplayName property value.
-
#resource_id ⇒ Object
Gets the resourceId property value.
-
#resource_id=(value) ⇒ Object
Sets the resourceId property value.
-
#risk_detail ⇒ Object
Gets the riskDetail property value.
-
#risk_detail=(value) ⇒ Object
Sets the riskDetail property value.
-
#risk_event_types ⇒ Object
Gets the riskEventTypes property value.
-
#risk_event_types=(value) ⇒ Object
Sets the riskEventTypes property value.
-
#risk_event_types_v2 ⇒ Object
Gets the riskEventTypes_v2 property value.
-
#risk_event_types_v2=(value) ⇒ Object
Sets the riskEventTypes_v2 property value.
-
#risk_level_aggregated ⇒ Object
Gets the riskLevelAggregated property value.
-
#risk_level_aggregated=(value) ⇒ Object
Sets the riskLevelAggregated property value.
-
#risk_level_during_sign_in ⇒ Object
Gets the riskLevelDuringSignIn property value.
-
#risk_level_during_sign_in=(value) ⇒ Object
Sets the riskLevelDuringSignIn property value.
-
#risk_state ⇒ Object
Gets the riskState property value.
-
#risk_state=(value) ⇒ Object
Sets the riskState property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#status ⇒ Object
Gets the status property value.
-
#status=(value) ⇒ Object
Sets the status property value.
-
#user_display_name ⇒ Object
Gets the userDisplayName property value.
-
#user_display_name=(value) ⇒ Object
Sets the userDisplayName property value.
-
#user_id ⇒ Object
Gets the userId property value.
-
#user_id=(value) ⇒ Object
Sets the userId property value.
-
#user_principal_name ⇒ Object
Gets the userPrincipalName property value.
-
#user_principal_name=(value) ⇒ Object
Sets the userPrincipalName property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new signIn and sets the default values.
158 159 160 |
# File 'lib/models/sign_in.rb', line 158 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
196 197 198 199 |
# File 'lib/models/sign_in.rb', line 196 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SignIn.new end |
Instance Method Details
#app_display_name ⇒ Object
Gets the appDisplayName property value. App name displayed in the Azure Portal. Supports $filter (eq, startsWith).
83 84 85 |
# File 'lib/models/sign_in.rb', line 83 def app_display_name return @app_display_name end |
#app_display_name=(value) ⇒ Object
Sets the appDisplayName property value. App name displayed in the Azure Portal. Supports $filter (eq, startsWith).
91 92 93 |
# File 'lib/models/sign_in.rb', line 91 def app_display_name=(value) @app_display_name = value end |
#app_id ⇒ Object
Gets the appId property value. Unique GUID representing the app ID in the Azure Active Directory. Supports $filter (eq).
98 99 100 |
# File 'lib/models/sign_in.rb', line 98 def app_id return @app_id end |
#app_id=(value) ⇒ Object
Sets the appId property value. Unique GUID representing the app ID in the Azure Active Directory. Supports $filter (eq).
106 107 108 |
# File 'lib/models/sign_in.rb', line 106 def app_id=(value) @app_id = value end |
#applied_conditional_access_policies ⇒ Object
Gets the appliedConditionalAccessPolicies property value. Provides a list of conditional access policies that are triggered by the corresponding sign-in activity.
113 114 115 |
# File 'lib/models/sign_in.rb', line 113 def applied_conditional_access_policies return @applied_conditional_access_policies end |
#applied_conditional_access_policies=(value) ⇒ Object
Sets the appliedConditionalAccessPolicies property value. Provides a list of conditional access policies that are triggered by the corresponding sign-in activity.
121 122 123 |
# File 'lib/models/sign_in.rb', line 121 def applied_conditional_access_policies=(value) @applied_conditional_access_policies = value end |
#client_app_used ⇒ Object
Gets the clientAppUsed property value. Identifies the client used for the sign-in activity. Modern authentication clients include Browser, modern clients. Legacy authentication clients include Exchange ActiveSync, IMAP, MAPI, SMTP, POP, and other clients. Supports $filter (eq).
128 129 130 |
# File 'lib/models/sign_in.rb', line 128 def client_app_used return @client_app_used end |
#client_app_used=(value) ⇒ Object
Sets the clientAppUsed property value. Identifies the client used for the sign-in activity. Modern authentication clients include Browser, modern clients. Legacy authentication clients include Exchange ActiveSync, IMAP, MAPI, SMTP, POP, and other clients. Supports $filter (eq).
136 137 138 |
# File 'lib/models/sign_in.rb', line 136 def client_app_used=(value) @client_app_used = value end |
#conditional_access_status ⇒ Object
Gets the conditionalAccessStatus property value. Reports status of an activated conditional access policy. Possible values are: success, failure, notApplied, and unknownFutureValue. Supports $filter (eq).
143 144 145 |
# File 'lib/models/sign_in.rb', line 143 def conditional_access_status return @conditional_access_status end |
#conditional_access_status=(value) ⇒ Object
Sets the conditionalAccessStatus property value. Reports status of an activated conditional access policy. Possible values are: success, failure, notApplied, and unknownFutureValue. Supports $filter (eq).
151 152 153 |
# File 'lib/models/sign_in.rb', line 151 def conditional_access_status=(value) @conditional_access_status = value end |
#correlation_id ⇒ Object
Gets the correlationId property value. The request ID sent from the client when the sign-in is initiated; used to troubleshoot sign-in activity. Supports $filter (eq).
165 166 167 |
# File 'lib/models/sign_in.rb', line 165 def correlation_id return @correlation_id end |
#correlation_id=(value) ⇒ Object
Sets the correlationId property value. The request ID sent from the client when the sign-in is initiated; used to troubleshoot sign-in activity. Supports $filter (eq).
173 174 175 |
# File 'lib/models/sign_in.rb', line 173 def correlation_id=(value) @correlation_id = value end |
#created_date_time ⇒ Object
Gets the createdDateTime property value. Date and time (UTC) the sign-in was initiated. Example: midnight on Jan 1, 2014 is reported as 2014-01-01T00:00:00Z. Supports $orderby, $filter (eq, le, and ge).
180 181 182 |
# File 'lib/models/sign_in.rb', line 180 def created_date_time return @created_date_time end |
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value. Date and time (UTC) the sign-in was initiated. Example: midnight on Jan 1, 2014 is reported as 2014-01-01T00:00:00Z. Supports $orderby, $filter (eq, le, and ge).
188 189 190 |
# File 'lib/models/sign_in.rb', line 188 def created_date_time=(value) @created_date_time = value end |
#device_detail ⇒ Object
Gets the deviceDetail property value. Device information from where the sign-in occurred; includes device ID, operating system, and browser. Supports $filter (eq, startsWith) on browser and operatingSytem properties.
204 205 206 |
# File 'lib/models/sign_in.rb', line 204 def device_detail return @device_detail end |
#device_detail=(value) ⇒ Object
Sets the deviceDetail property value. Device information from where the sign-in occurred; includes device ID, operating system, and browser. Supports $filter (eq, startsWith) on browser and operatingSytem properties.
212 213 214 |
# File 'lib/models/sign_in.rb', line 212 def device_detail=(value) @device_detail = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/models/sign_in.rb', line 219 def get_field_deserializers() return super.merge({ "appDisplayName" => lambda {|n| @app_display_name = n.get_string_value() }, "appId" => lambda {|n| @app_id = n.get_string_value() }, "appliedConditionalAccessPolicies" => lambda {|n| @applied_conditional_access_policies = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::AppliedConditionalAccessPolicy.create_from_discriminator_value(pn) }) }, "clientAppUsed" => lambda {|n| @client_app_used = n.get_string_value() }, "conditionalAccessStatus" => lambda {|n| @conditional_access_status = n.get_enum_value(MicrosoftGraph::Models::ConditionalAccessStatus) }, "correlationId" => lambda {|n| @correlation_id = n.get_string_value() }, "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() }, "deviceDetail" => lambda {|n| @device_detail = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::DeviceDetail.create_from_discriminator_value(pn) }) }, "ipAddress" => lambda {|n| @ip_address = n.get_string_value() }, "isInteractive" => lambda {|n| @is_interactive = n.get_boolean_value() }, "location" => lambda {|n| @location = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SignInLocation.create_from_discriminator_value(pn) }) }, "resourceDisplayName" => lambda {|n| @resource_display_name = n.get_string_value() }, "resourceId" => lambda {|n| @resource_id = n.get_string_value() }, "riskDetail" => lambda {|n| @risk_detail = n.get_enum_value(MicrosoftGraph::Models::RiskDetail) }, "riskEventTypes" => lambda {|n| @risk_event_types = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RiskEventType.create_from_discriminator_value(pn) }) }, "riskEventTypes_v2" => lambda {|n| @risk_event_types_v2 = n.get_collection_of_primitive_values(String) }, "riskLevelAggregated" => lambda {|n| @risk_level_aggregated = n.get_enum_value(MicrosoftGraph::Models::RiskLevel) }, "riskLevelDuringSignIn" => lambda {|n| @risk_level_during_sign_in = n.get_enum_value(MicrosoftGraph::Models::RiskLevel) }, "riskState" => lambda {|n| @risk_state = n.get_enum_value(MicrosoftGraph::Models::RiskState) }, "status" => lambda {|n| @status = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::SignInStatus.create_from_discriminator_value(pn) }) }, "userDisplayName" => lambda {|n| @user_display_name = n.get_string_value() }, "userId" => lambda {|n| @user_id = n.get_string_value() }, "userPrincipalName" => lambda {|n| @user_principal_name = n.get_string_value() }, }) end |
#ip_address ⇒ Object
Gets the ipAddress property value. IP address of the client used to sign in. Supports $filter (eq, startsWith).
250 251 252 |
# File 'lib/models/sign_in.rb', line 250 def ip_address return @ip_address end |
#ip_address=(value) ⇒ Object
Sets the ipAddress property value. IP address of the client used to sign in. Supports $filter (eq, startsWith).
258 259 260 |
# File 'lib/models/sign_in.rb', line 258 def ip_address=(value) @ip_address = value end |
#is_interactive ⇒ Object
Gets the isInteractive property value. Indicates if a sign-in is interactive or not.
265 266 267 |
# File 'lib/models/sign_in.rb', line 265 def is_interactive return @is_interactive end |
#is_interactive=(value) ⇒ Object
Sets the isInteractive property value. Indicates if a sign-in is interactive or not.
273 274 275 |
# File 'lib/models/sign_in.rb', line 273 def is_interactive=(value) @is_interactive = value end |
#location ⇒ Object
Gets the location property value. Provides the city, state, and country code where the sign-in originated. Supports $filter (eq, startsWith) on city, state, and countryOrRegion properties.
280 281 282 |
# File 'lib/models/sign_in.rb', line 280 def location return @location end |
#location=(value) ⇒ Object
Sets the location property value. Provides the city, state, and country code where the sign-in originated. Supports $filter (eq, startsWith) on city, state, and countryOrRegion properties.
288 289 290 |
# File 'lib/models/sign_in.rb', line 288 def location=(value) @location = value end |
#resource_display_name ⇒ Object
Gets the resourceDisplayName property value. Name of the resource the user signed into. Supports $filter (eq).
295 296 297 |
# File 'lib/models/sign_in.rb', line 295 def resource_display_name return @resource_display_name end |
#resource_display_name=(value) ⇒ Object
Sets the resourceDisplayName property value. Name of the resource the user signed into. Supports $filter (eq).
303 304 305 |
# File 'lib/models/sign_in.rb', line 303 def resource_display_name=(value) @resource_display_name = value end |
#resource_id ⇒ Object
Gets the resourceId property value. ID of the resource that the user signed into. Supports $filter (eq).
310 311 312 |
# File 'lib/models/sign_in.rb', line 310 def resource_id return @resource_id end |
#resource_id=(value) ⇒ Object
Sets the resourceId property value. ID of the resource that the user signed into. Supports $filter (eq).
318 319 320 |
# File 'lib/models/sign_in.rb', line 318 def resource_id=(value) @resource_id = value end |
#risk_detail ⇒ Object
Gets the riskDetail property value. Provides the ‘reason’ behind a specific state of a risky user, sign-in or a risk event. The possible values are: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, unknownFutureValue. The value none means that no action has been performed on the user or sign-in so far. Supports $filter (eq).Note: Details for this property require an Azure AD Premium P2 license. Other licenses return the value hidden.
325 326 327 |
# File 'lib/models/sign_in.rb', line 325 def risk_detail return @risk_detail end |
#risk_detail=(value) ⇒ Object
Sets the riskDetail property value. Provides the ‘reason’ behind a specific state of a risky user, sign-in or a risk event. The possible values are: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, unknownFutureValue. The value none means that no action has been performed on the user or sign-in so far. Supports $filter (eq).Note: Details for this property require an Azure AD Premium P2 license. Other licenses return the value hidden.
333 334 335 |
# File 'lib/models/sign_in.rb', line 333 def risk_detail=(value) @risk_detail = value end |
#risk_event_types ⇒ Object
Gets the riskEventTypes property value. Risk event types associated with the sign-in. The possible values are: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic, and unknownFutureValue. Supports $filter (eq).
340 341 342 |
# File 'lib/models/sign_in.rb', line 340 def risk_event_types return @risk_event_types end |
#risk_event_types=(value) ⇒ Object
Sets the riskEventTypes property value. Risk event types associated with the sign-in. The possible values are: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic, and unknownFutureValue. Supports $filter (eq).
348 349 350 |
# File 'lib/models/sign_in.rb', line 348 def risk_event_types=(value) @risk_event_types = value end |
#risk_event_types_v2 ⇒ Object
Gets the riskEventTypes_v2 property value. The list of risk event types associated with the sign-in. Possible values: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic, or unknownFutureValue. Supports $filter (eq, startsWith).
355 356 357 |
# File 'lib/models/sign_in.rb', line 355 def risk_event_types_v2 return @risk_event_types_v2 end |
#risk_event_types_v2=(value) ⇒ Object
Sets the riskEventTypes_v2 property value. The list of risk event types associated with the sign-in. Possible values: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic, or unknownFutureValue. Supports $filter (eq, startsWith).
363 364 365 |
# File 'lib/models/sign_in.rb', line 363 def risk_event_types_v2=(value) @risk_event_types_v2 = value end |
#risk_level_aggregated ⇒ Object
Gets the riskLevelAggregated property value. Aggregated risk level. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
370 371 372 |
# File 'lib/models/sign_in.rb', line 370 def risk_level_aggregated return @risk_level_aggregated end |
#risk_level_aggregated=(value) ⇒ Object
Sets the riskLevelAggregated property value. Aggregated risk level. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
378 379 380 |
# File 'lib/models/sign_in.rb', line 378 def risk_level_aggregated=(value) @risk_level_aggregated = value end |
#risk_level_during_sign_in ⇒ Object
Gets the riskLevelDuringSignIn property value. Risk level during sign-in. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
385 386 387 |
# File 'lib/models/sign_in.rb', line 385 def risk_level_during_sign_in return @risk_level_during_sign_in end |
#risk_level_during_sign_in=(value) ⇒ Object
Sets the riskLevelDuringSignIn property value. Risk level during sign-in. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
393 394 395 |
# File 'lib/models/sign_in.rb', line 393 def risk_level_during_sign_in=(value) @risk_level_during_sign_in = value end |
#risk_state ⇒ Object
Gets the riskState property value. Reports status of the risky user, sign-in, or a risk event. The possible values are: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, unknownFutureValue. Supports $filter (eq).
400 401 402 |
# File 'lib/models/sign_in.rb', line 400 def risk_state return @risk_state end |
#risk_state=(value) ⇒ Object
Sets the riskState property value. Reports status of the risky user, sign-in, or a risk event. The possible values are: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, unknownFutureValue. Supports $filter (eq).
408 409 410 |
# File 'lib/models/sign_in.rb', line 408 def risk_state=(value) @risk_state = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/models/sign_in.rb', line 416 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("appDisplayName", @app_display_name) writer.write_string_value("appId", @app_id) writer.write_collection_of_object_values("appliedConditionalAccessPolicies", @applied_conditional_access_policies) writer.write_string_value("clientAppUsed", @client_app_used) writer.write_enum_value("conditionalAccessStatus", @conditional_access_status) writer.write_string_value("correlationId", @correlation_id) writer.write_date_time_value("createdDateTime", @created_date_time) writer.write_object_value("deviceDetail", @device_detail) writer.write_string_value("ipAddress", @ip_address) writer.write_boolean_value("isInteractive", @is_interactive) writer.write_object_value("location", @location) writer.write_string_value("resourceDisplayName", @resource_display_name) writer.write_string_value("resourceId", @resource_id) writer.write_enum_value("riskDetail", @risk_detail) writer.write_collection_of_object_values("riskEventTypes", @risk_event_types) writer.write_collection_of_primitive_values("riskEventTypes_v2", @risk_event_types_v2) writer.write_enum_value("riskLevelAggregated", @risk_level_aggregated) writer.write_enum_value("riskLevelDuringSignIn", @risk_level_during_sign_in) writer.write_enum_value("riskState", @risk_state) writer.write_object_value("status", @status) writer.write_string_value("userDisplayName", @user_display_name) writer.write_string_value("userId", @user_id) writer.write_string_value("userPrincipalName", @user_principal_name) end |
#status ⇒ Object
Gets the status property value. Sign-in status. Includes the error code and description of the error (in case of a sign-in failure). Supports $filter (eq) on errorCode property.
447 448 449 |
# File 'lib/models/sign_in.rb', line 447 def status return @status end |
#status=(value) ⇒ Object
Sets the status property value. Sign-in status. Includes the error code and description of the error (in case of a sign-in failure). Supports $filter (eq) on errorCode property.
455 456 457 |
# File 'lib/models/sign_in.rb', line 455 def status=(value) @status = value end |
#user_display_name ⇒ Object
Gets the userDisplayName property value. Display name of the user that initiated the sign-in. Supports $filter (eq, startsWith).
462 463 464 |
# File 'lib/models/sign_in.rb', line 462 def user_display_name return @user_display_name end |
#user_display_name=(value) ⇒ Object
Sets the userDisplayName property value. Display name of the user that initiated the sign-in. Supports $filter (eq, startsWith).
470 471 472 |
# File 'lib/models/sign_in.rb', line 470 def user_display_name=(value) @user_display_name = value end |
#user_id ⇒ Object
Gets the userId property value. ID of the user that initiated the sign-in. Supports $filter (eq).
477 478 479 |
# File 'lib/models/sign_in.rb', line 477 def user_id return @user_id end |
#user_id=(value) ⇒ Object
Sets the userId property value. ID of the user that initiated the sign-in. Supports $filter (eq).
485 486 487 |
# File 'lib/models/sign_in.rb', line 485 def user_id=(value) @user_id = value end |
#user_principal_name ⇒ Object
Gets the userPrincipalName property value. User principal name of the user that initiated the sign-in. Supports $filter (eq, startsWith).
492 493 494 |
# File 'lib/models/sign_in.rb', line 492 def user_principal_name return @user_principal_name end |
#user_principal_name=(value) ⇒ Object
Sets the userPrincipalName property value. User principal name of the user that initiated the sign-in. Supports $filter (eq, startsWith).
500 501 502 |
# File 'lib/models/sign_in.rb', line 500 def user_principal_name=(value) @user_principal_name = value end |