Class: MicrosoftGraph::Models::TermStoreSet
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/term_store_set.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#children ⇒ Object
Gets the children property value.
-
#children=(value) ⇒ Object
Sets the children property value.
-
#created_date_time ⇒ Object
Gets the createdDateTime property value.
-
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new termStoreSet and sets the default values.
-
#localized_names ⇒ Object
Gets the localizedNames property value.
-
#localized_names=(value) ⇒ Object
Sets the localizedNames property value.
-
#parent_group ⇒ Object
Gets the parentGroup property value.
-
#parent_group=(value) ⇒ Object
Sets the parentGroup property value.
-
#properties ⇒ Object
Gets the properties property value.
-
#properties=(value) ⇒ Object
Sets the properties property value.
-
#relations ⇒ Object
Gets the relations property value.
-
#relations=(value) ⇒ Object
Sets the relations property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#terms ⇒ Object
Gets the terms property value.
-
#terms=(value) ⇒ Object
Sets the terms property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new termStoreSet and sets the default values.
53 54 55 |
# File 'lib/models/term_store_set.rb', line 53 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
76 77 78 79 |
# File 'lib/models/term_store_set.rb', line 76 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return TermStoreSet.new end |
Instance Method Details
#children ⇒ Object
Gets the children property value. Children terms of set in term [store].
38 39 40 |
# File 'lib/models/term_store_set.rb', line 38 def children return @children end |
#children=(value) ⇒ Object
Sets the children property value. Children terms of set in term [store].
46 47 48 |
# File 'lib/models/term_store_set.rb', line 46 def children=(value) @children = value end |
#created_date_time ⇒ Object
Gets the createdDateTime property value. Date and time of set creation. Read-only.
60 61 62 |
# File 'lib/models/term_store_set.rb', line 60 def created_date_time return @created_date_time end |
#created_date_time=(value) ⇒ Object
Sets the createdDateTime property value. Date and time of set creation. Read-only.
68 69 70 |
# File 'lib/models/term_store_set.rb', line 68 def created_date_time=(value) @created_date_time = value end |
#description ⇒ Object
Gets the description property value. Description that gives details on the term usage.
84 85 86 |
# File 'lib/models/term_store_set.rb', line 84 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. Description that gives details on the term usage.
92 93 94 |
# File 'lib/models/term_store_set.rb', line 92 def description=(value) @description = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/models/term_store_set.rb', line 99 def get_field_deserializers() return super.merge({ "children" => lambda {|n| @children = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreTerm.create_from_discriminator_value(pn) }) }, "createdDateTime" => lambda {|n| @created_date_time = n.get_date_time_value() }, "description" => lambda {|n| @description = n.get_string_value() }, "localizedNames" => lambda {|n| @localized_names = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreLocalizedName.create_from_discriminator_value(pn) }) }, "parentGroup" => lambda {|n| @parent_group = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::TermStoreGroup.create_from_discriminator_value(pn) }) }, "properties" => lambda {|n| @properties = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::KeyValue.create_from_discriminator_value(pn) }) }, "relations" => lambda {|n| @relations = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreRelation.create_from_discriminator_value(pn) }) }, "terms" => lambda {|n| @terms = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::TermStoreTerm.create_from_discriminator_value(pn) }) }, }) end |
#localized_names ⇒ Object
Gets the localizedNames property value. Name of the set for each languageTag.
115 116 117 |
# File 'lib/models/term_store_set.rb', line 115 def localized_names return @localized_names end |
#localized_names=(value) ⇒ Object
Sets the localizedNames property value. Name of the set for each languageTag.
123 124 125 |
# File 'lib/models/term_store_set.rb', line 123 def localized_names=(value) @localized_names = value end |
#parent_group ⇒ Object
Gets the parentGroup property value. The parentGroup property
130 131 132 |
# File 'lib/models/term_store_set.rb', line 130 def parent_group return @parent_group end |
#parent_group=(value) ⇒ Object
Sets the parentGroup property value. The parentGroup property
138 139 140 |
# File 'lib/models/term_store_set.rb', line 138 def parent_group=(value) @parent_group = value end |
#properties ⇒ Object
Gets the properties property value. Custom properties for the set.
145 146 147 |
# File 'lib/models/term_store_set.rb', line 145 def properties return @properties end |
#properties=(value) ⇒ Object
Sets the properties property value. Custom properties for the set.
153 154 155 |
# File 'lib/models/term_store_set.rb', line 153 def properties=(value) @properties = value end |
#relations ⇒ Object
Gets the relations property value. Indicates which terms have been pinned or reused directly under the set.
160 161 162 |
# File 'lib/models/term_store_set.rb', line 160 def relations return @relations end |
#relations=(value) ⇒ Object
Sets the relations property value. Indicates which terms have been pinned or reused directly under the set.
168 169 170 |
# File 'lib/models/term_store_set.rb', line 168 def relations=(value) @relations = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/models/term_store_set.rb', line 176 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_collection_of_object_values("children", @children) writer.write_date_time_value("createdDateTime", @created_date_time) writer.write_string_value("description", @description) writer.write_collection_of_object_values("localizedNames", @localized_names) writer.write_object_value("parentGroup", @parent_group) writer.write_collection_of_object_values("properties", @properties) writer.write_collection_of_object_values("relations", @relations) writer.write_collection_of_object_values("terms", @terms) end |
#terms ⇒ Object
Gets the terms property value. All the terms under the set.
192 193 194 |
# File 'lib/models/term_store_set.rb', line 192 def terms return @terms end |
#terms=(value) ⇒ Object
Sets the terms property value. All the terms under the set.
200 201 202 |
# File 'lib/models/term_store_set.rb', line 200 def terms=(value) @terms = value end |