Class: MicrosoftGraph::Models::ThumbnailSet
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/thumbnail_set.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new thumbnailSet and sets the default values.
-
#large ⇒ Object
Gets the large property value.
-
#large=(value) ⇒ Object
Sets the large property value.
-
#medium ⇒ Object
Gets the medium property value.
-
#medium=(value) ⇒ Object
Sets the medium property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#small ⇒ Object
Gets the small property value.
-
#small=(value) ⇒ Object
Sets the small property value.
-
#source ⇒ Object
Gets the source property value.
-
#source=(value) ⇒ Object
Sets the source property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new thumbnailSet and sets the default values.
25 26 27 |
# File 'lib/models/thumbnail_set.rb', line 25 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
33 34 35 36 |
# File 'lib/models/thumbnail_set.rb', line 33 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ThumbnailSet.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
41 42 43 44 45 46 47 48 |
# File 'lib/models/thumbnail_set.rb', line 41 def get_field_deserializers() return super.merge({ "large" => lambda {|n| @large = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) }, "medium" => lambda {|n| @medium = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) }, "small" => lambda {|n| @small = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) }, "source" => lambda {|n| @source = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Thumbnail.create_from_discriminator_value(pn) }) }, }) end |
#large ⇒ Object
Gets the large property value. A 1920x1920 scaled thumbnail.
53 54 55 |
# File 'lib/models/thumbnail_set.rb', line 53 def large return @large end |
#large=(value) ⇒ Object
Sets the large property value. A 1920x1920 scaled thumbnail.
61 62 63 |
# File 'lib/models/thumbnail_set.rb', line 61 def large=(value) @large = value end |
#medium ⇒ Object
Gets the medium property value. A 176x176 scaled thumbnail.
68 69 70 |
# File 'lib/models/thumbnail_set.rb', line 68 def medium return @medium end |
#medium=(value) ⇒ Object
Sets the medium property value. A 176x176 scaled thumbnail.
76 77 78 |
# File 'lib/models/thumbnail_set.rb', line 76 def medium=(value) @medium = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
84 85 86 87 88 89 90 91 |
# File 'lib/models/thumbnail_set.rb', line 84 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("large", @large) writer.write_object_value("medium", @medium) writer.write_object_value("small", @small) writer.write_object_value("source", @source) end |
#small ⇒ Object
Gets the small property value. A 48x48 cropped thumbnail.
96 97 98 |
# File 'lib/models/thumbnail_set.rb', line 96 def small return @small end |
#small=(value) ⇒ Object
Sets the small property value. A 48x48 cropped thumbnail.
104 105 106 |
# File 'lib/models/thumbnail_set.rb', line 104 def small=(value) @small = value end |
#source ⇒ Object
Gets the source property value. A custom thumbnail image or the original image used to generate other thumbnails.
111 112 113 |
# File 'lib/models/thumbnail_set.rb', line 111 def source return @source end |
#source=(value) ⇒ Object
Sets the source property value. A custom thumbnail image or the original image used to generate other thumbnails.
119 120 121 |
# File 'lib/models/thumbnail_set.rb', line 119 def source=(value) @source = value end |