Class: MicrosoftGraph::Models::UserExperienceAnalyticsAutopilotDevicesSummary
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::UserExperienceAnalyticsAutopilotDevicesSummary
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/user_experience_analytics_autopilot_devices_summary.rb
Overview
The user experience analytics summary of Devices not windows autopilot ready.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#devices_not_autopilot_registered ⇒ Object
Gets the devicesNotAutopilotRegistered property value.
-
#devices_not_autopilot_registered=(value) ⇒ Object
Sets the devicesNotAutopilotRegistered property value.
-
#devices_without_autopilot_profile_assigned ⇒ Object
Gets the devicesWithoutAutopilotProfileAssigned property value.
-
#devices_without_autopilot_profile_assigned=(value) ⇒ Object
Sets the devicesWithoutAutopilotProfileAssigned property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new userExperienceAnalyticsAutopilotDevicesSummary and sets the default values.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#total_windows10_devices_without_tenant_attached ⇒ Object
Gets the totalWindows10DevicesWithoutTenantAttached property value.
-
#total_windows10_devices_without_tenant_attached=(value) ⇒ Object
Sets the totalWindows10DevicesWithoutTenantAttached property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new userExperienceAnalyticsAutopilotDevicesSummary and sets the default values.
45 46 47 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 45 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
53 54 55 56 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 53 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UserExperienceAnalyticsAutopilotDevicesSummary.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 30 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 38 def additional_data=(value) @additional_data = value end |
#devices_not_autopilot_registered ⇒ Object
Gets the devicesNotAutopilotRegistered property value. The count of intune devices that are not autopilot registerd. Read-only.
61 62 63 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 61 def devices_not_autopilot_registered return @devices_not_autopilot_registered end |
#devices_not_autopilot_registered=(value) ⇒ Object
Sets the devicesNotAutopilotRegistered property value. The count of intune devices that are not autopilot registerd. Read-only.
69 70 71 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 69 def devices_not_autopilot_registered=(value) @devices_not_autopilot_registered = value end |
#devices_without_autopilot_profile_assigned ⇒ Object
Gets the devicesWithoutAutopilotProfileAssigned property value. The count of intune devices not autopilot profile assigned. Read-only.
76 77 78 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 76 def devices_without_autopilot_profile_assigned return @devices_without_autopilot_profile_assigned end |
#devices_without_autopilot_profile_assigned=(value) ⇒ Object
Sets the devicesWithoutAutopilotProfileAssigned property value. The count of intune devices not autopilot profile assigned. Read-only.
84 85 86 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 84 def devices_without_autopilot_profile_assigned=(value) @devices_without_autopilot_profile_assigned = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
91 92 93 94 95 96 97 98 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 91 def get_field_deserializers() return { "devicesNotAutopilotRegistered" => lambda {|n| @devices_not_autopilot_registered = n.get_number_value() }, "devicesWithoutAutopilotProfileAssigned" => lambda {|n| @devices_without_autopilot_profile_assigned = n.get_number_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "totalWindows10DevicesWithoutTenantAttached" => lambda {|n| @total_windows10_devices_without_tenant_attached = n.get_number_value() }, } end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
103 104 105 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 103 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
111 112 113 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 111 def odata_type=(value) @odata_type = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
119 120 121 122 123 124 125 126 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 119 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("devicesNotAutopilotRegistered", @devices_not_autopilot_registered) writer.write_number_value("devicesWithoutAutopilotProfileAssigned", @devices_without_autopilot_profile_assigned) writer.write_string_value("@odata.type", @odata_type) writer.write_number_value("totalWindows10DevicesWithoutTenantAttached", @total_windows10_devices_without_tenant_attached) writer.write_additional_data(@additional_data) end |
#total_windows10_devices_without_tenant_attached ⇒ Object
Gets the totalWindows10DevicesWithoutTenantAttached property value. The count of windows 10 devices that are Intune and co-managed. Read-only.
131 132 133 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 131 def total_windows10_devices_without_tenant_attached return @total_windows10_devices_without_tenant_attached end |
#total_windows10_devices_without_tenant_attached=(value) ⇒ Object
Sets the totalWindows10DevicesWithoutTenantAttached property value. The count of windows 10 devices that are Intune and co-managed. Read-only.
139 140 141 |
# File 'lib/models/user_experience_analytics_autopilot_devices_summary.rb', line 139 def total_windows10_devices_without_tenant_attached=(value) @total_windows10_devices_without_tenant_attached = value end |