Class: MicrosoftGraph::Models::UserExperienceAnalyticsScoreHistory
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/user_experience_analytics_score_history.rb
Overview
The user experience analytics device startup score history.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new userExperienceAnalyticsScoreHistory and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#startup_date_time ⇒ Object
Gets the startupDateTime property value.
-
#startup_date_time=(value) ⇒ Object
Sets the startupDateTime property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new userExperienceAnalyticsScoreHistory and sets the default values.
19 20 21 |
# File 'lib/models/user_experience_analytics_score_history.rb', line 19 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
27 28 29 30 |
# File 'lib/models/user_experience_analytics_score_history.rb', line 27 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UserExperienceAnalyticsScoreHistory.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
35 36 37 38 39 |
# File 'lib/models/user_experience_analytics_score_history.rb', line 35 def get_field_deserializers() return super.merge({ "startupDateTime" => lambda {|n| @startup_date_time = n.get_date_time_value() }, }) end |
#serialize(writer) ⇒ Object
Serializes information the current object
45 46 47 48 49 |
# File 'lib/models/user_experience_analytics_score_history.rb', line 45 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_date_time_value("startupDateTime", @startup_date_time) end |
#startup_date_time ⇒ Object
Gets the startupDateTime property value. The device startup date time. The value cannot be modified and is automatically populated. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 would look like this: ‘2014-01-01T00:00:00Z’. Returned by default.
54 55 56 |
# File 'lib/models/user_experience_analytics_score_history.rb', line 54 def startup_date_time return @startup_date_time end |
#startup_date_time=(value) ⇒ Object
Sets the startupDateTime property value. The device startup date time. The value cannot be modified and is automatically populated. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 would look like this: ‘2014-01-01T00:00:00Z’. Returned by default.
62 63 64 |
# File 'lib/models/user_experience_analytics_score_history.rb', line 62 def startup_date_time=(value) @startup_date_time = value end |