Class: MicrosoftGraph::Models::WebApplication
- Inherits:
-
Object
- Object
- MicrosoftGraph::Models::WebApplication
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/web_application.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#home_page_url ⇒ Object
Gets the homePageUrl property value.
-
#home_page_url=(value) ⇒ Object
Sets the homePageUrl property value.
-
#implicit_grant_settings ⇒ Object
Gets the implicitGrantSettings property value.
-
#implicit_grant_settings=(value) ⇒ Object
Sets the implicitGrantSettings property value.
-
#initialize ⇒ Object
constructor
Instantiates a new webApplication and sets the default values.
-
#logout_url ⇒ Object
Gets the logoutUrl property value.
-
#logout_url=(value) ⇒ Object
Sets the logoutUrl property value.
-
#odata_type ⇒ Object
Gets the @odata.type property value.
-
#odata_type=(value) ⇒ Object
Sets the @odata.type property value.
-
#redirect_uri_settings ⇒ Object
Gets the redirectUriSettings property value.
-
#redirect_uri_settings=(value) ⇒ Object
Sets the redirectUriSettings property value.
-
#redirect_uris ⇒ Object
Gets the redirectUris property value.
-
#redirect_uris=(value) ⇒ Object
Sets the redirectUris property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new webApplication and sets the default values.
49 50 51 |
# File 'lib/models/web_application.rb', line 49 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
57 58 59 60 |
# File 'lib/models/web_application.rb', line 57 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WebApplication.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
34 35 36 |
# File 'lib/models/web_application.rb', line 34 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
42 43 44 |
# File 'lib/models/web_application.rb', line 42 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
65 66 67 68 69 70 71 72 73 74 |
# File 'lib/models/web_application.rb', line 65 def get_field_deserializers() return { "homePageUrl" => lambda {|n| @home_page_url = n.get_string_value() }, "implicitGrantSettings" => lambda {|n| @implicit_grant_settings = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ImplicitGrantSettings.create_from_discriminator_value(pn) }) }, "logoutUrl" => lambda {|n| @logout_url = n.get_string_value() }, "@odata.type" => lambda {|n| @odata_type = n.get_string_value() }, "redirectUriSettings" => lambda {|n| @redirect_uri_settings = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::RedirectUriSettings.create_from_discriminator_value(pn) }) }, "redirectUris" => lambda {|n| @redirect_uris = n.get_collection_of_primitive_values(String) }, } end |
#home_page_url ⇒ Object
Gets the homePageUrl property value. Home page or landing page of the application.
79 80 81 |
# File 'lib/models/web_application.rb', line 79 def home_page_url return @home_page_url end |
#home_page_url=(value) ⇒ Object
Sets the homePageUrl property value. Home page or landing page of the application.
87 88 89 |
# File 'lib/models/web_application.rb', line 87 def home_page_url=(value) @home_page_url = value end |
#implicit_grant_settings ⇒ Object
Gets the implicitGrantSettings property value. Specifies whether this web application can request tokens using the OAuth 2.0 implicit flow.
94 95 96 |
# File 'lib/models/web_application.rb', line 94 def implicit_grant_settings return @implicit_grant_settings end |
#implicit_grant_settings=(value) ⇒ Object
Sets the implicitGrantSettings property value. Specifies whether this web application can request tokens using the OAuth 2.0 implicit flow.
102 103 104 |
# File 'lib/models/web_application.rb', line 102 def implicit_grant_settings=(value) @implicit_grant_settings = value end |
#logout_url ⇒ Object
Gets the logoutUrl property value. Specifies the URL that will be used by Microsoft’s authorization service to logout an user using front-channel, back-channel or SAML logout protocols.
109 110 111 |
# File 'lib/models/web_application.rb', line 109 def logout_url return @logout_url end |
#logout_url=(value) ⇒ Object
Sets the logoutUrl property value. Specifies the URL that will be used by Microsoft’s authorization service to logout an user using front-channel, back-channel or SAML logout protocols.
117 118 119 |
# File 'lib/models/web_application.rb', line 117 def logout_url=(value) @logout_url = value end |
#odata_type ⇒ Object
Gets the @odata.type property value. The OdataType property
124 125 126 |
# File 'lib/models/web_application.rb', line 124 def odata_type return @odata_type end |
#odata_type=(value) ⇒ Object
Sets the @odata.type property value. The OdataType property
132 133 134 |
# File 'lib/models/web_application.rb', line 132 def odata_type=(value) @odata_type = value end |
#redirect_uri_settings ⇒ Object
Gets the redirectUriSettings property value. The redirectUriSettings property
139 140 141 |
# File 'lib/models/web_application.rb', line 139 def redirect_uri_settings return @redirect_uri_settings end |
#redirect_uri_settings=(value) ⇒ Object
Sets the redirectUriSettings property value. The redirectUriSettings property
147 148 149 |
# File 'lib/models/web_application.rb', line 147 def redirect_uri_settings=(value) @redirect_uri_settings = value end |
#redirect_uris ⇒ Object
Gets the redirectUris property value. Specifies the URLs where user tokens are sent for sign-in, or the redirect URIs where OAuth 2.0 authorization codes and access tokens are sent.
154 155 156 |
# File 'lib/models/web_application.rb', line 154 def redirect_uris return @redirect_uris end |
#redirect_uris=(value) ⇒ Object
Sets the redirectUris property value. Specifies the URLs where user tokens are sent for sign-in, or the redirect URIs where OAuth 2.0 authorization codes and access tokens are sent.
162 163 164 |
# File 'lib/models/web_application.rb', line 162 def redirect_uris=(value) @redirect_uris = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/models/web_application.rb', line 170 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("homePageUrl", @home_page_url) writer.write_object_value("implicitGrantSettings", @implicit_grant_settings) writer.write_string_value("logoutUrl", @logout_url) writer.write_string_value("@odata.type", @odata_type) writer.write_collection_of_object_values("redirectUriSettings", @redirect_uri_settings) writer.write_collection_of_primitive_values("redirectUris", @redirect_uris) writer.write_additional_data(@additional_data) end |