Class: MicrosoftGraph::Models::Win32LobApp
- Inherits:
-
MobileLobApp
- Object
- Entity
- MobileApp
- MobileLobApp
- MicrosoftGraph::Models::Win32LobApp
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/win32_lob_app.rb
Overview
Contains properties and inherited properties for Win32 apps.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#applicable_architectures ⇒ Object
Gets the applicableArchitectures property value.
-
#applicable_architectures=(value) ⇒ Object
Sets the applicableArchitectures property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new win32LobApp and sets the default values.
-
#install_command_line ⇒ Object
Gets the installCommandLine property value.
-
#install_command_line=(value) ⇒ Object
Sets the installCommandLine property value.
-
#install_experience ⇒ Object
Gets the installExperience property value.
-
#install_experience=(value) ⇒ Object
Sets the installExperience property value.
-
#minimum_cpu_speed_in_m_hz ⇒ Object
Gets the minimumCpuSpeedInMHz property value.
-
#minimum_cpu_speed_in_m_hz=(value) ⇒ Object
Sets the minimumCpuSpeedInMHz property value.
-
#minimum_free_disk_space_in_m_b ⇒ Object
Gets the minimumFreeDiskSpaceInMB property value.
-
#minimum_free_disk_space_in_m_b=(value) ⇒ Object
Sets the minimumFreeDiskSpaceInMB property value.
-
#minimum_memory_in_m_b ⇒ Object
Gets the minimumMemoryInMB property value.
-
#minimum_memory_in_m_b=(value) ⇒ Object
Sets the minimumMemoryInMB property value.
-
#minimum_number_of_processors ⇒ Object
Gets the minimumNumberOfProcessors property value.
-
#minimum_number_of_processors=(value) ⇒ Object
Sets the minimumNumberOfProcessors property value.
-
#minimum_supported_windows_release ⇒ Object
Gets the minimumSupportedWindowsRelease property value.
-
#minimum_supported_windows_release=(value) ⇒ Object
Sets the minimumSupportedWindowsRelease property value.
-
#msi_information ⇒ Object
Gets the msiInformation property value.
-
#msi_information=(value) ⇒ Object
Sets the msiInformation property value.
-
#return_codes ⇒ Object
Gets the returnCodes property value.
-
#return_codes=(value) ⇒ Object
Sets the returnCodes property value.
-
#rules ⇒ Object
Gets the rules property value.
-
#rules=(value) ⇒ Object
Sets the rules property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#setup_file_path ⇒ Object
Gets the setupFilePath property value.
-
#setup_file_path=(value) ⇒ Object
Sets the setupFilePath property value.
-
#uninstall_command_line ⇒ Object
Gets the uninstallCommandLine property value.
-
#uninstall_command_line=(value) ⇒ Object
Sets the uninstallCommandLine property value.
Methods inherited from MobileLobApp
#committed_content_version, #committed_content_version=, #content_versions, #content_versions=, #file_name, #file_name=, #size, #size=
Methods inherited from MobileApp
#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new win32LobApp and sets the default values.
69 70 71 72 |
# File 'lib/models/win32_lob_app.rb', line 69 def initialize() super @odata_type = "#microsoft.graph.win32LobApp" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
78 79 80 81 |
# File 'lib/models/win32_lob_app.rb', line 78 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return Win32LobApp.new end |
Instance Method Details
#applicable_architectures ⇒ Object
Gets the applicableArchitectures property value. Contains properties for Windows architecture.
54 55 56 |
# File 'lib/models/win32_lob_app.rb', line 54 def applicable_architectures return @applicable_architectures end |
#applicable_architectures=(value) ⇒ Object
Sets the applicableArchitectures property value. Contains properties for Windows architecture.
62 63 64 |
# File 'lib/models/win32_lob_app.rb', line 62 def applicable_architectures=(value) @applicable_architectures = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/models/win32_lob_app.rb', line 86 def get_field_deserializers() return super.merge({ "applicableArchitectures" => lambda {|n| @applicable_architectures = n.get_enum_value(MicrosoftGraph::Models::WindowsArchitecture) }, "installCommandLine" => lambda {|n| @install_command_line = n.get_string_value() }, "installExperience" => lambda {|n| @install_experience = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Win32LobAppInstallExperience.create_from_discriminator_value(pn) }) }, "minimumCpuSpeedInMHz" => lambda {|n| @minimum_cpu_speed_in_m_hz = n.get_number_value() }, "minimumFreeDiskSpaceInMB" => lambda {|n| @minimum_free_disk_space_in_m_b = n.get_number_value() }, "minimumMemoryInMB" => lambda {|n| @minimum_memory_in_m_b = n.get_number_value() }, "minimumNumberOfProcessors" => lambda {|n| @minimum_number_of_processors = n.get_number_value() }, "minimumSupportedWindowsRelease" => lambda {|n| @minimum_supported_windows_release = n.get_string_value() }, "msiInformation" => lambda {|n| @msi_information = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::Win32LobAppMsiInformation.create_from_discriminator_value(pn) }) }, "returnCodes" => lambda {|n| @return_codes = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Win32LobAppReturnCode.create_from_discriminator_value(pn) }) }, "rules" => lambda {|n| @rules = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::Win32LobAppRule.create_from_discriminator_value(pn) }) }, "setupFilePath" => lambda {|n| @setup_file_path = n.get_string_value() }, "uninstallCommandLine" => lambda {|n| @uninstall_command_line = n.get_string_value() }, }) end |
#install_command_line ⇒ Object
Gets the installCommandLine property value. The command line to install this app
107 108 109 |
# File 'lib/models/win32_lob_app.rb', line 107 def install_command_line return @install_command_line end |
#install_command_line=(value) ⇒ Object
Sets the installCommandLine property value. The command line to install this app
115 116 117 |
# File 'lib/models/win32_lob_app.rb', line 115 def install_command_line=(value) @install_command_line = value end |
#install_experience ⇒ Object
Gets the installExperience property value. The install experience for this app.
122 123 124 |
# File 'lib/models/win32_lob_app.rb', line 122 def install_experience return @install_experience end |
#install_experience=(value) ⇒ Object
Sets the installExperience property value. The install experience for this app.
130 131 132 |
# File 'lib/models/win32_lob_app.rb', line 130 def install_experience=(value) @install_experience = value end |
#minimum_cpu_speed_in_m_hz ⇒ Object
Gets the minimumCpuSpeedInMHz property value. The value for the minimum CPU speed which is required to install this app.
137 138 139 |
# File 'lib/models/win32_lob_app.rb', line 137 def minimum_cpu_speed_in_m_hz return @minimum_cpu_speed_in_m_hz end |
#minimum_cpu_speed_in_m_hz=(value) ⇒ Object
Sets the minimumCpuSpeedInMHz property value. The value for the minimum CPU speed which is required to install this app.
145 146 147 |
# File 'lib/models/win32_lob_app.rb', line 145 def minimum_cpu_speed_in_m_hz=(value) @minimum_cpu_speed_in_m_hz = value end |
#minimum_free_disk_space_in_m_b ⇒ Object
Gets the minimumFreeDiskSpaceInMB property value. The value for the minimum free disk space which is required to install this app.
152 153 154 |
# File 'lib/models/win32_lob_app.rb', line 152 def minimum_free_disk_space_in_m_b return @minimum_free_disk_space_in_m_b end |
#minimum_free_disk_space_in_m_b=(value) ⇒ Object
Sets the minimumFreeDiskSpaceInMB property value. The value for the minimum free disk space which is required to install this app.
160 161 162 |
# File 'lib/models/win32_lob_app.rb', line 160 def minimum_free_disk_space_in_m_b=(value) @minimum_free_disk_space_in_m_b = value end |
#minimum_memory_in_m_b ⇒ Object
Gets the minimumMemoryInMB property value. The value for the minimum physical memory which is required to install this app.
167 168 169 |
# File 'lib/models/win32_lob_app.rb', line 167 def minimum_memory_in_m_b return @minimum_memory_in_m_b end |
#minimum_memory_in_m_b=(value) ⇒ Object
Sets the minimumMemoryInMB property value. The value for the minimum physical memory which is required to install this app.
175 176 177 |
# File 'lib/models/win32_lob_app.rb', line 175 def minimum_memory_in_m_b=(value) @minimum_memory_in_m_b = value end |
#minimum_number_of_processors ⇒ Object
Gets the minimumNumberOfProcessors property value. The value for the minimum number of processors which is required to install this app.
182 183 184 |
# File 'lib/models/win32_lob_app.rb', line 182 def minimum_number_of_processors return @minimum_number_of_processors end |
#minimum_number_of_processors=(value) ⇒ Object
Sets the minimumNumberOfProcessors property value. The value for the minimum number of processors which is required to install this app.
190 191 192 |
# File 'lib/models/win32_lob_app.rb', line 190 def minimum_number_of_processors=(value) @minimum_number_of_processors = value end |
#minimum_supported_windows_release ⇒ Object
Gets the minimumSupportedWindowsRelease property value. The value for the minimum supported windows release.
197 198 199 |
# File 'lib/models/win32_lob_app.rb', line 197 def minimum_supported_windows_release return @minimum_supported_windows_release end |
#minimum_supported_windows_release=(value) ⇒ Object
Sets the minimumSupportedWindowsRelease property value. The value for the minimum supported windows release.
205 206 207 |
# File 'lib/models/win32_lob_app.rb', line 205 def minimum_supported_windows_release=(value) @minimum_supported_windows_release = value end |
#msi_information ⇒ Object
Gets the msiInformation property value. The MSI details if this Win32 app is an MSI app.
212 213 214 |
# File 'lib/models/win32_lob_app.rb', line 212 def msi_information return @msi_information end |
#msi_information=(value) ⇒ Object
Sets the msiInformation property value. The MSI details if this Win32 app is an MSI app.
220 221 222 |
# File 'lib/models/win32_lob_app.rb', line 220 def msi_information=(value) @msi_information = value end |
#return_codes ⇒ Object
Gets the returnCodes property value. The return codes for post installation behavior.
227 228 229 |
# File 'lib/models/win32_lob_app.rb', line 227 def return_codes return @return_codes end |
#return_codes=(value) ⇒ Object
Sets the returnCodes property value. The return codes for post installation behavior.
235 236 237 |
# File 'lib/models/win32_lob_app.rb', line 235 def return_codes=(value) @return_codes = value end |
#rules ⇒ Object
Gets the rules property value. The detection and requirement rules for this app.
242 243 244 |
# File 'lib/models/win32_lob_app.rb', line 242 def rules return @rules end |
#rules=(value) ⇒ Object
Sets the rules property value. The detection and requirement rules for this app.
250 251 252 |
# File 'lib/models/win32_lob_app.rb', line 250 def rules=(value) @rules = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/models/win32_lob_app.rb', line 258 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_enum_value("applicableArchitectures", @applicable_architectures) writer.write_string_value("installCommandLine", @install_command_line) writer.write_object_value("installExperience", @install_experience) writer.write_number_value("minimumCpuSpeedInMHz", @minimum_cpu_speed_in_m_hz) writer.write_number_value("minimumFreeDiskSpaceInMB", @minimum_free_disk_space_in_m_b) writer.write_number_value("minimumMemoryInMB", @minimum_memory_in_m_b) writer.write_number_value("minimumNumberOfProcessors", @minimum_number_of_processors) writer.write_string_value("minimumSupportedWindowsRelease", @minimum_supported_windows_release) writer.write_object_value("msiInformation", @msi_information) writer.write_collection_of_object_values("returnCodes", @return_codes) writer.write_collection_of_object_values("rules", @rules) writer.write_string_value("setupFilePath", @setup_file_path) writer.write_string_value("uninstallCommandLine", @uninstall_command_line) end |
#setup_file_path ⇒ Object
Gets the setupFilePath property value. The relative path of the setup file in the encrypted Win32LobApp package.
279 280 281 |
# File 'lib/models/win32_lob_app.rb', line 279 def setup_file_path return @setup_file_path end |
#setup_file_path=(value) ⇒ Object
Sets the setupFilePath property value. The relative path of the setup file in the encrypted Win32LobApp package.
287 288 289 |
# File 'lib/models/win32_lob_app.rb', line 287 def setup_file_path=(value) @setup_file_path = value end |
#uninstall_command_line ⇒ Object
Gets the uninstallCommandLine property value. The command line to uninstall this app
294 295 296 |
# File 'lib/models/win32_lob_app.rb', line 294 def uninstall_command_line return @uninstall_command_line end |
#uninstall_command_line=(value) ⇒ Object
Sets the uninstallCommandLine property value. The command line to uninstall this app
302 303 304 |
# File 'lib/models/win32_lob_app.rb', line 302 def uninstall_command_line=(value) @uninstall_command_line = value end |