Class: MicrosoftGraph::Models::WindowsInformationProtectionPolicy
- Inherits:
-
WindowsInformationProtection
- Object
- Entity
- ManagedAppPolicy
- WindowsInformationProtection
- MicrosoftGraph::Models::WindowsInformationProtectionPolicy
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/windows_information_protection_policy.rb
Overview
Policy for Windows information protection without MDM
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#days_without_contact_before_unenroll ⇒ Object
Gets the daysWithoutContactBeforeUnenroll property value.
-
#days_without_contact_before_unenroll=(value) ⇒ Object
Sets the daysWithoutContactBeforeUnenroll property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new windowsInformationProtectionPolicy and sets the default values.
-
#mdm_enrollment_url ⇒ Object
Gets the mdmEnrollmentUrl property value.
-
#mdm_enrollment_url=(value) ⇒ Object
Sets the mdmEnrollmentUrl property value.
-
#minutes_of_inactivity_before_device_lock ⇒ Object
Gets the minutesOfInactivityBeforeDeviceLock property value.
-
#minutes_of_inactivity_before_device_lock=(value) ⇒ Object
Sets the minutesOfInactivityBeforeDeviceLock property value.
-
#number_of_past_pins_remembered ⇒ Object
Gets the numberOfPastPinsRemembered property value.
-
#number_of_past_pins_remembered=(value) ⇒ Object
Sets the numberOfPastPinsRemembered property value.
-
#password_maximum_attempt_count ⇒ Object
Gets the passwordMaximumAttemptCount property value.
-
#password_maximum_attempt_count=(value) ⇒ Object
Sets the passwordMaximumAttemptCount property value.
-
#pin_expiration_days ⇒ Object
Gets the pinExpirationDays property value.
-
#pin_expiration_days=(value) ⇒ Object
Sets the pinExpirationDays property value.
-
#pin_lowercase_letters ⇒ Object
Gets the pinLowercaseLetters property value.
-
#pin_lowercase_letters=(value) ⇒ Object
Sets the pinLowercaseLetters property value.
-
#pin_minimum_length ⇒ Object
Gets the pinMinimumLength property value.
-
#pin_minimum_length=(value) ⇒ Object
Sets the pinMinimumLength property value.
-
#pin_special_characters ⇒ Object
Gets the pinSpecialCharacters property value.
-
#pin_special_characters=(value) ⇒ Object
Sets the pinSpecialCharacters property value.
-
#pin_uppercase_letters ⇒ Object
Gets the pinUppercaseLetters property value.
-
#pin_uppercase_letters=(value) ⇒ Object
Sets the pinUppercaseLetters property value.
-
#revoke_on_mdm_handoff_disabled ⇒ Object
Gets the revokeOnMdmHandoffDisabled property value.
-
#revoke_on_mdm_handoff_disabled=(value) ⇒ Object
Sets the revokeOnMdmHandoffDisabled property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#windows_hello_for_business_blocked ⇒ Object
Gets the windowsHelloForBusinessBlocked property value.
-
#windows_hello_for_business_blocked=(value) ⇒ Object
Sets the windowsHelloForBusinessBlocked property value.
Methods inherited from WindowsInformationProtection
#assignments, #assignments=, #azure_rights_management_services_allowed, #azure_rights_management_services_allowed=, #data_recovery_certificate, #data_recovery_certificate=, #enforcement_level, #enforcement_level=, #enterprise_domain, #enterprise_domain=, #enterprise_i_p_ranges, #enterprise_i_p_ranges=, #enterprise_i_p_ranges_are_authoritative, #enterprise_i_p_ranges_are_authoritative=, #enterprise_internal_proxy_servers, #enterprise_internal_proxy_servers=, #enterprise_network_domain_names, #enterprise_network_domain_names=, #enterprise_protected_domain_names, #enterprise_protected_domain_names=, #enterprise_proxied_domains, #enterprise_proxied_domains=, #enterprise_proxy_servers, #enterprise_proxy_servers=, #enterprise_proxy_servers_are_authoritative, #enterprise_proxy_servers_are_authoritative=, #exempt_app_locker_files, #exempt_app_locker_files=, #exempt_apps, #exempt_apps=, #icons_visible, #icons_visible=, #indexing_encrypted_stores_or_items_blocked, #indexing_encrypted_stores_or_items_blocked=, #is_assigned, #is_assigned=, #neutral_domain_resources, #neutral_domain_resources=, #protected_app_locker_files, #protected_app_locker_files=, #protected_apps, #protected_apps=, #protection_under_lock_config_required, #protection_under_lock_config_required=, #revoke_on_unenroll_disabled, #revoke_on_unenroll_disabled=, #rights_management_services_template_id, #rights_management_services_template_id=, #smb_auto_encrypted_file_extensions, #smb_auto_encrypted_file_extensions=
Methods inherited from ManagedAppPolicy
#created_date_time, #created_date_time=, #description, #description=, #display_name, #display_name=, #last_modified_date_time, #last_modified_date_time=, #version, #version=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new windowsInformationProtectionPolicy and sets the default values.
51 52 53 54 |
# File 'lib/models/windows_information_protection_policy.rb', line 51 def initialize() super @odata_type = "#microsoft.graph.windowsInformationProtectionPolicy" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
60 61 62 63 |
# File 'lib/models/windows_information_protection_policy.rb', line 60 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WindowsInformationProtectionPolicy.new end |
Instance Method Details
#days_without_contact_before_unenroll ⇒ Object
Gets the daysWithoutContactBeforeUnenroll property value. Offline interval before app data is wiped (days)
68 69 70 |
# File 'lib/models/windows_information_protection_policy.rb', line 68 def days_without_contact_before_unenroll return @days_without_contact_before_unenroll end |
#days_without_contact_before_unenroll=(value) ⇒ Object
Sets the daysWithoutContactBeforeUnenroll property value. Offline interval before app data is wiped (days)
76 77 78 |
# File 'lib/models/windows_information_protection_policy.rb', line 76 def days_without_contact_before_unenroll=(value) @days_without_contact_before_unenroll = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/models/windows_information_protection_policy.rb', line 83 def get_field_deserializers() return super.merge({ "daysWithoutContactBeforeUnenroll" => lambda {|n| @days_without_contact_before_unenroll = n.get_number_value() }, "mdmEnrollmentUrl" => lambda {|n| @mdm_enrollment_url = n.get_string_value() }, "minutesOfInactivityBeforeDeviceLock" => lambda {|n| @minutes_of_inactivity_before_device_lock = n.get_number_value() }, "numberOfPastPinsRemembered" => lambda {|n| @number_of_past_pins_remembered = n.get_number_value() }, "passwordMaximumAttemptCount" => lambda {|n| @password_maximum_attempt_count = n.get_number_value() }, "pinExpirationDays" => lambda {|n| @pin_expiration_days = n.get_number_value() }, "pinLowercaseLetters" => lambda {|n| @pin_lowercase_letters = n.get_enum_value(MicrosoftGraph::Models::WindowsInformationProtectionPinCharacterRequirements) }, "pinMinimumLength" => lambda {|n| @pin_minimum_length = n.get_number_value() }, "pinSpecialCharacters" => lambda {|n| @pin_special_characters = n.get_enum_value(MicrosoftGraph::Models::WindowsInformationProtectionPinCharacterRequirements) }, "pinUppercaseLetters" => lambda {|n| @pin_uppercase_letters = n.get_enum_value(MicrosoftGraph::Models::WindowsInformationProtectionPinCharacterRequirements) }, "revokeOnMdmHandoffDisabled" => lambda {|n| @revoke_on_mdm_handoff_disabled = n.get_boolean_value() }, "windowsHelloForBusinessBlocked" => lambda {|n| @windows_hello_for_business_blocked = n.get_boolean_value() }, }) end |
#mdm_enrollment_url ⇒ Object
Gets the mdmEnrollmentUrl property value. Enrollment url for the MDM
103 104 105 |
# File 'lib/models/windows_information_protection_policy.rb', line 103 def mdm_enrollment_url return @mdm_enrollment_url end |
#mdm_enrollment_url=(value) ⇒ Object
Sets the mdmEnrollmentUrl property value. Enrollment url for the MDM
111 112 113 |
# File 'lib/models/windows_information_protection_policy.rb', line 111 def mdm_enrollment_url=(value) @mdm_enrollment_url = value end |
#minutes_of_inactivity_before_device_lock ⇒ Object
Gets the minutesOfInactivityBeforeDeviceLock property value. Specifies the maximum amount of time (in minutes) allowed after the device is idle that will cause the device to become PIN or password locked. Range is an integer X where 0 <= X <= 999.
118 119 120 |
# File 'lib/models/windows_information_protection_policy.rb', line 118 def minutes_of_inactivity_before_device_lock return @minutes_of_inactivity_before_device_lock end |
#minutes_of_inactivity_before_device_lock=(value) ⇒ Object
Sets the minutesOfInactivityBeforeDeviceLock property value. Specifies the maximum amount of time (in minutes) allowed after the device is idle that will cause the device to become PIN or password locked. Range is an integer X where 0 <= X <= 999.
126 127 128 |
# File 'lib/models/windows_information_protection_policy.rb', line 126 def minutes_of_inactivity_before_device_lock=(value) @minutes_of_inactivity_before_device_lock = value end |
#number_of_past_pins_remembered ⇒ Object
Gets the numberOfPastPinsRemembered property value. Integer value that specifies the number of past PINs that can be associated to a user account that can’t be reused. The largest number you can configure for this policy setting is 50. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then storage of previous PINs is not required. This node was added in Windows 10, version 1511. Default is 0.
133 134 135 |
# File 'lib/models/windows_information_protection_policy.rb', line 133 def number_of_past_pins_remembered return @number_of_past_pins_remembered end |
#number_of_past_pins_remembered=(value) ⇒ Object
Sets the numberOfPastPinsRemembered property value. Integer value that specifies the number of past PINs that can be associated to a user account that can’t be reused. The largest number you can configure for this policy setting is 50. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then storage of previous PINs is not required. This node was added in Windows 10, version 1511. Default is 0.
141 142 143 |
# File 'lib/models/windows_information_protection_policy.rb', line 141 def number_of_past_pins_remembered=(value) @number_of_past_pins_remembered = value end |
#password_maximum_attempt_count ⇒ Object
Gets the passwordMaximumAttemptCount property value. The number of authentication failures allowed before the device will be wiped. A value of 0 disables device wipe functionality. Range is an integer X where 4 <= X <= 16 for desktop and 0 <= X <= 999 for mobile devices.
148 149 150 |
# File 'lib/models/windows_information_protection_policy.rb', line 148 def password_maximum_attempt_count return @password_maximum_attempt_count end |
#password_maximum_attempt_count=(value) ⇒ Object
Sets the passwordMaximumAttemptCount property value. The number of authentication failures allowed before the device will be wiped. A value of 0 disables device wipe functionality. Range is an integer X where 4 <= X <= 16 for desktop and 0 <= X <= 999 for mobile devices.
156 157 158 |
# File 'lib/models/windows_information_protection_policy.rb', line 156 def password_maximum_attempt_count=(value) @password_maximum_attempt_count = value end |
#pin_expiration_days ⇒ Object
Gets the pinExpirationDays property value. Integer value specifies the period of time (in days) that a PIN can be used before the system requires the user to change it. The largest number you can configure for this policy setting is 730. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then the user’s PIN will never expire. This node was added in Windows 10, version 1511. Default is 0.
163 164 165 |
# File 'lib/models/windows_information_protection_policy.rb', line 163 def pin_expiration_days return @pin_expiration_days end |
#pin_expiration_days=(value) ⇒ Object
Sets the pinExpirationDays property value. Integer value specifies the period of time (in days) that a PIN can be used before the system requires the user to change it. The largest number you can configure for this policy setting is 730. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then the user’s PIN will never expire. This node was added in Windows 10, version 1511. Default is 0.
171 172 173 |
# File 'lib/models/windows_information_protection_policy.rb', line 171 def pin_expiration_days=(value) @pin_expiration_days = value end |
#pin_lowercase_letters ⇒ Object
Gets the pinLowercaseLetters property value. Pin Character Requirements
178 179 180 |
# File 'lib/models/windows_information_protection_policy.rb', line 178 def pin_lowercase_letters return @pin_lowercase_letters end |
#pin_lowercase_letters=(value) ⇒ Object
Sets the pinLowercaseLetters property value. Pin Character Requirements
186 187 188 |
# File 'lib/models/windows_information_protection_policy.rb', line 186 def pin_lowercase_letters=(value) @pin_lowercase_letters = value end |
#pin_minimum_length ⇒ Object
Gets the pinMinimumLength property value. Integer value that sets the minimum number of characters required for the PIN. Default value is 4. The lowest number you can configure for this policy setting is 4. The largest number you can configure must be less than the number configured in the Maximum PIN length policy setting or the number 127, whichever is the lowest.
193 194 195 |
# File 'lib/models/windows_information_protection_policy.rb', line 193 def pin_minimum_length return @pin_minimum_length end |
#pin_minimum_length=(value) ⇒ Object
Sets the pinMinimumLength property value. Integer value that sets the minimum number of characters required for the PIN. Default value is 4. The lowest number you can configure for this policy setting is 4. The largest number you can configure must be less than the number configured in the Maximum PIN length policy setting or the number 127, whichever is the lowest.
201 202 203 |
# File 'lib/models/windows_information_protection_policy.rb', line 201 def pin_minimum_length=(value) @pin_minimum_length = value end |
#pin_special_characters ⇒ Object
Gets the pinSpecialCharacters property value. Pin Character Requirements
208 209 210 |
# File 'lib/models/windows_information_protection_policy.rb', line 208 def pin_special_characters return @pin_special_characters end |
#pin_special_characters=(value) ⇒ Object
Sets the pinSpecialCharacters property value. Pin Character Requirements
216 217 218 |
# File 'lib/models/windows_information_protection_policy.rb', line 216 def pin_special_characters=(value) @pin_special_characters = value end |
#pin_uppercase_letters ⇒ Object
Gets the pinUppercaseLetters property value. Pin Character Requirements
223 224 225 |
# File 'lib/models/windows_information_protection_policy.rb', line 223 def pin_uppercase_letters return @pin_uppercase_letters end |
#pin_uppercase_letters=(value) ⇒ Object
Sets the pinUppercaseLetters property value. Pin Character Requirements
231 232 233 |
# File 'lib/models/windows_information_protection_policy.rb', line 231 def pin_uppercase_letters=(value) @pin_uppercase_letters = value end |
#revoke_on_mdm_handoff_disabled ⇒ Object
Gets the revokeOnMdmHandoffDisabled property value. New property in RS2, pending documentation
238 239 240 |
# File 'lib/models/windows_information_protection_policy.rb', line 238 def revoke_on_mdm_handoff_disabled return @revoke_on_mdm_handoff_disabled end |
#revoke_on_mdm_handoff_disabled=(value) ⇒ Object
Sets the revokeOnMdmHandoffDisabled property value. New property in RS2, pending documentation
246 247 248 |
# File 'lib/models/windows_information_protection_policy.rb', line 246 def revoke_on_mdm_handoff_disabled=(value) @revoke_on_mdm_handoff_disabled = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/models/windows_information_protection_policy.rb', line 254 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_number_value("daysWithoutContactBeforeUnenroll", @days_without_contact_before_unenroll) writer.write_string_value("mdmEnrollmentUrl", @mdm_enrollment_url) writer.write_number_value("minutesOfInactivityBeforeDeviceLock", @minutes_of_inactivity_before_device_lock) writer.write_number_value("numberOfPastPinsRemembered", @number_of_past_pins_remembered) writer.write_number_value("passwordMaximumAttemptCount", @password_maximum_attempt_count) writer.write_number_value("pinExpirationDays", @pin_expiration_days) writer.write_enum_value("pinLowercaseLetters", @pin_lowercase_letters) writer.write_number_value("pinMinimumLength", @pin_minimum_length) writer.write_enum_value("pinSpecialCharacters", @pin_special_characters) writer.write_enum_value("pinUppercaseLetters", @pin_uppercase_letters) writer.write_boolean_value("revokeOnMdmHandoffDisabled", @revoke_on_mdm_handoff_disabled) writer.write_boolean_value("windowsHelloForBusinessBlocked", @windows_hello_for_business_blocked) end |
#windows_hello_for_business_blocked ⇒ Object
Gets the windowsHelloForBusinessBlocked property value. Boolean value that sets Windows Hello for Business as a method for signing into Windows.
274 275 276 |
# File 'lib/models/windows_information_protection_policy.rb', line 274 def windows_hello_for_business_blocked return @windows_hello_for_business_blocked end |
#windows_hello_for_business_blocked=(value) ⇒ Object
Sets the windowsHelloForBusinessBlocked property value. Boolean value that sets Windows Hello for Business as a method for signing into Windows.
282 283 284 |
# File 'lib/models/windows_information_protection_policy.rb', line 282 def windows_hello_for_business_blocked=(value) @windows_hello_for_business_blocked = value end |