Class: MicrosoftGraph::Models::WindowsMalwareInformation
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/windows_malware_information.rb
Overview
Malware information entity.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_information_url ⇒ Object
Gets the additionalInformationUrl property value.
-
#additional_information_url=(value) ⇒ Object
Sets the additionalInformationUrl property value.
-
#category ⇒ Object
Gets the category property value.
-
#category=(value) ⇒ Object
Sets the category property value.
-
#device_malware_states ⇒ Object
Gets the deviceMalwareStates property value.
-
#device_malware_states=(value) ⇒ Object
Sets the deviceMalwareStates property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new windowsMalwareInformation and sets the default values.
-
#last_detection_date_time ⇒ Object
Gets the lastDetectionDateTime property value.
-
#last_detection_date_time=(value) ⇒ Object
Sets the lastDetectionDateTime property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#severity ⇒ Object
Gets the severity property value.
-
#severity=(value) ⇒ Object
Sets the severity property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new windowsMalwareInformation and sets the default values.
64 65 66 |
# File 'lib/models/windows_malware_information.rb', line 64 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
72 73 74 75 |
# File 'lib/models/windows_malware_information.rb', line 72 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WindowsMalwareInformation.new end |
Instance Method Details
#additional_information_url ⇒ Object
Gets the additionalInformationUrl property value. Indicates an informational URL to learn more about the malware
34 35 36 |
# File 'lib/models/windows_malware_information.rb', line 34 def additional_information_url return @additional_information_url end |
#additional_information_url=(value) ⇒ Object
Sets the additionalInformationUrl property value. Indicates an informational URL to learn more about the malware
42 43 44 |
# File 'lib/models/windows_malware_information.rb', line 42 def additional_information_url=(value) @additional_information_url = value end |
#category ⇒ Object
Gets the category property value. Category of the malware. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule. default value is invalid. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule.
49 50 51 |
# File 'lib/models/windows_malware_information.rb', line 49 def category return @category end |
#category=(value) ⇒ Object
Sets the category property value. Category of the malware. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule. default value is invalid. Possible values are: invalid, adware, spyware, passwordStealer, trojanDownloader, worm, backdoor, remoteAccessTrojan, trojan, emailFlooder, keylogger, dialer, monitoringSoftware, browserModifier, cookie, browserPlugin, aolExploit, nuker, securityDisabler, jokeProgram, hostileActiveXControl, softwareBundler, stealthNotifier, settingsModifier, toolBar, remoteControlSoftware, trojanFtp, potentialUnwantedSoftware, icqExploit, trojanTelnet, exploit, filesharingProgram, malwareCreationTool, remoteControlSoftware, tool, trojanDenialOfService, trojanDropper, trojanMassMailer, trojanMonitoringSoftware, trojanProxyServer, virus, known, unknown, spp, behavior, vulnerability, policy, enterpriseUnwantedSoftware, ransom, hipsRule.
57 58 59 |
# File 'lib/models/windows_malware_information.rb', line 57 def category=(value) @category = value end |
#device_malware_states ⇒ Object
Gets the deviceMalwareStates property value. List of devices affected by current malware with the malware state on each device
80 81 82 |
# File 'lib/models/windows_malware_information.rb', line 80 def device_malware_states return @device_malware_states end |
#device_malware_states=(value) ⇒ Object
Sets the deviceMalwareStates property value. List of devices affected by current malware with the malware state on each device
88 89 90 |
# File 'lib/models/windows_malware_information.rb', line 88 def device_malware_states=(value) @device_malware_states = value end |
#display_name ⇒ Object
Gets the displayName property value. Indicates the name of the malware
95 96 97 |
# File 'lib/models/windows_malware_information.rb', line 95 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. Indicates the name of the malware
103 104 105 |
# File 'lib/models/windows_malware_information.rb', line 103 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/models/windows_malware_information.rb', line 110 def get_field_deserializers() return super.merge({ "additionalInformationUrl" => lambda {|n| @additional_information_url = n.get_string_value() }, "category" => lambda {|n| @category = n.get_enum_value(MicrosoftGraph::Models::WindowsMalwareCategory) }, "deviceMalwareStates" => lambda {|n| @device_malware_states = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::MalwareStateForWindowsDevice.create_from_discriminator_value(pn) }) }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, "lastDetectionDateTime" => lambda {|n| @last_detection_date_time = n.get_date_time_value() }, "severity" => lambda {|n| @severity = n.get_enum_value(MicrosoftGraph::Models::WindowsMalwareSeverity) }, }) end |
#last_detection_date_time ⇒ Object
Gets the lastDetectionDateTime property value. Indicates the last time the malware was detected in UTC
124 125 126 |
# File 'lib/models/windows_malware_information.rb', line 124 def last_detection_date_time return @last_detection_date_time end |
#last_detection_date_time=(value) ⇒ Object
Sets the lastDetectionDateTime property value. Indicates the last time the malware was detected in UTC
132 133 134 |
# File 'lib/models/windows_malware_information.rb', line 132 def last_detection_date_time=(value) @last_detection_date_time = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
140 141 142 143 144 145 146 147 148 149 |
# File 'lib/models/windows_malware_information.rb', line 140 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_string_value("additionalInformationUrl", @additional_information_url) writer.write_enum_value("category", @category) writer.write_collection_of_object_values("deviceMalwareStates", @device_malware_states) writer.write_string_value("displayName", @display_name) writer.write_date_time_value("lastDetectionDateTime", @last_detection_date_time) writer.write_enum_value("severity", @severity) end |
#severity ⇒ Object
Gets the severity property value. Severity of the malware. Possible values are: unknown, low, moderate, high, severe. default is unknown. Possible values are: unknown, low, moderate, high, severe.
154 155 156 |
# File 'lib/models/windows_malware_information.rb', line 154 def severity return @severity end |
#severity=(value) ⇒ Object
Sets the severity property value. Severity of the malware. Possible values are: unknown, low, moderate, high, severe. default is unknown. Possible values are: unknown, low, moderate, high, severe.
162 163 164 |
# File 'lib/models/windows_malware_information.rb', line 162 def severity=(value) @severity = value end |