Class: MicrosoftGraph::Models::WindowsUniversalAppX
- Inherits:
-
MobileLobApp
- Object
- Entity
- MobileApp
- MobileLobApp
- MicrosoftGraph::Models::WindowsUniversalAppX
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/windows_universal_app_x.rb
Overview
Contains properties and inherited properties for Windows Universal AppX Line Of Business apps.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#applicable_architectures ⇒ Object
Gets the applicableArchitectures property value.
-
#applicable_architectures=(value) ⇒ Object
Sets the applicableArchitectures property value.
-
#applicable_device_types ⇒ Object
Gets the applicableDeviceTypes property value.
-
#applicable_device_types=(value) ⇒ Object
Sets the applicableDeviceTypes property value.
-
#committed_contained_apps ⇒ Object
Gets the committedContainedApps property value.
-
#committed_contained_apps=(value) ⇒ Object
Sets the committedContainedApps property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#identity_name ⇒ Object
Gets the identityName property value.
-
#identity_name=(value) ⇒ Object
Sets the identityName property value.
-
#identity_publisher_hash ⇒ Object
Gets the identityPublisherHash property value.
-
#identity_publisher_hash=(value) ⇒ Object
Sets the identityPublisherHash property value.
-
#identity_resource_identifier ⇒ Object
Gets the identityResourceIdentifier property value.
-
#identity_resource_identifier=(value) ⇒ Object
Sets the identityResourceIdentifier property value.
-
#identity_version ⇒ Object
Gets the identityVersion property value.
-
#identity_version=(value) ⇒ Object
Sets the identityVersion property value.
-
#initialize ⇒ Object
constructor
Instantiates a new windowsUniversalAppX and sets the default values.
-
#is_bundle ⇒ Object
Gets the isBundle property value.
-
#is_bundle=(value) ⇒ Object
Sets the isBundle property value.
-
#minimum_supported_operating_system ⇒ Object
Gets the minimumSupportedOperatingSystem property value.
-
#minimum_supported_operating_system=(value) ⇒ Object
Sets the minimumSupportedOperatingSystem property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Methods inherited from MobileLobApp
#committed_content_version, #committed_content_version=, #content_versions, #content_versions=, #file_name, #file_name=, #size, #size=
Methods inherited from MobileApp
#assignments, #assignments=, #categories, #categories=, #created_date_time, #created_date_time=, #description, #description=, #developer, #developer=, #display_name, #display_name=, #information_url, #information_url=, #is_featured, #is_featured=, #large_icon, #large_icon=, #last_modified_date_time, #last_modified_date_time=, #notes, #notes=, #owner, #owner=, #privacy_information_url, #privacy_information_url=, #publisher, #publisher=, #publishing_state, #publishing_state=
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new windowsUniversalAppX and sets the default values.
87 88 89 90 |
# File 'lib/models/windows_universal_app_x.rb', line 87 def initialize() super @odata_type = "#microsoft.graph.windowsUniversalAppX" end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
96 97 98 99 |
# File 'lib/models/windows_universal_app_x.rb', line 96 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WindowsUniversalAppX.new end |
Instance Method Details
#applicable_architectures ⇒ Object
Gets the applicableArchitectures property value. Contains properties for Windows architecture.
42 43 44 |
# File 'lib/models/windows_universal_app_x.rb', line 42 def applicable_architectures return @applicable_architectures end |
#applicable_architectures=(value) ⇒ Object
Sets the applicableArchitectures property value. Contains properties for Windows architecture.
50 51 52 |
# File 'lib/models/windows_universal_app_x.rb', line 50 def applicable_architectures=(value) @applicable_architectures = value end |
#applicable_device_types ⇒ Object
Gets the applicableDeviceTypes property value. Contains properties for Windows device type.
57 58 59 |
# File 'lib/models/windows_universal_app_x.rb', line 57 def applicable_device_types return @applicable_device_types end |
#applicable_device_types=(value) ⇒ Object
Sets the applicableDeviceTypes property value. Contains properties for Windows device type.
65 66 67 |
# File 'lib/models/windows_universal_app_x.rb', line 65 def applicable_device_types=(value) @applicable_device_types = value end |
#committed_contained_apps ⇒ Object
Gets the committedContainedApps property value. The collection of contained apps in the committed mobileAppContent of a windowsUniversalAppX app.
72 73 74 |
# File 'lib/models/windows_universal_app_x.rb', line 72 def committed_contained_apps return @committed_contained_apps end |
#committed_contained_apps=(value) ⇒ Object
Sets the committedContainedApps property value. The collection of contained apps in the committed mobileAppContent of a windowsUniversalAppX app.
80 81 82 |
# File 'lib/models/windows_universal_app_x.rb', line 80 def committed_contained_apps=(value) @committed_contained_apps = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/models/windows_universal_app_x.rb', line 104 def get_field_deserializers() return super.merge({ "applicableArchitectures" => lambda {|n| @applicable_architectures = n.get_enum_value(MicrosoftGraph::Models::WindowsArchitecture) }, "applicableDeviceTypes" => lambda {|n| @applicable_device_types = n.get_enum_value(MicrosoftGraph::Models::WindowsDeviceType) }, "committedContainedApps" => lambda {|n| @committed_contained_apps = n.get_collection_of_object_values(lambda {|pn| MicrosoftGraph::Models::MobileContainedApp.create_from_discriminator_value(pn) }) }, "identityName" => lambda {|n| @identity_name = n.get_string_value() }, "identityPublisherHash" => lambda {|n| @identity_publisher_hash = n.get_string_value() }, "identityResourceIdentifier" => lambda {|n| @identity_resource_identifier = n.get_string_value() }, "identityVersion" => lambda {|n| @identity_version = n.get_string_value() }, "isBundle" => lambda {|n| @is_bundle = n.get_boolean_value() }, "minimumSupportedOperatingSystem" => lambda {|n| = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::.create_from_discriminator_value(pn) }) }, }) end |
#identity_name ⇒ Object
Gets the identityName property value. The Identity Name.
121 122 123 |
# File 'lib/models/windows_universal_app_x.rb', line 121 def identity_name return @identity_name end |
#identity_name=(value) ⇒ Object
Sets the identityName property value. The Identity Name.
129 130 131 |
# File 'lib/models/windows_universal_app_x.rb', line 129 def identity_name=(value) @identity_name = value end |
#identity_publisher_hash ⇒ Object
Gets the identityPublisherHash property value. The Identity Publisher Hash.
136 137 138 |
# File 'lib/models/windows_universal_app_x.rb', line 136 def identity_publisher_hash return @identity_publisher_hash end |
#identity_publisher_hash=(value) ⇒ Object
Sets the identityPublisherHash property value. The Identity Publisher Hash.
144 145 146 |
# File 'lib/models/windows_universal_app_x.rb', line 144 def identity_publisher_hash=(value) @identity_publisher_hash = value end |
#identity_resource_identifier ⇒ Object
Gets the identityResourceIdentifier property value. The Identity Resource Identifier.
151 152 153 |
# File 'lib/models/windows_universal_app_x.rb', line 151 def identity_resource_identifier return @identity_resource_identifier end |
#identity_resource_identifier=(value) ⇒ Object
Sets the identityResourceIdentifier property value. The Identity Resource Identifier.
159 160 161 |
# File 'lib/models/windows_universal_app_x.rb', line 159 def identity_resource_identifier=(value) @identity_resource_identifier = value end |
#identity_version ⇒ Object
Gets the identityVersion property value. The identity version.
166 167 168 |
# File 'lib/models/windows_universal_app_x.rb', line 166 def identity_version return @identity_version end |
#identity_version=(value) ⇒ Object
Sets the identityVersion property value. The identity version.
174 175 176 |
# File 'lib/models/windows_universal_app_x.rb', line 174 def identity_version=(value) @identity_version = value end |
#is_bundle ⇒ Object
Gets the isBundle property value. Whether or not the app is a bundle.
181 182 183 |
# File 'lib/models/windows_universal_app_x.rb', line 181 def is_bundle return @is_bundle end |
#is_bundle=(value) ⇒ Object
Sets the isBundle property value. Whether or not the app is a bundle.
189 190 191 |
# File 'lib/models/windows_universal_app_x.rb', line 189 def is_bundle=(value) @is_bundle = value end |
#minimum_supported_operating_system ⇒ Object
Gets the minimumSupportedOperatingSystem property value. The minimum operating system required for a Windows mobile app.
196 197 198 |
# File 'lib/models/windows_universal_app_x.rb', line 196 def return end |
#minimum_supported_operating_system=(value) ⇒ Object
Sets the minimumSupportedOperatingSystem property value. The minimum operating system required for a Windows mobile app.
204 205 206 |
# File 'lib/models/windows_universal_app_x.rb', line 204 def (value) = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/models/windows_universal_app_x.rb', line 212 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_enum_value("applicableArchitectures", @applicable_architectures) writer.write_enum_value("applicableDeviceTypes", @applicable_device_types) writer.write_collection_of_object_values("committedContainedApps", @committed_contained_apps) writer.write_string_value("identityName", @identity_name) writer.write_string_value("identityPublisherHash", @identity_publisher_hash) writer.write_string_value("identityResourceIdentifier", @identity_resource_identifier) writer.write_string_value("identityVersion", @identity_version) writer.write_boolean_value("isBundle", @is_bundle) writer.write_object_value("minimumSupportedOperatingSystem", ) end |