Class: MicrosoftGraph::Models::WorkbookChartTitle
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/models/workbook_chart_title.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#format ⇒ Object
Gets the format property value.
-
#format=(value) ⇒ Object
Sets the format property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new workbookChartTitle and sets the default values.
-
#overlay ⇒ Object
Gets the overlay property value.
-
#overlay=(value) ⇒ Object
Sets the overlay property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#text ⇒ Object
Gets the text property value.
-
#text=(value) ⇒ Object
Sets the text property value.
-
#visible ⇒ Object
Gets the visible property value.
-
#visible=(value) ⇒ Object
Sets the visible property value.
Methods inherited from Entity
#additional_data, #additional_data=, #id, #id=, #odata_type, #odata_type=
Constructor Details
#initialize ⇒ Object
Instantiates a new workbookChartTitle and sets the default values.
25 26 27 |
# File 'lib/models/workbook_chart_title.rb', line 25 def initialize() super end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
33 34 35 36 |
# File 'lib/models/workbook_chart_title.rb', line 33 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WorkbookChartTitle.new end |
Instance Method Details
#format ⇒ Object
Gets the format property value. Represents the formatting of a chart title, which includes fill and font formatting. Read-only.
41 42 43 |
# File 'lib/models/workbook_chart_title.rb', line 41 def format return @format end |
#format=(value) ⇒ Object
Sets the format property value. Represents the formatting of a chart title, which includes fill and font formatting. Read-only.
49 50 51 |
# File 'lib/models/workbook_chart_title.rb', line 49 def format=(value) @format = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
56 57 58 59 60 61 62 63 |
# File 'lib/models/workbook_chart_title.rb', line 56 def get_field_deserializers() return super.merge({ "format" => lambda {|n| @format = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::WorkbookChartTitleFormat.create_from_discriminator_value(pn) }) }, "overlay" => lambda {|n| = n.get_boolean_value() }, "text" => lambda {|n| @text = n.get_string_value() }, "visible" => lambda {|n| @visible = n.get_boolean_value() }, }) end |
#overlay ⇒ Object
Gets the overlay property value. Boolean value representing if the chart title will overlay the chart or not.
68 69 70 |
# File 'lib/models/workbook_chart_title.rb', line 68 def return end |
#overlay=(value) ⇒ Object
Sets the overlay property value. Boolean value representing if the chart title will overlay the chart or not.
76 77 78 |
# File 'lib/models/workbook_chart_title.rb', line 76 def (value) = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
84 85 86 87 88 89 90 91 |
# File 'lib/models/workbook_chart_title.rb', line 84 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? super writer.write_object_value("format", @format) writer.write_boolean_value("overlay", ) writer.write_string_value("text", @text) writer.write_boolean_value("visible", @visible) end |
#text ⇒ Object
Gets the text property value. Represents the title text of a chart.
96 97 98 |
# File 'lib/models/workbook_chart_title.rb', line 96 def text return @text end |
#text=(value) ⇒ Object
Sets the text property value. Represents the title text of a chart.
104 105 106 |
# File 'lib/models/workbook_chart_title.rb', line 104 def text=(value) @text = value end |
#visible ⇒ Object
Gets the visible property value. A boolean value the represents the visibility of a chart title object.
111 112 113 |
# File 'lib/models/workbook_chart_title.rb', line 111 def visible return @visible end |
#visible=(value) ⇒ Object
Sets the visible property value. A boolean value the represents the visibility of a chart title object.
119 120 121 |
# File 'lib/models/workbook_chart_title.rb', line 119 def visible=(value) @visible = value end |