Class: MicrosoftGraph::Organization::Item::Branding::BrandingRequestBuilder::BrandingRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Organization::Item::Branding::BrandingRequestBuilder::BrandingRequestBuilderGetQueryParameters
- Defined in:
- lib/organization/item/branding/branding_request_builder.rb
Overview
Retrieve the default organizational branding object, if the Accept-Language header is set to 0 or default. If no default organizational branding object exists, this method returns a 404 Not Found error. If the Accept-Language header is set to an existing locale identified by the value of its id, this method retrieves the branding for the specified locale. This method retrieves only non-Stream properties, for example, usernameHintText and signInPageText. To retrieve Stream types of the default branding, for example, bannerLogo and backgroundImage, use the GET organizationalBrandingLocalization method.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
179 180 181 |
# File 'lib/organization/item/branding/branding_request_builder.rb', line 179 def @expand end |
#select ⇒ Object
Select properties to be returned
182 183 184 |
# File 'lib/organization/item/branding/branding_request_builder.rb', line 182 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/organization/item/branding/branding_request_builder.rb', line 188 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |