Class: MicrosoftGraph::Places::Item::PlaceItemRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Places::Item::PlaceItemRequestBuilder
- Defined in:
- lib/places/item/place_item_request_builder.rb
Overview
Provides operations to manage the collection of place entities.
Instance Method Summary collapse
-
#delete(request_configuration = nil) ⇒ Object
Delete entity from places.
-
#graph_room ⇒ Object
Casts the previous resource to room.
-
#graph_room_list ⇒ Object
Casts the previous resource to roomList.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new PlaceItemRequestBuilder and sets the default values.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of place object, which can be a room or roomList.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete entity from places.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of place object, which can be a room or roomList.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new PlaceItemRequestBuilder and sets the default values.
33 34 35 |
# File 'lib/places/item/place_item_request_builder.rb', line 33 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/places/{place%2Did}") end |
Instance Method Details
#delete(request_configuration = nil) ⇒ Object
Delete entity from places
41 42 43 44 45 46 47 48 49 |
# File 'lib/places/item/place_item_request_builder.rb', line 41 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#graph_room ⇒ Object
Casts the previous resource to room.
19 20 21 |
# File 'lib/places/item/place_item_request_builder.rb', line 19 def graph_room() return MicrosoftGraph::Places::Item::GraphRoom::GraphRoomRequestBuilder.new(@path_parameters, @request_adapter) end |
#graph_room_list ⇒ Object
Casts the previous resource to roomList.
24 25 26 |
# File 'lib/places/item/place_item_request_builder.rb', line 24 def graph_room_list() return MicrosoftGraph::Places::Item::GraphRoomList::GraphRoomListRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the properties of place object, which can be a room or roomList. You can identify the room or roomList by specifying the id or emailAddress property.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/places/item/place_item_request_builder.rb', line 56 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Place.create_from_discriminator_value(pn) }, error_mapping) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete entity from places
71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/places/item/place_item_request_builder.rb', line 71 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the properties of place object, which can be a room or roomList. You can identify the room or roomList by specifying the id or emailAddress property.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/places/item/place_item_request_builder.rb', line 88 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |