Class: MicrosoftGraph::Print::Printers::Item::TaskTriggers::TaskTriggersRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Print::Printers::Item::TaskTriggers::TaskTriggersRequestBuilder
- Defined in:
- lib/print/printers/item/task_triggers/task_triggers_request_builder.rb
Overview
Provides operations to manage the taskTriggers property of the microsoft.graph.printer entity.
Defined Under Namespace
Classes: TaskTriggersRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_print_task_trigger_id(print_task_trigger_id) ⇒ Object
Provides operations to manage the taskTriggers property of the microsoft.graph.printer entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a list of task triggers associated with the printer.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new TaskTriggersRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a new task trigger on the specified printer.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of task triggers associated with the printer.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new task trigger on the specified printer.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new TaskTriggersRequestBuilder and sets the default values.
44 45 46 |
# File 'lib/print/printers/item/task_triggers/task_triggers_request_builder.rb', line 44 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/print/printers/{printer%2Did}/taskTriggers{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_print_task_trigger_id(print_task_trigger_id) ⇒ Object
Provides operations to manage the taskTriggers property of the microsoft.graph.printer entity.
32 33 34 35 36 37 |
# File 'lib/print/printers/item/task_triggers/task_triggers_request_builder.rb', line 32 def by_print_task_trigger_id(print_task_trigger_id) raise StandardError, 'print_task_trigger_id cannot be null' if print_task_trigger_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["printTaskTrigger%2Did"] = print_task_trigger_id return MicrosoftGraph::Print::Printers::Item::TaskTriggers::Item::PrintTaskTriggerItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
24 25 26 |
# File 'lib/print/printers/item/task_triggers/task_triggers_request_builder.rb', line 24 def count() return MicrosoftGraph::Print::Printers::Item::TaskTriggers::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a list of task triggers associated with the printer. The list of task triggers defines which tasks will be triggered as a result of events that occur during printing. For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
52 53 54 55 56 57 58 59 60 |
# File 'lib/print/printers/item/task_triggers/task_triggers_request_builder.rb', line 52 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PrintTaskTriggerCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create a new task trigger on the specified printer. Currently, only one task trigger can be specified per printer, but this limit might be removed in the future.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/print/printers/item/task_triggers/task_triggers_request_builder.rb', line 67 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PrintTaskTrigger.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a list of task triggers associated with the printer. The list of task triggers defines which tasks will be triggered as a result of events that occur during printing. For details about how to use this API to add pull printing support to Universal Print, see Extending Universal Print to support pull printing.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/print/printers/item/task_triggers/task_triggers_request_builder.rb', line 82 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new task trigger on the specified printer. Currently, only one task trigger can be specified per printer, but this limit might be removed in the future.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/print/printers/item/task_triggers/task_triggers_request_builder.rb', line 101 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |