Class: MicrosoftGraph::SchemaExtensions::SchemaExtensionsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::SchemaExtensions::SchemaExtensionsRequestBuilder
- Defined in:
- lib/schema_extensions/schema_extensions_request_builder.rb
Overview
Provides operations to manage the collection of schemaExtension entities.
Defined Under Namespace
Classes: SchemaExtensionsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_schema_extension_id(schema_extension_id) ⇒ Object
Provides operations to manage the collection of schemaExtension entities.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get a list of schemaExtension objects in your tenant.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new SchemaExtensionsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a new schemaExtension definition and its associated schema extension property to extend a supporting resource type.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of schemaExtension objects in your tenant.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new schemaExtension definition and its associated schema extension property to extend a supporting resource type.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new SchemaExtensionsRequestBuilder and sets the default values.
38 39 40 |
# File 'lib/schema_extensions/schema_extensions_request_builder.rb', line 38 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/schemaExtensions{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_schema_extension_id(schema_extension_id) ⇒ Object
Provides operations to manage the collection of schemaExtension entities.
26 27 28 29 30 31 |
# File 'lib/schema_extensions/schema_extensions_request_builder.rb', line 26 def by_schema_extension_id(schema_extension_id) raise StandardError, 'schema_extension_id cannot be null' if schema_extension_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["schemaExtension%2Did"] = schema_extension_id return MicrosoftGraph::SchemaExtensions::Item::SchemaExtensionItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
18 19 20 |
# File 'lib/schema_extensions/schema_extensions_request_builder.rb', line 18 def count() return MicrosoftGraph::SchemaExtensions::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get a list of schemaExtension objects in your tenant. The schema extensions can be InDevelopment, Available, or Deprecated and includes schema extensions:+ Created by any apps you own in the current tenant.+ Owned by other apps that are marked as Available.+ Created by other developers from other tenants and marked as Available. This is different from other APIs that only return tenant-specific data. Extension data created based on schema extension definitions is tenant-specific and can only be accessed by apps explicitly granted permission.
46 47 48 49 50 51 52 53 54 |
# File 'lib/schema_extensions/schema_extensions_request_builder.rb', line 46 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SchemaExtensionCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create a new schemaExtension definition and its associated schema extension property to extend a supporting resource type. Schema extensions let you add strongly-typed custom data to a resource. The app that creates a schema extension is the owner app. Depending on the state of the extension, the owner app, and only the owner app, may update or delete the extension. See examples of how to define a schema extension that describes a training course, use the schema extension definition to create a new group with training course data, and add training course data to an existing group.
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/schema_extensions/schema_extensions_request_builder.rb', line 61 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SchemaExtension.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of schemaExtension objects in your tenant. The schema extensions can be InDevelopment, Available, or Deprecated and includes schema extensions:+ Created by any apps you own in the current tenant.+ Owned by other apps that are marked as Available.+ Created by other developers from other tenants and marked as Available. This is different from other APIs that only return tenant-specific data. Extension data created based on schema extension definitions is tenant-specific and can only be accessed by apps explicitly granted permission.
76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/schema_extensions/schema_extensions_request_builder.rb', line 76 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new schemaExtension definition and its associated schema extension property to extend a supporting resource type. Schema extensions let you add strongly-typed custom data to a resource. The app that creates a schema extension is the owner app. Depending on the state of the extension, the owner app, and only the owner app, may update or delete the extension. See examples of how to define a schema extension that describes a training course, use the schema extension definition to create a new group with training course data, and add training course data to an existing group.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/schema_extensions/schema_extensions_request_builder.rb', line 95 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |