Class: MicrosoftGraph::Security::Alerts_v2::AlertsV2RequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Security::Alerts_v2::AlertsV2RequestBuilder
- Defined in:
- lib/security/alerts_v2/alerts_v2_request_builder.rb
Overview
Provides operations to manage the alerts_v2 property of the microsoft.graph.security entity.
Defined Under Namespace
Classes: AlertsV2RequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_alert_id(alert_id) ⇒ Object
Provides operations to manage the alerts_v2 property of the microsoft.graph.security entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get a list of alert resources that have been created to track suspicious activities in an organization.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new Alerts_v2RequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to alerts_v2 for security.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of alert resources that have been created to track suspicious activities in an organization.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to alerts_v2 for security.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new Alerts_v2RequestBuilder and sets the default values.
40 41 42 |
# File 'lib/security/alerts_v2/alerts_v2_request_builder.rb', line 40 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/security/alerts_v2{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_alert_id(alert_id) ⇒ Object
Provides operations to manage the alerts_v2 property of the microsoft.graph.security entity.
28 29 30 31 32 33 |
# File 'lib/security/alerts_v2/alerts_v2_request_builder.rb', line 28 def by_alert_id(alert_id) raise StandardError, 'alert_id cannot be null' if alert_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["alert%2Did"] = alert_id return MicrosoftGraph::Security::Alerts_v2::Item::AlertItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
20 21 22 |
# File 'lib/security/alerts_v2/alerts_v2_request_builder.rb', line 20 def count() return MicrosoftGraph::Security::Alerts_v2::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get a list of alert resources that have been created to track suspicious activities in an organization. This operation lets you filter and sort through alerts to create an informed cyber security response. It exposes a collection of alerts that were flagged in your network, within the time range you specified in your environment retention policy. The most recent alerts are displayed at the top of the list.
48 49 50 51 52 53 54 55 56 |
# File 'lib/security/alerts_v2/alerts_v2_request_builder.rb', line 48 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SecurityAlertCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create new navigation property to alerts_v2 for security
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/security/alerts_v2/alerts_v2_request_builder.rb', line 63 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SecurityAlert.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a list of alert resources that have been created to track suspicious activities in an organization. This operation lets you filter and sort through alerts to create an informed cyber security response. It exposes a collection of alerts that were flagged in your network, within the time range you specified in your environment retention policy. The most recent alerts are displayed at the top of the list.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/security/alerts_v2/alerts_v2_request_builder.rb', line 78 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create new navigation property to alerts_v2 for security
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/security/alerts_v2/alerts_v2_request_builder.rb', line 97 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |