Class: MicrosoftGraph::Solutions::BookingBusinesses::BookingBusinessesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Solutions::BookingBusinesses::BookingBusinessesRequestBuilder
- Defined in:
- lib/solutions/booking_businesses/booking_businesses_request_builder.rb
Overview
Provides operations to manage the bookingBusinesses property of the microsoft.graph.solutionsRoot entity.
Defined Under Namespace
Classes: BookingBusinessesRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_booking_business_id(booking_business_id) ⇒ Object
Provides operations to manage the bookingBusinesses property of the microsoft.graph.solutionsRoot entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Get a collection of bookingBusiness objects that has been created for the tenant.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new BookingBusinessesRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Create a new Microsoft Bookings business in a tenant.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a collection of bookingBusiness objects that has been created for the tenant.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new Microsoft Bookings business in a tenant.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new BookingBusinessesRequestBuilder and sets the default values.
40 41 42 |
# File 'lib/solutions/booking_businesses/booking_businesses_request_builder.rb', line 40 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/solutions/bookingBusinesses{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}") end |
Instance Method Details
#by_booking_business_id(booking_business_id) ⇒ Object
Provides operations to manage the bookingBusinesses property of the microsoft.graph.solutionsRoot entity.
28 29 30 31 32 33 |
# File 'lib/solutions/booking_businesses/booking_businesses_request_builder.rb', line 28 def by_booking_business_id(booking_business_id) raise StandardError, 'booking_business_id cannot be null' if booking_business_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["bookingBusiness%2Did"] = booking_business_id return MicrosoftGraph::Solutions::BookingBusinesses::Item::BookingBusinessItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
20 21 22 |
# File 'lib/solutions/booking_businesses/booking_businesses_request_builder.rb', line 20 def count() return MicrosoftGraph::Solutions::BookingBusinesses::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get a collection of bookingBusiness objects that has been created for the tenant. This operation returns only the id and displayName of each Microsoft Bookings business in the collection. For performance considerations, it does not return other properties. You can get the other properties of a Bookings business by specifying its id in a GET operation.
48 49 50 51 52 53 54 55 56 |
# File 'lib/solutions/booking_businesses/booking_businesses_request_builder.rb', line 48 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::BookingBusinessCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Create a new Microsoft Bookings business in a tenant. This is the first step in setting up a Bookings business where you must specify the business display name. You can include other information such as business address, web site address, and scheduling policy, or set that information later by updating the bookingBusiness.
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/solutions/booking_businesses/booking_businesses_request_builder.rb', line 63 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::BookingBusiness.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get a collection of bookingBusiness objects that has been created for the tenant. This operation returns only the id and displayName of each Microsoft Bookings business in the collection. For performance considerations, it does not return other properties. You can get the other properties of a Bookings business by specifying its id in a GET operation.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/solutions/booking_businesses/booking_businesses_request_builder.rb', line 78 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Create a new Microsoft Bookings business in a tenant. This is the first step in setting up a Bookings business where you must specify the business display name. You can include other information such as business address, web site address, and scheduling policy, or set that information later by updating the bookingBusiness.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/solutions/booking_businesses/booking_businesses_request_builder.rb', line 97 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |