Class: MicrosoftGraph::Subscriptions::SubscriptionsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Subscriptions::SubscriptionsRequestBuilder
- Defined in:
- lib/subscriptions/subscriptions_request_builder.rb
Overview
Provides operations to manage the collection of subscription entities.
Defined Under Namespace
Classes: SubscriptionsRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_subscription_id(subscription_id) ⇒ Object
Provides operations to manage the collection of subscription entities.
-
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of webhook subscriptions, based on the app ID, the user, and the user’s role with a tenant.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new SubscriptionsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Subscribes a listener application to receive change notifications when the requested type of changes occur to the specified resource in Microsoft Graph.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of webhook subscriptions, based on the app ID, the user, and the user’s role with a tenant.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Subscribes a listener application to receive change notifications when the requested type of changes occur to the specified resource in Microsoft Graph.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new SubscriptionsRequestBuilder and sets the default values.
32 33 34 |
# File 'lib/subscriptions/subscriptions_request_builder.rb', line 32 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/subscriptions{?%24search,%24select}") end |
Instance Method Details
#by_subscription_id(subscription_id) ⇒ Object
Provides operations to manage the collection of subscription entities.
20 21 22 23 24 25 |
# File 'lib/subscriptions/subscriptions_request_builder.rb', line 20 def by_subscription_id(subscription_id) raise StandardError, 'subscription_id cannot be null' if subscription_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["subscription%2Did"] = subscription_id return MicrosoftGraph::Subscriptions::Item::SubscriptionItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of webhook subscriptions, based on the app ID, the user, and the user’s role with a tenant. The content of the response depends on the context in which the app is calling; for details, see the scenarios in the Permissions section.
40 41 42 43 44 45 46 47 48 |
# File 'lib/subscriptions/subscriptions_request_builder.rb', line 40 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::SubscriptionCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Subscribes a listener application to receive change notifications when the requested type of changes occur to the specified resource in Microsoft Graph. To identify the resources for which you can create subscriptions and the limitations on subscriptions, see Set up notifications for changes in resource data: Supported resources. Some resources support rich notifications, that is, notifications that include resource data. For more information about these resources, see Set up change notifications that include resource data: Supported resources.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/subscriptions/subscriptions_request_builder.rb', line 55 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Subscription.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve the properties and relationships of webhook subscriptions, based on the app ID, the user, and the user’s role with a tenant. The content of the response depends on the context in which the app is calling; for details, see the scenarios in the Permissions section.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/subscriptions/subscriptions_request_builder.rb', line 70 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Subscribes a listener application to receive change notifications when the requested type of changes occur to the specified resource in Microsoft Graph. To identify the resources for which you can create subscriptions and the limitations on subscriptions, see Set up notifications for changes in resource data: Supported resources. Some resources support rich notifications, that is, notifications that include resource data. For more information about these resources, see Set up change notifications that include resource data: Supported resources.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/subscriptions/subscriptions_request_builder.rb', line 89 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |