Class: MicrosoftGraph::Teams::Item::Clone::ClonePostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Teams::Item::Clone::ClonePostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teams/item/clone/clone_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#classification ⇒ Object
Gets the classification property value.
-
#classification=(value) ⇒ Object
Sets the classification property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#display_name ⇒ Object
Gets the displayName property value.
-
#display_name=(value) ⇒ Object
Sets the displayName property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new clonePostRequestBody and sets the default values.
-
#mail_nickname ⇒ Object
Gets the mailNickname property value.
-
#mail_nickname=(value) ⇒ Object
Sets the mailNickname property value.
-
#parts_to_clone ⇒ Object
Gets the partsToClone property value.
-
#parts_to_clone=(value) ⇒ Object
Sets the partsToClone property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#visibility ⇒ Object
Gets the visibility property value.
-
#visibility=(value) ⇒ Object
Sets the visibility property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new clonePostRequestBody and sets the default values.
70 71 72 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 70 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
78 79 80 81 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 78 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ClonePostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
40 41 42 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 40 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
48 49 50 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 48 def additional_data=(value) @additional_data = value end |
#classification ⇒ Object
Gets the classification property value. The classification property
55 56 57 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 55 def classification return @classification end |
#classification=(value) ⇒ Object
Sets the classification property value. The classification property
63 64 65 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 63 def classification=(value) @classification = value end |
#description ⇒ Object
Gets the description property value. The description property
86 87 88 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 86 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. The description property
94 95 96 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 94 def description=(value) @description = value end |
#display_name ⇒ Object
Gets the displayName property value. The displayName property
101 102 103 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 101 def display_name return @display_name end |
#display_name=(value) ⇒ Object
Sets the displayName property value. The displayName property
109 110 111 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 109 def display_name=(value) @display_name = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 116 def get_field_deserializers() return { "classification" => lambda {|n| @classification = n.get_string_value() }, "description" => lambda {|n| @description = n.get_string_value() }, "displayName" => lambda {|n| @display_name = n.get_string_value() }, "mailNickname" => lambda {|n| @mail_nickname = n.get_string_value() }, "partsToClone" => lambda {|n| @parts_to_clone = n.get_enum_value(MicrosoftGraph::Models::ClonableTeamParts) }, "visibility" => lambda {|n| @visibility = n.get_enum_value(MicrosoftGraph::Models::TeamVisibilityType) }, } end |
#mail_nickname ⇒ Object
Gets the mailNickname property value. The mailNickname property
130 131 132 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 130 def mail_nickname return @mail_nickname end |
#mail_nickname=(value) ⇒ Object
Sets the mailNickname property value. The mailNickname property
138 139 140 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 138 def mail_nickname=(value) @mail_nickname = value end |
#parts_to_clone ⇒ Object
Gets the partsToClone property value. The partsToClone property
145 146 147 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 145 def parts_to_clone return @parts_to_clone end |
#parts_to_clone=(value) ⇒ Object
Sets the partsToClone property value. The partsToClone property
153 154 155 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 153 def parts_to_clone=(value) @parts_to_clone = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 161 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("classification", @classification) writer.write_string_value("description", @description) writer.write_string_value("displayName", @display_name) writer.write_string_value("mailNickname", @mail_nickname) writer.write_enum_value("partsToClone", @parts_to_clone) writer.write_enum_value("visibility", @visibility) writer.write_additional_data(@additional_data) end |
#visibility ⇒ Object
Gets the visibility property value. The visibility property
175 176 177 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 175 def visibility return @visibility end |
#visibility=(value) ⇒ Object
Sets the visibility property value. The visibility property
183 184 185 |
# File 'lib/teams/item/clone/clone_post_request_body.rb', line 183 def visibility=(value) @visibility = value end |