Class: MicrosoftGraph::Teams::Item::Photo::PhotoRequestBuilder::PhotoRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- MicrosoftGraph::Teams::Item::Photo::PhotoRequestBuilder::PhotoRequestBuilderGetQueryParameters
- Defined in:
- lib/teams/item/photo/photo_request_builder.rb
Overview
Get the specified profilePhoto or its metadata (profilePhoto properties). The supported sizes of HD photos on Microsoft 365 are as follows: 48x48, 64x64, 96x96, 120x120, 240x240,360x360, 432x432, 504x504, and 648x648. Photos can be any dimension if they are stored in Azure Active Directory. You can get the metadata of the largest available photo, or specify a size to get the metadata for that photo size.If the size you request is not available, you can still get a smaller size that the user has uploaded and made available.For example, if the user uploads a photo that is 504x504 pixels, all but the 648x648 size of photo will be available for download.
Instance Attribute Summary collapse
-
#expand ⇒ Object
Expand related entities.
-
#select ⇒ Object
Select properties to be returned.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#expand ⇒ Object
Expand related entities
107 108 109 |
# File 'lib/teams/item/photo/photo_request_builder.rb', line 107 def @expand end |
#select ⇒ Object
Select properties to be returned
110 111 112 |
# File 'lib/teams/item/photo/photo_request_builder.rb', line 110 def select @select end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/teams/item/photo/photo_request_builder.rb', line 116 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "expand" return "%24expand" when "select" return "%24select" else return original_name end end |