Class: MicrosoftGraph::Teams::Item::PrimaryChannel::PrimaryChannelRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Teams::Item::PrimaryChannel::PrimaryChannelRequestBuilder
- Defined in:
- lib/teams/item/primary_channel/primary_channel_request_builder.rb
Overview
Provides operations to manage the primaryChannel property of the microsoft.graph.team entity.
Defined Under Namespace
Classes: PrimaryChannelRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#complete_migration ⇒ Object
Provides operations to call the completeMigration method.
-
#delete(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for teams.
-
#does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_name ⇒ Object
Provides operations to call the doesUserHaveAccess method.
-
#files_folder ⇒ Object
Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
-
#get(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new PrimaryChannelRequestBuilder and sets the default values.
-
#members ⇒ Object
Provides operations to manage the members property of the microsoft.graph.channel entity.
-
#messages ⇒ Object
Provides operations to manage the messages property of the microsoft.graph.channel entity.
-
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in teams.
-
#provision_email ⇒ Object
Provides operations to call the provisionEmail method.
-
#remove_email ⇒ Object
Provides operations to call the removeEmail method.
-
#shared_with_teams ⇒ Object
Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
-
#tabs ⇒ Object
Provides operations to manage the tabs property of the microsoft.graph.channel entity.
-
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for teams.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
-
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in teams.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new PrimaryChannelRequestBuilder and sets the default values.
77 78 79 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 77 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/teams/{team%2Did}/primaryChannel{?%24select,%24expand}") end |
Instance Method Details
#complete_migration ⇒ Object
Provides operations to call the completeMigration method.
28 29 30 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 28 def complete_migration() return MicrosoftGraph::Teams::Item::PrimaryChannel::CompleteMigration::CompleteMigrationRequestBuilder.new(@path_parameters, @request_adapter) end |
#delete(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for teams
85 86 87 88 89 90 91 92 93 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 85 def delete(request_configuration=nil) request_info = self.to_delete_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, nil, error_mapping) end |
#does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_name ⇒ Object
Provides operations to call the doesUserHaveAccess method.
33 34 35 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 33 def does_user_have_accessuser_id_user_id_tenant_id_tenant_id_user_principal_name_user_principal_name() return MicrosoftGraph::Teams::Item::PrimaryChannel::DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalName::DoesUserHaveAccessuserIdUserIdTenantIdTenantIdUserPrincipalNameUserPrincipalNameRequestBuilder.new(@path_parameters, @request_adapter) end |
#files_folder ⇒ Object
Provides operations to manage the filesFolder property of the microsoft.graph.channel entity.
38 39 40 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 38 def files_folder() return MicrosoftGraph::Teams::Item::PrimaryChannel::FilesFolder::FilesFolderRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
99 100 101 102 103 104 105 106 107 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 99 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Channel.create_from_discriminator_value(pn) }, error_mapping) end |
#members ⇒ Object
Provides operations to manage the members property of the microsoft.graph.channel entity.
43 44 45 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 43 def members() return MicrosoftGraph::Teams::Item::PrimaryChannel::Members::MembersRequestBuilder.new(@path_parameters, @request_adapter) end |
#messages ⇒ Object
Provides operations to manage the messages property of the microsoft.graph.channel entity.
48 49 50 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 48 def () return MicrosoftGraph::Teams::Item::PrimaryChannel::Messages::MessagesRequestBuilder.new(@path_parameters, @request_adapter) end |
#patch(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in teams
114 115 116 117 118 119 120 121 122 123 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 114 def patch(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_patch_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::Channel.create_from_discriminator_value(pn) }, error_mapping) end |
#provision_email ⇒ Object
Provides operations to call the provisionEmail method.
53 54 55 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 53 def provision_email() return MicrosoftGraph::Teams::Item::PrimaryChannel::ProvisionEmail::ProvisionEmailRequestBuilder.new(@path_parameters, @request_adapter) end |
#remove_email ⇒ Object
Provides operations to call the removeEmail method.
58 59 60 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 58 def remove_email() return MicrosoftGraph::Teams::Item::PrimaryChannel::RemoveEmail::RemoveEmailRequestBuilder.new(@path_parameters, @request_adapter) end |
#shared_with_teams ⇒ Object
Provides operations to manage the sharedWithTeams property of the microsoft.graph.channel entity.
63 64 65 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 63 def shared_with_teams() return MicrosoftGraph::Teams::Item::PrimaryChannel::SharedWithTeams::SharedWithTeamsRequestBuilder.new(@path_parameters, @request_adapter) end |
#tabs ⇒ Object
Provides operations to manage the tabs property of the microsoft.graph.channel entity.
68 69 70 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 68 def tabs() return MicrosoftGraph::Teams::Item::PrimaryChannel::Tabs::TabsRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_delete_request_information(request_configuration = nil) ⇒ Object
Delete navigation property primaryChannel for teams
129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 129 def to_delete_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :DELETE unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end return request_info end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Get the default channel, General, of a team.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 145 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |
#to_patch_request_information(body, request_configuration = nil) ⇒ Object
Update the navigation property primaryChannel in teams
164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/teams/item/primary_channel/primary_channel_request_builder.rb', line 164 def to_patch_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :PATCH request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, "application/json", body) return request_info end |