Class: MicrosoftGraph::Users::Item::Onenote::Pages::Item::CopyToSection::CopyToSectionPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Users::Item::Onenote::Pages::Item::CopyToSection::CopyToSectionPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#group_id ⇒ Object
Gets the groupId property value.
-
#group_id=(value) ⇒ Object
Sets the groupId property value.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new copyToSectionPostRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#site_collection_id ⇒ Object
Gets the siteCollectionId property value.
-
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value.
-
#site_id ⇒ Object
Gets the siteId property value.
-
#site_id=(value) ⇒ Object
Sets the siteId property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new copyToSectionPostRequestBody and sets the default values.
53 54 55 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 53 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
61 62 63 64 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 61 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CopyToSectionPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
38 39 40 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 38 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
46 47 48 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 46 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
69 70 71 72 73 74 75 76 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 69 def get_field_deserializers() return { "groupId" => lambda {|n| @group_id = n.get_string_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "siteCollectionId" => lambda {|n| @site_collection_id = n.get_string_value() }, "siteId" => lambda {|n| @site_id = n.get_string_value() }, } end |
#group_id ⇒ Object
Gets the groupId property value. The groupId property
81 82 83 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 81 def group_id return @group_id end |
#group_id=(value) ⇒ Object
Sets the groupId property value. The groupId property
89 90 91 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 89 def group_id=(value) @group_id = value end |
#id ⇒ Object
Gets the id property value. The id property
96 97 98 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 96 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
104 105 106 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 104 def id=(value) @id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
112 113 114 115 116 117 118 119 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 112 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("groupId", @group_id) writer.write_string_value("id", @id) writer.write_string_value("siteCollectionId", @site_collection_id) writer.write_string_value("siteId", @site_id) writer.write_additional_data(@additional_data) end |
#site_collection_id ⇒ Object
Gets the siteCollectionId property value. The siteCollectionId property
124 125 126 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 124 def site_collection_id return @site_collection_id end |
#site_collection_id=(value) ⇒ Object
Sets the siteCollectionId property value. The siteCollectionId property
132 133 134 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 132 def site_collection_id=(value) @site_collection_id = value end |
#site_id ⇒ Object
Gets the siteId property value. The siteId property
139 140 141 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 139 def site_id return @site_id end |
#site_id=(value) ⇒ Object
Sets the siteId property value. The siteId property
147 148 149 |
# File 'lib/users/item/onenote/pages/item/copy_to_section/copy_to_section_post_request_body.rb', line 147 def site_id=(value) @site_id = value end |