Class: MicrosoftGraph::Users::Item::OnlineMeetings::CreateOrGet::CreateOrGetPostRequestBody
- Inherits:
-
Object
- Object
- MicrosoftGraph::Users::Item::OnlineMeetings::CreateOrGet::CreateOrGetPostRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the additionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the additionalData property value.
-
#chat_info ⇒ Object
Gets the chatInfo property value.
-
#chat_info=(value) ⇒ Object
Sets the chatInfo property value.
-
#end_date_time ⇒ Object
Gets the endDateTime property value.
-
#end_date_time=(value) ⇒ Object
Sets the endDateTime property value.
-
#external_id ⇒ Object
Gets the externalId property value.
-
#external_id=(value) ⇒ Object
Sets the externalId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new createOrGetPostRequestBody and sets the default values.
-
#participants ⇒ Object
Gets the participants property value.
-
#participants=(value) ⇒ Object
Sets the participants property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#start_date_time ⇒ Object
Gets the startDateTime property value.
-
#start_date_time=(value) ⇒ Object
Sets the startDateTime property value.
-
#subject ⇒ Object
Gets the subject property value.
-
#subject=(value) ⇒ Object
Sets the subject property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new createOrGetPostRequestBody and sets the default values.
73 74 75 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 73 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
81 82 83 84 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 81 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CreateOrGetPostRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
43 44 45 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 43 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
51 52 53 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 51 def additional_data=(value) @additional_data = value end |
#chat_info ⇒ Object
Gets the chatInfo property value. The chatInfo property
58 59 60 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 58 def chat_info return @chat_info end |
#chat_info=(value) ⇒ Object
Sets the chatInfo property value. The chatInfo property
66 67 68 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 66 def chat_info=(value) @chat_info = value end |
#end_date_time ⇒ Object
Gets the endDateTime property value. The endDateTime property
89 90 91 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 89 def end_date_time return @end_date_time end |
#end_date_time=(value) ⇒ Object
Sets the endDateTime property value. The endDateTime property
97 98 99 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 97 def end_date_time=(value) @end_date_time = value end |
#external_id ⇒ Object
Gets the externalId property value. The externalId property
104 105 106 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 104 def external_id return @external_id end |
#external_id=(value) ⇒ Object
Sets the externalId property value. The externalId property
112 113 114 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 112 def external_id=(value) @external_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
119 120 121 122 123 124 125 126 127 128 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 119 def get_field_deserializers() return { "chatInfo" => lambda {|n| @chat_info = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::ChatInfo.create_from_discriminator_value(pn) }) }, "endDateTime" => lambda {|n| @end_date_time = n.get_date_time_value() }, "externalId" => lambda {|n| @external_id = n.get_string_value() }, "participants" => lambda {|n| @participants = n.get_object_value(lambda {|pn| MicrosoftGraph::Models::MeetingParticipants.create_from_discriminator_value(pn) }) }, "startDateTime" => lambda {|n| @start_date_time = n.get_date_time_value() }, "subject" => lambda {|n| @subject = n.get_string_value() }, } end |
#participants ⇒ Object
Gets the participants property value. The participants property
133 134 135 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 133 def participants return @participants end |
#participants=(value) ⇒ Object
Sets the participants property value. The participants property
141 142 143 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 141 def participants=(value) @participants = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 149 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("chatInfo", @chat_info) writer.write_date_time_value("endDateTime", @end_date_time) writer.write_string_value("externalId", @external_id) writer.write_object_value("participants", @participants) writer.write_date_time_value("startDateTime", @start_date_time) writer.write_string_value("subject", @subject) writer.write_additional_data(@additional_data) end |
#start_date_time ⇒ Object
Gets the startDateTime property value. The startDateTime property
163 164 165 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 163 def start_date_time return @start_date_time end |
#start_date_time=(value) ⇒ Object
Sets the startDateTime property value. The startDateTime property
171 172 173 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 171 def start_date_time=(value) @start_date_time = value end |
#subject ⇒ Object
Gets the subject property value. The subject property
178 179 180 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 178 def subject return @subject end |
#subject=(value) ⇒ Object
Sets the subject property value. The subject property
186 187 188 |
# File 'lib/users/item/online_meetings/create_or_get/create_or_get_post_request_body.rb', line 186 def subject=(value) @subject = value end |