Class: MicrosoftGraph::Users::Item::People::PeopleRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- MicrosoftGraph::Users::Item::People::PeopleRequestBuilder
- Defined in:
- lib/users/item/people/people_request_builder.rb
Overview
Provides operations to manage the people property of the microsoft.graph.user entity.
Defined Under Namespace
Classes: PeopleRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#by_person_id(person_id) ⇒ Object
Provides operations to manage the people property of the microsoft.graph.user entity.
-
#count ⇒ Object
Provides operations to count the resources in the collection.
-
#get(request_configuration = nil) ⇒ Object
Retrieve a collection of person objects ordered by their relevance to the user, which is determined by the user's communication and collaboration patterns, and business relationships.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new PeopleRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a collection of person objects ordered by their relevance to the user, which is determined by the user's communication and collaboration patterns, and business relationships.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new PeopleRequestBuilder and sets the default values.
41 42 43 |
# File 'lib/users/item/people/people_request_builder.rb', line 41 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/users/{user%2Did}/people{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select}") end |
Instance Method Details
#by_person_id(person_id) ⇒ Object
Provides operations to manage the people property of the microsoft.graph.user entity.
29 30 31 32 33 34 |
# File 'lib/users/item/people/people_request_builder.rb', line 29 def by_person_id(person_id) raise StandardError, 'person_id cannot be null' if person_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["person%2Did"] = person_id return MicrosoftGraph::Users::Item::People::Item::PersonItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#count ⇒ Object
Provides operations to count the resources in the collection.
21 22 23 |
# File 'lib/users/item/people/people_request_builder.rb', line 21 def count() return MicrosoftGraph::Users::Item::People::Count::CountRequestBuilder.new(@path_parameters, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Retrieve a collection of person objects ordered by their relevance to the user, which is determined by the user's communication and collaboration patterns, and business relationships. You can get this information via the People API. For examples, see the Examples section and the article Use the People API to get information about the people most relevant to you.
49 50 51 52 53 54 55 56 57 |
# File 'lib/users/item/people/people_request_builder.rb', line 49 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["4XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } error_mapping["5XX"] = lambda {|pn| MicrosoftGraph::Models::ODataErrorsODataError.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| MicrosoftGraph::Models::PersonCollectionResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Retrieve a collection of person objects ordered by their relevance to the user, which is determined by the user's communication and collaboration patterns, and business relationships. You can get this information via the People API. For examples, see the Examples section and the article Use the People API to get information about the people most relevant to you.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/users/item/people/people_request_builder.rb', line 63 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.add('Accept', 'application/json') unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end return request_info end |